//This file is licensed under the terms of the CC-LGPL
//                               
// You need to specify UTF8 character encoding and include the rounded L-Prism macros from Sam T Benge available from 
// POVRay Object Library and the standard colours, either by uncommenting the next lines, or putting the lines below 
// in your main file.
/*
#global_settings {charset utf8 assumed_gamma 1.0}
//
#include "colors.inc"
#include "rlp.inc"
*/
//*****INTRODUCTION*******************
// There are three components to the utility of these #macros:
//
// 1) A collection of 3D chamfered/rounded characters, comprising a roman font, a math italic font, a greek font and 
//    a number of mathematical symbols;
//
// 2) A #macro (CL_rlp_make_text_string) that takes a standard text string, using keyboard characters, and typesets
//    the characters into an object, with spacing and limited super- and subscript capability. Single character 
//    subscripts and superscripts are available using the ^ and _ characters. More complex super and sub-scripts can 
//    be made using the letter_adjust facility. See below.
//
//    Simple (though clunky) scaled bold and sheared italic versions of the fonts can be chosen, but may not work well 
//    with super- and sub-scripts or other mathematical ideas.
// 
//    Selection between the roman and math fonts is done with the # character as the toggle. Selecting a single alternate 
//    character is done with the | character. Most math characters and symbols have an alternate (with the alternates 
//    of the letters being the greek letters). Some roman characters have alternates since I ran out of math characters.
//    The corner character () makes the next character bold in Roman or underlined in maths (i.e. a vector)
//    
//    Various adjustments of each letter are possible using the array CL_adjust_letter or a copy. This is quite powerful.
//    See CL_letter_test.pov, but it is done in a very clunky way. Such adjustments also allow for multiple character 
//    superscripts and subscripts, amongst other things;
//
// 3) A collection of #macros that (usually) take one or more text strings or one or more objects, as produced by 
//    CL_rlp_make_test_string or other routines, and typesets them into various mathematical constructs such as 
//    fractions, sums, products, integrals, arrays, equations and so on. 
//
//    The file CL_rlp_template_test.pov gives examples of the calls of these #macros 
// 
//    Search for DDDD Met Bat to go to this collection of #macros at the end of the file.
// 
//*****LETTER PRODUCTION MACRO CALLS********************
//
// Each character/symbol has a #macro. Arguments for all the character/symbol #marcos are:
//
// z1    = back z-value
// z2    = front z-value
// d_rad = a default corner radius. Can be zero to allow for sharp corners. Will be limited below 0.05
// offs  = the chamfer size/round radius. 0 gives square edges (why?), 0.02-0.04 is good, will be limited to 0.05
// cham  = 0 rounded
//       = 1 chamfered. Set offs to 0 for square edges
//
// Lower left hand corner of a letter is usually at (0,0). Math f and p are allowed to go a little negative in x; 
// Letter height is usually either 1.4 or 2.0, with a few in between;
// Letter width is proportional;    
// Letter width, Letter height, Superscript height (e.g. 2.0 for capitals, 1.4 for most lowercase) and Drop below line 
//               (a +ve number) return in 
// letter_dimensions = array[4];
//
// You will need to deal with any kerning using letter_adjust in your call to CL_rlp_make_text_string, 
// or by inserting negative space between letters (|, = -0.5, |! = -0.2). 
//
//*****CHARACTERS***************** 
//
// It is essential to specify #global_settings {charset utf8} as given above. If ASCII is used, you will get copious 
// parse error warnings that a non-ASCII character has been found, but worse, there is some confusion between the 
// pound character and the space character which ends up with spaces appearing as pound signs. There are other 
// confused characters if you don't use {charset utf8}.
//
// All the standard keyboard characters are standardly available out of CL_rlp_make_text_string with the exception of:
//
// 1) The double quote (") since it is used to delimit strings in the POV-Ray editor and two consequtive single quotes 
//    (left or right) work just as well as one double quote character; 
// 2) The backslash is only available as an alternate character of the % (|%) since putting a \ in a POV-Ray string 
//    is used as an escape sequence;
// 3) The | (vertical line) is used to denote an alternate character. It is available as || in Roman;  
// 4) The ^ (caret) denotes the next character is a superscript. It is available as |^ in Roman;
// 5) The _ (underscore) character denotes the next character is a subscript. It is available as |_ in Roman 
// 6) The # (hash) character toggles between math fonts and normal fonts. It is available as |# in Roman. 
// 7) The  (corner) character denotes the next character is vectorised. Underlined in math mode, emboldened in Roman.
//    Available as | in Roman.
// 
// If a character with no allowed for usage appears in the string, an asterisk will be substituted. We do cover all 
// characters available from an English keyboard, but other character codes can get into a string.
//
// The maths fonts are math italic. 
//
// The alternate math font characters are greek characters. Many capital greek characters correspond to capital 
// roman characters, but they are also available as the alternate capital math character. Thus #|A will look like a 
// Roman capital A. The normal (roman) fonts do not currently have that many alternate characters defined. If further 
// alternate characters are required, the rest of the Roman characters are free to be used.  
//
//*****ROMAN AND MATHEMATICAL CHARACTERS***** 
//
// The # symbol toggles whether roman or mathematical italic letters are to be used. We start off in Roman.
// That is to say, # toggles between upright roman and mathematical italic.
//
//*****ALTERNATE CHARACTERS******************
//
// There are a several alternate characters curently identified in standard (roman) mode. They are listed below.
// Some of these are intended to be used in mathematical expressions. You would need to toggle out of maths, use the 
// alternate Roman character, then toggle back into maths, e.g #|n# gets you a bold n vector if you are in 
// maths mode. 
//
// LIST OF ALTERNATE STANDARD ROMAN CHARACTERS (Put a | as the preceding letter)
// Letter                                  | alternate 
//   L                                script L (Laplace transform operator) 
//
//   A                                blackboard bold A (Algebraic numbers)
//   C                                blackboard bold C (Complex numbers)
//   N                                blackboard bold N (Naturals)
//   Q                                blackboard bold Q (Rationals)
//   R                                blackboard bold R (Reals)
//   Z                                blackboard bold Z (Integers)
//
//   S                                spadesuit symbol
//   T                                heartsuit symbol
//   U                                diamondsuit symbol
//   V                                clubsuit symbol
//
//   d                                a math style non italic d used, by some people including me, for infinitesimals.
//   h                                left right harpoons
//
//   n                                underlined, hatted unit vector n
//   p                                underlined, hatted unit vector phi
//   r                                underlined, hatted unit vector r
//   t                                underlined, hatted unit vector theta
//   
//   8                                infinity
//   0                                zero slash
//                                   euro
//   $                                yen
//   %                                backslash
//   ` (left inverted comma)          degrees
//   ' (right inverted comma)         prime    
//   ?                                upside down question mark
//
//   |                                vertical
//   ^                                caret
//   _                                underscore
//   #                                hash
//                                   corner
//
// STANDARD MATHS CHARACTERS
// Not all keyboard characters give the expected result in standard math mode. Below are the exceptions.
//                                   one quarter character (-0.45 to 2.25)
//   $                                one half character
//   &                                three quarters character
//   ?                                general fraction character, e.g 7/8. Specifying the global variables 
//                                    CL_frac_numerator and CL_frac_denominator as single character integers (not zero) 
//                                    specifies the numerals for the fraction. If you need more than one general fraction 
//                                    in a string you will need to construct objects.
//
// ALTERNATE MATHS CHARATERS
//
// Most alternate small maths letters give the greek small letter. Some exceptions: j and v. Capital alternate 
// letters give the greek capital letter, no J or V. Some greek capitals are standard upright Roman, others are bespoke 
// upright greek. In math mode, the alternate capital J is Aleph, alternate small j is the partial character, alternate 
// capital V is for all, alternate small v is there exists.
//
// Numerals and symbols give rise to interestiong alternate characters in a more or less random manner. See below.
//
// LIST OF ALTERNATE MATHS CHARACTERS (Put a | as the preceding letter when in math mode)
// Letter     | alternate           Letter      | alternate
//   A    greek capital Alpha (A)     a    greek small alpha
//   B    greek capital Beta (B)      b    greek small beta
//   C    greek capital Chi (X)       c    greek small chi
//   D    greek capital Delta         d    greek small delta
//   E    greek capital Epsilon (E)   e    greek small epsilon
//   F    greek capital Phi           f    greek small phi
//   G    greek capital Gamma         g    greek small gamma
//   H    greek capital Eta (H)       h    greek small eta
//   I    greek capital Iota (I)      i    greek small iota                     
//   J    hebrew Aleph                j    maths curly d (partial)
//   K    greek capital Kappa (K)     k    greek small kappa
//   L    greek capital Lambda        l    greek small lambda
//   M    greek capital Mu (M)        m    greek small mu
//   N    greek capital Nu (N)        n    greek small nu
//   o    greek capital Omicron (O)   o    greek omicron, mathematical o
//   P    greek capital Pi            p    greek small pi
//   Q    greek capital Theta         q    greek small theta
//   R    greek capital RHO (P)       r    greek small rho
//   S    greek capital Sigma         s    greek small sigma
//   T    greek capital Tau (T)       t    greek small tau
//   U    greek capital Upsilon       u    greek small upsilon, mathematical v (very similar in LaTeX)
//   V    maths For All               v    maths There Exists     
//   W    greek capital Omega         w    greek small omega
//   X    greek capital Xi            x    greek small xi
//   Y    greek capital Psi           y    greek small psi
//   Z    greek capital Zeta (Z)      z    greek small zeta
// 
//   0    zero slash
//   1    unit vector i
//   2    unit vector j
//   3    unit vector k
//   4    right arrow
//   5    mapsto
//   6    implies
//   7    not equal to
//   8    infinity sign
//   9    nabla (grad to you, but LaTeX calls it nabla)
//
//   |    |
//   ^    oint small         Normal character is used as special to denote an alternate character.
//   _    oint large         Normal character is used as special to denote a superscript.
//   #    double oint small  Normal character is used as special to denote a subscript. 
//       double oint large  Normal character is used as special to produce a vector character.
//
//   !    0.2 negative space. Similar to LaTeX. You might use it instead of phaffing with the letter adjust array. See |,
//   ?    Right harpoon. The standard character is a left harpoon.   
//       O plus. Standard character is the one quarter character.
//   $    O times. Standard character is the one half character.
//   %    \ (backslash - the normal backslash character is used as an escape sequence by POV-Ray)
//   &    square root symbol. If you insist. Could use the square root #macro. Standard math & character is three quarters.  
//   *    times sign
//   (    cup (union)
//   )    cap (intersection)
//   [    integral sign
//   ]    big integral sign
//   {    langle
//   }    rangle
//   -    minus/plus
//   +    plus/minus
//   =    equivalence sign
//   /    divides sign
//   ;    approximately equals
//   :    alternative approximately equals 
//   '    normal is mathematical prime, alternate is superscript dagger
//   `    normal is superscript degrees (small circle), alternate is subscript scaled small circle, as in aleph null.
//   ,    0.5 negative space. See |! and space to see how to move things about in 0.1 steps.
//   .    normal is dot product (centred on 0.9), alternate is bullet (centred on 0.9)
//   @    proportional to. Standard character is a general fraction, with the single digits specified by
//        CL_frac_numerator and CL_frac_denominator. 
//   ~    implies and is implied by
//   <    less than or equals 
//   >    greater than or equals
//
// space  A normal space is 0.4, i.e. not much space. The alternate space is 1.0
//
//*****Multiple size characters
//
// Greek Sigma and Pi (capitals) are available as CL_rlp_Sigma and CL_rlp_Pi going from y=0 to y=2.
// They are also available as bigSigma/Pi (-0.5 to 2.5) and BigSigma/Pi (-1 to 3). These are accessed using the 
// CL_rlp_make_sumprod #macro as inline or displaystyle sums and products. 
// 
// Integral (-0.3 to 2.1) and bigIntegral (-1.1 to 2.9) are accessible as math alternates to [ and ]. These two as well as 
// BigIntegral (-1.8 to 3.4) and ReallyBigIntegral (-2.5 to 4.3) are accessed using the CL_rlp_make_Integral #macro.
//
// Circled, double and triple integrals are available using CL_make_linesurfacevolume_integrals and CL_make_multiple_integrals. 
// A circled Integral (-0.3 to 2.1) and a circled bigIntegral (-1.1 to 2.9) are available as alternate ^ and _, with the two 
// sizes of circled double integrals available as alternate # and . The two sizes of uncircled double and triple integrals 
// are available using more than one single integral signs and some negative space.
//
//*****Complicated super and subscript structures
//
// Single character super- and sub-scripts are easily available just in the CL_rlp_make_text_string #macro using the ^ and _ 
// special characters. Superscripts are based on the superscript height of the character, returned in letter_dimensions. 
// Subscripts are always sub the y=0 line.
//
// If a character has both a super- and a sub-script, the superscript should come first, then perhaps several 
// negative space characters to taste, then the subscript.
//
// Multi-character subscripts are easy because they are all based on y=0, so just keep using the _ character, e.g. C_2_x works fine. 
//
// Multi-character superscripts can be more complicated because they are based on the height of the 'previous' character. Superscript 
// heights for characters are usually 2.0 for a capital or numeral, 1.4 for a small letter and variable for symbols. The minus has 
// been given a superscript height of 1.4, so "#x^-^2" works OK. "#A^-^2" wouldn't work, since the superscript height for A is 2.0, 
// that for - is 1.4 so the 2 would appear lower than the minus.
//
// Rather than fixing the problem properly, the different spaces have been given phantom superscript heights. 
// Thus a -ve space (|, = -0.5, |! = -0.2) and a standard space (= +0.4) have heights of 2.0 while the alternate space (|  = 1.0) 
// has been given height 1.4. SO, though "#A^-^2" doesn't work, A^-|!|! ^2 does. You may need more negative space than you think because 
// spaces are treated like any other character and have the inter-character space allocated between them.
//
// Giving spaces a phantom superscript height is also necessary to generate certain symbols, like  ^nC_r (with a leading space) and  ^2^3^8U_9_2.
//
// Not all super- and sub- script objects can be generated using a simple text string. Multiple character super- or subscripts may require use 
// of the CL_letter_adjust facility. See the CL_rlp_letter_test.pov example file where the string "#e^-^x^2" has adjustment to produce a useable object. 
// This would be the only way to get three level superscript object: x^x^x^x for example.
//
// The CL_make_supersubscript #macro will attach super- and sub-scripts generated using strings to a previously generated object, but 
// you have then lost the convenience of generating relatively complex expressions from a single string.
// 
//*****Vectors
//
// Single vectorised symbols are available using the corner character (). In math mode this puts a line under the 
// math italic character (my favourite). In Roman mode, the character is enboldened by 1 1.3 scaling in the x-direction. 
// This isn't that satisfactory in my opinion, but the alternative is a complete mathbold font, which I haven't produced.
//
// Marking single characters or multi-character expressions as vectors can be done in several ways using CL_make_embellish (see below)
// but that creates an object that will need to be concatenated etc.. The  special character is just a quick, if limited,
// way of including vectors into strings.  
// 
//*****Embellished Objects
//
// Objects can be over- and/or under-embellished in several ways. Type set text strings 
// in super- or sub-script size can appear over and/or under the embellished object.
// 
// Over embellishment:
//  0) No embellishment;
//  1) Over lined;
//  2) Over tilded;
//  3) Over vectored;
//  4) Over caretted;
//  5) Over curly braced;
//  6) Over acute accent;
//  7) Over grave accent;
//  8) Over small circle;
//  9) Over single dot;
// 10) Over double dot;
// 11) Square/Rounded corner box around the object;
//
// Under embellishment:
//  0) No under embellishment
//  1) Under lined              based on y = 0;
//  2) Under lined              based on the drop below of the object;
//  3) Under tilded             based on y = 0;
//  4) Under tilded             based on the drop below of the object;  
//  5) Under vectored           based on y = 0;
//  6) Under vectored           based on the drop below of the object;
//  7) Under right harpooned    based on y = 0;  
//  8) Under right harpooned    based on the drop below of the object;
//  9) Under curly braced       based on the drop below of the object; 
// 10) Under cedilla            based on y = 0;
// 11) Square/Rounded corner box around the object;
//
// Over embellishment is done before under embellishment.
//
// Since both over- and under-embellishment can be with a box, and a final box is available, a triple boxed object is 
// available. No idea why you would want two boxes, let alone three.
//
// You can also have centred under- and over- text strings that go under or over 
// the embellishment, if there is one, or the main string.
//
// By default, many embellishments will be stretched horizontally to cover the whole width of the object
// and all embellishments will be placed in a (hopefully) sensible default position. You can use
// 
// #local embellish_adjust = array[4][4]{{add_dist_x, add_scale_y, shift_x, shift_y}, // Over  text
//                                       {add_dist_x, add_scale_y, shift_x, shift_y}, // Over  embellishment
//                                       {add_dist_x, add_scale_y, shift_x, shift_y}, // Under embellishment
//                                       {add_dist_x, add_scale_y, shift_x, shift_y}, // Under text
//
// The contents of embellish_adjust can be initially left at all zeros. If adjustment is required, 
// they are used as follows;    
//
// add_dist_x  add or subtract a distance to the x-width of the embellishemnt. This dictates a scale factor. 
// add_scale_y add or subtract an amount to the scale factor in the y-direction. Thus 1 doubles the size 
//             and -0.4 results in a 0.6 scale factor.
// shift_x     add or subtract a shift in the x direction. shift_x = add_dist_x/2 will keep a scaled 
//             embellishment centered over the object.
// shift_y     move the embellishment up or down from its default position.
// 
//
// Over embellishing an i or a j conventionally removes the dot. The unit vectors are available as |1, |2 and |3  
// in math mode, but if you want other over-embellishments, the no-dot characters are available as CL_rlp_imath and 
// CL_rlp_jmath character calls. 
//
// All this is achieved using the #macro CL_rlp_make_embellish(...). Which is a slight problem, since putting an 
// embellishment on a single character in a long string that could otherwise be made with a single call to 
// CL_rlp_maketext_string(...) will now require several calls to make #macros. Oh well. The flexibility of the 
// embellishments available (and ease of extending the range) is going to have to be sufficient excuse for this kludge.  
//
// If only a single charater in a complex string needs embellishng, you may prefer to send the whole string to the 
// #macro and adjust the position of the embellishment. See the examples in CL_rlp_embellish_test.pov.
//
//*****Elastic structures
//
// Delimiters such as (, [, {, |, langle and the right hand variants are available as characters, but also as fully 
// elastic structures using the CL_rlp_make_elactic_bracket_pair #macro, which puts the elastic delimiter structures
// around an object. Possibly different left and right delimiters, including the nul delimiter. The elastic delimiters 
// are used in some other make #macros.
//
// A fully elastic square root structure is available using the CL_rlp_elastic_surd #macro. 
//
//*****List of #macros to use the characters   
//
// This section just gives a list of the routines. Use CL_template_test.pov as a copy and paste template.
//
//#macro CL_rlp_make_text_string_set(set_type) Set some global variables.
//                                             set_type = 1: Chamfered edge, sharp corners; 2: Chamfered edge, round corners; 
//                                                        3: Rounded edge, sharp corners;   4: Rounded edge, round corners, my favourite.  
//#macro CL_rlp_make_text_string(...)  
//#macro CL_rlp_make_fraction(...)
//#macro CL_rlp_make_text_fraction(...) 
//#macro CL_rlp_make_text_function_fraction(...)
//#macro CL_rlp_make_elastic_bracket_pair(...)
//#macro CL_rlp_make_sumprod(...)
//#macro CL_rlp_make_supersubscript(...)
//#macro CL_rlp_make_integral(...) 
//#macro CL_rlp_make_multiple_integrals(...)
//#macro CL_rlp_make_linesurfacevolume_integral(...)
//#macro CL_rlp_make_array(...)
//#macro CL_rlp_make_elastic_surd(...) 
//#macro CL_rlp_make_stack(...)
//#macro CL_rlp_make_equation(...)
//#macro CL_rlp_make_concatenate(...) 
//#macro CL_rlp_make_embellish(...) 
//
//*************************************************************************************************
// Search for TYPESETTING MACROS to get to CL_rlp_make_text_string*********************************
// Search for DDDD Met Bat to get to the other typesetting macros**********************************
// Use CL_rlp_template_test.pov for examples of the #macro calls***********************************
//*************************************************************************************************
// SET-UP MACRO (ALWAYS call this #macro. set_type is 1-4)***************************************** 
//*************************************************************************************************
#macro CL_rlp_make_text_string_set(set_type)
//
//*****HAND CRAFTED LETTER ADJUSTMENT**************************************************************
//
// A real kludge, and quite hard to use but, with effort, you can probably make the adjustment you want.
// The ith entry refers to the ith character, including #, |, ^, _,  in the count.
// Needs to be at least as many entries in the array as in the string sent to CL_rlp_make_text_string.     
//
// letter_adjust is kern    Letter widths are variable, from 0.25 (comma) to 2.4 (W). -ve moves left. 
//                  raise   Letter heights variable, small from 1.4 to 2.0, large all 2.0. -ve drops. raise translates up and down
//                  shear   1.0 is 45 degrees to the right, so 0.2-0.4 is more reasonable. Sheared italic is 0.3, 
//                          Negative goes left.
//                  scale   Default 1.0. Super- and sub-scripts are normally 0.6 to give you a clue.  
//                  rotate  Leave at zero, unless you really want to. You will probably have to mess with several 
//                          of the others to fix any problems. Rotated letters may go outside the assumed letter bounds, and this 
//                          won't be allowed for in the overall bounding box.
//
//********************************************|*******************|*******************|*******************|*******************|*******************|*******************|*******************|*******************|*******************|*******************|*
// I'm not expecting text strings longer than 100 characters. If you are, increase the length of this array.
#declare CL_letter_adjust    = array[5][100]{{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
                                             {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
                                             {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
                                             {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
                                             {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}};
//******************************************************************************************************************************************************************************************************************************************************
//                                             
#declare CL_z1               = -0.25;                  // z2 - z1 should be bigger than 2*CL_offs. 
#declare CL_z2               =  0.25;
#declare CL_d_rad            =  0.0;                   // 0.0 or 0.05. Default corner radius. Smaller values round off inner,  
//                                                        but not outer corners (don't know why, its an rlp.inc thing)
#declare CL_offs             =  0.04;                  // Clipped from above back to 0.04. Down to 0.02 is still nice.
#declare CL_cham             =  1;                     // 0 for rounded, 1 for chamfered
#declare CL_font_type        =  0;                     // 0 for normal,  1 for a sheared italic, 2 for a stretched bold, 
//                                                                       3 for bold italic.
//                                                                       If you use anything but 0, maths text may may break horribly.
#declare CL_dimensions_out   = array[4]{0,0,0,0};      // Returns from CL_rlp_make_text_string as the width (length?), 
//                                                        height above the line, a superscript height and drop below the line 
//                                                        of the typeset string.
#declare CL_tiny_space       =  0.1;                   // Default space between letters. 0.05 to 0.2 looks OK
#declare CL_small_space      =  0.2;                   // Space around e.g. brackets. 
#declare CL_medium_space     =  0.4;                   // Separation in mathematical expressions. Small letters are 1.4 high.
#declare CL_large_space      =  0.8;                   // Larger space, for separating elements in an array, perhaps.
#declare CL_huge_space       =  1.4;                   // Even larger space. Some letters are this wide. 
//
#declare CL_embellish_adjust = array[5][4]{{0,0,0,0},  // Over  text.          add_to_scale_x, add_to_scale_y, shift_x, shift_y
                                           {0,0,0,0},  // Over  embellishment. add_dist_x, scale_y, shift_x, shift_y
                                           {0,0,0,0},  // Under embellishment. add_dist_x, scale_y, shift_x, shift_y
                                           {0,0,0,0},  // Under text.          add_to_scale_x, add_to_scale_y, shift_x, shift_y
                                           {0,0,0,0}}; // Outer box.           add_to_thick, add_to_gap, out_rad, inn_rad
//
#declare CL_oint             =  1;                     // = 0 sets the integral characters to be circled. 1 otherwise
#declare CL_debug_lines      =  0;                     // = 1 sets debug lines and messages to on. Off otherwise.  
#declare CL_frac_numerator   =  1;                     // A kludge to produce a character fraction from the math mode @ character.
#declare CL_frac_denominator =  2;                     // With these set to, say, 7 and 8 you get 7/8 instead of @ in math mode.
//
#if(set_type=2) 
  #declare CL_d_rad          =  0.05;                  // 0.0 or 0.05. Default corner radius. Smaller values round off inner, 
//                                                        but not outer corners (don't know why)
#end
#if(set_type=3) 
  #declare CL_cham           =  0;                     // 0 for rounded, 1 for chamfered
#end
//
#if(set_type=4) 
  #declare CL_cham           =  0;                     // 0 for rounded, 1 for chamfered
  #declare CL_d_rad          =  0.05;                  // 0.0 or 0.05. Default corner radius. Smaller values round off inner, 
//                                                        but not outer corners (don't know why)
#end
//
#end  
//*************************************************************************************************
// Search for DDDD Met Bat to get to CL_rlp_make_text_string***************************************
//*************************************************************************************************
// ROMAN CAPITAL LETTERS **************************************************************************
//*************************************************************************************************
// A
//*************************************************************************************************
#macro CL_rlp_A(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                         
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.100,0.000>
 <0.200,0.100,0.100>,
 <0.850,2.000,0.000>,

 <0.950,2.000,0.000>,
 <1.600,0.100,0.100>,
 <1.800,0.100,0.000>,

 <1.800,0.000,0.000>,
 <1.050,0.000,0.000>,
 <1.050,0.100,0.000>,

 <1.250,0.100,0.100>,
 <0.980,0.900,0.000>,
 <0.585,0.900,0.000>,

 <0.310,0.100,0.100>,
 <0.500,0.100,0.000>,
 <0.500,0.000,0.000>,

 <0.000,0.000,0.000> 
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[3]{
 <0.620,1.000,0.000>,
 <0.945,1.000,0.000>,
 <0.785,1.480,0.000>
}

// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Blackboard Bold A
//*************************************************************************************************
#macro CL_rlp_bb_A(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                         
#local letter_dimensions[0] = 2.2; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[4];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.000>, 
 <0.000,0.150,0.000>,
 <0.200,0.150,0.100>,     // 0.1
 <1.025,2.000,0.000>,

 <1.175,2.000,0.000>,
 <2.000,0.150,0.100>,     // 0.1
 <2.200,0.150,0.000>,

 <2.200,0.000,0.000>,
 <1.200,0.000,0.000>,
 <1.200,0.150,0.000>,

 <1.400,0.150,0.100>,    // 0.1
 <1.150,0.700,0.000>,
 <0.595,0.700,0.000>,

 <0.360,0.150,0.600>,    // 0.5
 <0.900,0.150,0.000>,
 <0.900,0.000,0.000>,

}
// container, 2nd subset: top hole
#local pts[1] =
array[3]{
 <0.670,0.850,0.000>,
 <1.100,0.850,0.000>,
 <0.880,1.340,0.000>
}
// container, 3nd subset: right hole
#local pts[2] =
array[4]{
 <1.830,0.150,0.000>,
 <1.100,1.800,0.000>,
 <0.970,1.500,0.000>,
 <1.570,0.150,0.000>
}
// container, 4th subset: left hole
#local pts[3] =
array[4]{
 <0.540,0.150,0.000>,
 <0.440,0.210,0.200>,
 <0.425,0.320,0.000>,
 <0.350,0.150,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// B
//*************************************************************************************************
#macro CL_rlp_B(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.5; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.400,2.000,1.1/2>,

 <1.400,0.900,1.1/2>,
 <0.550,0.900,0.000>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>,
 <0.000,0.000,0.000>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.550,1.000,0.000>,
 <1.050,1.000,0.775/2>,
 <1.050,1.900,0.775/2>,
 <0.550,1.900,0.100>
}
#local pts1 = array[1];
#local pts1[0] =
array[8]{
 <0.550,0.100,0.000>,
 <1.150,0.100,0.400>,
 <1.150,0.900,0.400>,

 <0.550,0.900,0.000>,
 <0.550,1.000,0.000>,
 <1.500,1.000,0.600>,

 <1.500,0.000,0.600>,
 <0.550,0.000,0.000>
}
// invoking the object macro
union{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end
//*************************************************************************************************
// C
//*************************************************************************************************
#macro CL_rlp_C(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                   
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,1.000>,    // 1.0 End
 <0.000,2.000,1.000>,    // 1.0 External curve - base
 <1.300,2.000,0.300>,    // External curve - left side

 <1.700,1.800,0.100>,    // Upper serif
 <1.700,2.000,0.000>,    // Upper serif
 <1.800,2.000,0.000>,    // Upper serif

 <1.800,1.475,0.000>,    // Upper serif
 <1.700,1.475,0.000>,    // Upper serif
 <1.700,1.675,0.200>,    // Upper serif

 <1.300,1.900,0.400>,
 <0.350,1.800,0.800>,    // 0.9 Internal curve - left
 <0.350,0.200,0.800>,    // 0.9 Internal curve - bottom

 <1.400,0.100,0.400>,
 <1.730,0.450,0.000>,
 <1.800,0.400,0.000>,

 <1.500,0.000,0.500>,     // End
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Blackboard Bold C
//*************************************************************************************************
#macro CL_rlp_bb_C(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                   
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,0.000,1.000>,    // Origin  1.0
 <0.000,2.000,1.000>,    // 1.0
 <1.300,2.000,0.300>,    // 

 <1.650,1.800,0.100>,    // Upper serif
 <1.650,2.000,0.000>,    // Upper serif
 <1.800,2.000,0.000>,    // Upper serif

 <1.800,1.325,0.000>,    // Upper serif
 <1.650,1.325,0.000>,    // Upper serif
 <1.200,1.850,0.200>,    // 

 <0.700,1.800,0.400>,    // 
 <0.700,0.200,0.400>,    // 
 <1.300,0.150,0.300>,

 <1.730,0.480,0.000>,     // 
 <1.800,0.400,0.000>,
 <1.400,0.000,0.400>
}
// container, 2nd subset: left hole 
#local pts[1] =
array[6]{
 <0.150,1.500,1.000>,
 <0.150,0.500,1.000>,
 <0.650,0.230,0.000>,
 
 <0.550,0.430,0.200>,
 <0.550,1.570,0.200>,
 <0.650,1.770,0.000>
}
// container, 2nd subset: left hole 
//#local pts[1] =
//array[4]{
// <0.150,1.500,1.000>,
// <0.150,0.500,1.000>,
// <0.550,0.270,0.000>,
 
// <0.550,1.730,0.000>
//}
// container, 3rd subset: serif hole 
#local pts[2] =
array[4]{
 <1.650,1.530,0.000>,
 <1.650,1.700,0.000>,
 <1.600,1.650,0.100>,
 
 <1.500,1.700,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
//D
//*************************************************************************************************
#macro CL_rlp_D(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.800,2.000,1.000>,

 <1.800,0.000,1.000>,
 <0.000,0.000,0.000>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.550,0.100,0.100>,
 <1.450,0.100,0.900>,
 <1.450,1.900,0.900>,
 <0.550,1.900,0.100>
}

// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// E
//*************************************************************************************************
#macro CL_rlp_E(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.500,2.000,0.000>,

 <1.600,1.700,0.000>,
 <1.500,1.660,0.000>,
 <1.410,1.900,0.100>,

 <0.550,1.900,0.100>,
 <0.550,1.000,0.000>,
 <1.000,1.000,0.100>,

 <1.000,1.200,0.000>,
 <1.100,1.200,0.000>,
 <1.100,0.700,0.000>,

 <1.000,0.700,0.000>,
 <1.000,0.900,0.100>,
 <0.550,0.900,0.000>,

 <0.550,0.100,0.100>,
 <1.350,0.100,0.100>,
 <1.600,0.450,0.000>,

 <1.700,0.400,0.000>,
 <1.500,0.000,0.000>,
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// F
//*************************************************************************************************
#macro CL_rlp_F(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[22]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.500,2.000,0.000>,

 <1.600,1.700,0.000>,
 <1.500,1.660,0.000>,
 <1.410,1.900,0.100>,

 <0.550,1.900,0.100>,
 <0.550,1.000,0.000>,
 <1.000,1.000,0.100>,

 <1.000,1.200,0.000>,
 <1.100,1.200,0.000>,
 <1.100,0.700,0.000>,

 <1.000,0.700,0.000>,
 <1.000,0.900,0.100>,
 <0.550,0.900,0.000>,

 <0.550,0.100,0.100>,
 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>,

 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// G
//*************************************************************************************************
#macro CL_rlp_G(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{  

 <1.800,0.300,0.000>,    // Base of vertical - outer
 <1.100,-.550,1.100>,    // External curve - base
 <-.420,1.000,1.000>,    // External curve - left side

 <0.800,2.200,0.800>,    // External curve - top
 <1.700,1.800,0.100>,    // Upper serif
 <1.700,2.000,0.000>,    // Upper serif

 <1.800,2.000,0.000>,    // Upper serif
 <1.800,1.475,0.000>,    // Upper serif
 <1.700,1.475,0.000>,    // Upper serif

 <1.700,1.675,0.250>,    // Upper serif
 <0.800,2.000,0.800>,    // Internal curve - upper
 <0.150,1.000,0.800>,    // Internal curve - left

 <0.900,-.150,0.800>,    // Internal curve - bottom
 <1.450,0.300,0.000>,    // Base of vertical - inner
 <1.450,0.900,0.100>,
 
 <1.250,0.900,0.000>,
 <1.250,1.000,0.000>,
 <2.000,1.000,0.000>,

 <2.000,0.900,0.000>,
 <1.800,0.900,0.100>,
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// H
//*************************************************************************************************
#macro CL_rlp_H(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <0.750,2.000,0.000>,

 <0.750,1.900,0.000>,
 <0.550,1.900,0.100>,
 <0.550,1.000,0.000>,

 <1.250,1.000,0.000>,
 <1.250,1.900,0.100>,
 <1.050,1.900,0.000>,

 <1.050,2.000,0.000>,
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,

 <1.600,1.900,0.100>,
 <1.600,0.100,0.100>,
 <1.800,0.100,0.000>,

 <1.800,0.000,0.000>,
 <1.050,0.000,0.000>,
 <1.050,0.100,0.000>,

 <1.250,0.100,0.100>,
 <1.250,0.900,0.000>,
 <0.550,0.900,0.000>,

 <0.550,0.100,0.100>,
 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>, 
 
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// I
//*************************************************************************************************
#macro CL_rlp_I(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.75; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <0.750,2.000,0.000>,

 <0.750,1.900,0.000>,
 <0.550,1.900,0.100>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>,
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// J
//*************************************************************************************************
#macro CL_rlp_J(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <0.425,0.100,0.400>, 
 <0.625,0.200,0.400>,
 <0.625,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.000>,
 <0.000,1.700,0.000>,

 <0.100,2.000,0.000>,
 <1.500,2.000,0.000>, 
 <1.600,1.700,0.000>,
 
 <1.500,1.660,0.000>,
 <1.410,1.900,0.100>,
 <0.975,1.900,0.100>,
 
 <0.975,0.000,0.600>,
 <0.375,0.000,0.400>, 
 <0.110,0.200,0.600>,
 
 <-.020,0.700,0.300>,   // Roundy bit
 <0.370,0.700,0.300>,   // Roundy bit
 <0.240,0.300,0.400>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// K
//*************************************************************************************************
#macro CL_rlp_K(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.875; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[27]{
 <0.000,0.100,0.000>,    // Bottom left serif
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <0.750,2.000,0.000>,

 <0.750,1.900,0.000>,
 <0.550,1.900,0.100>,    // End of top left serif
 <0.550,1.100,0.000>,    // Upper kink

 <1.250,1.900,0.100>,    // Upper right serif
 <1.050,1.900,0.000>,
 <1.050,2.000,0.000>,

 <1.675,2.000,0.000>,
 <1.675,1.900,0.000>,
 <1.500,1.900,0.100>,

 <0.800,1.100,0.000>,    // Outer kink
 <1.700,0.100,0.100>,
 <1.875,0.100,0.000>,

 <1.875,0.000,0.000>,
 <1.050,0.000,0.000>,
 <1.050,0.100,0.000>,

 <1.250,0.100,0.100>,
 <0.550,0.900,0.000>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>, 
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// L
//*************************************************************************************************
#macro CL_rlp_L(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <0.750,2.000,0.000>,

 <0.750,1.900,0.000>,
 <0.550,1.900,0.100>,
 <0.550,0.100,0.100>,
 
 <1.350,0.100,0.100>,
 <1.600,0.450,0.000>,
 <1.700,0.400,0.000>,
 
 <1.500,0.000,0.000>,
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Script L for Laplace transform operator.
//*************************************************************************************************
#macro CL_rlp_scr_L(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 <-.100,0.000,0.350>, // Left origin
 <0.200,0.500,0.450>, // Bottom loop
 <0.870,0.300,0.000>,

 <1.152,0.447,0.300>,
 <1.480,0.965,0.000>, // Upper armpit 
 <0.245,0.791,1.200>,

 <1.230,2.000,0.300>,
 <1.638,2.000,0.000>, // End of upper tail
 <1.638,1.900,0.000>, // End of upper tail
 
 <1.270,1.900,0.300>,
 <0.712,1.000,0.800>,
 <1.533,1.080,0.000>,
 
 <2.100,2.000,0.300>, // Top of loop
 <2.700,2.000,0.300>, // Top of loop
 <2.700,1.150,0.600>,
 
 <1.747,1.000,0.000>,  
 <1.366,0.354,0.300>,   
 <1.100,0.220,0.000>,
 
 <1.639,0.030,0.500>,
 <2.330,0.500,0.000>,  // End of lower tail
 <2.400,0.432,0.000>,  // End of lower tail  
 
 <1.668,-.100,0.500>,
 <0.911,0.136,0.000>,
 <0.295,0.000,0.100>
}
// container, 2nd subset: upper loop inner
#local pts[1] =
array[4]{
 <1.820,1.120,0.000>,
 <2.550,1.300,0.500>,
 <2.550,1.900,0.200,>
 
 <2.250,1.900,0.200>
}
// container, 3rd subset: lower loop inner
#local pts[2] =
array[4]{
 <0.650,0.220,0.000>,
 <0.300,0.350,0.300>,
 <0.080,0.100,0.150,>
 
 <0.300,0.100,0.200>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// M
//*************************************************************************************************
#macro CL_rlp_M(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.2; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[25]{
 <0.000,0.100,0.000>,  // Lower left serif
 <0.200,0.100,0.100>,  // Lower left serif
 <0.200,1.900,0.100>,  // Upper left serif

 <0.000,1.900,0.000>,  // Upper left serif
 <0.000,2.000,0.000>,  // Upper left serif
 <0.500,2.000,0.000>,  // Upper left corner 

 <1.125,0.500,0.000>,  // Middle upper vertex 
 <1.690,2.000,0.000>,  // Upper  right corner 
 <2.200,2.000,0.000>,  // Upper right serif

 <2.200,1.900,0.000>,  // Upper right serif
 <2.000,1.900,0.100>,  // Upper right serif
 <2.000,0.100,0.100>,  // Lower right serif

 <2.200,0.100,0.000>,  // Lower right serif
 <2.200,0.000,0.000>,  // Lower right serif
 <1.450,0.000,0.000>,  // Lower right serif

 <1.450,0.100,0.000>,  // Lower right serif
 <1.650,0.100,0.100>,  // Lower right serif
 <1.650,1.600,0.000>,  // Upper right armpit

 <1.050,0.000,0.000>,  // Middle left lower vertex
 <0.950,0.000,0.000>,  // Middle right lower vertex
 <0.300,1.600,0.000>,  // Upper left armpit 
 
 <0.300,0.100,0.100>,  // Lower left serif
 <0.500,0.100,0.000>,  // Lower left serif
 <0.500,0.000,0.000>,  // Lower left serif
 
 <0.000,0.000,0.000>   // Lower left serif
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// N
//*************************************************************************************************
#macro CL_rlp_N(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.100,0.000>,  // Lower left serif
 <0.200,0.100,0.100>,  // Lower left serif
 <0.200,1.900,0.100>,  // Upper left serif

 <0.000,1.900,0.000>,  // Upper left serif
 <0.000,2.000,0.000>,  // Upper left serif
 <0.500,2.000,0.000>,  // Upper left corner 

 <1.500,0.60,0.000>,  // Right lower armpit 
 <1.500,1.900,0.100>,  // Upper right serif
 <1.300,1.900,0.000>,  // Upper right serif

 <1.300,2.000,0.000>,  // Upper right serif
 <1.800,2.000,0.000>,  // Upper right serif
 <1.800,1.900,0.000>,  // Upper right serif

 <1.600,1.900,0.100>,  // Upper right serif
 <1.600,0.000,0.000>,  // Lower right corner
 <1.500,0.000,0.000>,  // Lower left  corner

 <0.300,1.700,0.000>,  // Upper left armpit 
 <0.300,0.100,0.100>,  // Lower left serif
 <0.500,0.100,0.000>,  // Lower left serif

 <0.500,0.000,0.000>,  // Lower left serif
 <0.000,0.000,0.000>   // Lower left serif
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//*************************************************************************************************
// Blackboard Bold N
//*************************************************************************************************
#macro CL_rlp_bb_N(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.85; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.150,0.000>,  // Lower left serif
 <0.200,0.150,0.100>,  // Lower left serif
 <0.200,1.850,0.100>,  // Upper left serif

 <0.000,1.850,0.000>,  // Upper left serif
 <0.000,2.000,0.000>,  // Upper left serif
 <0.700,2.000,0.000>,  // Upper left corner 

 <1.500,0.887,0.000>,  // Right lower armpit 
 <1.500,1.850,0.100>,  // Upper right serif
 <1.300,1.850,0.000>,  // Upper right serif

 <1.300,2.000,0.000>,  // Upper right serif
 <1.850,2.000,0.000>,  // Upper right serif
 <1.850,1.850,0.000>,  // Upper right serif

 <1.650,1.850,0.100>,  // Upper right serif
 <1.650,0.000,0.000>,  // Lower right corner
 <1.500,0.000,0.000>,  // Lower left  corner

 <0.350,1.600,0.000>,  // Upper left armpit 
 <0.350,0.150,0.100>,  // Lower left serif
 <0.550,0.150,0.000>,  // Lower left serif

 <0.550,0.000,0.000>,  // Lower left serif
 <0.000,0.000,0.000>   // Lower left serif
}  
// container, 2nd subset: inner cutout
#local pts[1] =
array[4]{
 <0.620,1.850,0>,
 <0.350,1.850,0>,
 <1.500,0.250,0>,
 
 <1.500,0.640,0>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// O
//*************************************************************************************************
#macro CL_rlp_O(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,2.000,0.900>,
 <1.800,2.000,0.900>,
 <1.800,0.000,0.900>,

 <0.000,0.000,0.900>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.350,0.100,0.550>,
 <1.450,0.100,0.550>,
 <1.450,1.900,0.550>,
 <0.350,1.900,0.550>
}

// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// P
//*************************************************************************************************
#macro CL_rlp_P(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.400,2.000,1.1/2>,

 <1.400,0.900,1.1/2>,
 <0.550,0.900,0.000>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>,
 <0.000,0.000,0.000>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.550,1.000,0.000>,
 <1.050,1.000,0.775/2>,
 <1.050,1.900,0.775/2>,
 <0.550,1.900,0.000>
}

// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Q
//*************************************************************************************************
#macro CL_rlp_Q(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.5; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,2.000,0.900>,
 <1.800,2.000,0.900>,
 <1.800,0.000,0.900>,

 <0.000,0.000,0.900>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.350,0.100,0.550>,
 <1.450,0.100,0.550>,
 <1.450,1.900,0.550>,
 <0.350,1.900,0.550>
        }
//
#local pts1 = array[1];
// container, 3rd subset: dinky bit
#local pts1[0] =
array[4]{
 <1.000,0.100,0.000>,
 <1.300,0.170,0.000>,
 <1.570,-.350,0.000>,

 <1.500,-.400,0.000>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end   
//*************************************************************************************************
// Blackboard Bold Q
//*************************************************************************************************
#macro CL_rlp_bb_Q(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.5; // Drop below line
//
#local pts = array[5];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,2.000,1.000>,    // 1
 <2.000,2.000,1.000>,    // 1
 <2.000,0.200,0.700>,    // 0.7

 <1.400,0.015,0.000>,    // 0.0
 <1.600,-.300,0.500>,    // 0.5
 <2.000,-.500,0.000>,
 
 <2.000,-.600,0.000>,
 <1.100,-.600,0.700>,    // 0.7
 <0.600,0.025,0.000>,
  
 <0.000,0.200,0.700>     // 
        }
// container, 2nd subset: middle hole
#local pts[1] =
array[4]{
 <0.550,0.100,0.450>,
 <1.450,0.100,0.450>,
 <1.450,1.850,0.450>,

 <0.550,1.850,0.450>
        }
// container, 3rd subset: tail hole
#local pts[2] =
array[6]{
 <0.825,-.025,0.000>,
 <1.175,-.450,0.700>,
 <1.650,-.460,0.000>,
  
 <1.400,-.300,0.300>,   // 0.3
 <1.225,-.025,0.000>,
 <1.000,-.075,0.300>
        }
// container, 4th subset: left hole
#local pts[3] =
array[6]{
 <0.150,1.450,0.400>,
 <0.150,0.450,0.400>,
 <0.500,0.250,0.000>,
  
 <0.400,0.400,0.200>,   // 0.0
 <0.400,1.500,0.200>,
 <0.500,1.700,0.000>
        }
// container, 5th subset: right hole
#local pts[4] =
array[6]{
 <1.850,1.450,0.400>,
 <1.500,1.700,0.000>,
 <1.600,1.500,0.200>,
  
 <1.600,0.400,0.200>,   // 0.0
 <1.500,0.250,0.000>,
 <1.850,0.450,0.400>
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// R
//*************************************************************************************************
#macro CL_rlp_R(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.400,2.000,1.1/2>,

 <1.400,0.900,1.1/2>,  

 
 <0.900,0.900,0.000>,
 <1.400,0.100,0.100>,
 <1.600,0.100,0.000>, 
 
 <1.600,0.000,0.000>,
 <0.850,0.000,0.000>,
 <0.850,0.100,0.000>, 

 <1.075,0.100,0.100>,
 <0.575,0.900,0.000>, 
 
 
 <0.550,0.900,0.000>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.000>,
 <0.750,0.000,0.000>,
 <0.000,0.000,0.000>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.550,1.000,0.000>,
 <1.050,1.000,0.775/2>,
 <1.050,1.900,0.775/2>, 
 
 <0.550,1.900,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Blackboard Bold R
//*************************************************************************************************
#macro CL_rlp_bb_R(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.1; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[5];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.150,0.000>,
 <0.200,0.150,0.100>,
 <0.200,1.850,0.100>,

 <0.000,1.850,0.000>,
 <0.000,2.000,0.000>,
 <1.900,2.000,0.550>,    // front of roundy bit

 <1.900,0.900,0.550>,    // front of roundy bit

 
 <1.400,0.900,0.000>,
 <1.900,0.150,0.100>,
 <2.100,0.150,0.000>, 
 
 <2.100,0.000,0.000>,
 <1.050,0.000,0.000>,
 <1.050,0.150,0.000>, 

 <1.275,0.150,0.100>,
 <0.775,0.900,0.000>, 
 
 
 <0.750,0.900,0.000>,
 <0.750,0.150,0.100>,

 <0.950,0.150,0.000>,
 <0.950,0.000,0.000>,
 <0.000,0.000,0.000>
        }
// container, 2nd subset: main upper hole
#local pts[1] =
array[4]{
 <0.750,1.050,0.000>,
 <1.250,1.050,0.400>,
 <1.250,1.850,0.400>, 
 
 <0.750,1.850,0.000>
        }
// container, 3rd subset: vertical stroke hole
#local pts[2] =
array[4]{
 <0.350,0.150,0.000>,
 <0.600,0.150,0.000>,
 <0.600,1.850,0.000>, 
 
 <0.350,1.850,0.000>
        }
// container, 4th subset: slanted stroke hole
#local pts[3] =
array[4]{
 <1.450,0.150,0.000>,
 <1.720,0.150,0.000>,
 <1.220,0.900,0.000>, 
 
 <0.950,0.900,0.000>
        }
// container, 5th subset: secondary round hole
#local pts[4] =
array[6]{
 <1.750,1.050,0.400>,
 <1.750,1.850,0.400>,
 <1.200,1.850,0.000>, 
 
 <1.400,1.650,0.300>,
 <1.400,1.250,0.300>,
 <1.200,1.050,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// S
//*************************************************************************************************
#macro CL_rlp_S(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.525,0.000>,    // Lower serif
 <0.100,0.525,0.000>,    // Lower serif
 <0.100,0.325,0.250>,    // Lower serif

 <0.850,0.000,0.600>,    // Internal curve - base
 <1.500,0.500,0.600>,    // Internal curve - right side
 <-.420,1.500,0.800>,    // External curve - left side

 <0.850,2.200,0.800>,    // External curve - top
 <1.500,1.800,0.100>,    // Upper serif
 <1.500,2.000,0.000>,    // Upper serif

 <1.600,2.000,0.000>,    // Upper serif
 <1.600,1.475,0.000>,    // Upper serif
 <1.500,1.475,0.000>,    // Upper serif

 <1.500,1.675,0.250>,    // Upper serif
 <0.850,2.000,0.600>,    // Internal curve - upper
 <0.100,1.500,0.600>,    // Internal curve - left

 <2.100,0.500,0.800>,    // External curve - right
 <0.850,-.200,0.800>,    // External curve - bottom
 <0.100,0.200,0.100>,    // Lower serif

 <0.100,0.000,0.100>,    // Lower serif
 <0.000,0.000,0.000>     // Lower serif
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//*************************************************************************************************
// T
//*************************************************************************************************
#macro CL_rlp_T(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.425,0.100,0.000>, 
 <0.625,0.100,0.100>,
 <0.625,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.000>,
 <0.000,1.700,0.000>,

 <0.100,2.000,0.000>,
 <1.500,2.000,0.000>, 
 <1.600,1.700,0.000>,
 
 <1.500,1.660,0.000>,
 <1.410,1.900,0.100>,
 <0.975,1.900,0.100>,
 
 <0.975,0.100,0.100>,
 <1.175,0.100,0.000>,
 <1.175,0.000,0.000>,
 
 <0.425,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// U
//*************************************************************************************************
#macro CL_rlp_U(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.900,0.000>, 
 <0.000,2.000,0.000>,
 <0.750,2.000,0.000>, 
 
 <0.750,1.900,0.000>, 
 <0.550,1.900,0.100>,
 <0.550,0.100,0.500>,    // Inner
 <1.500,0.100,0.500>,    // Inner

 <1.500,1.900,0.100>,
 <1.300,1.900,0.000>, 
 <1.300,2.000,0.000>,
 
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,
 <1.600,1.900,0.100>,
 
 <1.600,0.000,0.550>,    // Outer
 <0.200,0.000,0.550>,    // Outer
 <0.200,1.900,0.100>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// V
//*************************************************************************************************
#macro CL_rlp_V(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,1.900,0.000>,    // Left serif
 <0.000,2.000,0.000>,    // Left serif
 <0.750,2.000,0.000>,    // Left serif
 
 <0.750,1.900,0.000>,    // Left serif
 <0.550,1.900,0.100>,    // Left serif
 <1.010,0.500,0.000>,    // Inner vertex

 <1.500,1.900,0.100>,    // Right serif
 <1.300,1.900,0.000>, 
 <1.300,2.000,0.000>,
 
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,
 <1.610,1.900,0.100>,
 
 <0.950,0.000,0.000>,    // Outer
 <0.850,0.000,0.000>,    // Outer
 <0.200,1.900,0.100>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// W
//*************************************************************************************************
#macro CL_rlp_W(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 <0.000,1.900,0.000>,    // Left serif
 <0.000,2.000,0.000>,    // Left serif
 <0.750,2.000,0.000>,    // Left serif
 
 <0.750,1.900,0.000>,    // Left serif
 <0.550,1.900,0.100>,    // Left serif
 <0.860,0.700,0.000>,    // Inner vertex - left

 <1.160,1.800,0.000>,
 <1.150,1.900,0.100>,
 <0.950,1.900,0.000>,
 
 <0.950,2.000,0.000>,
 <1.700,2.000,0.000>,
 <1.700,1.900,0.000>,
 
 <1.500,1.900,0.100>,
 <1.790,0.700,0.000>,    // Inner vertex - right
 <2.100,1.900,0.100>,    // Right serif

 <1.900,1.900,0.000>, 
 <1.900,2.000,0.000>,
 <2.400,2.000,0.000>,

 <2.400,1.900,0.000>,
 <2.210,1.900,0.100>,
 <1.720,0.000,0.000>,    // Outer

 <1.620,0.000,0.000>,    // Outer
 <1.210,1.600,0.000>,    // Middle vertex - outer
 <0.780,0.000,0.000>,

 <0.680,0.000,0.000>,
 <0.180,1.900,0.100>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// X
//*************************************************************************************************
#macro CL_rlp_X(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.000,0.100,0.000>,    // Bottom left serif
 <0.180,0.100,0.100>,    // Bottom left serif
 <0.771,0.906,0.000>,    // Left middle  - tweaker
 
 <0.180,1.900,0.100>,    // Top left serif
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,

 <0.750,2.000,0.000>,
 <0.750,1.900,0.000>,
 <0.550,1.900,0.100>,    // Top left serif

 <0.975,1.185,0.000>,    // Upper middle - tweaker
 <1.500,1.900,0.100>,    // Top right serif
 <1.300,1.900,0.000>,

 <1.300,2.000,0.000>,
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,    

 <1.620,1.900,0.100>,    // Top right serif
 <1.025,1.102,0.000>,    // Right middle - tweaker
 <1.620,0.100,0.100>,    // Bottom right serif
 
 <1.800,0.100,0.000>,
 <1.800,0.000,0.000>,
 <1.050,0.000,0.000>, 
 
 <1.050,0.100,0.000>,
 <1.250,0.100,0.100>,
 <0.822,0.821,0.000>,    // Bottom middle
 
 <0.300,0.100,0.100>,
 <0.500,0.100,0.000>,
 <0.500,0.000,0.000>,
 
 <0.000,0.000,0.000>,
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Y
//*************************************************************************************************
#macro CL_rlp_Y(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[21]{
 <0.000,1.900,0.000>,    // Left serif
 <0.000,2.000,0.000>,    // Left serif
 <0.750,2.000,0.000>,    // Left serif
 
 <0.750,1.900,0.000>,    // Left serif
 <0.550,1.900,0.100>,    // Left serif
 <1.025,1.100,0.000>,    // Inner vertex - tweaker

 <1.500,1.900,0.100>,    // Right serif
 <1.300,1.900,0.000>, 
 <1.300,2.000,0.000>,
 
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,  
 <1.620,1.900,0.100>,
 
 <1.075,0.970,0.000>,     // Tweaker
 <1.075,0.100,0.100>, 
 <1.275,0.100,0.000>,
 
 <1.275,0.000,0.000>,
 <0.525,0.000,0.000>,
 <0.525,0.100,0.000>,

 <0.725,0.100,0.100>,    // Outer
 <0.725,1.000,0.000>,    // Outer 
 <0.180,1.900,0.100>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Z
//*************************************************************************************************
#macro CL_rlp_Z(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.000>, 
 <0.000,0.100,0.000>,
 <1.300,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.000>,
 <0.000,1.700,0.000>,

 <0.100,2.000,0.000>,
 <1.700,2.000,0.000>, 
 <1.700,1.900,0.000>,
 
 <0.500,0.100,0.100>,
 <1.350,0.100,0.100>,
 <1.600,0.450,0.000>,
 
 <1.700,0.400,0.000>,
 <1.500,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end      
//*************************************************************************************************
// Blackboard Bold Z
//*************************************************************************************************
#macro CL_rlp_bb_Z(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.85; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[4];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.000>, 
 <0.000,0.150,0.000>,
 <1.200,1.850,0.000>, 
 
 <0.375,1.850,0.600>,    // 0.6
 <0.140,1.200,0.000>,
 <0.000,1.250,0.000>,

 <0.250,2.000,0.000>,
 <1.850,2.000,0.000>, 
 <1.850,1.850,0.000>,
 
 <0.650,0.150,0.000>,
 <1.450,0.150,0.800>,
 <1.710,0.975,0.000>,
 
 <1.850,0.950,0.000>,
 <1.600,0.000,0.000>
}
// container, 2nd subset: top serif
#local pts[1] =
array[4]{
 <0.350,1.850,0.000>,
 <0.300,1.700,0.000>,  
 <0.385,1.810,0.300>,
 
 <0.500,1.850,0.000>
}
// container, 3rd subset: bottom serif
#local pts[2] =
array[4]{
 <1.475,0.150,0.000>,
 <1.550,0.400,0.000>,  
 <1.400,0.220,0.300>,
 
 <1.225,0.150,0.000>
}
// container, 4th subset: inner stroke
#local pts[3] =
array[4]{
 <0.175,0.150,0.000>,
 <0.475,0.150,0.000>,  
 <1.660,1.850,0.000>,
 
 <1.375,1.850,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//*************************************************************************************************
// ROMAN SMALL LETTERS ****************************************************************************
//*************************************************************************************************
// a
//*************************************************************************************************
#macro CL_rlp_a(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.700>,     // Outer lower
 <0.000,1.400,0.700>,     // Outer upper
 <1.000,1.400,0.800>,     // Upper middle
 
 <1.150,1.300,0.000>,     // Right vertical
 <1.150,1.400,0.000>,     // Right vertical
 <1.550,1.400,0.000>,     // Right vertical
  
 <1.550,1.300,0.000>,
 <1.400,1.300,0.100>,
 <1.400,0.100,0.100>,
 
 <1.550,0.100,0.000>,
 <1.550,0.000,0.000>,
 <1.150,0.000,0.000>,
 
 <1.150,0.120,0.000>,
 <1.000,0.000,0.600>
         }
#local pts[1] =
array[4]{
 <1.150,1.340,0.800>,     // Inner middle upper

 <0.050,1.230,0.900>,     // Inner left upper
 <0.650,-.100,1.000>, 
 
 <1.150,0.250,0.000>,
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.552,  0   ,0> < 1.552, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.550,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.550, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//***************************************************************************************************
// b
//***************************************************************************************************
#macro CL_rlp_b(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.550,0.000,0.600>
 <0.400,0.120,0.000>,
 <0.400,0.000,0.000>,

 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <0.150,0.100,0.100>,

 <0.150,1.900,0.100>,
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,     // Right vertical

 <0.400,2.000,0.000>,     // Right vertical
 <0.400,1.300,0.000>,     // Right vertical
 <0.550,1.400,0.800>,     // Upper middle

 <1.550,1.400,0.700>,     // Outer upper
 <1.550,0.000,0.700>,     // Outer lower  
         }
#local pts[1] =
array[4]{
 <0.400,0.250,0.000>,
 <1.350,-.150,1.200>, 
 <1.130,1.230,0.800>,     // Inner left upper

 <0.400,1.340,0.800>,     // Inner middle upper

// <0.400,0.250,0.000>,
// <0.900,-.100,1.000>, 
// <1.550,1.230,0.900>,     // Inner left upper

// <0.400,1.340,0.800>,     // Inner middle upper
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.552,  0   ,0> < 1.552, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.550,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.550, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// c
//**************************************************************************************
#macro CL_rlp_c(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.000,0.000,0.700>,     // Outer lower
 <0.000,1.400,0.700>,     // Outer upper
 <1.200,1.400,0.800>,     // Upper middle
 
 <1.450,0.900,0.300>,     // Right round upper
 <1.150,0.800,0.300>,     // Right round lower
 <1.000,1.340,0.800>,     // Inner middle upper

 <0.050,1.230,0.900>,     // Inner left upper
 <0.650,-.100,1.000>, 
// <1.050,0.175,1.000>,
 
 <1.350,0.400,0.000>,
 <1.400,0.325,0.000>,
 <1.100,0.000,0.600>
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//*************************************************************************************************
// d
//*************************************************************************************************
#macro CL_rlp_d(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.700>,     // Outer lower
 <0.000,1.400,0.700>,     // Outer upper
 <1.000,1.400,0.800>,     // Upper middle
 
 <1.150,1.300,0.000>,     // Right vertical
 <1.150,2.000,0.000>,     // Right vertical
 <1.550,2.000,0.000>,     // Right vertical
  
 <1.550,1.900,0.000>,
 <1.400,1.900,0.100>,
 <1.400,0.100,0.100>,
 
 <1.550,0.100,0.000>,
 <1.550,0.000,0.000>,
 <1.150,0.000,0.000>,
 
 <1.150,0.120,0.000>,
 <1.000,0.000,0.600>
         }
#local pts[1] =
array[4]{
 <1.150,1.340,0.800>,     // Inner middle upper

 <0.050,1.230,0.900>,     // Inner left upper
 <0.650,-.100,1.000>, 
 
 <1.150,0.250,0.000>,
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.552,  0   ,0> < 1.552, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.550,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.550, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// e
//**************************************************************************************
#macro CL_rlp_e(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,0.000,0.699>,     // Outer lower
 <0.000,1.400,0.600>,     // Outer upper
 <1.200,1.400,0.800>,     // Upper middle
 
 <1.450,0.850,0.300>,     // Right round upper
 <1.150,0.850,0.000>,     // Right round lower
 <0.300,0.850,0.000>,     // Inner left upper

 <0.450,-.300,1.000>, 
 <1.350,0.400,0.000>,
 <1.400,0.325,0.000>,

 <1.100,0.000,0.600>
}
#local pts[1] =
array[3]{
 <0.310,0.950,0.000>
 <1.100,0.950,0.000>,
 <0.550,1.900,0.900>,     // Inner middle upper
        }

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// f
//**************************************************************************************
#macro CL_rlp_f(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.95; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.150,0.100,0.100>,       
 
 <0.150,0.900,0.000>,
 <0.000,0.900,0.000>,
 <0.000,1.000,0.000>,
 
 <0.150,1.000,0.000>,
 <0.150,2.000,0.400>,     
 <0.900,2.000,0.400>,     

 <0.960,1.500,0.300>,     
 <0.650,1.500,0.300>,
 <0.750,1.900,0.300>,
 
 <0.400,1.900,0.300>,
 <0.400,1.000,0.000>,
 <0.550,1.000,0.000>,
 
 <0.550,0.900,0.000>,
 <0.400,0.900,0.000>,     
 <0.400,0.100,1.000>, 
 
 <0.550,0.100,0.000>,
 <0.550,0.000,0.000>
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 0.952,  0   ,0> < 0.952, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.95 ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 0.95 , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//*************************************************************************************************
// g
//*************************************************************************************************
#macro CL_rlp_g(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.8; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.700>,     // Outer lower
 <0.000,1.400,0.700>,     // Outer upper
 <1.000,1.400,0.800>,     // Upper middle
 
 <1.150,1.300,0.000>,     // Right vertical
 <1.150,1.400,0.000>,     // Right vertical
 <1.550,1.400,0.000>,     // Right vertical
  
 <1.550,1.300,0.000>,
 <1.400,1.300,0.100>, 
 <1.400,-.800,0.800>,
 
 <0.100,-.800,0.600>,
 <0.100,-.150,0.300>,
 <0.450,-.150,0.300>,
 
 <0.300,-.700,0.400>,
 <1.150,-.700,0.600>,
 <1.150,0.120,0.000>,

 <1.000,0.000,0.700>
         }
#local pts[1] =
array[4]{
 <1.150,1.340,0.800>,     // Inner middle upper

 <0.050,1.230,0.900>,     // Inner left upper
 <0.650,-.100,1.000>, 
 
 <1.150,0.250,0.000>,
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//***************************************************************************************************
// h
//***************************************************************************************************
#macro CL_rlp_h(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.550,0.000,0.000>,
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 
 <0.150,0.100,0.100>,
 <0.150,1.900,0.100>,
 <0.000,1.900,0.000>,
 
 <0.000,2.000,0.000>,     
 <0.400,2.000,0.000>,     
 <0.400,1.200,0.000>,     

 <1.250,2.000,1.060>,     
 <1.250,0.100,0.100>,     
 <1.400,0.100,0.000>,     

 <1.400,0.000,0.000>,
 <0.850,0.000,0.000>,
 <0.850,0.100,0.000>,

 <1.000,0.100,0.100>,
 <1.000,1.800,0.900>,
 <0.400,1.060,0.000>,

 <0.400,0.100,0.100>,
 <0.550,0.100,0.000>   
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// i
//**************************************************************************************
#macro CL_rlp_i(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.150,0.100,0.100>,       
 
 <0.150,1.300,0.100>,  
 <0.000,1.300,0.000>,
 <0.000,1.400,0.000>,
      
 <0.400,1.400,0.000>,     
 <0.400,0.100,1.000>, 
 <0.550,0.100,0.000>,

 <0.550,0.000,0.000>
}
// invoking the object macro
union{
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.15,1.6,0> }
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  #local letter_dimensions[0] = 0.55; // Width 
  #local letter_dimensions[1] = 1.85; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
#end   
//**************************************************************************************
// j
//**************************************************************************************
#macro CL_rlp_j(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <-.060,-.300,0.300>,     
 <0.250,-.300,0.300>,     
 <0.150,-.700,0.300>,       
 
 <0.500,-.700,0.300>,  
 <0.500,1.300,0.100>,
 <0.350,1.300,0.000>,
      
 <0.350,1.400,0.000>,     
 <0.750,1.400,0.000>, 
 <0.750,-.800,0.400>,

 <0.000,-.800,0.400>
}
// invoking the object macro
union{
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.5,1.6,0> }
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  #local letter_dimensions[0] = 0.75; // Width 
  #local letter_dimensions[1] = 1.85; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.8; // Drop below line     
         }
#end    
//**************************************************************************************
// k
//**************************************************************************************
#macro CL_rlp_k(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[25]{
 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.150,0.100,0.100>,       
 
 <0.150,1.900,0.100>,  
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
      
 <0.400,2.000,0.000>, 
 <0.400,0.900,0.000>,
 <1.000,1.300,0.100>,
 
 <0.850,1.300,0.000>,
 <0.850,1.400,0.000>,
 <1.250,1.400,0.000>,
 
 <1.250,1.300,0.000>,
 <1.160,1.300,0.100>,
 <0.570,0.890,0.000>,
 
 <1.320,0.100,0.100>,
 <1.400,0.100,0.000>,
 <1.400,0.000,0.000>,
 
 <0.850,0.000,0.000>,
 <0.850,0.100,0.000>,  
 <1.000,0.100,0.100>,
 
 <0.400,0.700,0.000>,    
 <0.400,0.100,1.000>, 
 <0.550,0.100,0.000>,
 
 <0.550,0.000,0.000>
          }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// l
//**************************************************************************************
#macro CL_rlp_l(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.55; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.150,0.100,0.100>,       
 
 <0.150,1.900,0.100>,  
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
      
 <0.400,2.000,0.000>,     
 <0.400,0.100,1.000>, 
 <0.550,0.100,0.000>,

 <0.550,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//***************************************************************************************************
// m
//***************************************************************************************************
#macro CL_rlp_m(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.25; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[30]{
 <0.550,0.000,0.000>,
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 
 <0.150,0.100,0.100>,
 <0.150,1.300,0.100>,
 <0.000,1.300,0.000>,
 
 <0.000,1.400,0.000>,     
 <0.400,1.400,0.000>,     
 <0.400,1.200,0.000>,     

 <0.950,1.710,1.200>, 
 <1.220,1.170,0.000>,
 <2.100,2.000,1.060>,
 
 <2.100,0.100,0.100>,
 <2.250,0.100,0.000>,
 <2.250,0.000,0.000>,
 
 <1.700,0.000,0.000>,
 <1.700,0.100,0.000>,
 <1.850,0.100,0.100>,
 
 <1.850,1.800,0.900>,
 <1.250,1.060,0.000>,     
 <1.250,0.100,0.100>,
      
 <1.400,0.100,0.000>,     
 <1.400,0.000,0.000>,
 <0.850,0.000,0.000>,     
 
 <0.850,0.100,0.000>,
 <1.000,0.100,0.100>,
 <1.000,1.800,0.900>,
 
 <0.400,1.060,0.000>,
 <0.400,0.100,0.100>,
 <0.550,0.100,0.000>,   
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 2.102,  0   ,0> < 2.102, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.100,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 2.100, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//***************************************************************************************************
// n
//***************************************************************************************************
#macro CL_rlp_n(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.550,0.000,0.000>,
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 
 <0.150,0.100,0.100>,
 <0.150,1.300,0.100>,
 <0.000,1.300,0.000>,
 
 <0.000,1.400,0.000>,     
 <0.400,1.400,0.000>,     
 <0.400,1.200,0.000>,     

 <1.250,2.000,1.060>,     
 <1.250,0.100,0.100>,     
 <1.400,0.100,0.000>,     

 <1.400,0.000,0.000>,
 <0.850,0.000,0.000>,
 <0.850,0.100,0.000>,

 <1.000,0.100,0.100>,
 <1.000,1.800,0.900>,
 <0.400,1.060,0.000>,

 <0.400,0.100,0.100>,
 <0.550,0.100,0.000>,   
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// o
//*************************************************************************************************
#macro CL_rlp_o(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.000,0.700>,     
 <0.000,1.400,0.700>,     
 <1.400,1.400,0.700>,     
 
 <1.400,0.000,0.700>,     
         }
#local pts[1] =
array[4]{
 <0.350,0.100,0.600>,     
 <1.150,0.100,0.600>,     
 <1.050,1.300,0.600>, 
 
 <0.250,1.300,0.600>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//***************************************************************************************************
// p
//***************************************************************************************************
#macro CL_rlp_p(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.8; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.550,0.000,0.600>
 <0.400,0.120,0.000>,
 <0.400,-.700,0.100>,
 
 <0.550,-.700,0.000>,
 <0.550,-.800,0.000>,
 <0.000,-.800,0.000>,

 <0.000,-.700,0.000>,
 <0.150,-.700,0.100>,
 <0.150,1.300,0.100>,

 <0.000,1.300,0.000>,
 <0.000,1.400,0.000>,     
 <0.400,1.400,0.000>,     

 <0.400,1.300,0.000>,     
 <0.550,1.400,0.800>,     
 <1.550,1.400,0.700>,     
 
 <1.550,0.000,0.700>,       
         }
#local pts[1] =
array[4]{
 <0.400,0.250,0.000>,
 <1.350,-.150,1.200>, 
 <1.130,1.230,0.800>,     // Inner left upper

 <0.400,1.340,0.800>,     // Inner middle upper

// <0.400,0.250,0.000>,
// <0.900,-.100,1.000>, 
// <1.550,1.230,0.900>,     // Inner left upper

// <0.400,1.340,0.800>,     // Inner middle upper
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.552,  0   ,0> < 1.552, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.550,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.550, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//*************************************************************************************************
// q
//*************************************************************************************************
#macro CL_rlp_q(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.55; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.8; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.700>,     // Outer lower
 <0.000,1.400,0.700>,     // Outer upper
 <1.000,1.400,0.800>,     // Upper middle
 
 <1.150,1.300,0.000>,     // Right vertical
 <1.150,1.400,0.000>,     // Right vertical
 <1.550,1.400,0.000>,     // Right vertical
  
 <1.550,1.300,0.000>,
 <1.400,1.300,0.100>,
 <1.400,-.700,0.100>,
 
 <1.550,-.700,0.000>,
 <1.550,-.800,0.000>,
 <1.000,-.800,0.000>,
 
 <1.000,-.700,0.000>,
 <1.150,-.700,0.100>,
 <1.150,0.120,0.000>,
 
 <1.000,0.000,0.600>
         }
#local pts[1] =
array[4]{
 <1.150,1.340,0.800>,     // Inner middle upper

 <0.050,1.230,0.900>,     // Inner left upper
 <0.650,-.100,1.000>, 
 
 <1.150,0.250,0.000>,
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.552,  0   ,0> < 1.552, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.550,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.550, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end    
//**************************************************************************************
// r
//**************************************************************************************
#macro CL_rlp_r(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.2; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.150,0.100,0.100>,       
 
 <0.150,1.300,0.100>,  
 <0.000,1.300,0.000>,
 <0.000,1.400,0.000>,
      
 <0.400,1.400,0.000>,  
 <0.400,1.200,0.000>,
 <0.900,1.600,0.800>,
 
 <1.240,1.050,0.300>,
 <1.020,0.880,0.300>,
 <0.800,1.400,0.700>,
 
 <0.400,1.060,0.000>,   
 <0.400,0.100,1.000>, 
 <0.550,0.100,0.000>,

 <0.550,0.000,0.000>
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.202,  0   ,0> < 1.202, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.2  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.2  , 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// s
//*************************************************************************************************
#macro CL_rlp_s(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.000,0.000>,    // Lower serif
 <0.000,0.400,0.000>,    // Lower serif
 <0.100,0.400,0.000>,    // Lower serif

 <0.100,0.200,0.400>,    // Internal curve - base
 <0.600,0.100,0.400>,    // Internal curve - right side
 <0.850,0.420,0.600>,    // External curve - left side

 <-.325,0.825,0.600>,    // External curve - top
 <0.350,1.460,0.300>,    // Upper serif
 <0.900,1.300,0.100>,    // Upper serif

 <0.900,1.400,0.000>,    // Upper serif
 <1.000,1.400,0.000>,    // Upper serif
 <1.000,1.000,0.000>,    // Upper serif

 <0.900,1.000,0.000>,    // Upper serif  
 <0.900,1.200,0.300>,
 <0.400,1.300,0.400>,    // Internal curve - left

 <0.150,0.980,0.600>,    // External curve - right
 <1.325,0.575,0.600>,    // External curve - bottom
 <0.650,-.060,0.300>,    // Lower serif 
 
 <0.100,0.100,0.100>,    // Lower serif
 <0.100,0.000,0.000>
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.102,  0   ,0> < 1.102, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.002,  0   ,0> < 1.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.202,  0   ,0> < 1.202, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.200,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.200, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//***************************************************************************************************
// t
//***************************************************************************************************
#macro CL_rlp_t(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.85; // Width 
#local letter_dimensions[1] = 1.8; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
#local letter_width   = 0.85;
#local letter_height  = 1.4;
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[17]{
 <0.000,1.400,0.000>,
 <0.200,1.400,0.100>,
 <0.200,1.600,0.000>,
 
 <0.350,1.800,0.000>,
 <0.450,1.800,0.000>,
 <0.450,1.400,0.000>, 
 
 <0.750,1.400,0.000>,
 <0.750,1.300,0.000>,     
 <0.450,1.300,0.000>,     

 <0.450,0.100,0.200>,     
 <0.750,0.150,0.300>,     
 <0.750,0.300,0.000>,     

 <0.850,0.300,0.000>,     
 <0.850,0.000,0.400>,
 <0.200,0.000,0.400>, 
 
 <0.200,1.300,0.000>,
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end     
//***************************************************************************************************
// u
//***************************************************************************************************
#macro CL_rlp_u(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <0.000,1.400,0.000>,
 <0.400,1.400,0.000>,
 <0.400,0.120,0.600>,
                        
 <0.800,0.160,0.400>,                       
 <1.000,0.350,0.000>,   
 <1.000,1.400,0.000>,
    
 <1.400,1.400,0.000>,
 <1.400,1.300,0.000>, 
 <1.250,1.300,0.100>,
 
 <1.250,0.100,0.100>,     
 <1.400,0.100,0.000>,     
 <1.400,0.000,0.000>,     
 
 <1.000,0.000,0.000>,     
 <1.000,0.200,0.000>,     
 <0.800,0.000,0.400>,
      
 <0.150,0.000,0.600>,
 <0.150,1.300,0.100>,
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//***************************************************************************************************
// v
//***************************************************************************************************
#macro CL_rlp_v(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.2; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,1.400,0.000>,
 <0.550,1.400,0.000>,
 <0.550,1.300,0.000>,
 
 <0.400,1.300,0.100>,
 <0.700,0.450,0.000>,   // Bottom of inner v
 <1.000,1.300,0.100>,
 
 <0.850,1.300,0.000>, 
 <0.850,1.400,0.000>,
 <1.200,1.400,0.000>,     

 <1.200,1.300,0.000>,     
 <1.100,1.300,0.100>,     
 <0.650,0.000,0.000>,
      
 <0.550,0.000,0.000>,     
 <0.100,1.300,0.100>,     
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//***************************************************************************************************
// w
//***************************************************************************************************
#macro CL_rlp_w(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.05; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[25]{
 <0.000,1.400,0.000>,
 <0.550,1.400,0.000>,
 <0.550,1.300,0.000>,
 
 <0.400,1.300,0.100>,
 <0.700,0.450,0.000>,   // Bottom of inner v
 <1.000,1.300,0.100>,
 
 <0.850,1.300,0.000>,   
 <0.850,1.400,0.000>,   // Upper corner of middle left serif
 <1.400,1.400,0.000>,  
 
 <1.400,1.300,0.000>,
 <1.250,1.300,0.100>,
 <1.550,0.450,0.000>,   // Bottom of inner v

 <1.850,1.300,0.100>,
 <1.700,1.300,0.000>, 
 <1.700,1.400,0.000>,

 <2.050,1.400,0.000>,     
 <2.050,1.300,0.000>,     
 <1.950,1.300,0.100>,     

 <1.500,0.000,0.000>,  
 <1.400,0.000,0.000>,     
 <1.030,1.070,0.000>,   // Middle lower vertex - tweaker
       
 <0.650,0.000,0.000>,
 <0.550,0.000,0.000>,     
 <0.100,1.300,0.100>,
      
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//***************************************************************************************************
// x
//***************************************************************************************************
#macro CL_rlp_x(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.000,1.400,0.000>,
 <0.550,1.400,0.000>,
 <0.550,1.300,0.000>,
 
 <0.400,1.300,0.100>,     // Point
 <0.751,0.835,0.000>,     // tweaker top
 <1.150,1.300,0.100>,     // Point
 
 <1.000,1.300,0.000>,
 <1.000,1.400,0.000>,     
 <1.400,1.400,0.000>,     

 <1.400,1.300,0.000>,     
 <1.280,1.300,0.100>,    // Point 
 <0.812,0.754,0.000>,    // tweaker  right

 <1.305,0.100,0.100>,    // Point  
 <1.400,0.100,0.000>,
 <1.400,0.000,0.000>,
 
 <0.850,0.000,0.000>,
 <0.850,0.100,0.000>,
 <1.000,0.100,0.100>,   // Point
 
 <0.643,0.558,0.000>,   // tweaker  bott
 <0.250,0.100,0.100>,   // Point
 <0.400,0.100,0.000>,
 
 <0.400,0.000,0.000>,
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 
 <0.120,0.100,0.100>,
 <0.583,0.640,0.000>,    // tweaker left
 <0.095,1.300,0.100>,    // Point
 
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//***************************************************************************************************
// y
//***************************************************************************************************
#macro CL_rlp_y(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.2; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.8; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,1.400,0.000>,
 <0.550,1.400,0.000>,
 <0.550,1.300,0.000>,
 
 <0.400,1.300,0.100>,
 <0.700,0.450,0.000>,   // Bottom of inner v
 <1.000,1.300,0.100>,
 
 <0.850,1.300,0.000>, 
 <0.850,1.400,0.000>,
 <1.200,1.400,0.000>,     

 <1.200,1.300,0.000>,     
 <1.100,1.300,0.100>,     
 <0.373,-.800,0.300>,
  
 <0.000,-.800,0.400>,
 <0.000,-.300,0.300>,
 <0.350,-.350,0.300>,
 
 <0.200,-.600,0.300>,
 <0.320,-.650,0.300>,     
 <0.550,0.000,0.000>,    //End of tail 
 <0.100,1.300,0.100>,
      
 <0.000,1.300,0.000>
         }
// invoking the object macro
//  cylinder{<-0.002, -0.8   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402, -0.8   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.802,0> < 1.400,-0.802,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//***************************************************************************************************
// z
//***************************************************************************************************
#macro CL_rlp_z(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.2; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,1.150,0.000>,
 <0.000,1.400,0.000>,
 <1.200,1.400,0.000>,
 
 <1.200,1.300,0.000>,
 <0.300,0.100,0.100>,
 <1.100,0.100,0.100>, 
 
 <1.100,0.250,0.000>,
 <1.200,0.250,0.000>,     
 <1.200,0.000,0.000>,     

 <0.000,0.000,0.000>,     
 <0.000,0.100,0.000>,     
 <0.900,1.300,0.100>,     

 <0.100,1.300,0.100>,     
 <0.100,1.150,0.000>,
         }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 1.400,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.400,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.400, 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// GREEK CAPITALS *********************************************************************************
//*************************************************************************************************
// Alpha = A, Beta = B, Chi = X
//*************************************************************************************************
// Delta
//*************************************************************************************************
#macro CL_rlp_Delta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <0.850,2.000,0.000>,

 <0.950,2.000,0.000>,
 <1.800,0.100,0.000>,
 <1.800,0.000,0.000>,
        }
#local pts[1] =
array[3]{ 
 <0.120,0.100,0.000>,
 <1.450,0.100,0.000>,
 <0.790,1.600,0.000>,
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Epsilon = E
//*************************************************************************************************
// Phi
//*************************************************************************************************
#macro CL_rlp_Phi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.625,0.100,0.000>,
 <0.825,0.100,0.100>,
 <0.825,0.400,0.000>,

 <0.000,0.400,0.600>,
 <0.000,1.600,0.600>,
 <0.825,1.600,0.000>,

 <0.825,1.900,0.100>,
 <0.625,1.900,0.000>,
 <0.625,2.000,0.000>,

 <1.375,2.000,0.000>,
 <1.375,1.900,0.000>,
 <1.175,1.900,0.100>,

 <1.175,1.600,0.000>,
 <2.000,1.600,0.600>,
 <2.000,0.400,0.600>,
 
 <1.175,0.400,0.000>,
 <1.175,0.100,0.100>,
 <1.375,0.100,0.000>,
 
 <1.375,0.000,0.000>,
 <0.625,0.000,0.000>
}
#local pts[1] =
array[4]{
 <0.825,0.500,0.000>,
 <0.825,1.500,0.000>,
 <0.350,1.500,0.500>,

 <0.350,0.500,0.500>
}
#local pts[2] =
array[4]{
 <1.650,1.500,0.500>,
 <1.175,1.500,0.000>,
 <1.175,0.500,0.000>,

 <1.650,0.500,0.500>,
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Gamma
//*************************************************************************************************
#macro CL_rlp_Gamma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.500,2.000,0.000>,

 <1.600,1.700,0.000>,
 <1.500,1.660,0.000>,
 <1.410,1.900,0.100>,

 <0.550,1.900,0.100>,
 <0.550,0.100,0.100>,
 <0.750,0.100,0.000>,

 <0.750,0.000,0.000>,
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Eta = H, Iota = I, No J, Kappa = K
//*************************************************************************************************
// Lambda
//*************************************************************************************************
#macro CL_rlp_Lambda(z1,z2,d_rad,offs,cham,letter_dimensions)
  object{CL_rlp_V(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0,180> translate <1.8,2.0,0>}
#end
//*************************************************************************************************
// Mu = M, Nu = N, Omicron = O
//*************************************************************************************************
// Pi
//*************************************************************************************************
#macro CL_rlp_Pi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.100,0.000>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.800,2.000,0.000>,

 <1.800,1.900,0.000>,
 <1.600,1.900,0.100>,
 <1.600,0.100,0.100>,

 <1.800,0.100,0.000>,
 <1.800,0.000,0.000>,
 <1.050,0.000,0.000>,

 <1.050,0.100,0.000>,
 <1.250,0.100,0.100>,
 <1.250,1.900,0.100>,

 <0.550,1.900,0.100>,
 <0.550,0.100,0.100>,
 <0.750,0.100,0.000>,

 <0.750,0.000,0.000>, 
 <0.000,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Big Pi
//*************************************************************************************************
#macro CL_rlp_bigPi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.7; // Width 
#local letter_dimensions[1] = 2.5; // Height
#local letter_dimensions[2] = 2.5; // Superscript height
#local letter_dimensions[3] = 0.5; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,-.350,0.000>,
 <0.300,-.350,0.150>,
 <0.300,2.350,0.150>,

 <0.000,2.350,0.000>,
 <0.000,2.500,0.000>,
 <2.700,2.500,0.000>,

 <2.700,2.350,0.000>,
 <2.400,2.350,0.150>,
 <2.400,-.350,0.150>,

 <2.700,-.350,0.000>,
 <2.700,-.500,0.000>,
 <1.750,-.500,0.000>,

 <1.750,-.350,0.000>,
 <2.050,-.350,0.150>,
 <2.050,2.350,0.150>,

 <0.650,2.350,0.150>,
 <0.650,-.350,0.150>,
 <0.950,-.350,0.000>,

 <0.950,-.500,0.000>, 
 <0.000,-.500,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Very big Pi
//*************************************************************************************************
#macro CL_rlp_BigPi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 3.6; // Width 
#local letter_dimensions[1] = 3.0; // Height
#local letter_dimensions[2] = 3.0; // Superscript height
#local letter_dimensions[3] = 1.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,-.850,0.000>,
 <0.300,-.850,0.150>,
 <0.300,2.850,0.150>,

 <0.000,2.850,0.000>,
 <0.000,3.000,0.000>,
 <3.600,3.000,0.000>,

 <3.600,2.850,0.000>,
 <3.300,2.850,0.150>,
 <3.300,-.850,0.150>,

 <3.600,-.850,0.000>,
 <3.600,-1.00,0.000>,
 <2.650,-1.00,0.000>,

 <2.650,-.850,0.000>,
 <2.950,-.850,0.150>,
 <2.950,2.850,0.150>,

 <0.650,2.850,0.150>,
 <0.650,-.850,0.150>,
 <0.950,-.850,0.000>,

 <0.950,-1.00,0.000>, 
 <0.000,-1.00,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Theta
//*************************************************************************************************
#macro CL_rlp_Theta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.500,0.625,0.000>,
 <0.500,1.375,0.000>,
 <0.600,1.375,0.000>,

 <0.600,1.175,0.100>,
 <1.200,1.175,0.100>,
 <1.200,1.375,0.000>,

 <1.300,1.375,0.000>,
 <1.300,0.625,0.000>,
 <1.200,0.625,0.000>,

 <1.200,0.825,0.100>,
 <0.600,0.825,0.100>,
 <0.600,0.625,0.000>
}
// invoking the object macro
union{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_O(z1,z2,d_rad,offs,cham,letter_dimensions)}
     }
#end 
//*************************************************************************************************
// Rho = P
//*************************************************************************************************
// Sigma
//*************************************************************************************************
#macro CL_rlp_Sigma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <0.700,1.000,0.000>,

 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 <1.600,2.000,0.000>,

 <1.700,1.700,0.000>,
 <1.600,1.660,0.000>,    // Upper serif inner
 <1.500,1.900,0.100>,

 <0.420,1.900,0.000>,    // Upper corner
 <0.979,1.198,0.000>,    // mid point
 <0.320,0.350,0.000>,    // Lower corner

 <1.650,0.350,0.150>,    // Lower serif inner
 <1.700,0.650,0.000>,
 <1.800,0.630,0.000>,

 <1.700,0.000,0.000>
        }
// invoking the object macro
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Big Sigma
//*************************************************************************************************
#macro CL_rlp_bigSigma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.7; // Width 
#local letter_dimensions[1] = 2.5; // Height
#local letter_dimensions[2] = 2.5; // Superscript height
#local letter_dimensions[3] = 0.5; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,-.500,0.000>,
 <0.000,-.400,0.000>,
 <1.050,1.000,0.000>,

 <0.000,2.400,0.000>,
 <0.000,2.500,0.000>,
 <2.500,2.500,0.000>,

 <2.600,2.100,0.000>,
 <2.480,2.060,0.000>,    // Upper serif inner
 <2.400,2.350,0.150>,

 <0.490,2.350,0.000>,    // Upper corner
 <1.390,1.180,0.000>,    // mid point
 <0.380,-.150,0.000>,    // Lower corner

 <2.400,-.150,0.220>,    // Lower serif inner
 <2.580,0.330,0.000>,
 <2.700,0.300,0.000>,

 <2.550,-.500,0.000>
        }
// invoking the object macro
//  cylinder{<-0.002, -0.5 ,0> <-0.002,  2.5 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.702, -0.5 ,0> < 2.702,  2.5 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.502,0> < 2.7  ,-0.502,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.502,0> < 2.7  , 2.502,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Very big Sigma
//*************************************************************************************************
#macro CL_rlp_BigSigma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 3.6; // Width 
#local letter_dimensions[1] = 3.0; // Height
#local letter_dimensions[2] = 3.0; // Superscript height
#local letter_dimensions[3] = 1.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,-1.00,0.000>,
 <0.000,-0.90,0.000>,
 <1.400,1.000,0.000>,

 <0.000,2.900,0.000>,
 <0.000,3.000,0.000>,
 <3.375,3.000,0.000>,

 <3.500,2.500,0.000>,
 <3.370,2.440,0.000>,    // Upper serif inner
 <3.170,2.850,0.100>,

 <0.500,2.850,0.000>,    // Upper corner
 <1.740,1.198,0.000>,    // mid point
 <0.380,-.650,0.000>,    // Lower corner

 <3.200,-.650,0.150>,    // Lower serif inner
 <3.470,-.140,0.000>,
 <3.600,-.180,0.000>,

 <3.400,-1.00,0.000>
        }
// invoking the object macro
//  cylinder{<-0.002, -1.0 ,0> <-0.002,  3.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 3.602, -0.5 ,0> < 3.602,  3.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-1.002,0> < 3.6  ,-1.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 3.002,0> < 3.6  , 3.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Tau = T  
//*************************************************************************************************
// Upsilon
//*************************************************************************************************
#macro CL_rlp_Upsilon(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[23]{
 <0.525,0.000,0.000>,
 <0.525,0.100,0.000>,
 <0.725,0.100,0.100>,

 <0.725,1.100,0.300>,
 <0.500,1.650,0.200>,
 <0.100,1.650,0.200>,

 <0.100,1.400,0.000>,
 <0.000,1.400,0.000>,
 <0.000,2.000,0.300>,

 <0.500,2.000,0.200>, 
 <0.800,1.500,0.400>,
 <0.900,1.100,0.000>,
 
 <1.000,1.500,0.400>,
 <1.300,2.000,0.200>,
 <1.800,2.000,0.300>,

 <1.800,1.400,0.000>,
 <1.700,1.400,0.000>,
 <1.700,1.650,0.200>,

 <1.300,1.650,0.200>,
 <1.075,1.100,0.300>,      
 <1.075,0.100,0.100>,      

 <1.275,0.100,0.000>,
 <1.275,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// No V
//*************************************************************************************************
// Omega
//*************************************************************************************************
#macro CL_rlp_Omega(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 <0.000,0.000,0.000>,
 <0.000,0.550,0.000>,
 <0.100,0.550,0.000>,

 <0.100,0.350,0.100>,
 <0.650,0.350,0.000>,
 <0.650,0.450,0.000>,

 <0.100,0.600,0.600>,
 <0.100,2.000,0.900>,
 <1.900,2.000,0.900>,

 <1.900,0.600,0.600>,
 <1.350,0.450,0.000>,
 <1.350,0.350,0.000>,

 <1.900,0.350,0.100>,
 <1.900,0.550,0.000>,
 <2.000,0.550,0.000>,

 <2.000,0.000,0.000>,
 <1.150,0.000,0.000>,
 <1.150,0.100,0.000>,

 <1.250,0.550,0.000>, 
 <1.550,0.700,0.900>,      // Inner
 <1.550,1.900,0.900>,      // Inner

 <0.450,1.900,0.900>,
 <0.450,0.700,0.900>,
 <0.750,0.550,0.000>,
 
 <0.850,0.100,0.000>,
 <0.850,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Xi
//*************************************************************************************************
#macro CL_rlp_Xi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.000,0.000>,
 <0.000,0.600,0.000>,
 <0.100,0.600,0.000>,

 <0.100,0.350,0.150>,
 <1.700,0.350,0.150>,
 <1.700,0.600,0.000>,

 <1.800,0.600,0.000>,
 <1.800,0.000,0.000>,
         }
#local pts[1] =
array[12]{
 <0.300,0.625,0.000>,
 <0.300,1.375,0.000>,
 <0.400,1.375,0.000>,

 <0.400,1.175,0.100>,
 <1.400,1.175,0.100>,
 <1.400,1.375,0.000>,

 <1.500,1.375,0.000>,
 <1.500,0.625,0.000>,
 <1.400,0.625,0.000>,

 <1.400,0.825,0.100>,
 <0.400,0.825,0.100>,
 <0.400,0.625,0.000>
         }
#local pts[2] =
array[8]{
 <0.150,2.000,0.000>,
 <1.650,2.000,0.000>,
 <1.700,1.470,0.000>,

 <1.600,1.470,0.000>,
 <1.575,1.650,0.100>,
 <0.225,1.650,0.100>,

 <0.200,1.450,0.000>,
 <0.100,1.450,0.000>
       }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Psi
//*************************************************************************************************
#macro CL_rlp_Psi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.625,0.100,0.000>,
 <0.825,0.100,0.100>,
 <0.825,0.900,0.000>,

 <0.200,0.900,0.600>,
 <0.200,1.900,0.150>,
 <0.000,1.900,0.000>, 
 
 <0.000,2.000,0.000>,
 <0.550,2.000,0.500>,
 <0.550,1.000,0.300>,
 
 <0.825,1.000,0.000>,
 <0.825,1.900,0.100>,
 <0.625,1.900,0.000>,
 
 <0.625,2.000,0.000>,
 <1.375,2.000,0.000>,
 <1.375,1.900,0.000>,

 <1.175,1.900,0.100>,
 <1.175,1.000,0.000>,
 <1.450,1.000,0.300>,

 <1.450,2.000,0.500>,
 <2.000,2.000,0.000>, 
 <2.000,1.900,0.000>,
 
 <1.800,1.900,0.150>,
 <1.800,0.900,0.600>,
 <1.175,0.900,0.000>,
 
 <1.175,0.100,0.100>,
 <1.375,0.100,0.000>, 
 <1.375,0.000,0.000>,
 
 <0.625,0.000,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Zeta = Z   
//*************************************************************************************************
//*************************************************************************************************
// Greek small letters
//*************************************************************************************************
// Greek alpha
//*************************************************************************************************
#macro CL_rlp_alpha(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <1.680,0.180,0.050>,     // End of tail  050
 <1.550,0.000,0.150>,     // 150
 <1.100,0.000,0.300>,     // 200

 <1.100,0.280,0.000>,     //
 <0.800,0.000,0.250>,     // 400
 <0.000,0.000,0.500>,     // 400
 
 <0.000,0.930,0.400>,     // 600
 <0.479,1.400,0.300>,     // 250
 <1.300,1.400,0.600>,     // 200
 
 <1.300,0.630,0.000>,
 <1.470,0.870,0.300>,
 <1.630,1.330,0.050>, 

 <1.720,1.300,0.050>, 
 <1.560,0.830,0.300>,
 <1.300,0.450,0.000>,    // Stays zero
 
 <1.310,0.100,0.150>,    // 170
 <1.500,0.100,0.100>,    // 150
 <1.610,0.240,0.050>     // End of tail 050
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[6]{
 <1.100,0.420,0.000>,     // 150
 <1.100,1.300,0.400>,
 <0.540,1.300,0.200>,     // 200

 <0.250,0.850,0.300>,     // 500
 <0.130,0.100,0.400>,     // 350
 <0.750,0.100,0.200>      // 200
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.702,  0   ,0> < 1.702,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.7  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.7  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.17,.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.405,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Greek beta
//*************************************************************************************************
#macro CL_rlp_beta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <-.010,-.588,0.050>,
 <0.633,2.000,0.600>,   // 600
 <1.600,2.000,0.350>,   // 350
 
 <1.600,1.368,0.300>,   // 300
 <1.218,1.132,0.000>,             
 <1.448,0.893,0.300>,    // 300

 <1.448,0.000,0.700>,   //  700           
 <0.450,0.000,0.350>,   //  350
 <0.300,0.228,0.000>,   // 

 <0.090,-.612,0.050>   // 
}
#local pts[1] =
array[13]{
 <0.713,1.900,0.550>,   
 <0.340,0.400,0.200>,
 <0.500,0.100,0.300>,
 
 <1.248,0.100,0.500>,
 <1.248,0.950,0.200>,
 <1.130,1.070,0.000>,
 
 <0.900,0.900,0.100>,
 <0.600,0.900,0.170>,
 <0.650,1.300,0.190>,
 
 <1.000,1.350,0.150>,
 <1.140,1.210,0.000>,
 <1.400,1.380,0.400>, 

 <1.400,1.900,0.200>,
         } 
#local pts[2] =
array[5]{
 <0.700,1.000,0.100>,
 <0.860,1.000,0.100>,   //
 <1.050,1.145,0.000>,   //
 
 <0.950,1.250,0.100>,   //
 <0.750,1.200,0.100>    //
         } 
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.602, -0.6 ,0> < 1.602,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.60  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.60  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.36,0.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek chi
//*************************************************************************************************
#macro CL_rlp_chi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.100,1.200,0.050>,
 <0.000,1.200,0.050>,
 <0.000,1.400,0.150>,

 <0.370,1.400,0.200>,  
 <0.896,0.516,0.000>,
 <1.650,1.270,0.050>,
 
 <1.720,1.200,0.050>,
 <0.950,0.430,0.000>,
 <1.510,-.500,0.050>,
 
 <1.600,-.500,0.050>, 
 <1.600,-.400,0.050>,
 <1.700,-.400,0.050>,

 <1.700,-.600,0.150>,
 <1.330,-.600,0.200>,  
 <0.804,0.284,0.000>,

 <0.050,-.470,0.500>,
 <-.020,-.400,0.500>,
 <0.749,0.368,0.000>,
 
 <0.190,1.300,0.050>,    
 <0.100,1.300,0.050> 
}
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.702, -0.6 ,0> < 1.702,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.70  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.70  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-45> translate <0.85,.4,0>} 
//  box{<-0.100,-1.4,-0.101> < 0.100,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,31> translate <0.85,0.4,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek delta
//*************************************************************************************************
#macro CL_rlp_delta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.28; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <-.300,0.000,0.700>,     // 
 <0.000,1.050,0.600>,     // 
 <0.606,1.240,0.000>,     // Always zero

 <0.370,1.760,0.300>,     //
 <0.732,2.070,0.300>,     // 300
 <1.180,1.800,0.120>,     // 
 
 <1.046,1.620,0.120>,     // 
 <0.730,1.930,0.200>,     // 
 <0.530,1.750,0.200>,     // 
 
 <1.130,0.700,0.600>,     
 <0.650,0.000,0.300>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[5]{
 <-.050,0.100,0.400>,     // 
 <0.550,0.100,0.200>,
 <0.800,0.700,0.350>,     // 

 <0.650,1.150,0.000>,     // Always zero
 <0.200,1.000,0.500>      // 
}

// invoking the object macro
object{
//  cylinder{<-0.152,  0   ,0> <-0.152,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.132,  0   ,0> < 1.132,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.13  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.13  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.17,.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.405,.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
  translate <0.15,0,0>
     }
#end  
//*************************************************************************************************
// Greek epsilon
//*************************************************************************************************
#macro CL_rlp_epsilon(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.1; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <1.100,1.400,0.050>,
 <1.100,1.300,0.050>,
 <0.400,1.300,0.400>,

 <0.320,0.850,0.000>,    
 <0.868,0.850,0.050>,
 <0.868,0.750,0.050>, 
 
 <0.300,0.750,0.000>,
 <0.210,0.100,0.400>,
 <0.730,0.100,0.150>,

 <1.000,0.300,0.050>,
 <1.050,0.220,0.050>,  //   
 <0.762,0.000,0.200>, 

 <0.000,0.000,0.600>,
 <0.000,1.400,0.800>
}
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.372, -0.6 ,0> < 1.372,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.50  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.100,-1.4,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2,.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek phi
//*************************************************************************************************
#macro CL_rlp_phi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.46; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <-.050,-1.29,0.050>,
 <-.050,-.700,0.000>, 
 <-.700,-.700,0.650>,

 <-.700,0.700,0.650>,  
 <-.050,0.700,0.000>,
 <-.050,1.310,0.050>, 
 
 <0.050,1.290,0.050>,
 <0.050,0.700,0.000>,
 <0.700,0.700,0.650>,  

 <0.700,-.700,0.650>,
 <0.050,-.700,0.000>, 
 <0.050,-1.31,0.050> 
 }
#local pts[1] =
array[4]{   
 <-.050,-.600,0.000>,
 <-.050,0.600,0.000>,
 <-.500,0.600,0.450>,
   
 <-.500,-.600,0.450>
        }
#local pts[2] =
array[4]{  
 <0.050,-.600,0.000>, 
 <0.500,-.600,0.450>,
 <0.500,0.600,0.450>,

 <0.050,0.600,0.000>  
        }
// invoking the object macro
//  cylinder{< -.002, -0.6 ,0> < -.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.462, -0.6 ,0> < 1.462,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< -.002,-0.602,0> < 1.400  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< -.002, 2.002,0> < 1.400  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-0.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.08,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.09,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       matrix <1,0,0,0.25,1,0,0,0,1,0.73,0.7,0>} // translate <0.73,0.7,0>
//
#end
//*************************************************************************************************
// Greek gamma
//*************************************************************************************************
#macro CL_rlp_gamma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.69; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <-.010,0.850,0.050>,
 <0.236,1.400,0.300>,
 <0.822,1.400,0.300>, 
 
 <1.020,1.000,0.200>,
 <1.083,0.390,0.000>,   // Upper nick 
 <1.250,0.780,0.500>,
  
 <1.630,1.280,0.050>,
 <1.710,1.210,0.050>,
 <1.330,0.720,0.500>,

 <1.110,0.190,0.000>,   // Neck right
 <1.150,-.247,0.200>,
 <1.100,-.600,0.200>,  //  Base

 <0.760,-.600,0.220>,  //  Base
 <0.830,-.202,0.200>,
 <1.000,0.200,0.000>,  // Neck left

 <0.900,1.200,0.400>,  // 0.400
 <0.300,1.200,0.200>,
 <0.070,0.810,0.050> 
}
#local pts[1] =
array[5]{
 <1.000,-.500,0.050>,
 <1.050,-.240,0.170>,
 <1.025,-.000,0.000>, 
 
 <0.930,-.230,0.150>,
 <0.880,-.500,0.050>
         } 
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.692, -0.6 ,0> < 1.692,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.50  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,6> translate <1.0,.7,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-23.5> translate <1.27,.7,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,5> translate <0.8,.7,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-23> translate <1.5,0.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek eta
//*************************************************************************************************
#macro CL_rlp_eta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.37; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.580,1.047,0.300>,
 <0.312,-.025,0.100>,
 <0.118,0.023,0.100>,

 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.521,1.400,0.170>,
 
 <0.590,1.190,0.000>,  // Upper nick  
 <0.800,1.400,0.200>, 
 <1.478,1.400,0.500>,
 
 <0.970,-.624,0.100>,   // Bottom
 <0.780,-.577,0.100>,   // Bottom
 
 <1.245,1.300,0.400>,
 <0.850,1.300,0.250> 
}
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.372, -0.6 ,0> < 1.372,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.50  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.100,-1.4,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//**************************************************************************************
// Greek iota
//**************************************************************************************
#macro CL_rlp_iota(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.82; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.273,1.424,0.100>,    // Top
 <0.467,1.376,0.100>,    // Top
 <0.148,0.100,0.200>,

 <0.627,0.100,0.300>, 
 <0.733,0.524,0.050>,    // Lower serif
 <0.830,0.500,0.050>,    // Lower serif

 <0.710,0.000,0.350>,
 <-.085,0.000,0.400>,
 
}
// invoking the object macro
//  cylinder{< 0.193,  0   ,0> < 0.193,  1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 0.822,  0   ,0> < 0.822,  1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.82  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 0.82  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.8,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.195,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek kappa
//*************************************************************************************************
#macro CL_rlp_kappa(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.49; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[23]{
 <0.375,0.800,0.000>,   // Under corner
 <0.172,-.025,0.100>,
 <-.022,0.023,0.100>,

 <0.350,1.500,0.100>,  // Left upper
 <0.550,1.450,0.100>,  // Right upper
 <0.430,1.000,0.000>,  // Upper nick

 <0.950,1.400,0.200>,   //0.200
 <1.628,1.400,0.600>,
 <1.400,0.850,0.200>,  // Start of bobble

 <1.150,0.850,0.250>, 
 <1.150,1.150,0.250>,                  
 <1.360,1.150,0.000>,  // End of bobble. Stays zero radius                  

 <1.295,1.300,0.250>,
 <1.000,1.300,0.250>, 
 <0.500,0.913,0.000>,   // End of twiddle

 <1.188,0.800,0.400>,  //0.400  Top of h
 <1.013,0.100,0.200>,
 <1.292,0.100,0.200>, 

 <1.398,0.524,0.050>,
 <1.495,0.500,0.050>,
 <1.375,0.000,0.250>,   // Bottom right

 <0.780,0.000,0.400>,   // Bottom right
 <0.955,0.700,0.300>,   //0.400 Inner top
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.492,  0   ,0> < 1.492,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.50  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.25,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.0,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.06,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek lambda
//*************************************************************************************************
#macro CL_rlp_lambda(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.5; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.250,1.900,0.050>,
 <0.250,2.000,0.050>,
 <0.605,2.000,0.250>, 

 <1.355,0.100,0.100>,
 <1.500,0.100,0.050>,
 <1.500,0.000,0.050>,

 <1.180,0.000,0.200>,    // 
 <0.860,0.800,0.000>,
 <0.130,-.040,0.100>,    // Bottom leg
 
 <-.040,0.090,0.100>,    // Bottom leg
 <0.810,0.910,0.000>,
 <0.430,1.900,0.100>,    // 
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.502,  0   ,0> < 1.502,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.50  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.50  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-0.8,-0.101> < 0.100,1.5,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,21.5> translate <1.01,.7,0>} 
//  box{<-0.100,-.4,-0.101> < 0.100,1.0,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-43> translate <0.3,0.30,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek mu
//*************************************************************************************************
#macro CL_rlp_mu(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.5; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[19]{
 <0.580,1.047,0.300>,
 <0.312,-.025,0.100>,
 <0.118,0.023,0.100>,

 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.521,1.400,0.170>,
 
 <0.590,1.190,0.000>,  // Upper nick  
 <0.800,1.400,0.150>,  // 0.200
 <1.100,1.400,0.150>,
 
 <1.245,1.300,0.000>,
 <1.426,2.024,0.100>, 
 <1.624,1.976,0.100>,  // Lower drop
 
 <1.122,-.024,0.100>,
 <0.926,0.024,0.100>,
 <1.245,1.300,0.400>,
 
 <0.850,1.300,0.250> 
}
// invoking the object macro
//  cylinder{<-0.102, -0.6 ,0> <-0.102,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.502, -0.6 ,0> < 1.502,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.50  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.4,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.3,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.11,.7,0>} 
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  rotate <0,0,180> translate <1.5,1.4,0>
      }
//
#end
//*************************************************************************************************
// Greek nu
//*************************************************************************************************
#macro CL_rlp_nu(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.5; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.050>,
 <0.000,0.100,0.050>,
 <0.285,1.250,0.100>, 

 <0.050,1.250,0.050>,
 <0.050,1.350,0.050>,
 <0.300,1.400,0.100>,

 <0.510,1.400,0.050>,    // 0.050
 <0.510,1.300,0.100>,    // 0.100
 <0.222,0.160,0.000>,    // Left nick

 <0.990,0.530,0.700>,    // Inner bend
 <1.350,1.424,0.100>,    // Right upper
 <1.540,1.350,0.100>,    // Right upper

 <1.070,0.455,0.700>,    // Outer bend
 <0.100,0.000,0.050> 
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.502,  0   ,0> < 1.502,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.50  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.9,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.253,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.0,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-22   > translate <1.49,1.5,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek omicron is Math o
//*************************************************************************************************
// Greek pi
//*************************************************************************************************
#macro CL_rlp_pi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.67;// Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <-.024,0.980,0.050>,
 <0.280,1.400,0.300>,
 <1.670,1.400,0.100>,

 <1.670,1.200,0.100>,
 <1.170,1.200,0.000>,
 <1.040,0.600,0.400>,
 
 <1.260,0.032,0.100>,
 <1.060,-.040,0.100>,
 <0.888,0.600,0.500>,
 
 <1.070,1.200,0.000>,
 <0.740,1.200,0.000>,
 <0.375,-.024,0.100>,
 
 <0.170,0.050,0.100>,
 <0.640,1.200,0.000>,
 <0.274,1.200,0.200>,
 
 <0.048,0.930,0.050>  
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672,  0   ,0> < 1.672,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.67  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.67  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,15> translate <0.99,.6,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-21.5> translate <0.465,.5,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-35> translate <0,0.92,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greek theta
//*************************************************************************************************
#macro CL_rlp_theta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.32; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <-.300,-1.00,0.300>,
 <-.800,0.000,0.800>, 
 <-.300,1.000,0.300>,

 <0.300,1.000,0.300>,  
 <0.800,0.000,0.800>,
 <0.300,-1.00,0.300>
 }
#local pts[1] =
array[6]{   
 <-.400,0.050,0.000>,
 <0.400,0.050,0.000>,
 <0.400,0.400,0.350>,
   
 <0.200,0.900,0.200>,
 <-.200,0.900,0.200>,
 <-.400,0.400,0.350> 
        }
#local pts[2] =
array[6]{  
 <0.400,-.050,0.000>,
 <-.400,-.050,0.000>,   
 <-.400,-.400,0.350> 
 
 <-.200,-.900,0.200>,
 <0.200,-.900,0.200>,
 <0.400,-.400,0.350>,  
        }
// invoking the object macro
//  cylinder{< -.002, -0.0 ,0> < -.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.322, -0.0 ,0> < 1.322,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< -.002,-0.002,0> < 1.300  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< -.002, 2.002,0> < 1.300  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-0.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.08,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.09,.7,0>} 
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
  matrix <1,0,0,0.25,1,0,0,0,1,0.66,1,0> // translate <0.66,1,0>
     }
//
#end
//*************************************************************************************************
// Greek rho
//*************************************************************************************************
#macro CL_rlp_rho(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.3; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[7]{
 <-.300,-.600,0.100>,
 <0.200,1.400,0.600>, 
 <1.450,1.400,0.700>,

 <1.100,0.000,0.600>,  
 <0.300,0.000,0.200>,
 <0.100,0.150,0.000>,
 
 <-.100,-.630,0.100>
}
#local pts[1] =
array[4]{   
 <0.050,0.100,0.600>   
 <0.850,0.100,0.500>,   
 <1.250,1.300,0.600>,  

 <0.440,1.300,0.500>  
        }
// invoking the object macro
//  cylinder{< -.202, -0.6 ,0> < -.202,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.300, -0.6 ,0> < 1.300,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< -.202,-0.602,0> < 1.300  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< -.202, 1.402,0> < 1.300  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.3,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.13,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.17,.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek sigma
//*************************************************************************************************
#macro CL_rlp_sigma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.65; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[7]{
 <-.150,0.000,0.700>,
 <0.200,1.400,0.600>, 
 <1.650,1.400,0.100>, 
 
 <1.650,1.200,0.100>,
 <1.100,1.200,0.000>,
 <1.351,1.050,0.300>,
 
 <1.100,0.000,0.600>
}
#local pts[1] =
array[4]{   
 <0.050,0.100,0.600>   
 <0.850,0.100,0.500>,   
 <1.225,1.200,0.600>,  

 <0.415,1.200,0.500>   
        }
// invoking the object macro
//  cylinder{< -.002,  0   ,0> < -.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.650,  0   ,0> < 1.650,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.002,-0.002,0> < 1.650  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.002, 1.402,0> < 1.650  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.13,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.17,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek tau
//*************************************************************************************************
#macro CL_rlp_tau(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.5;// Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <-.024,0.980,0.050>,
 <0.280,1.400,0.300>,
 <1.500,1.400,0.100>,

 <1.500,1.200,0.100>,
 <0.870,1.200,0.000>,

 <0.625,-.030,0.100>,    // Base
 <0.420,0.020,0.100>,    // Base
 <0.770,1.200,0.000>,

 <0.274,1.200,0.200>,
 <0.048,0.930,0.050>  
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.502,  0   ,0> < 1.502,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.50  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.50  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14> translate <0.65,.5,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-35> translate <0,0.92,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//*************************************************************************************************
// Greek upsilon is math v, no greek v
//*************************************************************************************************
// Greek omega
//*************************************************************************************************
#macro CL_rlp_omega(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.93; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[23]{
 <1.000,0.700,0.100>,
 <1.083,0.915,0.100>     // 100
 <1.280,0.860,0.100>,    // 100   
 
 <1.260,0.675,0.100>,
 <1.138,0.400,0.000>,    // Left inner corner  400
 <1.300,0.200,0.400>,

 <1.735,0.200,0.350>,    // 350
 <2.035,0.715,0.300>,    // Inner mid curve  300
 <1.794,1.375,0.150>,    // 150

 <2.045,1.425,0.150>,    // 150
 <2.145,0.700,0.400>,    // Outer mid curve         400
 <1.745,0.000,0.400>,    // Right botton corner    400

 <1.205,0.000,0.200>,    // Left bottom corner     200
 <1.050,0.280,0.000>,   //  Lower nick - radius stays at zero
 <0.855,0.000,0.200>,    // 200

 <0.300,0.000,0.300>,    // 500 
 <0.100,0.715,0.400>,
 <0.537,1.422,0.050>,    // 120

 <0.622,1.368,0.050>,    // 300 
 <0.210,0.705,0.500>,
 <0.348,0.200,0.350>,    // 300

 <0.800,0.200,0.350>,    // 100
 <0.990,0.420,0.000>,    // 200              
         }
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.932  , 0   ,0> < 1.932  , 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,-0.002  ,0> < 1.93  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 1.402  ,0> < 1.93  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,0,-0.101> < 0.100,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.96,0,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
object{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
  translate <-0.175,0,0> 
      }
//
#end
//*************************************************************************************************
// Greek xi
//*************************************************************************************************
#macro CL_rlp_xi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.25; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[31]{
 <0.430,-.490,0.050>,
 <0.484,-.400,0.050>,
 <0.780,-.548,0.200>, 
 
 <0.850,-.260,0.200>,   //             200
 <-.530,0.440,1.000>,    // 850
 <0.400,0.910,0.000>,   // Left nick   000

 <0.121,1.050,0.300>,   // Left top    300
 <0.304,1.606,0.300>,   // Left bottom  - upper  300
 <0.604,1.760,0.000>,   // Left nick    - upper   000

 <0.508,1.800,0.120>,   // Left top     - upper 
 <0.508,2.000,0.050>,
 <0.608,2.000,0.050>,

 <0.608,1.870,0.050>,   // Loop top
 <0.715,1.815,0.000>,   // Loop upper nick
 <0.945,1.935,0.150>,   // Loop upper
 
 <1.200,1.878,0.100>,   // Loop right
 <1.200,1.660,0.100>,   // Loop right
 <0.978,1.570,0.150>,   // Loop lower
 
 <0.707,1.700,0.000>,   // Loop lower nick
 <0.424,1.547,0.400>,   // Loop bottom   400
 <0.404,1.020,0.100>,   // Loop top

 <0.511,0.965,0.000>,   // Loop upper nick
 <0.741,1.085,0.150>,   // Loop upper
 <0.996,1.028,0.100>,   // Loop right

 <0.996,0.810,0.100>,   // Loop right
 <0.774,0.720,0.150>,   // Loop lower
 <0.503,0.850,0.000>,   // Loop lower nick

 <-.200,0.500,0.800>,    // 650
 <1.042,-.136,0.400>,  
 <0.869,-.600,0.200>,

 <0.611,-.600,0.200>
}
#local pts[1] =
array[5]{
 <0.620,0.910,0.000>,
 <0.770,0.830,0.070>,
 <0.890,0.870,0.050>, 
 
 <0.890,0.950,0.050>,
 <0.750,0.970,0.070>
         } 
#local pts[2] =
array[5]{
 <0.824,1.760,0.000>,
 <0.974,1.680,0.070>,   //070
 <1.094,1.720,0.050>,   //050
 
 <1.094,1.800,0.050>,   //050
 <0.954,1.820,0.070>    //070
         } 
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.252, -0.6 ,0> < 1.252,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.20  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.20  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.0,1.865,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-63> translate <0.8,1.80,0>} 
//  box{<-0.100,-1.4,-0.101> < 0.100,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.35,.03,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.5,.915,0>} 
//  box{<-0.050,-2.0,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-63> translate <0.8,1.06,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0,0.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.10,1,0,0,0,1,-0.13,0,0>}
//
#end
//*************************************************************************************************
// Greek psi
//*************************************************************************************************
#macro CL_rlp_psi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[22]{
 <1.540,1.425,0.150>,    // Top right
 <1.640,0.700,0.400>,    // Outer mid curve
 <1.240,0.000,0.400>,    // Right botton corner

 <0.755,0.000,0.000>,
 <0.604,-.616,0.050>,
 <0.505,-.588,0.050>,

 <0.654,0.000,0.000>,   
 <0.110,0.000,0.530>,    // Left bottom corner
 <0.437,1.300,0.120>,    

 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 <-.005,0.919,0.050>,

 <0.125,1.400,0.190>,
 <0.668,1.400,0.300>,
 <0.343,0.100,0.300>,     // Left inner corner

 <0.679,0.100,0.000>,
 <1.156,2.016,0.050>, 
 <1.256,1.992,0.050>,
 
 <0.780,0.100,0.000>
 <1.180,0.100,0.350>,
 <1.530,0.715,0.300>,                  

 <1.290,1.375,0.150> 
}
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002, 2.0  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.600, -0.6 ,0> < 1.600, 2.0  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, -0.6 ,0> < 1.600,-0.6  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 2.002,0> < 1.600, 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.050,-1.3,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.88,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Greek zeta
//*************************************************************************************************
#macro CL_rlp_zeta(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.2; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 <0.430,-.490,0.050>,
 <0.484,-.400,0.050>,
 <0.780,-.548,0.200>, 
 
 <0.850,-.260,0.200>,
 <0.000,0.170,0.300>,   // 200 
 <0.000,0.800,0.300>,
 
 <0.254,1.581,0.500>,   // Left bottom  - upper  300
 <0.604,1.760,0.000>,   // Left nick    - upper
 <0.508,1.800,0.120>,   // Left top     - upper 

 <0.508,2.000,0.050>,
 <0.608,2.000,0.050>,
 <0.608,1.870,0.050>,   // Loop top

 <0.715,1.815,0.000>,   // Loop upper nick
 <0.945,1.935,0.150>,   // Loop upper
 <1.200,1.878,0.100>,   // Loop right

 <1.200,1.660,0.100>,   // Loop right
 <0.978,1.570,0.150>,   // Loop lower
 <0.707,1.700,0.000>,   // Loop lower nick

 <0.344,1.507,0.400>,   // Loop bottom        400
 <0.190,0.800,0.300>,
 <0.190,0.300,0.300>,   // 200

 <1.042,-.136,0.400>,  
 <0.869,-.600,0.200>,
 <0.611,-.600,0.200>
}
#local pts[1] =
array[5]{
 <0.824,1.760,0.000>,
 <0.974,1.680,0.070>,   //070
 <1.094,1.720,0.050>,   //050
 
 <1.094,1.800,0.050>,   //050
 <0.954,1.820,0.070>    //070
         } 
// invoking the object macro
//  cylinder{<-0.002, -0.6 ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.202, -0.6 ,0> < 1.202,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.20  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.20  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.5,1.865,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-63> translate <0.8,1.80,0>} 
//  box{<-0.100,-1.4,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.5,.03,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,63> translate <0.5,.915,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-63> translate <0.8,1.06,0>} 
//  box{<-0.050,-1.4,-0.101> < 0.050,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-23> translate <1.5,0.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Mathematical capital letters *******************************************************************
//*************************************************************************************************
// Maths A
//*************************************************************************************************
#macro CL_rlp_mathA(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                         
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.100,0.050>
 <0.200,0.100,0.100>,
 <0.850,2.000,0.050>,

 <0.950,2.000,0.050>,
 <1.600,0.100,0.100>,
 <1.800,0.100,0.050>,

 <1.800,0.000,0.050>,
 <1.130,0.000,0.050>,
 <1.130,0.100,0.050>,

 <1.330,0.100,0.100>,   // 100
 <1.060,0.900,0.000>,   //
 <0.585,0.900,0.000>,   

 <0.310,0.100,0.100>,
 <0.500,0.100,0.050>,
 <0.500,0.000,0.050>,

 <0.000,0.000,0.050> 
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[3]{
 <0.620,1.000,0.000>,    
 <1.025,1.000,0.000>,   //
 <0.825,1.590,0.000>    //
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.802, 0 ,0> < 1.802,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,18.9> translate <1.16,1,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,0,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths B
//*************************************************************************************************
#macro CL_rlp_mathB(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.67; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <1.300,2.000,1.1/2>,

 <1.300,0.900,1.1/2>,
 <0.450,0.900,0.000>,
 <0.450,0.100,0.100>,

 <0.650,0.100,0.050>,
 <0.650,0.000,0.050>,
 <0.000,0.000,0.050>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.450,1.000,0.000>,
 <1.050,1.000,0.775/2>,
 <1.050,1.900,0.775/2>,
 <0.450,1.900,0.100>
}
#local pts1 = array[1];
#local pts1[0] =
array[8]{
 <0.450,0.100,0.000>,
 <1.250,0.100,0.400>,
 <1.250,0.900,0.400>,

 <0.450,0.900,0.000>,
 <0.450,1.000,0.000>,
 <1.500,1.000,0.600>,

 <1.500,0.000,0.600>,
 <0.450,0.000,0.000>
}
// invoking the object macro
union{
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672, 0 ,0> < 1.672,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
     }
#end
//*************************************************************************************************
// Maths C
//*************************************************************************************************
#macro CL_rlp_mathC(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//                   
#local letter_dimensions[0] = 1.97; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <1.800,0.400,0.050>,    // End
 <1.100,-.450,1.100>,    // External curve - base
 <-.280,1.000,1.100>,    // External curve - left side

 <0.800,2.200,0.800>,    // External curve - top
 <1.700,1.800,0.100>,    // Upper serif
 <1.700,2.000,0.050>,    // Upper serif

 <1.800,2.000,0.050>,    // Upper serif
 <1.800,1.475,0.050>,    // Upper serif
 <1.700,1.475,0.050>,    // Upper serif

 <1.700,1.675,0.250>,    // Upper serif
 <0.800,2.000,0.800>,    // Internal curve - upper
 <0.150,1.000,0.800>,    // Internal curve - left

 <0.900,-.100,0.800>,    // Internal curve - bottom
 <1.730,0.450,0.050>     // End
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.972, 0 ,0> < 1.972,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.97  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.97  , 2.002,0> 0.002 pigment{Red}}
//  box{<0.098,0,-0.11> <0.33,2.0,-0.12> pigment{rgbt <1,0,0,0.8>}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.32,0,0>    
     }
//
#end
//*************************************************************************************************
// Maths D
//*************************************************************************************************
#macro CL_rlp_mathD(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.97; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <1.700,2.000,1.000>,

 <1.700,0.000,1.000>,
 <0.000,0.000,0.050>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.450,0.100,0.100>,
 <1.450,0.100,0.900>,
 <1.450,1.900,0.900>,
 <0.450,1.900,0.100>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.972, 0 ,0> < 1.972,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths E
//*************************************************************************************************
#macro CL_rlp_mathE(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.7; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <1.400,2.000,0.050>,

 <1.500,1.700,0.050>,
 <1.400,1.660,0.050>,
 <1.310,1.900,0.100>,

 <0.450,1.900,0.100>,
 <0.450,1.000,0.000>,
 <0.900,1.000,0.100>,

 <0.900,1.200,0.050>,
 <1.000,1.200,0.050>,
 <1.000,0.700,0.050>,

 <0.900,0.700,0.050>,
 <0.900,0.900,0.100>,
 <0.450,0.900,0.000>,

 <0.450,0.100,0.100>,
 <1.250,0.100,0.100>,
 <1.500,0.450,0.050>,

 <1.600,0.400,0.050>,
 <1.400,0.000,0.050>,
 <0.000,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.912, 0 ,0> < 1.912,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths F
//*************************************************************************************************
#macro CL_rlp_mathF(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.91; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[22]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <1.400,2.000,0.050>,

 <1.500,1.700,0.050>,
 <1.400,1.660,0.050>,
 <1.310,1.900,0.100>,

 <0.450,1.900,0.100>,
 <0.450,1.000,0.000>,
 <0.900,1.000,0.100>,

 <0.900,1.200,0.050>,
 <1.000,1.200,0.050>,
 <1.000,0.700,0.050>,

 <0.900,0.700,0.050>,
 <0.900,0.900,0.100>,
 <0.450,0.900,0.000>,

 <0.450,0.100,0.100>,
 <0.650,0.100,0.050>,
 <0.650,0.000,0.050>,

 <0.000,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.912, 0 ,0> < 1.912,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths G
//*************************************************************************************************
#macro CL_rlp_mathG(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.97; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{  

 <1.750,0.300,0.050>,    // Base of vertical - outer
 <1.100,-.450,1.100>,    // External curve - base
 <-.280,1.000,1.100>,    // External curve - left side

 <0.800,2.200,0.800>,    // External curve - top
 <1.700,1.800,0.100>,    // Upper serif
 <1.700,2.000,0.050>,    // Upper serif

 <1.800,2.000,0.050>,    // Upper serif
 <1.800,1.475,0.050>,    // Upper serif
 <1.700,1.475,0.050>,    // Upper serif

 <1.700,1.675,0.250>,    // Upper serif
 <0.800,2.000,0.800>,    // Internal curve - upper
 <0.150,1.000,0.800>,    // Internal curve - left

 <0.900,-.150,0.800>,    // Internal curve - bottom
 <1.500,0.300,0.000>,    // Base of vertical - inner
 <1.500,0.900,0.100>,
 
 <1.300,0.900,0.050>,
 <1.300,1.000,0.050>,
 <1.950,1.000,0.050>,

 <1.950,0.900,0.050>,
 <1.750,0.900,0.100>,
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.972, 0 ,0> < 1.972,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.97  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.97  , 2.002,0> 0.002 pigment{Red}}
//  box{<0.098,0,-0.11> <0.33,2.0,-0.12> pigment{rgbt <1,0,0,0.8>}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.32,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths H
//*************************************************************************************************
#macro CL_rlp_mathH(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.18; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <0.650,2.000,0.050>,

 <0.650,1.900,0.050>,
 <0.450,1.900,0.100>,
 <0.450,1.000,0.000>,

 <1.250,1.000,0.000>,
 <1.250,1.900,0.100>,
 <1.050,1.900,0.050>,

 <1.050,2.000,0.050>,
 <1.700,2.000,0.050>,
 <1.700,1.900,0.050>,

 <1.500,1.900,0.100>,
 <1.500,0.100,0.100>,
 <1.700,0.100,0.050>,

 <1.700,0.000,0.050>,
 <1.050,0.000,0.050>,
 <1.050,0.100,0.050>,

 <1.250,0.100,0.100>,
 <1.250,0.900,0.000>,
 <0.450,0.900,0.000>,

 <0.450,0.100,0.100>,
 <0.650,0.100,0.050>,
 <0.650,0.000,0.050>, 
 
 <0.000,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.182, 0 ,0> < 2.182,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
// 
#end
//*************************************************************************************************
// Maths I
//*************************************************************************************************
#macro CL_rlp_mathI(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.13; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <0.650,2.000,0.050>,

 <0.650,1.900,0.050>,
 <0.450,1.900,0.100>,
 <0.450,0.100,0.100>,

 <0.650,0.100,0.050>,
 <0.650,0.000,0.050>,
 <0.000,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.132, 0 ,0> < 1.132,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end 
//*************************************************************************************************
// Maths J
//*************************************************************************************************
#macro CL_rlp_mathJ(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.86; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <0.425,0.100,0.400>, 
 <0.675,0.200,0.400>,
 <0.675,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.050>,
 <0.000,1.700,0.050>,

 <0.100,2.000,0.050>,
 <1.500,2.000,0.050>, 
 <1.600,1.700,0.050>,
 
 <1.500,1.660,0.050>,
 <1.410,1.900,0.100>,
 <0.925,1.900,0.100>,
 
 <0.925,0.000,0.600>,
 <0.375,0.000,0.400>, 
 <0.110,0.200,0.600>,
 
 <-.020,0.700,0.300>,   // Roundy bit
 <0.370,0.700,0.300>,   // Roundy bit
 <0.240,0.300,0.400>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.872, 0 ,0> < 1.872,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.16,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths K
//*************************************************************************************************
#macro CL_rlp_mathK(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.93; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[27]{
 <0.100,0.100,0.050>,    // Bottom left serif
 <0.300,0.100,0.100>,
 <0.300,1.900,0.100>,

 <0.100,1.900,0.050>,
 <0.100,2.000,0.050>,
 <0.750,2.000,0.050>,

 <0.750,1.900,0.050>,
 <0.550,1.900,0.100>,    // End of top left serif
 <0.550,1.100,0.000>,    // Upper kink

 <1.250,1.900,0.100>,    // Upper right serif
 <1.050,1.900,0.050>,
 <1.050,2.000,0.050>,

 <1.550,2.000,0.050>,
 <1.550,1.900,0.050>,
 <1.380,1.900,0.100>,    // 100

 <0.695,1.115,0.000>,    // Outer kink
 <1.580,0.100,0.100>,    // 100
 <1.750,0.100,0.050>,

 <1.750,0.000,0.050>,
 <1.050,0.000,0.050>,
 <1.050,0.100,0.050>,

 <1.250,0.100,0.100>,
 <0.550,0.900,0.000>,   // Lower nick - no radius
 <0.550,0.100,0.100>,

 <0.750,0.100,0.050>,
 <0.750,0.000,0.050>, 
 <0.100,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.932, 0 ,0> < 1.932,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
//    box{<0,-0.2,-0.11> <0.25,1.8,-0.12> rotate <0,0,41.2> translate <1.34,0,0> pigment{rgbt <1,0,0,0.8>}}
//    box{<0, 1.0,-0.11> <0.1,2.8,-0.12> rotate <0,0,-41.2> translate <-0.415,0,0> pigment{rgbt <1,0,0,0.8>}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.11,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths L
//*************************************************************************************************
#macro CL_rlp_mathL(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.67; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <0.650,2.000,0.050>,

 <0.650,1.900,0.050>,
 <0.450,1.900,0.100>,
 <0.450,0.100,0.100>,
 
 <1.250,0.100,0.100>,
 <1.500,0.450,0.050>,
 <1.600,0.400,0.050>,
 
 <1.400,0.000,0.050>,
 <0.000,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672, 0 ,0> < 1.672,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths M
//*************************************************************************************************
#macro CL_rlp_mathM(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.58; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[25]{
 <0.000,0.100,0.050>,  // Lower left serif
 <0.200,0.100,0.100>,  // Lower left serif
 <0.200,1.900,0.100>,  // Upper left serif

 <0.000,1.900,0.050>,  // Upper left serif
 <0.000,2.000,0.050>,  // Upper left serif
 <0.408,2.000,0.050>,  // Upper left corner 

 <1.070,0.360,0.000>,  // Middle upper vertex 
 <1.690,2.000,0.050>,  // Upper  right corner 
 <2.100,2.000,0.050>,  // Upper right serif

 <2.100,1.900,0.050>,  // Upper right serif
 <1.900,1.900,0.100>,  // Upper right serif
 <1.900,0.100,0.100>,  // Lower right serif

 <2.100,0.100,0.050>,  // Lower right serif
 <2.100,0.000,0.050>,  // Lower right serif
 <1.450,0.000,0.050>,  // Lower right serif

 <1.450,0.100,0.050>,  // Lower right serif
 <1.650,0.100,0.100>,  // Lower right serif
 <1.650,1.600,0.000>,  // Upper right armpit

 <1.050,0.000,0.050>,  // Middle left lower vertex
 <0.950,0.000,0.050>,  // Middle right lower vertex
 <0.300,1.600,0.000>,  // Upper left armpit 
 
 <0.300,0.100,0.100>,  // Lower left serif
 <0.500,0.100,0.050>,  // Lower left serif
 <0.500,0.000,0.050>,  // Lower left serif
 
 <0.000,0.000,0.050>   // Lower left serif
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.582, 0 ,0> < 2.582,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{
//    box{<0,-0.2,-0.11> <0.25,2.2,-0.12> rotate <0,0,22> translate <0.95,0,0> pigment{rgbt <1,0,0,0.8>}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>    
      }
//
#end
//*************************************************************************************************
// Maths N
//*************************************************************************************************
#macro CL_rlp_mathN(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.28; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.100,0.050>,  // Lower left serif
 <0.200,0.100,0.100>,  // Lower left serif
 <0.200,1.900,0.100>,  // Upper left serif

 <0.000,1.900,0.050>,  // Upper left serif
 <0.000,2.000,0.050>,  // Upper left serif
 <0.395,2.000,0.050>,  // Upper left corner 

 <1.500,0.433,0.000>,  // Right lower armpit 
 <1.500,1.900,0.100>,  // Upper right serif
 <1.300,1.900,0.050>,  // Upper right serif

 <1.300,2.000,0.050>,  // Upper right serif
 <1.800,2.000,0.050>,  // Upper right serif
 <1.800,1.900,0.050>,  // Upper right serif

 <1.600,1.900,0.100>,  // Upper right serif
 <1.600,0.000,0.050>,  // Lower right corner
 <1.500,0.000,0.050>,  // Lower left  corner

 <0.300,1.700,0.000>,  // Upper left armpit 
 <0.300,0.100,0.100>,  // Lower left serif
 <0.500,0.100,0.050>,  // Lower left serif

 <0.500,0.000,0.050>,  // Lower left serif
 <0.000,0.000,0.050>   // Lower left serif
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.282, 0 ,0> < 2.282,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
      matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0> } 
//
#end
//*************************************************************************************************
// Maths O
//*************************************************************************************************
#macro CL_rlp_mathO(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,2.000,0.900>,
 <1.800,2.000,0.900>,
 <1.800,0.000,0.900>,

 <0.000,0.000,0.900>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.250,0.100,0.650>,
 <1.550,0.100,0.650>,
 <1.550,1.900,0.650>, 
 
 <0.250,1.900,0.650>
}

// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672, 0 ,0> < 1.672,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//  union{
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.2,0,0>}
//
#end
//*************************************************************************************************
// Maths P
//*************************************************************************************************
#macro CL_rlp_mathP(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.67; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,0.100,0.050>,
 <0.200,0.100,0.100>,
 <0.200,1.900,0.100>,

 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,
 <1.300,2.000,1.1/2>,

 <1.300,0.900,1.1/2>,
 <0.450,0.900,0.000>,
 <0.450,0.100,0.100>,

 <0.650,0.100,0.050>,
 <0.650,0.000,0.050>,
 <0.000,0.000,0.050>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.450,1.000,0.000>,
 <1.050,1.000,0.775/2>,
 <1.050,1.900,0.775/2>,
 <0.450,1.900,0.100>
}

// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672, 0 ,0> < 1.672,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>}
//
#end
//*************************************************************************************************
// Maths Q
//*************************************************************************************************
#macro CL_rlp_mathQ(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.9; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.5; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,2.000,0.900>,
 <1.800,2.000,0.900>,
 <1.800,0.000,0.900>,

 <0.000,0.000,0.900>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.250,0.100,0.650>,
 <1.550,0.100,0.650>,
 <1.550,1.900,0.650>,
 <0.250,1.900,0.650>
        }
//
#local pts1 = array[1];
// container, 1st subset: outer edge
#local pts1[0] =
array[4]{
 <1.000,0.100,0.000>,
 <1.300,0.170,0.000>,
 <1.570,-.350,0.000>,

 <1.500,-.400,0.000>
        }
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.902, 0 ,0> < 1.902,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
union{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
  matrix <1,0,0,0.25,1,0,0,0,1,-0.2,0,0>    
     }
//
#end
//*************************************************************************************************
// Maths R
//*************************************************************************************************
#macro CL_rlp_mathR(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.67; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.100,0.100,0.050>,
 <0.300,0.100,0.100>,
 <0.300,1.900,0.100>,

 <0.100,1.900,0.050>,
 <0.100,2.000,0.050>,
 <1.400,2.000,1.1/2>,

 <1.400,0.900,1.1/2>,  

 
 <0.850,0.900,0.000>,    // 
 <1.350,0.100,0.100>,
 <1.500,0.100,0.050>, 
 
 <1.500,0.000,0.050>,
 <0.900,0.000,0.050>,
 <0.900,0.100,0.050>, 

 <1.090,0.100,0.100>,
 <0.590,0.900,0.000>, 
 
 
 <0.550,0.900,0.000>,
 <0.550,0.100,0.100>,

 <0.750,0.100,0.050>,
 <0.750,0.000,0.050>,
 <0.100,0.000,0.050>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.550,1.000,0.000>,
 <1.150,1.000,0.450>,
 <1.150,1.900,0.450>, 
 
 <0.550,1.900,0.100>
        }
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.672, 0 ,0> < 1.672,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
       matrix <1,0,0,0.25,1,0,0,0,1,-0.11,0,0>}
//
#end
//*************************************************************************************************
// Maths S
//*************************************************************************************************
#macro CL_rlp_mathS(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.08; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.000,0.525,0.050>,    // Lower serif
 <0.100,0.525,0.050>,    // Lower serif
 <0.100,0.325,0.250>,    // Lower serif

 <0.850,0.000,0.600>,    // Internal curve - base        600
 <1.580,0.450,0.600>,    // Internal curve - right side  600
 <-.420,1.500,0.800>,    // External curve - left side   800

 <0.850,2.200,0.800>,    // External curve - top         800
 <1.500,1.800,0.100>,    // Upper serif
 <1.500,2.000,0.050>,    // Upper serif

 <1.600,2.000,0.050>,    // Upper serif
 <1.600,1.475,0.050>,    // Upper serif
 <1.500,1.475,0.050>,    // Upper serif

 <1.500,1.675,0.250>,    // Upper serif
 <0.850,2.000,0.600>,    // Internal curve - upper       600
 <0.050,1.540,0.600>,    // Internal curve - left        600

 <2.100,0.480,0.900>,    // External curve - right       800
 <0.850,-.200,0.800>,    // External curve - bottom      800
 <0.100,0.200,0.100>,    // Lower serif

 <0.100,0.000,0.050>,    // Lower serif
 <0.000,0.000,0.050>     // Lower serif
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.082, 0 ,0> < 2.082,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 2.08  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.08  , 2.002,0> 0.002 pigment{Red}}
//    box{<0,-0.2,-0.11> <0.25,2.5,-0.12> rotate <0,0,62.5> translate <1.8,0.35,0> pigment{rgbt <1,0,0,0.8>}}
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>}
//
#end   
//*************************************************************************************************
// Maths T
//*************************************************************************************************
#macro CL_rlp_mathT(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.58; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.475,0.100,0.050>, 
 <0.675,0.100,0.100>,
 <0.675,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.050>,
 <0.000,1.700,0.050>,

 <0.100,2.000,0.050>,
 <1.500,2.000,0.050>, 
 <1.600,1.700,0.050>,
 
 <1.500,1.660,0.050>,
 <1.410,1.900,0.100>,
 <0.925,1.900,0.100>,
 
 <0.925,0.100,0.100>,
 <1.125,0.100,0.050>,
 <1.125,0.000,0.050>,
 
 <0.475,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.582, 0 ,0> < 1.582,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.44,0,0>}
//
#end
//*************************************************************************************************
// Maths U
//*************************************************************************************************
#macro CL_rlp_mathU(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.94; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.900,0.050>, 
 <0.000,2.000,0.050>,
 <0.650,2.000,0.050>, 
 
 <0.650,1.900,0.050>, 
 <0.450,1.900,0.100>,
 <0.450,0.100,0.550>,    // Inner
 <1.500,0.100,0.550>,    // Inner

 <1.500,1.900,0.100>,
 <1.300,1.900,0.050>, 
 <1.300,2.000,0.050>,
 
 <1.800,2.000,0.050>,
 <1.800,1.900,0.050>,
 <1.600,1.900,0.100>,
 
 <1.600,0.000,0.630>,    // Outer
 <0.200,0.000,0.700>,    // Outer
 <0.200,1.900,0.100>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.942, 0 ,0> < 1.942,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
      matrix <1,0,0,0.25,1,0,0,0,1,-0.35,0,0>}
//
#end
//*************************************************************************************************
// Maths V
//*************************************************************************************************
#macro CL_rlp_mathV(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,1.900,0.050>,    // Left serif
 <0.000,2.000,0.050>,    // Left serif
 <0.670,2.000,0.050>,    // Left serif
 
 <0.670,1.900,0.050>,    // Left serif
 <0.460,1.900,0.100>,    // Left serif  100
 <0.980,0.400,0.000>,    // Inner vertex

 <1.500,1.900,0.100>,    // Right serif
 <1.300,1.900,0.050>, 
 <1.300,2.000,0.050>,
 
 <1.800,2.000,0.050>,
 <1.800,1.900,0.050>,
 <1.610,1.900,0.100>,
 
 <0.950,0.000,0.050>,    // Outer
 <0.850,0.000,0.050>,    // Outer
 <0.200,1.900,0.100>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.802, 0 ,0> < 1.802,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,18.9> translate <0.64,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.49,0,0>}
//
#end     
//*************************************************************************************************
// Maths W
//*************************************************************************************************
#macro CL_rlp_mathW(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 <0.000,1.900,0.050>,    // Left serif
 <0.000,2.000,0.050>,    // Left serif
 <0.630,2.000,0.050>,    // Left serif
 
 <0.630,1.900,0.050>,    // Left serif
 <0.440,1.900,0.100>,    // Left serif
 <0.810,0.500,0.000>,    // Inner vertex - left

 <1.160,1.800,0.000>,
 <1.150,1.900,0.100>,
 <0.950,1.900,0.050>,
 
 <0.950,2.000,0.050>,
 <1.590,2.000,0.050>,
 <1.590,1.900,0.050>,
 
 <1.390,1.900,0.100>,    // 100
 <1.745,0.520,0.000>,    // Inner vertex - right
 <2.100,1.900,0.100>,    // Right serif

 <1.900,1.900,0.050>, 
 <1.900,2.000,0.050>,
 <2.400,2.000,0.050>,

 <2.400,1.900,0.050>,
 <2.210,1.900,0.100>,
 <1.720,0.000,0.050>,    // Outer

 <1.620,0.000,0.050>,    // Outer
 <1.210,1.600,0.000>,    // Middle vertex - outer
 <0.780,0.000,0.050>,

 <0.680,0.000,0.050>,
 <0.180,1.900,0.100>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.402, 0 ,0> < 2.402,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,14.75> translate <0.55,1,0>} 
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,14.40> translate <1.495,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.49,0,0>}
//
#end
//*************************************************************************************************
// Maths X
//*************************************************************************************************
#macro CL_rlp_mathX(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.25; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.000,0.100,0.050>,    // Bottom left serif
 <0.180,0.100,0.100>,    // Bottom left serif
 <0.771,0.906,0.000>,    // Left middle  - tweaker
 
 <0.180,1.900,0.100>,    // Top left serif
 <0.000,1.900,0.050>,
 <0.000,2.000,0.050>,

 <0.670,2.000,0.050>,
 <0.670,1.900,0.050>,
 <0.470,1.900,0.100>,    // Top left serif

 <0.932,1.127,0.000>,    // Upper middle - tweaker
 <1.500,1.900,0.100>,    // Top right serif
 <1.300,1.900,0.050>,

 <1.300,2.000,0.050>,
 <1.800,2.000,0.050>,
 <1.800,1.900,0.050>,    

 <1.620,1.900,0.100>,    // Top right serif
 <0.990,1.032,0.000>,    // Right middle - tweaker
 <1.545,0.100,0.100>,    // Bottom right serif
 
 <1.725,0.100,0.050>,
 <1.725,0.000,0.050>,
 <1.050,0.000,0.050>, 
 
 <1.050,0.100,0.050>,
 <1.250,0.100,0.100>,
 <0.827,0.816,0.000>,    // Bottom middle
 
 <0.300,0.100,0.100>,
 <0.500,0.100,0.050>,
 <0.500,0.000,0.050>,
 
 <0.000,0.000,0.050>,
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.282, 0 ,0> < 2.282,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,30.75> translate <0.865,1,0>} 
//    box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-36.25> translate <0.9,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>}
//
#end
//*************************************************************************************************
// Maths Y
//*************************************************************************************************
#macro CL_rlp_mathY(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[21]{
 <0.000,1.900,0.050>,    // Left serif
 <0.000,2.000,0.050>,    // Left serif
 <0.670,2.000,0.050>,    // Left serif
 
 <0.670,1.900,0.050>,    // Left serif
 <0.470,1.900,0.100>,    // Left serif
 <0.995,1.040,0.000>,    // Inner vertex - tweaker

 <1.500,1.900,0.100>,    // Right serif
 <1.300,1.900,0.050>, 
 <1.300,2.000,0.050>,
 
 <1.800,2.000,0.050>,
 <1.800,1.900,0.050>,  
 <1.620,1.900,0.100>,
 
 <1.025,0.890,0.000>,     // Tweaker
 <1.025,0.100,0.100>, 
 <1.225,0.100,0.050>,
 
 <1.225,0.000,0.050>,
 <0.575,0.000,0.050>,
 <0.575,0.100,0.050>,

 <0.775,0.100,0.100>,    // Outer
 <0.775,0.920,0.000>,    // Outer 
 <0.180,1.900,0.100>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.802, 0 ,0> < 1.802,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,31.25> translate <0.875,1,0>} 
//    box{<-0.050,-1.4,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-30.6> translate <1.03,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.49,0,0>}
//
#end
//*************************************************************************************************
// Maths Z
//*************************************************************************************************
#macro CL_rlp_mathZ(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.09; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.000,0.050>, 
 <0.000,0.100,0.050>,
 <1.300,1.900,0.100>, 
 
 <0.190,1.900,0.100>,
 <0.100,1.660,0.050>,
 <0.000,1.700,0.050>,

 <0.100,2.000,0.050>,
 <1.610,2.000,0.050>, 
 <1.610,1.900,0.050>,
 
 <0.315,0.100,0.100>,
 <1.250,0.100,0.100>,
 <1.500,0.450,0.050>,
 
 <1.600,0.400,0.050>,
 <1.400,0.000,0.050>
}
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.092, 0 ,0> < 2.092,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 0.002,0> < 1.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.80  , 2.002,0> 0.002 pigment{Red}}
//    box{<-0.125,-1.4,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-35.8> translate <0.805,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       matrix <1,0,0,0.25,1,0,0,0,1,-0.01,0,0>}
//
#end   
//*************************************************************************************************
// Mathematical small letters *********************************************************************
//*************************************************************************************************
// Maths a
//*************************************************************************************************
#macro CL_rlp_matha(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <1.410,0.520,0.050>,
 <1.280,0.000,0.200>,
 <0.850,0.000,0.200>,

 <0.815,0.215,0.000>,
 <0.580,0.000,0.200>,
 <0.000,0.000,0.400>,
 
 <0.000,0.930,0.600>,
 <0.479,1.400,0.250>,
 <0.874,1.400,0.200>,
 
 <1.020,1.200,0.000>,
 <1.065,1.360,0.100>,
 <1.256,1.310,0.100>,
 
 <0.955,0.100,0.170>,
 <1.205,0.100,0.150>,
 <1.315,0.545,0.050>  
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.200>,
 <0.250,0.850,0.500>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.17,.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.405,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths b
//*************************************************************************************************
#macro CL_rlp_mathb(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.239; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.112,0.000,0.600>,
 <0.570,1.850,0.100>, 
 <0.340,1.850,0.050>,

 <0.340,1.950,0.050>,
 <0.690,2.000,0.100>,
 <0.790,2.000,0.050>,  

 <0.790,1.900,0.100>,
 <0.630,1.240,0.000>,  // Upper nick  
 <0.800,1.400,0.200>, 

 <1.578,1.400,0.600>,
 <1.228,0.000,0.500>
}
#local pts[1] =
array[5]{   
 <0.580,1.047,0.300>   // Inner
 <0.343,0.100,0.350>,  // Inner 
 <1.045,0.100,0.300>,  // Inner

 <1.345,1.300,0.400>,  // Inner
 <0.850,1.300,0.250>   // Inner
        }
// invoking the object macro
//  cylinder{< 0.23,  0   ,0> < 0.23,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.372,  0   ,0> < 1.372,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.230,-0.002,0> < 1.37  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.230, 2.002,0> < 1.37  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       translate <-0.232,0,0>}
//       
#end
//*************************************************************************************************
// Maths c
//*************************************************************************************************
#macro CL_rlp_mathc(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.205; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <-.150,0.000,0.800>,      // Lower left
 <0.200,1.400,0.600>, 
 <1.300,1.400,0.800>,      

 <1.200,0.800,0.200>,
 <0.950,0.800,0.200>, 
 <0.950,1.100,0.300>,
                       
 <1.120,1.050,0.000>,    // Stays zero radius                  
 <1.050,1.300,0.300>,    // 0.400
 <0.380,1.300,0.500>     // 0.500
 <0.082,0.100,0.600>,    // 0.600    

 <0.950,0.100,0.300>,     
 <1.120,0.480,0.050>,
 <1.200,0.450,0.050>,
 
 <1.050,0.000,0.800>
}
//#local pts[1] =
//array[4]{   
// <0.265,0.800,0.000>   
// <1.100,0.800,0.200>,   
// <1.100,1.300,0.400>,  

// <0.380,1.300,0.400>   
//        }
// invoking the object macro
//  cylinder{< 0.023,  0   ,0> < 0.023,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.230,  0   ,0> < 1.230,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.023,-0.002,0> < 1.230  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.023, 1.402,0> < 1.230  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.13,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       translate <-.025,0,0>}
//       
#end
//*************************************************************************************************
// Maths d
//*************************************************************************************************
#macro CL_rlp_mathd(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[19]{
 <1.410,0.520,0.050>,
 <1.280,0.000,0.200>,
 <0.850,0.000,0.200>,

 <0.815,0.215,0.000>,    // Lower nick
 <0.580,0.000,0.200>,
 <0.000,0.000,0.400>,
 
 <0.000,0.930,0.500>,
 <0.479,1.400,0.300>,
 <0.874,1.400,0.200>,
 
 <1.020,1.200,0.000>,    // Upper nick
 <1.180,1.850,0.100>, 
 <0.950,1.850,0.050>,
 
 <0.950,1.950,0.050>,
 <1.300,2.000,0.100>,
 <1.400,2.000,0.050>,
  
 <1.400,1.900,0.100>,
 <0.955,0.100,0.170>,
 <1.205,0.100,0.150>,

 <1.315,0.545,0.050>  
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.300>,
 <0.250,0.850,0.450>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths e
//*************************************************************************************************
#macro CL_rlp_mathe(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.215; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <-.150,0.000,0.800>,
 <0.200,1.400,0.600>, 
 <1.300,1.400,0.800>,      // 0.700

 <1.200,0.700,0.400>,
 <0.240,0.700,0.000>,
 <0.050,0.100,0.600>,     // 0.600   

 <0.950,0.100,0.300>,     // 0.500
 <1.120,0.480,0.050>,
 <1.200,0.450,0.050>,
 
 <1.050,0.000,0.800>
}
#local pts[1] =
array[4]{   
 <0.265,0.800,0.000>   
 <1.100,0.800,0.200>,   
 <1.100,1.300,0.400>,  

 <0.380,1.300,0.400>   
        }
// invoking the object macro
//  cylinder{< 0.023,  0   ,0> < 0.023,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.240,  0   ,0> < 1.240,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.023,-0.002,0> < 1.240  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.023, 1.402,0> < 1.240  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.13,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       translate <-.025,0,0>}
//       
#end
//*************************************************************************************************
// Maths f
//*************************************************************************************************
#macro CL_rlp_mathf(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.9; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 <0.340,0.947,0.300>,  
 <0.208,0.400,0.000>,
 <0.600,0.400,0.050>,
 
 <0.600,0.300,0.050>,
 <0.183,0.300,0.000>,
 <-.217,-1.300,0.600>,
     
 <-1.268,-1.300,0.600>,
 <-1.010,-0.750,0.200>,  // Start of bobble
 <-0.760,-0.750,0.250>, 

 <-0.760,-1.050,0.250>,                     
 <-0.960,-1.050,0.000>,  // End of bobble. Stays zero radius                  
 <-0.905,-1.200,0.250>,

 <-0.640,-1.200,0.250> 
 <-0.340,-0.947,0.300>,  
 <-0.033, 0.300,0.000>,

 <-0.430, 0.300,0.050>,
 <-0.430, 0.400,0.050>,
 <-0.008, 0.400,0.000>,

 <0.217,1.300,0.600>,    
 <1.268,1.300,0.600>,
 <1.010,0.750,0.200>,  // Start of bobble

 <0.760,0.750,0.250>, 
 <0.760,1.050,0.250>,                     
 <0.960,1.050,0.000>,  // End of bobble. Stays zero radius                  

 <0.905,1.200,0.250>,
 <0.640,1.200,0.250> 
}
// invoking the object macro
//  cylinder{<-0.802, -1.3   ,0> <-0.802, 1.3  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.1  , -1.3   ,0> < 1.1  , 1.3  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.800,-1.302  ,0> < 1.1  ,-1.302,0> 0.002 pigment{Red}}
//  cylinder{<-0.800, 1.302  ,0> < 1.1  , 1.302,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.3,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0,0,0>} 
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
       translate <0.8,0.7,0>}
//       
#end
//*************************************************************************************************
// Maths g
//*************************************************************************************************
#macro CL_rlp_mathg(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.24; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <0.779,-.600,0.600>,  
 <-.273,-.600,0.600>,
 <-.014,-.050,0.200>,  // Start of bobble

 <0.236,-.050,0.250>, 
 <0.236,-.350,0.250>,                     
 <0.036,-.350,0.000>,  // End of bobble. Stays zero radius                  

 <0.091,-.500,0.250>,
 <0.361,-.500,0.250>, 
 <0.661,-.247,0.300>, 

 <0.763,0.150,0.000>,  // Lower nick
 <0.580,0.000,0.200>,  
 <0.000,0.000,0.400>,

 <0.000,0.930,0.600>,
 <0.479,1.400,0.250>,
 <0.874,1.400,0.200>,

 <1.020,1.200,0.000>,
 <1.065,1.360,0.100>,    // Upper round 
 <1.256,1.310,0.100>,    // Upper round
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.200>,
 <0.250,0.850,0.500>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}

// invoking the object macro
//  cylinder{<-0.002, -0.6   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.242, -0.6   ,0> < 1.242,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.4  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.5,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths h
//*************************************************************************************************
#macro CL_rlp_mathh(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.49; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.440,1.047,0.300>,
 <0.172,-.025,0.100>,
 <-.022,0.023,0.100>,

 <0.430,1.850,0.100>, 
 <0.200,1.850,0.050>,
 <0.200,1.950,0.050>,

 <0.550,2.000,0.100>,
 <0.650,2.000,0.050>,  
 <0.650,1.900,0.100>,
 
 <0.490,1.240,0.000>,  // Upper nick  
 <0.660,1.400,0.200>, 
 <1.338,1.400,0.500>,
 
 <1.013,0.100,0.200>,
 <1.292,0.100,0.200>, 
 <1.398,0.524,0.050>,
 
 <1.495,0.500,0.050>,
 <1.375,0.000,0.250>,
 <0.780,0.000,0.400>,
 
 <1.105,1.300,0.400>,
 <0.710,1.300,0.250> 
}
// invoking the object macro
//  cylinder{< 0.138,  0   ,0> < 0.138,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.632,  0   ,0> < 1.632,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.140,-0.002,0> < 1.63  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.140, 2.002,0> < 1.63  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       translate <-0.14,0,0>}
//       
#end
//*************************************************************************************************
// Maths i
//*************************************************************************************************
#macro CL_rlp_mathi(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.668,1.400,0.300>,
 
 <0.343,0.100,0.200>,
 <0.622,0.100,0.200>, 
 <0.728,0.524,0.050>,
 
 <0.825,0.500,0.050>,
 <0.705,0.000,0.250>,
 <0.110,0.000,0.400>,
 
}
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.85 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.822,  0   ,0> < 0.822,  1.85 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.82  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.852,0> < 0.82  , 1.852,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.3,1.6,0>}
  #local letter_dimensions[0] = 0.82; // Width 
  #local letter_dimensions[1] = 1.85; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
#end
//*************************************************************************************************
// Maths j
//*************************************************************************************************
#macro CL_rlp_mathj(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.9; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 < 0.278, 0.700,0.500>,  
 <-0.217,-1.300,0.600>,  
 <-1.268,-1.300,0.600>,

 <-1.010,-0.750,0.200>,  // Start of bobble
 <-0.760,-0.750,0.250>, 
 <-0.760,-1.050,0.250>,                     

 <-0.960,-1.050,0.000>,  // End of bobble. Stays zero radius                  
 <-0.905,-1.200,0.250>,
 <-0.640,-1.200,0.250> 

 <-0.340,-0.947,0.300>,                    
 < 0.047, 0.600,0.300>, 
 <-0.420, 0.600,0.200>,                     

 <-0.528, 0.176,0.050>,  // End of loop                  
 <-0.625, 0.200,0.050>,  // End of loop
 <-0.500, 0.700,0.260> 
}
// invoking the object macro
union{
//  cylinder{<-0.802, -1.3   ,0> <-0.802, 1.15  ,0> 0.002 pigment{Red}}
//  cylinder{< 0.18 , -1.3   ,0> < 0.18 , 1.15  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.800,-1.302  ,0> < 0.18 ,-1.302,0> 0.002 pigment{Red}}
//  cylinder{<-0.800, 1.152  ,0> < 0.18 , 1.152,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.3,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0,0,0>} 
//  box{<-0.050, 0.0,-0.101> < 0.050,0.8,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <-0.6235,0,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) translate <-0.15,0.9,0>}
  #local letter_dimensions[0] = 0.98; // Width 
  #local letter_dimensions[1] = 1.85; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.6; // Drop below line
  translate <0.8,0.7,0>
     }
#end
//*************************************************************************************************
// Maths k
//*************************************************************************************************
#macro CL_rlp_mathk(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.49; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[27]{
 <0.375,0.800,0.000>,   // Under corner
 <0.172,-.025,0.100>,
 <-.022,0.023,0.100>,

 <0.430,1.850,0.100>, 
 <0.200,1.850,0.050>,
 <0.200,1.950,0.050>,

 <0.550,2.000,0.100>,
 <0.650,2.000,0.050>,  
 <0.650,1.900,0.100>,
 
 <0.430,1.000,0.000>,  //0.200 Top of h
 <0.950,1.400,0.200>,   //0.200

 <1.628,1.400,0.600>,
 <1.400,0.850,0.200>,  // Start of bobble
 <1.150,0.850,0.250>, 

 <1.150,1.150,0.250>,                  
 <1.360,1.150,0.000>,  // End of bobble. Stays zero radius                  
 <1.295,1.300,0.250>,

 <1.000,1.300,0.250>, 
 <0.500,0.913,0.000>,   // End of twiddle
 <1.188,0.800,0.400>,  //0.400  Top of h
 
 <1.013,0.100,0.200>,
 <1.292,0.100,0.200>, 
 <1.398,0.524,0.050>,
 
 <1.495,0.500,0.050>,
 <1.375,0.000,0.250>,   // Bottom right
 <0.780,0.000,0.400>,   // Bottom right
 
 <0.955,0.700,0.300>,   //0.400 Inner top
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.492,  0   ,0> < 1.492,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.50  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.50  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.25,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.0,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.06,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Maths l
//*************************************************************************************************
#macro CL_rlp_mathl(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.05; // Width 
#local letter_dimensions[1] = 2.0;  // Height
#local letter_dimensions[2] = 1.4;  // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[17]{
 <0.225,1.400,0.600>,    // Mid side left  0.600
 <0.678,2.000,0.250>,    // Top left corner 0.250
 <1.050,2.000,0.200>,    // Top right corner 0.200

 <1.050,1.400,0.500>,    // Mid side right 0.400
 <0.425,0.510,0.000>,    // Tweaked to look right
 <0.425,0.100,0.250>,    // 

 <0.620,0.100,0.100>, 
 <0.910,0.400,0.050>,    // Right tail
 <0.980,0.330,0.050>,    // Right tail

 <0.670,0.000,0.150>,
 <0.225,0.000,0.400>,
 <0.235,0.300,0.000>,    // Left lower nick

 <0.150,0.200,0.100>,
 <0.000,0.200,0.050>,
 <0.000,0.300,0.050>,
 
 <0.100,0.300,0.050>,
 <0.225,0.460,0.000>  
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[5]{
 <0.950,1.420,0.450>
 <0.950,1.900,0.070>,
 <0.725,1.900,0.170>,

 <0.425,1.300,0.500>,
 <0.425,0.700,0.000>,
}
// invoking the object macro
//  cylinder{<-0.002, 0    ,0> <-0.002, 2.0  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.052, 0    ,0> < 1.052, 2.0  ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.05 , 0    ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.05 , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,0> translate <0.325,0.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-37> translate <0.45,0.67,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths m
//*************************************************************************************************
#macro CL_rlp_mathm(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.44; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[28]{
 <0.580,1.047,0.300>,
 <0.312,-.025,0.100>,
 <0.118,0.023,0.100>,

 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.521,1.400,0.170>,
 
 <0.590,1.190,0.000>,  // Left upper nick  
 <0.800,1.400,0.200>, 
 <1.350,1.400,0.500>,
 
 <1.380,1.190,0.000>,  // Right upper nick  
 <1.610,1.400,0.200>, 
 <2.288,1.400,0.500>,
 
 <1.963,0.100,0.200>,
 <2.242,0.100,0.200>, 
 <2.348,0.524,0.050>,
 
 <2.445,0.500,0.050>,
 <2.325,0.000,0.250>,
 <1.730,0.000,0.400>,
 
 <2.055,1.300,0.400>,
 <1.660,1.300,0.250>, 
 <1.390,1.047,0.300>, 
 
 <1.122,-.025,0.100>,
 <0.928,0.023,0.100>,
 <1.245,1.300,0.400>,

 <0.850,1.300,0.250> 
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.442,  0   ,0> < 2.442,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.44  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 2.44  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,0.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2 ,0.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <2.01,0.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths n
//*************************************************************************************************
#macro CL_rlp_mathn(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.63; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <0.580,1.047,0.300>,
 <0.312,-.025,0.100>,
 <0.118,0.023,0.100>,

 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.521,1.400,0.170>,
 
 <0.590,1.190,0.000>,  // Upper nick  
 <0.800,1.400,0.200>, 
 <1.478,1.400,0.500>,
 
 <1.153,0.100,0.200>,
 <1.432,0.100,0.200>, 
 <1.538,0.524,0.050>,
 
 <1.635,0.500,0.050>,
 <1.515,0.000,0.250>,
 <0.920,0.000,0.400>,
 
 <1.245,1.300,0.400>,
 <0.850,1.300,0.250> 
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.632,  0   ,0> < 1.632,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.63  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.63  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.2,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths o. Also greek omicron
//*************************************************************************************************
#macro CL_rlp_matho(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.3; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <-.150,0.000,0.700>,
 <0.200,1.400,0.600>, 
 <1.450,1.400,0.700>,

 <1.100,0.000,0.600>
}
#local pts[1] =
array[4]{   
 <0.050,0.100,0.600>   
 <0.850,0.100,0.500>,   
 <1.250,1.300,0.600>,  

 <0.440,1.300,0.500>   
        }
// invoking the object macro
//  cylinder{< -.002,  0   ,0> < -.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.300,  0   ,0> < 1.300,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.002,-0.002,0> < 1.300  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.002, 1.402,0> < 1.300  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.13,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.17,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Maths p
//*************************************************************************************************
#macro CL_rlp_mathp(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[19]{
 <1.410,0.520,0.050>,
 <1.280,0.000,0.200>,
 <0.850,0.000,0.200>,

 <0.815,0.215,0.000>,    // Lower nick
 <0.580,0.000,0.200>,
 <0.000,0.000,0.400>,
 
 <0.000,0.930,0.500>,
 <0.479,1.400,0.300>,
 <0.874,1.400,0.200>,
 
 <1.020,1.200,0.000>,    // Upper nick
 <1.205,1.900,0.100>, 
 <1.005,1.900,0.050>,
 
 <1.005,2.000,0.050>,
 <1.600,2.000,0.050>,
 <1.600,1.900,0.050>,
 
 <1.400,1.900,0.100>,
 <0.955,0.100,0.170>,
 <1.205,0.100,0.150>,

 <1.315,0.545,0.050>  
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.300>,
 <0.250,0.850,0.450>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}

// invoking the object macro
//  cylinder{<-0.002, -0.6  ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402, -0.6  ,0> < 1.402,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602 ,0> < 1.4  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402 ,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//    box{<-0.100,-.7,-0.101> < 0.100,1.3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       rotate <0,0,180> translate <1.4,1.4,0>}
//
#end
//*************************************************************************************************
// Maths q
//*************************************************************************************************
#macro CL_rlp_mathq(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.24; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.400,-.600,0.050>,  //
 <0.400,-.500,0.050>,  //
 <0.600,-.500,0.100>,  //

 <0.763,0.150,0.000>,  // Lower nick
 <0.580,0.000,0.200>,   
 <0.000,0.000,0.400>,
 
 <0.000,0.930,0.600>,
 <0.479,1.400,0.250>,
 <0.874,1.400,0.200>,
 
 <1.020,1.200,0.000>,
 <1.065,1.360,0.100>,    // Upper round
 <1.256,1.310,0.100>,    // Upper round
 
 <0.804,-.500,0.100>,
 <1.004,-.500,0.050>,
 <1.004,-.600,0.050>  
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.200>,
 <0.250,0.850,0.500>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}

// invoking the object macro
//  cylinder{<-0.002, -0.6   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.242, -0.6   ,0> < 1.242,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.602,0> < 1.4  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-1.5,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths r
//*************************************************************************************************
#macro CL_rlp_mathr(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.33; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[18]{
 <0.580,1.047,0.300>,
 <0.312,-.025,0.100>,
 <0.118,0.023,0.100>,

 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.521,1.400,0.170>,
 
 <0.590,1.190,0.000>,  // Upper nick  
 <0.800,1.400,0.200>, 
 <1.478,1.400,0.600>,
 
 <1.250,0.850,0.200>,  // Start of bobble
 <1.000,0.850,0.250>, 
 <1.000,1.150,0.250>,
                       
 <1.210,1.150,0.000>,    // End of bobble. Stays zero radius                  

 
 <1.145,1.300,0.250>,
 <0.850,1.300,0.250> 
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.322,  0   ,0> < 1.322,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.33  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.33  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths s
//*************************************************************************************************
#macro CL_rlp_maths(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.02; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[20]{
 <1.080,0.585,0.500>,   //***** 0.500 Outer right lower
 <0.700,0.000,0.300>,   //*****Lower inner0.300
 <-.178,0.000,0.650>,   // 0.600

 <0.080,0.550,0.200>,   // Start of bobble
 <0.330,0.550,0.250>, 
 <0.330,0.250,0.250>,                     

 <0.110,0.250,0.000>,   // End of bobble. Stays zero radius                  
 <0.155,0.100,0.200>,   // 0.250
 <0.550,0.100,0.200>,   //***** 0.250

 <0.800,0.500,0.300>    //***** 0.300  Inner right lower
 <-.080,0.900,0.500>,   // Outer left upper
 <0.421,1.400,0.200>,

 <1.178,1.400,0.600>,   // DONT TOUCH
 <0.950,0.850,0.200>,   // Start of bobble
 <0.700,0.850,0.250>, 

 <0.700,1.150,0.250>,                   
 <0.910,1.150,0.000>,   // End of bobble. Stays zero radius                  
 <0.845,1.300,0.150>,   // DONT TOUCH

 <0.450,1.300,0.200>,   // 0.250
 <0.190,1.000,0.300>    // 0.300
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.022,  0   ,0> < 1.022,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.02  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.02  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,65> translate <0.6,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.09> translate <0.19,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.09> translate <0.83,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Maths t
//*************************************************************************************************
#macro CL_rlp_matht(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.8; // Width 
#local letter_dimensions[1] = 1.85; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,0.000,0.400>,  
 <0.250,1.000,0.000>,
 <0.000,1.000,0.050>,
 
 <0.000,1.100,0.050>,
 <0.275,1.100,0.000>,
 <0.468,1.873,0.100>, 
 
 <0.662,1.825,0.100>,
 <0.481,1.100,0.000>,
 <0.800,1.100,0.050>,
 
 <0.800,1.000,0.050>,
 <0.456,1.000,0.000>,
 <0.231,0.100,0.200>, 

 <0.610,0.100,0.200>,
 <0.710,0.500,0.050>,
 <0.807,0.476,0.050>,

 <0.688,0.000,0.270>,  
}
// <0.312,-.025,0.100>,
// <0.118,0.023,0.100>,
// invoking the object macro
//  cylinder{< -.002,  0   ,0> < -.002,  1.85,0> 0.002 pigment{Red}}
//  cylinder{< 0.802,  0   ,0> < 0.802,  1.85 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.80  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.140, 1.852,0> < 0.80  , 1.852,0> 0.002 pigment{Red}}
//  box{<0.000,0.0,-0.101> < 0.200,1.85,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0,0,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
//  translate <-0.14,0,0>
//
#end
//*************************************************************************************************
// Maths u
//*************************************************************************************************
#macro CL_rlp_mathu(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_mathn(z1,z2,d_rad,offs,cham,letter_dimensions) 
       rotate <0,0,180> translate <1.63,1.4,0>}
//
#end
//*************************************************************************************************
// Maths v
//*************************************************************************************************
#macro CL_rlp_mathv(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.46; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <1.400,1.425,0.150>,   
 <1.500,0.700,0.400>,    // Outer mid curve
 <1.100,0.000,0.400>,    // Right botton corner

 <0.110,0.000,0.600>,    // Left bottom corner
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,

 <0.092,0.895,0.050>,
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,

 <0.668,1.400,0.300>,
 <0.343,0.100,0.400>,     // Left inner corner
 <1.040,0.100,0.350>,
 
 <1.390,0.715,0.300>,                  
 <1.150,1.375,0.150> 
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.460,  0   ,0> < 1.460, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,  0   ,0> < 1.460,  0   ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 1.402,0> < 1.460, 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Maths w
//*************************************************************************************************
#macro CL_rlp_mathw(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.1; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[22]{
 <1.213,1.425,0.100> 
 <1.407,1.377,0.100>,  
 <1.088,0.100,0.400>,     // Left inner corner

 <1.685,0.100,0.350>,
 <2.035,0.715,0.300>,    // Inner mid curve
 <1.794,1.375,0.150>, 

 <2.045,1.425,0.150>,   
 <2.145,0.700,0.400>,    // Outer mid curve
 <1.745,0.000,0.400>,    // Right botton corner

 <1.205,0.000,0.200>,    // Left bottom corner
 <1.072,0.200,0.000>,   // 0.902,0.100,0.000 Lower nick - radius stays at zero
 <0.855,0.000,0.200>,    // 0.805,0.000,0.250

 <0.110,0.000,0.500>,
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,

 <0.092,0.895,0.050>,
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,

 <0.668,1.400,0.300>,
 <0.343,0.100,0.300>,
 <0.662,0.100,0.100>, 

 <0.910,0.200,0.200>,                  
         }
// invoking the object macro
//  cylinder{<-0.002, 0  ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 2.102  , 0   ,0> < 2.102  , 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,-0.002  ,0> < 2.1  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 1.402  ,0> < 2.1  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,0,-0.101> < 0.100,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.96,0,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Maths x
//*************************************************************************************************
#macro CL_rlp_mathx(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.765; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts_sub_upper =
array[16]{
// <0.770,0.600,0.000>,
// <0.562,0.600,0.000>,

 <0.737,1.300,0.220>,    
 <0.150,1.300,0.370>,  // Don't move
 <0.042,0.895,0.050>,  // Don't move
 
 <-.055,0.919,0.050>,  // Don't move
 <0.075,1.400,0.450>,  // Don't move
 <0.721,1.400,0.170>,
 
 <0.850,1.240,0.000>,  // Upper nick  
 <1.100,1.400,0.200>, 
 <1.728,1.400,0.600>,
 
 <1.500,0.850,0.200>,  // Start of bobble
 <1.250,0.850,0.250>, 
 <1.250,1.150,0.250>,
                       
 <1.450,1.150,0.000>,    // End of bobble. Stays zero radius                  

 
 <1.410,1.270,0.300>,
 <1.150,1.300,0.250>, 
 <0.880,1.047,0.300>
} 
//
#local pts_sub_lower = array[16];
#local icount = 0;
#while(icount < 16)
  #local pt = pts_sub_upper[icount];
  #local pt_rot = vrotate(<pt.x,pt.y,0>,z*180);
  #local pts_sub_lower[icount] = <pt_rot.x+1.38150,pt_rot.y+1.4,pt.z>;
  #local icount = icount + 1;
#end
//
#local pts_sub_both = array[32];
#local icount       = 0;
#while(icount < 16)
  #local pts_sub_both[icount]    = pts_sub_upper[icount];
  #local pts_sub_both[icount+16] = pts_sub_lower[icount];
  #local icount = icount + 1;
#end
//
#local pts     = array[1];
#local pts[0]  = pts_sub_both;
// invoking the object macro
object{
//  cylinder{<-0.182,  0   ,0> <-0.182,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.572,  0   ,0> < 1.572,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< -.180,-0.002,0> < 1.57  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< -.180, 1.402,0> < 1.57  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.69,.7,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
  translate <0.19,0,0>
     }
#end
//*************************************************************************************************
// Maths y
//*************************************************************************************************
#macro CL_rlp_mathy(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[23]{
 <1.407,1.377,0.100>,  
 <0.913,-.600,0.600>,  
 <-.138,-.600,0.600>,

 <0.120,-.050,0.200>,  // Start of bobble
 <0.370,-.050,0.250>, 
 <0.370,-.350,0.250>,                     

 <0.170,-.350,0.000>,  // End of bobble. Stays zero radius                  
 <0.225,-.500,0.250>,
 <0.495,-.500,0.250>, 

 <0.795,-.247,0.300>, 
 <0.882,0.100,0.000>,   // Lower nick - radius stays at zero
 <0.705,0.000,0.150>,

 <0.110,0.000,0.500>,
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,

 <0.092,0.895,0.050>,
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,

 <0.668,1.400,0.300>,
 <0.343,0.100,0.300>,
 <0.662,0.100,0.100>, 

 <0.910,0.200,0.200>,                  
 <1.213,1.425,0.100> 
}
// invoking the object macro
//  cylinder{<-0.002, -0.6   ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.40  , -0.6   ,0> < 1.40  , 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,-0.602  ,0> < 1.4  ,-0.602,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 1.402  ,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-0.6,-0.101> < 0.100,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.96,0,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,0.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.39,.7,0>} 
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// Maths z
//*************************************************************************************************
#macro CL_rlp_mathz(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.3; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 <0.060,-.020,0.050>,       // Lower left corner
 <-.015,0.045,0.050>,       // Lower left corner
 <0.170,0.370,0.300>, 
  
 <1.024,1.105,0.030>,
 <0.810,1.085,0.100>,  
 <0.437,1.308,0.200>,

 <0.340,1.030,0.050>,
 <0.244,1.052,0.050>, 
 <0.370,1.400,0.300>,     // Top of upper

 <0.763,1.400,0.300>,     // Top of upper
 <1.000,1.200,0.050>,   
 <1.100,1.200,0.050>,

 <1.240,1.420,0.050>,     // Upper right corner
 <1.325,1.365,0.050>,     // Upper right corner
 <1.160,1.060,0.300>, 
 
 <0.264,0.300,0.030>,
 <0.500,0.300,0.100>,
 <0.800,0.200,0.200>,
 
 <1.130,0.500,0.050>,      // Lower end
 <1.200,0.470,0.050>,      // Lower end
 <1.000,0.000,0.300>,      // Bottom of lower
 
 <0.545,0.000,0.200>,      // Botton of lower
 <0.350,0.200,0.100>,
 <0.200,0.170,0.100>
         }
// invoking the object macro
//  cylinder{<-0.002, 0   ,0> <-0.002, 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{< 1.30  , 0   ,0> < 1.30  , 1.4  ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,-0.002  ,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, 1.402  ,0> < 1.3  , 1.402,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
//
#end
//*************************************************************************************************
// NUMERALS ***************************************************************************************
//*************************************************************************************************
// 0  (zero)
//*************************************************************************************************
#macro CL_rlp_0(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <-.500,1.000,1.207>,
 <0.700,2.200,0.486>,
 <1.900,1.000,1.207>,

 <0.700,-.200,0.486>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.350,0.100,0.350>,
 <1.050,0.100,0.350>,
 <1.050,1.900,0.350>,
 <0.350,1.900,0.350>
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Zero slash
//*************************************************************************************************
#macro CL_rlp_zeroslash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <-.500,1.000,1.207>,
 <0.700,2.200,0.486>,
 <1.900,1.000,1.207>,

 <0.700,-.200,0.486>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.350,0.100,0.350>,
 <1.050,0.100,0.350>,
 <1.050,1.900,0.350>,
 <0.350,1.900,0.350>
}

#local pts1 = array[1];
#local pts1[0] =
array[6]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <1.300,2.000,0.000>,

 <1.400,2.000,0.000>,
 <1.400,1.900,0.000>,
 <0.100,0.000,0.000>
}
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end
//*************************************************************************************************
// 1
//*************************************************************************************************
#macro CL_rlp_1(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.325,0.000,0.000>,
 <0.325,0.100,0.000>,
 <0.525,0.100,0.100>,

 <0.525,1.600,0.100>,
 <0.325,1.600,0.000>,   // Left point
 <0.325,1.680,0.000>,   // Left point
 
 <0.775,2.000,0.000>,   // Outer round
 <0.875,2.000,0.000>,   // Outer round
 <0.875,0.100,0.100>,
 
 <1.075,0.100,0.000>,
 <1.075,0.000,0.000>
         }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// 2
//*************************************************************************************************
#macro CL_rlp_2(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <1.160,1.260,0.400>,

 <0.660,1.860,0.400>,
 <0.061,1.370,0.000>,   // Left point
 <0.000,1.420,0.000>,   // Left point
 
 <0.500,2.360,0.800>,   // Outer round
 <1.740,1.320,0.800>,   // Outer round
 <0.460,0.350,0.000>,
 
 <1.200,0.350,0.200>,
 <1.320,0.540,0.000>,
 <1.400,0.500,0.000>,
 
 <1.200,0.000,0.000>    // Bottom
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// 3
//*************************************************************************************************
#macro CL_rlp_3(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <-.088,0.200,0.300>,   // Lower round
 <0.170,0.520,0.300>,   // Lower round
 <0.740,-.100,0.450>,   // Lower inner

 <1.400,0.920,0.800>,   // Lower inner
 <0.540,0.920,0.000>,   // Middle point
 <0.500,1.000,0.000>,   // Middle point
 
 <0.940,1.320,0.400>,   // Upper inner
 <0.460,1.900,0.400>,   // Upper inner
 <0.070,1.540,0.000>,   // Upper point
 
 <0.000,1.600,0.000>,   // Upper point
 <0.560,2.234,1.000>,   // Upper outer 
 <1.500,1.500,0.800>,   // Upper outer 

 <0.900,1.100,0.000>,   // Outer middle point
 <1.670,1.000,1.600>,
 <0.940,-.220,1.000>,
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// 4
//*************************************************************************************************
#macro CL_rlp_4(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.750,0.000,0.000>,
 <0.750,0.500,0.000>,
 <0.000,0.500,0.000>,

 <0.000,0.850,0.000>,
 <0.750,2.000,0.000>,
 <1.100,2.000,0.000>,
 
 <1.100,0.850,0.000>,
 <1.400,0.850,0.000>,
 <1.400,0.500,0.000>,
 
 <1.100,0.500,0.000>,
 <1.100,0.000,0.000>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.750,0.850,0.000>,
 <0.750,1.800,0.000>, 
 <0.140,0.860,0.000>,
 <0.140,0.850,0.000>
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// 5
//*************************************************************************************************
#macro CL_rlp_5(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <-.088,0.250,0.350>,   // Lower round
 <0.200,0.570,0.350>,   // Lower round
 <0.740,-.170,0.600>,   // Lower inner

 <1.400,0.920,0.800>,   // Lower inner
// <0.000,1.100,0.000>,   // Middle point
 <0.000,1.200,0.000>,   // Middle point
 
 <0.200,2.000,0.000>,   // Upper top
 <1.300,2.000,0.000>,   // Upper right
 <1.300,1.900,0.000>,   // Upper right
 
 <1.200,1.650,0.000>,   // Right gorizontal  
 <0.210,1.650,0.000>,
 <0.140,1.350,0.000>,
 
 <2.000,1.300,1.500>,
 <0.840,-.230,1.000>,
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
#end 
//*************************************************************************************************
// 6
//*************************************************************************************************
#macro CL_rlp_6(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
object{CL_rlp_9(z1,z2,d_rad,offs,cham,letter_dimensions) 
       translate <-0.7,-1,0> rotate <0,0,180> translate <0.7,1,0> }
//
#end 
//*************************************************************************************************
// 7
//*************************************************************************************************
#macro CL_rlp_7(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <1.400,2.000,0.000>,
 <1.400,1.900,0.000>,
 <0.750,0.000,0.000>,

 <0.650,0.000,0.000>, 
 <0.650,0.100,0.000>,
 <1.180,1.650,0.000>, 
   
 <0.200,1.650,0.100>,
 <0.080,1.460,0.000>,
 <0.000,1.500,0.000>,

 <0.200,2.000,0.000>    
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// 8
//*************************************************************************************************
#macro CL_rlp_8(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <-.700,0.000,1.325>,   // Lower left
 <0.530,1.030,0.000>,   // Left waist 
 <-.500,2.000,1.200>,   // Left upper   

 <1.900,2.000,1.200>    // Right upper  
 <0.835,1.140,0.000>,   // Right waist
 <2.000,0.000,1.250>,
        }
#local pts[1] =
array[3]{
 <0.630,0.960,0.000>,
 <-.400,0.100,1.000>,   
 <1.600,0.100,1.000>   
        }
#local pts[2] =
array[3]{
 <0.750,1.220,0.000>,   
 <1.500,1.900,0.800>,   
 <-.100,1.900,0.800>
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// 9
//*************************************************************************************************
#macro CL_rlp_9(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.900,0.500,0.500>,   // Right lower
 <0.987,1.080,0.000>,   // Middle point
 <0.000,0.600,1.000>,   // Left lower

 <0.000,2.000,0.900>,   // Top left
 <1.400,2.000,0.900>,   // Top right 
 <1.400,0.500,1.000>,   // Right outer

 <0.250,0.000,0.000>,   // Lower tip 
 <0.200,0.085,0.000>,   // Lower tip
        }
#local pts[1] =
array[4]{
 <0.350,1.900,0.350>,   
 <0.350,1.000,0.450>,   
 <1.000,1.200,0.000>,   

 <1.050,1.900,0.300>,   
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Mathematical fractions (1/4, 1/2, 3/4, all others using CL_frac_numerator and CL_frac_denominator)
//*************************************************************************************************
// quarter (1/4)
//*************************************************************************************************
#macro CL_rlp_quarter(z1,z2,d_rad,offs,cham,letter_dimensions)
//
//union{
  union{
    object{CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions) 
           scale <0.6,0.6,1> translate <0,0.15,0>}
    object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-0.90,0> scale <0.6,0.6,1>}       
    object{CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
        translate <0,0.9,0>}
//  
//  cylinder{<-0.004,-0.454,0> <-0.004, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.844,-0.454,0> < 0.844, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.454,0> < 0.84 ,-0.454,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.252,0> < 0.84 , 2.252,0> 0.002 pigment{Red}}
// 
//     }
#local letter_dimensions[0] = 0.84;  // Width 
#local letter_dimensions[1] = 2.25; // Height
#local letter_dimensions[2] = 2.25; // Superscript height
#local letter_dimensions[3] = 0.45; // Drop below line
//
#end
//*************************************************************************************************
// half (1/2)
//*************************************************************************************************
#macro CL_rlp_half(z1,z2,d_rad,offs,cham,letter_dimensions)
//
//union{
  union{
    object{CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions) 
           scale <0.6,0.6,1> translate <0,0.15,0>}
    object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-0.90,0> scale <0.6,0.6,1>}       
    object{CL_rlp_math2(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
        translate <0,0.9,0>}
//  
//  cylinder{<-0.004,-0.454,0> <-0.004, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.844,-0.454,0> < 0.844, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.454,0> < 0.84 ,-0.454,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.252,0> < 0.84 , 2.252,0> 0.002 pigment{Red}}
// 
//     }
#local letter_dimensions[0] = 0.84;  // Width 
#local letter_dimensions[1] = 2.25; // Height
#local letter_dimensions[2] = 2.25; // Superscript height
#local letter_dimensions[3] = 0.45; // Drop below line
//
#end
//*************************************************************************************************
// three quarters (3/4)
//*************************************************************************************************
#macro CL_rlp_threequarters(z1,z2,d_rad,offs,cham,letter_dimensions)
//
//union{
  union{
    object{CL_rlp_math3(z1,z2,d_rad,offs,cham,letter_dimensions) 
           scale <0.6,0.6,1> translate <0,0.15,0>}
    object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-0.9,0> scale <0.6,0.6,1>}       
    object{CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
        translate <0,0.9,0>}
//  
//  cylinder{<-0.004,-0.454,0> <-0.004, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.844,-0.454,0> < 0.844, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.454,0> < 0.84 ,-0.454,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.252,0> < 0.84 , 2.252,0> 0.002 pigment{Red}}
// 
//     }
#local letter_dimensions[0] = 0.84;  // Width 
#local letter_dimensions[1] = 2.25; // Height
#local letter_dimensions[2] = 2.25; // Superscript height
#local letter_dimensions[3] = 0.45; // Drop below line
//
#end
//*************************************************************************************************
// General fraction
//*************************************************************************************************
#macro CL_rlp_general_fraction(z1,z2,d_rad,offs,cham,letter_dimensions)
//
//union{
  union{
    #switch(CL_frac_numerator)
    #case(1)
      object{CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(2)
      object{CL_rlp_math2(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(3)
      object{CL_rlp_math3(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(4)
      object{CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(5)
      object{CL_rlp_math5(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(6)
      object{CL_rlp_math6(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(7)
      object{CL_rlp_math7(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(8)
      object{CL_rlp_math8(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #break
    #case(9)
      object{CL_rlp_math9(z1,z2,d_rad,offs,cham,letter_dimensions) 
             scale <0.6,0.6,1> translate <0,0.15,0>}
    #end
//    
    object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
           translate <0,-0.9,0> scale <0.6,0.6,1>}       
//
    #switch(CL_frac_denominator)
    #case(1)
      object{CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(2)
      object{CL_rlp_math2(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(3)
      object{CL_rlp_math3(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(4)
      object{CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(5)
      object{CL_rlp_math5(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(6)
      object{CL_rlp_math6(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(7)
      object{CL_rlp_math7(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(8)
      object{CL_rlp_math8(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #break
    #case(9)
      object{CL_rlp_math9(z1,z2,d_rad,offs,cham,letter_dimensions) 
             translate <0,-2.0,0> scale <0.6,0.6,1> translate <0,-0.15,0>}
    #end
        translate <0,0.9,0>}
//  
//  cylinder{<-0.004,-0.454,0> <-0.004, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.844,-0.454,0> < 0.844, 2.25 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.454,0> < 0.84 ,-0.454,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.252,0> < 0.84 , 2.252,0> 0.002 pigment{Red}}
// 
//     }
#local letter_dimensions[0] = 0.84;  // Width 
#local letter_dimensions[1] = 2.25; // Height
#local letter_dimensions[2] = 2.25; // Superscript height
#local letter_dimensions[3] = 0.45; // Drop below line
//
#end
//*************************************************************************************************
// Mathematical Numerals **************************************************************************
//*************************************************************************************************
// Math 0  (zero)
//*************************************************************************************************
#macro CL_rlp_math0(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <-.240,1.000,0.900>,
 <0.350,2.000,0.350>, 
 <1.050,2.000,0.350>,
 <1.640,1.000,0.900>,

 <1.050,0.000,0.350>,
 <0.350,0.000,0.350>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.250,0.100,0.450>,
 <1.150,0.100,0.450>,
 <1.150,1.900,0.450>,
 <0.250,1.900,0.450>
}
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Math zero slash
//*************************************************************************************************
#macro CL_rlp_mathzeroslash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <-.240,1.000,0.900>,
 <0.350,2.000,0.350>, 
 <1.050,2.000,0.350>,
 <1.640,1.000,0.900>,

 <1.050,0.000,0.350>,
 <0.350,0.000,0.350>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.250,0.100,0.450>,
 <1.150,0.100,0.450>,
 <1.150,1.900,0.450>,
 <0.250,1.900,0.450>
}
//
#local pts1 = array[1];
#local pts1[0] =
array[6]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <1.300,2.000,0.000>,

 <1.400,2.000,0.000>,
 <1.400,1.900,0.000>,
 <0.100,0.000,0.000>
}
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end
//*************************************************************************************************
// Math 1
//*************************************************************************************************
#macro CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.375,0.000,0.000>,
 <0.375,0.100,0.000>,
 <0.575,0.100,0.100>,

 <0.575,1.700,0.100>,
 <0.375,1.700,0.000>,   // Left point
 <0.375,1.780,0.000>,   // Left point
 
 <0.700,2.000,0.000>,   // Outer round
 <0.825,2.000,0.000>,   // Outer round
 <0.825,0.100,0.100>,
 
 <1.025,0.100,0.000>,
 <1.025,0.000,0.000>
         }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Math 2
//*************************************************************************************************
#macro CL_rlp_math2(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <0.000,0.000,0.000>,
 <0.000,0.100,0.000>,
 <1.240,1.340,0.400>,   // 400

 <0.740,1.940,0.400>,   // 400
 <0.061,1.370,0.000>,   // Left point
 <0.000,1.420,0.000>,   // Left point
 
 <0.500,2.360,0.800>,   // Outer round
 <1.740,1.320,0.800>,   // Outer round
 <0.350,0.250,0.000>,
 
 <1.200,0.250,0.200>,
 <1.320,0.440,0.000>,
 <1.400,0.400,0.000>,
 
 <1.240,0.000,0.000>    // Bottom
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Math 3
//*************************************************************************************************
#macro CL_rlp_math3(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <-.088,0.200,0.200>,   // Lower round  .3
 <0.120,0.470,0.200>,   // Lower round  .3
 <0.740,-.100,0.550>,   // Lower inner  

 <1.500,0.920,0.650>,   // Lower inner  
 <0.540,0.920,0.000>,   // Middle point
 <0.500,1.000,0.000>,   // Middle point
 
 <1.200,1.520,0.400>,   // Upper inner  
 <0.600,1.950,0.400>,   // Upper inner  
 <0.070,1.540,0.000>,   // Upper point
 
 <0.000,1.600,0.000>,   // Upper point
 <0.560,2.234,1.000>,   // Upper outer 
 <1.500,1.500,0.800>,   // Upper outer 

 <0.900,1.100,0.000>,   // Outer middle point
 <1.670,1.000,1.600>,   // 
 <0.940,-.220,1.000>,   // 
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Math 4
//*************************************************************************************************
#macro CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[11]{
 <0.850,0.000,0.000>,
 <0.850,0.500,0.000>,
 <0.000,0.500,0.000>,

 <0.000,0.750,0.000>,
 <0.850,2.000,0.000>,
 <1.100,2.000,0.000>,
 
 <1.100,0.750,0.000>,
 <1.400,0.750,0.000>,
 <1.400,0.500,0.000>,
 
 <1.100,0.500,0.000>,
 <1.100,0.000,0.000>
        }
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.850,0.750,0.000>,
 <0.850,1.800,0.000>, 
 <0.140,0.760,0.000>,
 <0.140,0.750,0.000>
}

// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Math 5
//*************************************************************************************************
#macro CL_rlp_math5(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <-.088,0.250,0.240>,   // Lower round
 <0.080,0.500,0.240>,   // Lower round
 <0.740,-.170,0.600>,   // Lower inner   .6

 <1.600,1.050,0.900>,   // Lower inner   .8
 <0.000,1.200,0.000>,   // Middle point
 
 <0.200,2.000,0.000>,   // Upper top
 <1.300,2.000,0.000>,   // Upper right
 <1.300,1.900,0.000>,   // Upper right
 
 <1.200,1.750,0.000>,   // Right gorizontal  
 <0.240,1.750,0.000>,
 <0.140,1.350,0.000>,
 
 <2.000,1.300,1.500>,
 <0.840,-.230,1.000>,
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Math 6
//*************************************************************************************************
#macro CL_rlp_math6(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
object{CL_rlp_math9(z1,z2,d_rad,offs,cham,letter_dimensions) 
       translate <-0.7,-1,0> rotate <0,0,180> translate <0.7,1,0> }
//
#end 
//*************************************************************************************************
// Math 7
//*************************************************************************************************
#macro CL_rlp_math7(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <1.400,2.000,0.000>,
 <1.400,1.900,0.000>,
 <0.750,0.000,0.000>,

 <0.650,0.000,0.000>, 
 <0.650,0.100,0.000>,
 <1.221,1.750,0.000>, 
   
 <0.200,1.750,0.100>,
 <0.080,1.560,0.000>,
 <0.000,1.600,0.000>,

 <0.180,2.000,0.000>    
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Math 8
//*************************************************************************************************
#macro CL_rlp_math8(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <-.700,0.000,1.325>,   // Lower left
 <0.555,1.030,0.000>,   // Left waist 
 <-.500,2.000,1.200>,   // Left upper   

 <1.900,2.000,1.200>    // Right upper  
 <0.827,1.123,0.000>,   // Right waist
 <2.000,0.000,1.250>,
        }
#local pts[1] =
array[3]{
 <0.630,0.960,0.000>,
 <-.400,0.100,1.050>,   
 <1.600,0.100,1.000>   
        }
#local pts[2] =
array[3]{
 <0.750,1.192,0.000>,   
 <1.600,1.900,0.930>,   
 <-.050,1.900,0.800>
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.050,-0.6,-0.101> < 0.050,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-50> translate <0.4,0.835,0>} 
//  box{<-0.125,-0.6,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,48> translate <0.96,0.835,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Maths 9
//*************************************************************************************************
#macro CL_rlp_math9(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <1.060,0.500,0.600>,   // Right lower
 <1.120,1.080,0.000>,   // Middle point
 <0.000,0.600,1.000>,   // Left lower

 <0.000,2.000,0.900>,   // Top left
 <1.400,2.000,0.900>,   // Top right 
 <1.400,0.500,1.000>,   // Right outer

 <0.250,0.000,0.000>,   // Lower tip 
 <0.200,0.085,0.000>,   // Lower tip
        }
#local pts[1] =
array[4]{
 <0.250,1.900,0.450>,   
 <0.250,0.950,0.450>,   
 <1.130,1.200,0.000>,   

 <1.180,1.900,0.450>,   
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.4  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.125,-0.6,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-5> translate <1.2,0.6,0>} 
//  box{<-0.125,-0.6,-0.101> < 0.125,1.4,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,0> translate <0.125,0.6,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// PUNCTUATION ************************************************************************************
//*************************************************************************************************
// Full stop
//*************************************************************************************************
#macro CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 0.25; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.250,0.1250>,
 <0.250,0.250,0.1250>,
 <0.250,0.000,0.1250>,

 <0.000,0.000,0.1250>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end     
//*************************************************************************************************
// Bullet
//*************************************************************************************************
#macro CL_rlp_bullet(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.6; // Width 
#local letter_dimensions[1] = 1.3; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,1.300,0.300>,
 <0.600,1.300,0.300>,
 <0.60 ,0.700,0.300>,

 <0.000,0.700,0.300>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Comma
//*************************************************************************************************
#macro CL_rlp_comma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 0.25; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.250,0.125>,
 <0.250,0.250,0.125>,                    
 <0.250,-.200,0.200>,
                     
 <0.000,-.200,0.000>, 
 <0.000,-.100,0.000>,                   
 <0.125,-.100,0.125>,
  
 <0.125,0.000,0.000>, 
 <0.000,0.000,0.125>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Semi colon
//*************************************************************************************************
#macro CL_rlp_semi_colon(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_comma(z1,z2,d_rad,offs,cham,letter_dimensions)}
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,0.725,0>}
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 0.8; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//#local letter_height = letter_height + 0.725;
     }
//
#end     
//*************************************************************************************************
// Colon
//*************************************************************************************************
#macro CL_rlp_colon(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)}
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,0.725,0>}
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 0.8; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end
//*************************************************************************************************
// Exclamation mark
//*************************************************************************************************
#macro CL_rlp_exclamation_mark(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_width  = 0.25;
#local letter_height = 2.0;
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.075,0.450,0.000>,
 <-.010,2.050,0.125>,
 <0.260,2.050,0.125>,

 <0.175,0.450,0.0>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)}
  #local letter_dimensions[0] = 0.25; // Width 
  #local letter_dimensions[1] = 2.0; // Height
  #local letter_dimensions[2] = 2.0; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
#end 
//*************************************************************************************************
// Question mark
//*************************************************************************************************
#macro CL_rlp_question_mark(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <0.240,1.700,0.400>,
 <0.370,1.300,0.300>,   // Roundy bit
 <-.020,1.300,0.300>,   // Roundy bit

 <0.110,2.000,0.800>,
 <0.975,2.000,0.800>,  
 <0.975,1.300,0.800>,

 <0.550,0.900,0.400>,   // Base
 <0.475,0.450,0.000>,   // Base
 <0.375,0.450,0.000>,   // Base
 <0.300,0.900,0.400>,   // Base
 <0.600,1.300,0.600>, 

 <0.625,1.800,0.400>,
 <0.425,1.900,0.400> 
}
// invoking the object macro
union{ 
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0.3,0,0> }
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
     }
#local letter_dimensions[0] = 0.975; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end
//*************************************************************************************************
// Upside down question mark
//*************************************************************************************************
#macro CL_rlp_upside_down_question_mark(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_question_mark(z1,z2,d_rad,offs,cham,letter_dimensions) 
         rotate <0,0,180> translate <0.975,2.0,0>}
//
#end
//*************************************************************************************************
// Right inverted comma
//*************************************************************************************************
#macro CL_rlp_right_inverted_comma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_comma(z1,z2,d_rad,offs,cham,letter_dimensions)
       translate <0,1.8,0>}
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end
//*************************************************************************************************
//Left inverted comma
//*************************************************************************************************
#macro CL_rlp_left_inverted_comma(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_comma(z1,z2,d_rad,offs,cham,letter_dimensions)
       translate <-0.125,-0.125,0> rotate <0,0,180> translate <0.125,1.7,0>}
#local letter_dimensions[0] = 0.25; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end
//*************************************************************************************************
// Round left bracket
//*************************************************************************************************
#macro CL_rlp_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.8; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.700,-.200,0.000>,
 <-1.20,1.000,2.100>,
 <0.700,2.200,0.000>,

 <0.790,2.110,0.000>,
 <-.200,1.000,1.500>,
 <0.790,-.110,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Round right bracket
//*************************************************************************************************
#macro CL_rlp_round_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions) 
       scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end
//*************************************************************************************************
// Square left bracket
//*************************************************************************************************
#macro CL_rlp_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.6; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,2.200,0.000>,
 <0.600,2.200,0.000>,
 <0.600,2.100,0.000>,

 <0.350,2.100,0.000>,
 <0.350,-.100,0.000>,
 <0.600,-.100,0.000>,
 
 <0.600,-.200,0.000>,
 <0.000,-.200,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Square right bracket
//*************************************************************************************************
#macro CL_rlp_square_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions) 
       scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end   
//*************************************************************************************************
// Curly left brace part
//*************************************************************************************************
#macro CL_rlp_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.6; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.600,-.200,0.000>,
 <0.200,-.200,0.400>,
 <0.050,0.250,0.600>,

 <0.300,0.950,0.300>,
 <0.000,0.950,0.000>,
 <0.000,1.050,0.000>,
 
 <0.400,1.050,0.400>,
 <0.550,0.500,0.600>,
 <0.300,-.100,0.300>,
 
 <0.600,-.100,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Curly left bracket
//*************************************************************************************************
#macro CL_rlp_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions)}
  object{CL_rlp_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions) 
         scale <1,-1,1> translate <0,2.0,0>}
     }
//
#end   
//*************************************************************************************************
// Curly right bracket
//*************************************************************************************************
#macro CL_rlp_curly_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
         scale <-1,1,1> translate <0.6,0,0>}
//
#end
//*************************************************************************************************
// Mathematical Brackets **************************************************************************   
//*************************************************************************************************
// Math round left bracket
//*************************************************************************************************
#macro CL_rlp_math_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.62; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.700,-.200,0.000>,
 <-.700,0.900,2.500>,
 <0.700,2.000,0.000>,

 <0.770,1.930,0.000>,
 <-.200,0.900,1.500>,
 <0.770,-.130,0.000>
        }
// invoking the object macro
//  cylinder{<-0.002, -0.2 ,0> <-0.002,  2.2 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.622, -0.2 ,0> < 0.622,  2.2 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.202,0> < 0.62 ,-0.202,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.202,0> < 0.62 , 2.202,0> 0.004 pigment{Red}}
//  box{<-0.100,-1.2,-0.101> < 0.100,1.2,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,0> translate <0.100,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       translate <-0.15,0,0>}
//
#end 
//*************************************************************************************************
// Elastic math round left bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_round_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//   
// Working out the dimensions. We are assuming bheight is greater than 2.4.
// Thickness goes from 0.2 at bheight = 2.4 to 0.35 when bheight = 4.8 and above. 
// The bracket centres on y=1.0 
//
#local s_thick  = 0.2+(bheight-2.4)*0.15/2.4;
#local hbheight = bheight/2; 
#local bracrad  = bheight*1.78145/2.4;
#local bracsep  = 0;
#local thetang  = 3.131592*42.35/180;
//
#if(s_thick > 0.35)
  #local s_thick = 0.35;
#end
#if(bheight > 4.8)
  #local bracrad = 2*1.78145; 
  #local bracsep = (bheight-4.8)/2;
#end
#local deltrad  = (s_thick - 0.1)/(1 - cos(thetang));
#local tildrad  = bracrad - 0.1 - deltrad;
//  
#local letter_dimensions[0] =  bracrad-(bracrad-0.1)*cos(thetang); // Width 
#local letter_dimensions[1] =  hbheight+1.0;  // Height
#local letter_dimensions[2] =  hbheight+1.0;  // Superscript height
#local letter_dimensions[3] = -hbheight+1.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 < 0.000                             , bracrad*sin(thetang/2)                     +bracsep,bracrad>,
 < bracrad*(1-cos(thetang))          , bracrad*sin(thetang)                       +bracsep,0.000  >,
 < bracrad-(bracrad-0.1)*cos(thetang), (bracrad-0.1)*sin(thetang)                 +bracsep,0.000  >,

 < s_thick                           , tildrad*sin(thetang/2)+deltrad*sin(thetang)+bracsep,tildrad>,
 < s_thick                           ,-tildrad*sin(thetang/2)-deltrad*sin(thetang)-bracsep,tildrad>,
 
 < bracrad-(bracrad-0.1)*cos(thetang),-(bracrad-0.1)*sin(thetang)                 -bracsep,0.000  >,
 < bracrad*(1-cos(thetang))          ,-bracrad*sin(thetang)                       -bracsep,0.000  >,
 < 0.000                             ,-bracrad*sin(thetang/2)                     -bracsep,bracrad>
        }
// invoking the object macro
//  cylinder{<-0.002, -hbheight+1.0 ,0> <-0.002,  hbheight+1.0 ,0> 0.004 pigment{Red}}
//  cylinder{< bracrad-(bracrad-0.1)*cos(thetang), -hbheight+1.0 ,0> < bracrad-(bracrad-0.1)*cos(thetang),  hbheight+1.0 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-hbheight+1.0,0> < bracrad-(bracrad-0.1)*cos(thetang) ,-hbheight+1.0,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, hbheight+1.0,0> <bracrad-(bracrad-0.1)*cos(thetang) , hbheight+1.0,0> 0.004 pigment{Red}}
//  box{<0.000,-1.2,-0.101> < s_thick,1.2,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,0> translate <0,1,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       translate <0,1.0,0>}
//
#end 
//*************************************************************************************************
// Math round right bracket
//*************************************************************************************************
#macro CL_rlp_math_round_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_math_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions) 
       scale <-1,1,1> translate <0.55,0,0>}
//
#end
//*************************************************************************************************
// Elastic math round right bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_round_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
object{CL_rlp_elastic_math_round_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions) 
       scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end//*************************************************************************************************
// Math square left bracket
//*************************************************************************************************
#macro CL_rlp_math_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.40; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,2.200,0.000>,
 <0.400,2.200,0.000>,
 <0.400,2.100,0.000>,

 <0.200,2.100,0.000>,
 <0.200,-.100,0.000>,
 <0.400,-.100,0.000>,
 
 <0.400,-.200,0.000>,
 <0.000,-.200,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Elastic math square left bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_square_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//   
// Working out the dimensions. We are assuming bheight is greater than 2.4.
// Thickness goes from 0.2 at bheight = 2.4 to 0.35 when bheight = 4.8 and above. 
// The bracket centres on y=1.0
//
#local s_thick = 0.2+(bheight-2.4)*0.15/2.4;
#local hbheight = bheight/2;
//
#if(s_thick > 0.35)
  #local s_thick = 0.35;
#end
//
#local letter_dimensions[0] =  s_thick+0.2; // Width 
#local letter_dimensions[1] =  hbheight+1; // Height
#local letter_dimensions[2] =  hbheight+1; // Superscript height
#local letter_dimensions[3] = -hbheight+1; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000      , hbheight+1.0,0.000>,
 <s_thick+0.2, hbheight+1.0,0.000>,
 <s_thick+0.2, hbheight+0.9,0.000>,

 <s_thick    , hbheight+0.9,0.000>,
 <s_thick    ,-hbheight+1.1,0.000>,
 <s_thick+0.2,-hbheight+1.1,0.000>,
 
 <s_thick+0.2,-hbheight+1.0,0.000>,
 <0.000      ,-hbheight+1.0,0.000>
        }
// invoking the object macro
//  box{<-0.175,-3,-0.101> < 0.175,3,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,0> translate <0.175,0,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Math square right bracket
//*************************************************************************************************
#macro CL_rlp_math_square_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_math_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions) 
       scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end   
//*************************************************************************************************
// Elastic math square right bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_square_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
object{CL_rlp_elastic_math_square_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions) 
       scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end   
//*************************************************************************************************
// Math curly left brace part
//*************************************************************************************************
#macro CL_rlp_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions)
//
// this pointset will contain two subsets eventually
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.6; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.600,-.200,0.000>,
 <0.200,-.200,0.400>,    // 400
 <0.200,0.950,0.300>,    // 300

 <0.000,0.950,0.000>,
 <0.000,1.050,0.000>,
 <0.400,1.050,0.400>,    // 400

 <0.400,-.100,0.300>,    // 300
 <0.600,-.100,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Elastic math curly left brace part
//*************************************************************************************************
#macro CL_rlp_elastic_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//   
// Working out the dimensions. We are assuming bheight is greater than 2.4.
// Thickness goes from 0.2 at bheight = 2.4 to 0.35 when bheight = 4.8 and above. 
// The bracket centres on y=1.0  
//
#local s_thick = 0.2+(bheight-2.4)*0.15/2.4;
#local hbheight = bheight/2;
//
#if(s_thick > 0.35)
  #local s_thick = 0.35;
#end
//  
#local letter_dimensions[0] =  3*s_thick; // Width 
#local letter_dimensions[1] =  hbheight+1.0; // Height
#local letter_dimensions[2] =  hbheight+1.0; // Superscript height
#local letter_dimensions[3] =  hbheight-1.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000    ,-.050       ,0.000    >,
 <0.000    ,0.050       ,0.000    >,    // 
 <s_thick  ,0.050       ,s_thick  >,    // 

 <s_thick  ,hbheight    ,2*s_thick>,
 <3*s_thick,hbheight    ,0.000    >,
 <3*s_thick,hbheight-0.1,0.000    >,    // 

 <2*s_thick,hbheight-0.1,0.400    >,    // 
 <2*s_thick,-.050       ,2*s_thick>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Math curly left bracket
//*************************************************************************************************
#macro CL_rlp_math_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions)}
  object{CL_rlp_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,letter_dimensions) 
         scale <1,-1,1> translate <0,2.0,0>}
     }
//
#end   
//*************************************************************************************************
// Elastic Math curly left bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_curly_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
union{
  object{CL_rlp_elastic_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
         translate <0,1.0,0>}
  object{CL_rlp_elastic_math_curly_left_brace_part(z1,z2,d_rad,offs,cham,bheight,letter_dimensions) 
         scale <1,-1,1> translate <0,1.0,0>}
     }
//
#end   
//*************************************************************************************************
// Math curly right bracket
//*************************************************************************************************
#macro CL_rlp_math_curly_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_math_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)
         scale <-1,1,1> translate <0.6,0,0>}
//
#end   
//*************************************************************************************************
// Elastic math curly right bracket
//*************************************************************************************************
#macro CL_rlp_elastic_math_curly_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
object{CL_rlp_elastic_math_curly_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
         scale <-1,1,1> translate <letter_dimensions[0],0,0>}
//
#end   
//*************************************************************************************************
// Langle
//*************************************************************************************************
#macro CL_rlp_langle(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.800,-.200,0.000>,
 <0.700,-.200,0.000>,    // 400
 <0.000,0.900,0.000>,    // 300

 <0.700,2.000,0.000>,
 <0.800,2.000,0.000>,
 <0.800,1.900,0.000>,    // 400

 <0.160,0.900,0.000>,    // 300
 <0.800,-.100,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Elastic langle
//*************************************************************************************************
#macro CL_rlp_elastic_langle(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//   
// Working out the dimensions. We are assuming bheight is greater than 2.4.
// Thickness goes from 0.2 at bheight = 2.4 to 0.35 when bheight = 4.8 and above. 
// The bracket centres on y=1.0
//
#local s_thick = 0.14+(bheight-2.4)*0.06/2.4;
#local hbheight = bheight/2;
//
#if(s_thick > 0.2)
  #local s_thick = 0.2;
#end  
//
#local hypot   = sqrt(0.49+hbheight*hbheight);
#local backbit = s_thick*hypot/hbheight;
#local dropbit = hbheight*backbit/(hbheight+0.7);
//  
#local letter_dimensions[0] =  0.7+dropbit;  // Width 
#local letter_dimensions[1] =  hbheight+1.0; // Height
#local letter_dimensions[2] =  hbheight+1.0; // Superscript height
#local letter_dimensions[3] = -hbheight+1.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000        , 0.000           ,0.000>,
 <0.700        , hbheight        ,0.000>,    // 400
 <0.700+dropbit, hbheight        ,0.000>,    // 300

 <0.700+dropbit, hbheight-dropbit,0.000>,
 <backbit      , 0.000           ,0.000>,
 <0.700+dropbit,-hbheight+dropbit,0.000>,    // 400

 <0.700+dropbit,-hbheight        ,0.000>,    // 300
 <0.700        ,-hbheight        ,0.000>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       translate <0,1.0,0>}
//       
#end  
//*************************************************************************************************
// Rangle
//*************************************************************************************************
#macro CL_rlp_rangle(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_langle(z1,z2,d_rad,offs,cham,letter_dimensions)
         scale <-1,1,1> translate <0.8,0,0>}
//
#end 
//*************************************************************************************************
// Elastic rangle
//*************************************************************************************************
#macro CL_rlp_elastic_rangle(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
object{CL_rlp_elastic_langle(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
         scale <-1,1,1> translate <0.8,0,0>}
//
#end 
//*************************************************************************************************
// Cup
//*************************************************************************************************
#macro CL_rlp_cup(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,2.000,0.000>,
 <0.140,2.000,0.000>,    // 
 <0.140,0.140,0.560>,    // 

 <1.260,0.140,0.560>,
 <1.260,2.000,0.000>,
 <1.400,2.000,0.000>,    // 

 <1.400,0.000,0.700>,    // 
 <0.000,0.000,0.700>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end   
//*************************************************************************************************
// Cap
//*************************************************************************************************
#macro CL_rlp_cap(z1,z2,d_rad,offs,cham,letter_dimensions)  
//
object{CL_rlp_cup(z1,z2,d_rad,offs,cham,letter_dimensions)
         scale <1,-1,1> translate <0,2,0>}
//
#end
//*************************************************************************************************
// OTHER SYMBOLS **********************************************************************************
//*************************************************************************************************
// Surd
//*************************************************************************************************
#macro CL_rlp_surd(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.93; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,1.030,0.000>,
 <0.330,1.210,0.000>, 
 <0.608,0.450,0.000>,
 
 <0.842,2.000,0.000>,
 <0.930,2.000,0.000>,
 <0.930,1.900,0.000>,

 <0.640,0.000,0.000>,
 <0.560,0.000,0.000>,
 <0.190,1.010,0.000>,

 <0.050,0.940,0.000>
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.932,  0   ,0> < 0.932,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.93 ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 0.93 , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.10,-1,-0.101> < 0.10,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,20> translate <0.485,0.5,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-62> translate <0.86,1.430,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,2,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-8.6> translate <0.645,0.36,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Elastic surd
//*************************************************************************************************
#macro CL_rlp_elastic_surd(z1,z2,d_rad,offs,cham,inner_size,space_around,super_num,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
//inner_size{Width of inclusion, height above, super height, drop below} 
//
#local width_inside = inner_size[0];
#local height_above = inner_size[1];
#local drop_below   = inner_size[3]; 
//
#local total_height = height_above+drop_below+space_around+0.1;
#local total_width  = width_inside+0.2;
#local arm_slope    = 1.9/0.29;
#local top_corner_x = (total_height-0.450)/arm_slope+0.608;
#local rig_corner_x = top_corner_x+total_width;
#local inn_vertex_x = (total_height-0.1)/arm_slope+0.640;
//
#local letter_dimensions[0] = top_corner_x+total_width+0.1; // Width 
#local letter_dimensions[1] = total_height-drop_below; // Height
#local letter_dimensions[2] = top_corner_x+0.1; // Shift for the inner part
#local letter_dimensions[3] = drop_below; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <0.000           ,1.030           ,0.000>,
 <0.330           ,1.210           ,0.000>, 
 <0.608           ,0.450           ,0.000>,
 
 <top_corner_x    ,total_height    ,0.000>,
 <rig_corner_x    ,total_height    ,0.000>,
 <rig_corner_x    ,total_height-0.3,0.000>,  
 
 <rig_corner_x-0.1,total_height-0.3,0.000>,  
 <rig_corner_x-0.1,total_height-0.1,0.000>,  
 <inn_vertex_x    ,total_height-0.1,0.000>,  
   
 <0.640           ,0.000           ,0.000>,
 <0.560           ,0.000           ,0.000>,
 <0.190           ,1.010           ,0.000>,

 <0.050           ,0.940           ,0.000>
        }
// invoking the object macro
#if(CL_debug_lines = 1)
  union{                 
#end
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.932,  0   ,0> < 0.932,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 0.93 ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 0.93 , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.10,-1,-0.101> < 0.10,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,20> translate <0.485,0.5,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-62> translate <0.86,1.430,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,2,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-8.6> translate <0.645,0.36,0>} 
union{
    #if(super_num = 3)  
      #local super_dimensions = array[4]{0,0,0,0};
      object{CL_rlp_math3(z1,z2,d_rad,offs,cham,super_dimensions)   
                          scale <0.4,0.4,1> translate <top_corner_x-0.75,total_height-0.8,0>
            }
    #end
    #if(super_num = 4)  
      #local super_dimensions = array[4]{0,0,0,0};
      object{CL_rlp_math4(z1,z2,d_rad,offs,cham,super_dimensions)   
                          scale <0.4,0.4,1> translate <top_corner_x-0.75,total_height-0.8,0>
            }
    #end
    rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
    translate <0,-drop_below,0> 
       }
#if(CL_debug_lines = 1)
  cylinder{< 0.002               ,-letter_dimensions[3],0> < 0.002               , letter_dimensions[1],0> 0.02 pigment{Red}}
  cylinder{< letter_dimensions[0],-letter_dimensions[3],0> < letter_dimensions[0], letter_dimensions[1],0> 0.02 pigment{Red}}
  cylinder{< 0.000               ,-letter_dimensions[3],0> < letter_dimensions[0],-letter_dimensions[3],0> 0.02 pigment{Red}}
  cylinder{< 0.000               , letter_dimensions[1],0> < letter_dimensions[0], letter_dimensions[1],0> 0.02 pigment{Red}}
     } 
#end
//
#end 
//*************************************************************************************************
// Tilde
//*************************************************************************************************
#macro CL_rlp_tilde(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.0; // Height
#local letter_dimensions[2] = 1.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,1.000,0.000>, 
 <0.100,1.000,0.000>,
 <0.100,0.700,0.300>,    
 
 <1.400,1.350,0.800>,    //
 <1.400,0.600,0.000>,
 <1.300,0.600,0.000>,
 
 <1.300,0.900,0.300>,
 <0.000,0.250,0.800>     //
        }
// invoking the object macro
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)  
       scale <1,-1,1> translate <0,1.6,0>}
//       
#end  
//*************************************************************************************************
// Maths tilde
//*************************************************************************************************
#macro CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.03; // Height
#local letter_dimensions[2] = 1.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.850,0.000>, 
 <0.065,0.900,0.000>,
 <0.300,0.700,0.300>,    // 300 
 
 <1.200,1.050,0.500>,    // 800
 <1.400,0.650,0.000>,
 <1.335,0.600,0.000>,
 
 <1.100,0.800,0.300>,    // 300
 <0.200,0.450,0.500>     // 800
        }
// invoking the object macro
//union{
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)  
       scale <1,-1,1> translate <0,1.6,0>}   
//  cylinder{< 0.002               ,-letter_dimensions[3],0> < 0.002               , letter_dimensions[1],0> 0.02 pigment{Red}}
//  cylinder{< letter_dimensions[0],-letter_dimensions[3],0> < letter_dimensions[0], letter_dimensions[1],0> 0.02 pigment{Red}}
//  cylinder{< 0.000               ,-letter_dimensions[3],0> < letter_dimensions[0],-letter_dimensions[3],0> 0.02 pigment{Red}}
//  cylinder{< 0.000               , letter_dimensions[1],0> < letter_dimensions[0], letter_dimensions[1],0> 0.02 pigment{Red}}
//  cylinder{< 0.000               , 0.67,0> < letter_dimensions[0], 0.67,0> 0.02 pigment{Red}}
//     }
#end   
//*************************************************************************************************
// Maths prime
//*************************************************************************************************
#macro CL_rlp_prime(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.3; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,1.400,0.000>, 
 <0.000,2.000,0.150>,
 <0.300,2.000,0.150>,    //  
 
 <0.100,1.400,0.000>,    // 
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Maths i without the dot
//*************************************************************************************************
#macro CL_rlp_imath(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.668,1.400,0.300>,
 
 <0.343,0.100,0.200>,
 <0.622,0.100,0.200>, 
 <0.728,0.524,0.050>,
 
 <0.825,0.500,0.050>,
 <0.705,0.000,0.250>,
 <0.110,0.000,0.400>
 } 
//
// invoking the object macro
//  cylinder{<-0.002,-0.300,0> <-0.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.002,-0.300,0> < 1.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.302,0> < 1.000,-0.302,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.000, 2.002,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
       translate <0.09,0,0>}
  #local letter_dimensions[0] = 1.0; // Width 
  #local letter_dimensions[1] = 1.4; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.3; // Drop below line
//
#end
//*************************************************************************************************
// Math j without the dot
//*************************************************************************************************
#macro CL_rlp_jmath(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 < 0.278, 0.700,0.500>,  
 <-0.217,-1.300,0.600>,  
 <-1.268,-1.300,0.600>,

 <-1.010,-0.750,0.200>,  // Start of bobble
 <-0.760,-0.750,0.250>, 
 <-0.760,-1.050,0.250>,                     

 <-0.960,-1.050,0.000>,  // End of bobble. Stays zero radius                  
 <-0.905,-1.200,0.250>,
 <-0.640,-1.200,0.250> 

 <-0.340,-0.947,0.300>,                    
 < 0.047, 0.600,0.300>, 
 <-0.420, 0.600,0.200>,                     

 <-0.528, 0.176,0.050>,  // End of loop                  
 <-0.625, 0.200,0.050>,  // End of loop
 <-0.500, 0.700,0.260> 
}
// invoking the object macro
//  cylinder{<-0.002, -0.6   ,0> <-0.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.102, -0.6   ,0> < 1.102, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, -0.6   ,0> < 2.00 ,-0.60 ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,  2.00  ,0> < 1.0  , 2.00 ,0> 0.002 pigment{Red}}
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
       translate <0.8,0.7,0> }
  #local letter_dimensions[0] = 0.98; // Width 
  #local letter_dimensions[1] = 1.40; // Height
  #local letter_dimensions[2] = 1.40; // Superscript height
  #local letter_dimensions[3] = 0.60; // Drop below line
//
#end
//*************************************************************************************************
// UNIT VECTORS ***********************************************************************************
//*************************************************************************************************
// Unit vec i
//*************************************************************************************************
#macro CL_rlp_iuvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.437,1.300,0.120>,    
 <0.200,1.300,0.120>,
 <0.092,0.895,0.050>,
 
 <-.005,0.919,0.050>,
 <0.125,1.400,0.190>,
 <0.668,1.400,0.300>,
 
 <0.343,0.100,0.200>,
 <0.622,0.100,0.200>, 
 <0.728,0.524,0.050>,
 
 <0.825,0.500,0.050>,
 <0.705,0.000,0.250>,
 <0.110,0.000,0.400>
} 
//
#local pts1 = array[1]  
#local pts1[0] =
array[4]{
 <0.000,-.200,0.000>,
 <0.900,-.200,0.000>,
 <0.900,-.360,0.000>,
 
 <0.000,-.360,0.000>
        }
// invoking the object macro
union{
//  cylinder{<-0.002,-0.300,0> <-0.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.002,-0.300,0> < 1.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.302,0> < 1.000,-0.302,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.000, 2.002,0> 0.002 pigment{Red}}
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
         translate <0.09,0,0>}
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0,0,0>}
  #local letter_dimensions[0] = 1.0; // Width 
  #local letter_dimensions[1] = 1.85; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
     }
//     
#end
//*************************************************************************************************
// Unit vec j
//*************************************************************************************************
#macro CL_rlp_juvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.1; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.6; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 < 0.278, 0.700,0.500>,  
 <-0.217,-1.300,0.600>,  
 <-1.268,-1.300,0.600>,

 <-1.010,-0.750,0.200>,  // Start of bobble
 <-0.760,-0.750,0.250>, 
 <-0.760,-1.050,0.250>,                     

 <-0.960,-1.050,0.000>,  // End of bobble. Stays zero radius                  
 <-0.905,-1.200,0.250>,
 <-0.640,-1.200,0.250> 

 <-0.340,-0.947,0.300>,                    
 < 0.047, 0.600,0.300>, 
 <-0.420, 0.600,0.200>,                     

 <-0.528, 0.176,0.050>,  // End of loop                  
 <-0.625, 0.200,0.050>,  // End of loop
 <-0.500, 0.700,0.260> 
}
//
#local pts1 = array[1]  
#local pts1[0] =
array[4]{
 <0.050,-.200,0.000>,
 <0.900,-.200,0.000>,
 <0.900,-.360,0.000>,
 
 <0.050,-.360,0.000>
        }
// invoking the object macro
union{
//  cylinder{<-0.002, -0.6   ,0> <-0.002, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.102, -0.6   ,0> < 1.102, 2.00 ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000, -0.6   ,0> < 2.00 ,-0.60 ,0> 0.002 pigment{Red}}
//  cylinder{<-0.000,  2.00  ,0> < 1.0  , 2.00 ,0> 0.002 pigment{Red}}
  object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
         translate <0.8,0.7,0>}
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.05,0,0>}
  #local letter_dimensions[0] = 0.98; // Width 
  #local letter_dimensions[1] = 2.00; // Height
  #local letter_dimensions[2] = 2.00; // Superscript height
  #local letter_dimensions[3] = 0.6; // Drop below line
     } 
//     
#end
//*************************************************************************************************
// Unit vec k
//*************************************************************************************************
#macro CL_rlp_kuvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[27]{
 <0.375,0.800,0.000>,   // Under corner
 <0.172,-.025,0.100>,
 <-.022,0.023,0.100>,

 <0.430,1.850,0.100>, 
 <0.200,1.850,0.050>,
 <0.200,1.950,0.050>,

 <0.550,2.000,0.100>,
 <0.650,2.000,0.050>,  
 <0.650,1.900,0.100>,
 
 <0.430,1.000,0.000>,  //0.200 Top of h
 <0.950,1.400,0.200>,   //0.200

 <1.628,1.400,0.600>,
 <1.400,0.850,0.200>,  // Start of bobble
 <1.150,0.850,0.250>, 

 <1.150,1.150,0.250>,                  
 <1.360,1.150,0.000>,  // End of bobble. Stays zero radius                  
 <1.295,1.300,0.250>,

 <1.000,1.300,0.250>, 
 <0.500,0.913,0.000>,   // End of twiddle
 <1.188,0.800,0.400>,  //0.400  Top of h
 
 <1.013,0.100,0.200>,
 <1.292,0.100,0.200>, 
 <1.398,0.524,0.050>,
 
 <1.495,0.500,0.050>,
 <1.375,0.000,0.250>,   // Bottom right
 <0.780,0.000,0.400>,   // Bottom right
 
 <0.955,0.700,0.300>,   //0.400 Inner top
}
//
#local pts1 = array[1]  
#local pts1[0] =
array[4]{
 <0.000,-.200,0.000>,
 <1.400,-.200,0.000>,
 <1.400,-.360,0.000>,
 
 <0.000,-.360,0.000>
        }
// invoking the object macro
union{
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.5 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.492,  0   ,0> < 1.492,  2.5 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.49  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.502,0> < 1.49  , 2.502,0> 0.004 pigment{Red}}
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham) 
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham) 
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.05,0.5,0>}
  #local letter_dimensions[0] = 1.49; // Width 
  #local letter_dimensions[1] = 2.5; // Height
  #local letter_dimensions[2] = 2.0; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
     }
#end
//*************************************************************************************************
// Unit vec n
//*************************************************************************************************
#macro CL_rlp_nuvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,-.200,0.000>,    
 <1.470,-.200,0.000>,
 <1.470,-.360,0.000>,
 
 <0.000,-.360,0.000>
} 
//
// invoking the object macro
union{
//  cylinder{<-0.002,-0.380,0> <-0.002, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 1.632,-0.380,0> < 1.632, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.382,0> < 1.630,-0.382,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.102,0> < 1.630, 2.102,0> 0.004 pigment{Red}}
  object{CL_rlp_mathn(z1,z2,ld_rad,l_offs,cham,letter_dimensions)}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.3,0.1,0>}
  #local letter_dimensions[0] = 1.63; // Width 
  #local letter_dimensions[1] = 2.00; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
     }
//     
#end 
//*************************************************************************************************
// Unit vec r
//*************************************************************************************************
#macro CL_rlp_ruvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,-.200,0.000>,    
 <1.200,-.200,0.000>,
 <1.200,-.360,0.000>,
 
 <0.000,-.360,0.000>
} 
//
// invoking the object macro
union{
  object{CL_rlp_mathr(z1,z2,ld_rad,l_offs,cham,letter_dimensions)}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.25,0.1,0>}
  #local letter_dimensions[0] = 1.33; // Width 
  #local letter_dimensions[1] = 2.00; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
//  cylinder{<-0.002,-0.380,0> <-0.002, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 1.332,-0.380,0> < 1.332, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.382,0> < 1.630,-0.382,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.630, 2.002,0> 0.004 pigment{Red}}
     }
//     
#end  
//*************************************************************************************************
// Unit vec phi
//*************************************************************************************************
#macro CL_rlp_phiuvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,-.200,0.000>,    
 <1.350,-.200,0.000>,
 <1.350,-.360,0.000>,
 
 <0.000,-.360,0.000>
} 
//
// invoking the object macro
union{
//  cylinder{<-0.002,-0.380,0> <-0.002, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 1.502,-0.380,0> < 1.502, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.382,0> < 1.630,-0.382,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.102,0> < 1.630, 2.102,0> 0.004 pigment{Red}}
  object{CL_rlp_phi(z1,z2,ld_rad,l_offs,cham,letter_dimensions)}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.5,0.3,0>}
  #local letter_dimensions[0] = 1.50; // Width 
  #local letter_dimensions[1] = 2.30; // Height
  #local letter_dimensions[2] = 1.4; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
     }
//     
#end 
//*************************************************************************************************
// Unit vec theta
//*************************************************************************************************
#macro CL_rlp_thetauvec(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,-.200,0.000>,    
 <1.200,-.200,0.000>,
 <1.200,-.360,0.000>,
 
 <0.000,-.360,0.000>
} 
//
// invoking the object macro
union{
//  cylinder{<-0.002,-0.380,0> <-0.002, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 1.352,-0.380,0> < 1.352, 1.852 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.382,0> < 1.630,-0.382,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.302,0> < 1.630, 2.302,0> 0.004 pigment{Red}}
  object{CL_rlp_theta(z1,z2,ld_rad,l_offs,cham,letter_dimensions)}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.35,0.5,0>}
  #local letter_dimensions[0] = 1.35; // Width 
  #local letter_dimensions[1] = 2.35; // Height
  #local letter_dimensions[2] = 2.0; // Superscript height
  #local letter_dimensions[3] = 0.38; // Drop below line
     }
//     
#end  
//*************************************************************************************************
// SPECIAL CHARACTERS *****************************************************************************
//*************************************************************************************************
// Hash
//*************************************************************************************************
#macro CL_rlp_hash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[32]{
 <0.210,0.000,0.000>, 
 <0.210,0.050,0.000>,
 <0.320,0.600,0.000>,
 
 <0.000,0.600,0.000>,
 <0.000,0.700,0.000>,
 <0.340,0.700,0.000>,
                                             
 <0.460,1.300,0.000>,
 <0.140,1.300,0.000>,
 <0.140,1.400,0.000>,
    
 <0.480,1.400,0.000>,
 <0.600,2.000,0.000>,   // Top of first slash
 <0.690,2.000,0.000>,
 
 <0.690,1.950,0.000>,
 <0.580,1.400,0.000>,
 <0.980,1.400,0.000>, 
 
 <1.100,2.000,0.000>,  // Top of second slash
 <1.190,2.000,0.000>,
 <1.190,1.950,0.000>,
 
 <1.080,1.400,0.000>,
 <1.400,1.400,0.000>,
 <1.400,1.300,0.000>,
 
 <1.060,1.300,0.000>,
 <0.940,0.700,0.000>,
 
 <1.260,0.700,0.000>,
 <1.260,0.600,0.000>,
 <0.920,0.600,0.000>,
 
 <0.800,0.000,0.000>,
 <0.710,0.000,0.000>,
 <0.710,0.050,0.000>,
                    
 <0.820,0.600,0.000>,                    
 <0.420,0.600,0.000>,                    
 <0.300,0.000,0.000>
        }
#local pts[1] =
array[4]{
 <0.440,0.700,0.000>, 
 <0.840,0.700,0.000>,
 <0.960,1.300,0.000>,
 
 <0.560,1.300,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Caret
//*************************************************************************************************
#macro CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.0; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,1.400,0.000>, 
 <0.000,1.500,0.000>,
 <0.500,2.000,0.000>,
 
 <1.000,1.500,0.000>,
 <1.000,1.400,0.000>,
 <0.900,1.400,0.000>,
 
 <0.500,1.800,0.000>,   // Inner vertex
 <0.100,1.400,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Underscore
//*************************************************************************************************
#macro CL_rlp_underscore(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 0.1; // Height
#local letter_dimensions[2] = 0.1; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.000,0.000>, 
 <0.000,0.100,0.000>,
 <1.600,0.100,0.000>,
 
 <1.600,0.000,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Asterisk part
//*************************************************************************************************
#macro CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.3; // Width 
#local letter_dimensions[1] = 0.7; // Height
#local letter_dimensions[2] = 0.7; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.050,-.050,0.000>, 
 <-.050,-.050,0.000>,
 <-.050,0.200,0.100>,
 
 <-.150,0.500,0.150>,
 <0.150,0.500,0.150>,
 <0.050,0.200,0.100>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Asterisk 
//*************************************************************************************************
#macro CL_rlp_asterisk(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
union{
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) }
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0, 60>}
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0,120>}
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0,180>}
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0,240>}
  object{CL_rlp_asteriskpart(z1,z2,d_rad,offs,cham,letter_dimensions) rotate <0,0,300>}
  translate <0.7,1.0,0>
     }
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.5; // Height
#local letter_dimensions[2] = 1.5; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end  
//*************************************************************************************************
// Dagger
//*************************************************************************************************
#macro CL_rlp_dagger(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.52; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[13]{
 <0.000,1.850,0.000>, 
 <0.000,1.950,0.000>,
 <0.200,1.950,0.000>,
 
 <0.150,2.200,0.150>,
 <0.370,2.200,0.150>,
 <0.320,1.950,0.000>,
 
 <0.520,1.950,0.000>,
 <0.520,1.850,0.000>,
 <0.320,1.850,0.000>,
 
 <0.370,1.600,0.000>,
 <0.260,1.000,0.000>,
 <0.150,1.600,0.000>,
 
 <0.200,1.850,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Degree symbol 
//*************************************************************************************************
#macro CL_rlp_degrees(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.5; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,1.500,0.250>,  
 <0.000,2.000,0.250>,
 <0.500,2.000,0.250>,
 
 <0.500,1.500,0.250>
        }
#local pts[1] =
array[4]{
 <0.100,1.900,0.150>,  
 <0.100,1.600,0.150>,
 <0.400,1.600,0.150>,
 
 <0.400,1.900,0.150>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Null subscript 
//*************************************************************************************************
#macro CL_rlp_nullsubscript(z1,z2,d_rad,offs,cham,letter_dimensions)    
  object{ 
    CL_rlp_degrees(z1,z2,d_rad,offs,cham,letter_dimensions)  
    translate <0,-1.7,0> scale <1,1.2,1>
        }  
  #local letter_dimensions[0] = 0.5; // Width 
  #local letter_dimensions[1] = 0.5; // Height
  #local letter_dimensions[2] = 0.5; // Superscript height
  #local letter_dimensions[3] = 0.24; // Drop below line
#end
//*************************************************************************************************
// Percent 
//*************************************************************************************************
#macro CL_rlp_percent(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.000,0.000,0.000>, 
 <0.000,0.100,0.000>,
 <1.490,2.000,0.000>,
 
 <1.600,2.000,0.000>,
 <1.600,1.900,0.000>,
 <0.110,0.000,0.000>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_nullsubscript(z1,z2,d_rad,offs,cham,letter_dimensions)translate <0.1,1.4,0>}
  object{CL_rlp_nullsubscript(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0.9,0.4,0>}  
  #local letter_dimensions[0] = 1.6; // Width 
  #local letter_dimensions[1] = 2.0; // Height
  #local letter_dimensions[2] = 2.0; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }  
//     
#end  
//*************************************************************************************************
// Ampersand 
//*************************************************************************************************
#macro CL_rlp_ampersand(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.1; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[23]{
 <2.100,0.350,0.000>,   // Right twiddle lower
 <1.620,-.220,0.500>,   // Bottom round
 <1.150,0.250,0.000>,   // Bottom nick
 
 <0.600,-.150,0.450>,
 <-.380,0.600,0.700>,   // Left round
 <0.610,1.090,0.000>,   // Upper nick
 
 <0.220,2.000,0.700>,   // Upper left
 <1.400,2.000,0.400>,   // Upper right
 <1.400,1.400,0.200>,
 
 <0.960,1.160,0.000>,   // Right middle nick 
 <1.180,0.800,0.290>,
 <1.340,0.560,0.000>,   // Right lower nick
 
 <1.550,0.820,0.200>,
 <1.700,1.200,0.200>,
 
 <1.460,1.200,0.000>,   // Left  serif lower
 <1.460,1.300,0.000>,   // Left  serif upper
 <1.950,1.300,0.000>,   // Right serif upper
 
 <1.950,1.200,0.000>,   // Right serif lower
 <1.810,1.200,0.200>,
 <1.660,0.770,0.300>,
 
 <1.400,0.470,0.000>,
 <1.700,0.000,0.400>,
 <2.010,0.400,0.000>    // Right twiddle upper
        } 
        
#local pts[1] =
array[5]{
 <1.080,0.320,0.000>,   // Bottom hole right lower 
 <0.800,0.650,0.350>,
 <0.650,1.000,0.000>,
 <0.150,0.710,0.400>,
 
 <0.760,0.060,0.400>
         }
#local pts[2] =
array[4]{
 <0.910,1.250,0.000>,   
 <1.180,1.400,0.300>,    // 0.300
 <1.180,1.900,0.400>,    // 0.400
 
 <0.540,1.900,0.400>
        }
// invoking the object macro
//  cylinder{<-0.002,  0   ,0> <-0.002,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 2.102,  0   ,0> < 2.102,  2   ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.1  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.1  , 2.002,0> 0.002 pigment{Red}}
//  box{<-0.175,-1,-0.101> < 0.175,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,32> translate <0.86,1,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-62> translate <0.86,1.169,0>} 
//  box{<-0.05,-1,-0.101> < 0.05,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-52> translate <1.2,0.36,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//**********************************************************************************************
// At symbol
//**********************************************************************************************
#macro CL_rlp_at(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.1; // Width 
#local letter_dimensions[1] = 1.8; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.4; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[17]{
 <1.400,0.520,0.300>,         // 0.3
 <1.400,0.900,0.001>,    // False end
 <1.600,0.900,0.001>,    // False end
 
 <1.600,0.545,0.300>,    // 0.300 Not the big radius
 <1.280,0.000,0.200>,
 <0.850,0.000,0.200>,

 <0.815,0.215,0.000>,
 <0.580,0.000,0.200>,
 <0.000,0.000,0.400>,

 <0.000,0.930,0.600>,
 <0.479,1.400,0.250>,
 <0.874,1.400,0.200>,

 <1.020,1.200,0.000>,
 <1.065,1.360,0.100>,
 <1.256,1.310,0.100>,

 <0.955,0.100,0.170>,
 <1.205,0.100,0.200>,  // 0.150 
       }
// container, 3rdnd subset: edge of hole
#local pts[1] =
array[7]{
 <0.808,0.340,0.150>,
 <0.991,1.082,0.150>,
 <0.825,1.300,0.200>,
 
 <0.540,1.300,0.200>,
 <0.250,0.850,0.500>,
 <0.130,0.100,0.350>,
 
 <0.546,0.100,0.200>
}
#local pts1 = array[1];
#local pts1[0] =
array[12]{
 <1.400,0.800,0.001>,
 <1.400,1.700,0.800>,
 <-.300,1.700,0.900>,      //  <-.300,1.700,0.900>,
 
 <-.300,-.300,0.900>,    
 <1.100,-.300,0.300>,    // Internal end corner
 <1.520,0.070,0.000>,    // End bit - zero radius

 <1.600,0.000,0.000>,    // End bit - zero radius
 <1.170,-.400,0.400>,    // External end corner
 <-.500,-.400,1.100>,

 <-.500,1.800,1.100>,      //  <-.500,1.800,1.100>, 
 <1.600,1.800,1.000>,
 <1.600,0.800,0.001>
     }
     
     
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 1.4  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 1.4  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.17,.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.405,.7,0>} 
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
  translate <0.5,0,0>
     }
#end
//*************************************************************************************************
// Vertical
//*************************************************************************************************
#macro CL_rlp_vertical(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 0.2; // Width 
#local letter_dimensions[1] = 2.2; // Height
#local letter_dimensions[2] = 2.2; // Superscript height
#local letter_dimensions[3] = 0.2; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.030,-.200,0.000>, 
 <0.030,2.200,0.000>,
 <0.170,2.200,0.000>,
 
 <0.170,-.200,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Elastic vertical
//*************************************************************************************************
#macro CL_rlp_elastic_vertical(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
// Working out the dimensions. We are assuming bheight is greater than 2.4.
// Thickness goes from 0.2 at bheight = 2.4 to 0.35 when bheight = 4.8 and above. 
// The bracket centres on y=1.0
#local s_thick = 0.14+(bheight-2.4)*0.06/2.4;
#local hbheight = bheight/2;
//
#if(s_thick > 0.2)
  #local s_thick = 0.2;
#end
//
#local letter_dimensions[0] =  s_thick+0.06; // Width 
#local letter_dimensions[1] =  hbheight+1; // Height
#local letter_dimensions[2] =  hbheight+1; // Superscript height
#local letter_dimensions[3] = -hbheight+1; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.030        ,-hbheight+1.0,0.000>, 
 <0.030        , hbheight+1.0,0.000>,
 <s_thick+0.030, hbheight+1.0,0.000>,
 
 <s_thick+0.030,-hbheight+1.0,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// MATHEMATICAL SYMBOLS ***************************************************************************
//*************************************************************************************************
// Aleph
//*************************************************************************************************
#macro CL_rlp_Aleph(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[27]{
 <-.145,1.602,0.340>, 
 <0.250,2.010,0.070>,   // Central upper round point
 <0.320,1.980,0.050>,   // Central upper round point
 
 <0.280,1.700,0.200>,   
 <1.001,1.102,0.000>,   // Upper base of right arm
 <1.273,1.429,0.000>,   // Upper top of right arm
 
 <0.773,1.845,0.500>,
 <1.400,2.000,0.000>,   // Right upper point
 <1.260,1.804,0.300>, 
 
 <1.798,1.356,0.500>,
 <1.522,1.026,0.000>,   // Right lower point
 <1.503,1.237,0.300>,
 
 <1.349,1.365,0.000>,   // Lower top of right arm 
 <1.077,1.038,0.000>,   // Lower base of right arm
 <1.845,0.398,0.340>,

 <1.450,-.010,0.070>,
 <1.385,0.020,0.050>,
 <1.385,0.300,0.200>,

 <0.431,1.122,0.000>,
 <0.155,0.790,0.300>,     // Knee inner   0.300
 <0.700,0.500,0.250>,
 
 <0.700,0.000,0.250>,     // 0.600
 <0.100,0.000,0.050>,
 <0.100,0.100,0.050>,

 <0.400,0.100,0.250>,                    
 <0.018,0.782,0.300>,    // Knee outer                  
 <0.354,1.186,0.000>                                            
        }
// invoking the object macro
//  #local boxlength = 1.15;
//  cylinder{<-0.002,  0   , 0  > <-0.002, 2.000,0  > 0.002 pigment{Red}}
//  cylinder{< 1.702,  0   , 0  > < 1.702, 2.000,0  > 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002, 0  > < 1.700,-0.002,0  > 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002, 0  > < 1.700, 2.002,0  > 0.002 pigment{Red}}
//  cylinder{< 0.85 , 1    ,-0.3> < 0.85 , 1    ,0.3> 0.030 pigment{Green}}
//  union{
//    box{<-0.175,-boxlength,-0.101> < 0.175, boxlength,0.101>} 
//    box{<-0.7  , 0.4      ,-0.101> <-0.175, 0.5      ,0.101>}
//    box{< 0.175,-0.05     ,-0.101> < 0.6  ,-0.15     ,0.101>}
//    box{< 0.6,-0.5,-0.101> <0.88,0.6,0.101> }
//    pigment{rgbt <1,0,0,0.8>} rotate <0,0,50.19> translate <0.85,1,0>
//       }
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Maths small integral sign
//*************************************************************************************************
#macro CL_rlp_Integral(z1,z2,d_rad,offs,cham,oint,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[24]{
 < 0.061,-1.400,0.700>,  // 0.8  
 <-0.989,-1.400,0.600>,
 <-0.731,-0.850,0.200>,  // Start of bobble

 <-0.481,-0.850,0.250>, 
 <-0.481,-1.150,0.250>,                     
 <-0.681,-1.150,0.000>,  // End of bobble. Stays zero radius                  

 <-0.626,-1.300,0.250>,
 <-0.361,-1.300,0.250> 
 <-0.061,-1.047,0.300>,  // 0.3

 <-0.061,-0.700,0.300>,
 <-0.120, 0.000,0.600>,
 <-0.061, 0.700,0.300>     

 <-0.061, 1.400,0.700>,  // 0.6    
 < 0.989, 1.400,0.600>,
 < 0.731, 0.850,0.200>,  // Start of bobble

 < 0.481, 0.850,0.250>, 
 < 0.481, 1.150,0.250>,                     
 < 0.681, 1.150,0.000>,  // End of bobble. Stays zero radius                  

 < 0.626, 1.300,0.250>,
 < 0.361, 1.300,0.250>, 
 < 0.061, 1.047,0.400>,   // 0.3     
     
 < 0.061, 0.700,0.300>,
 < 0.120, 0.000,0.600>,
 < 0.061,-0.700,0.300>     
} 
// invoking the object macro
#if(oint = 0)
  union{
#end
//  cylinder{<-0.002, -0.4   ,0> <-0.002 , 2.2  ,0> 0.004 pigment{Red}}
//  cylinder{< 1.91 , -0.4   ,0> < 1.91  , 2.2  ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.402  ,0> < 1.91  ,-0.402,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.202  ,0> < 1.91  , 2.202,0> 0.004 pigment{Red}}
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
         rotate <0,0,-10> translate <0.9,0.9,0>} 
#if(oint = 0)
  #local box_dimensions = array[5]{0.8,0.8,0.1,0.4,0.4};
  object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
         translate <-0.4,-0.4,0> rotate <0,0,-10> translate <0.9,0.9,0>}
     }  
#end
//
#local letter_dimensions[0] = 1.91; // Width 
#local letter_dimensions[1] = 2.20; // Height
#local letter_dimensions[2] = 2.20; // Superscript height
#local letter_dimensions[3] = 0.40; // Drop below line
//
#end
//*************************************************************************************************
// Maths big integral sign
//*************************************************************************************************
#macro CL_rlp_bigIntegral(z1,z2,d_rad,offs,cham,oint,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 < 0.061,-2.100,0.700>,  // 0.7  
 <-0.989,-2.100,0.600>,
 <-0.731,-1.550,0.200>,  // Start of bobble

 <-0.481,-1.550,0.250>, 
 <-0.481,-1.850,0.250>,                     
 <-0.681,-1.850,0.000>,  // End of bobble. Stays zero radius                  

 <-0.626,-2.000,0.250>,
 <-0.361,-2.000,0.250> 
 <-0.061,-1.747,0.300>,  // 0.3

 <-0.061,-1.100,0.300>,  // 0.3
 <-0.150,-0.300,0.300>,
 <-0.150, 0.300,0.300>,
 <-0.061, 1.100,0.300>,  // 0.3  

 <-0.061, 2.100,0.700>,  // 0.7    
 < 0.989, 2.100,0.600>,
 < 0.731, 1.550,0.200>,  // Start of bobble

 < 0.481, 1.550,0.250>, 
 < 0.481, 1.850,0.250>,                     
 < 0.681, 1.850,0.000>,  // End of bobble. Stays zero radius                  

 < 0.626, 2.000,0.250>,
 < 0.361, 2.000,0.250>, 
 < 0.061, 1.747,0.400>,  // 0.4     
     
 < 0.061, 1.100,0.300>,  // 0.3
 < 0.150, 0.300,0.300>,
 < 0.150,-0.300,0.300>, 
 < 0.061,-1.100,0.300>     
}
// invoking the object macro
#if(oint = 0)
  union{
#end
//  cylinder{<-0.002, -1.05  ,0> <-0.002, 3.05 ,0> 0.009 pigment{Red}}
//  cylinder{< 2.17 , -1.05  ,0> < 2.17 , 3.05 ,0> 0.009 pigment{Red}}
//  cylinder{< 0.000,-1.102  ,0> < 1.9  ,-1.102,0> 0.009 pigment{Red}}
//  cylinder{< 0.000, 2.902  ,0> < 1.9  , 2.902,0> 0.009 pigment{Red}}
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
         rotate <0,0,-10> translate <1.05,0.9,0>}
#if(oint = 0)
  #local box_dimensions = array[5]{1,1,0.1,0.5,0.5};
  object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
         translate <-0.5,-0.5,0> rotate <0,0,-10> translate <1.05,0.9,0>}
     }  
#end  
//  
#local letter_dimensions[0] = 2.17; // Width 
#local letter_dimensions[1] = 2.9;  // Height
#local letter_dimensions[2] = 2.9;  // Superscript height
#local letter_dimensions[3] = 1.1;  // Drop below line
//
#end
//*************************************************************************************************
// Maths very big integral sign
//*************************************************************************************************
#macro CL_rlp_BigIntegral(z1,z2,d_rad,offs,cham,oint,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 < 0.061,-2.850,0.700>,  // 0.7  
 <-0.989,-2.850,0.600>,
 <-0.731,-2.300,0.200>,  // Start of bobble

 <-0.481,-2.300,0.250>, 
 <-0.481,-2.600,0.250>,                     
 <-0.681,-2.600,0.000>,  // End of bobble. Stays zero radius                  

 <-0.626,-2.750,0.250>,
 <-0.361,-2.750,0.250> 
 <-0.061,-2.497,0.300>,  // 0.3

 <-0.061,-1.700,0.400>,   // 0.3
 <-0.180,-0.600,0.500>,
 <-0.180, 0.600,0.500>,
 <-0.061, 1.700,0.400>,   // 0.3  

 <-0.061, 2.850,0.700>,  // 0.7    
 < 0.989, 2.850,0.600>,
 < 0.731, 2.300,0.200>,  // Start of bobble

 < 0.481, 2.300,0.250>, 
 < 0.481, 2.600,0.250>,                     
 < 0.681, 2.600,0.000>,  // End of bobble. Stays zero radius                  

 < 0.626, 2.750,0.250>,
 < 0.361, 2.750,0.250>, 
 < 0.061, 2.497,0.400>,   // 0.4     
     
 < 0.061, 1.700,0.400>,  // 0.3
 < 0.180, 0.600,0.500>,
 < 0.180,-0.600,0.500>, 
 < 0.061,-1.700,0.400>     
}
// invoking the object macro
#if(oint = 0)
  union{
#end
//  cylinder{<-0.002, -1.8    ,0> <-0.002, 3.6   ,0> 0.009 pigment{Red}}
//  cylinder{< 2.45 , -1.8    ,0> < 2.45 , 3.6   ,0> 0.009 pigment{Red}}
//  cylinder{< 0.000, -1.802  ,0> < 2.0  ,-1.802 ,0> 0.009 pigment{Red}}
//  cylinder{< 0.000,  3.652  ,0> < 2.1  , 3.652 ,0> 0.009 pigment{Red}}
//  box{<-0.175,-2.7,-0.101> < 0.175,2.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-4> translate <1,1,0>} 
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
         rotate <0,0,-10> translate <1.2,0.9,0>}
#if(oint = 0)
  #local box_dimensions = array[5]{1.2,1.2,0.1,0.6,0.6};
  object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
         translate <-0.6,-0.6,0> rotate <0,0,-10> translate <1.2,0.9,0>}
     }  
#end
//  
#local letter_dimensions[0] = 2.45; // Width 
#local letter_dimensions[1] = 3.65;  // Height
#local letter_dimensions[2] = 3.65;  // Superscript height
#local letter_dimensions[3] = 1.6;  // Drop below line
//
#end
//*************************************************************************************************
// Maths really big integral sign
//*************************************************************************************************
#macro CL_rlp_ReallyBigIntegral(z1,z2,d_rad,offs,cham,oint,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[26]{
 < 0.061,-3.600,0.700>,  // 0.7  
 <-0.989,-3.600,0.600>,
 <-0.731,-3.050,0.200>,  // Start of bobble

 <-0.481,-3.050,0.250>, 
 <-0.481,-3.300,0.250>,                     
 <-0.681,-3.300,0.000>,  // End of bobble. Stays zero radius                  

 <-0.626,-3.500,0.250>,
 <-0.361,-3.500,0.250> 
 <-0.061,-3.247,0.300>,  // 0.3

 <-0.061,-2.300,0.400>,   // 0.3
 <-0.200,-1.000,0.700>,
 <-0.200, 1.000,0.700>,
 <-0.061, 2.300,0.400>,   // 0.3  

 <-0.061, 3.600,0.700>,  // 0.7    
 < 0.989, 3.600,0.600>,
 < 0.731, 3.050,0.200>,  // Start of bobble

 < 0.481, 3.050,0.250>, 
 < 0.481, 3.300,0.250>,                     
 < 0.681, 3.300,0.000>,  // End of bobble. Stays zero radius                  

 < 0.626, 3.500,0.250>,
 < 0.361, 3.500,0.250>, 
 < 0.061, 3.247,0.400>,   // 0.4     
     
 < 0.061, 2.300,0.400>,  // 0.3
 < 0.200, 1.000,0.700>,
 < 0.200,-1.000,0.700>, 
 < 0.061,-2.300,0.400>     
}
// invoking the object macro
#if(oint = 0)
  union{
#end
//  cylinder{<-0.002, -2.5    ,0> <-0.002, 4.3   ,0> 0.006 pigment{Red}}
//  cylinder{< 2.62 , -2.5    ,0> < 2.62 , 4.3   ,0> 0.006 pigment{Red}}
//  cylinder{< 0.000, -2.502  ,0> < 2.0  ,-2.502 ,0> 0.006 pigment{Red}}
//  cylinder{< 0.000,  4.352  ,0> < 2.3  , 4.352 ,0> 0.006 pigment{Red}}
//  box{<-0.175,-2.7,-0.101> < 0.175,2.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-4> translate <1,1,0>} 
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
         rotate <0,0,-10> translate <1.2,0.9,0>}
#if(oint = 0)
  #local box_dimensions = array[5]{1.4,1.4,0.1,0.7,0.7};
  object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
         translate <-0.7,-0.7,0> rotate <0,0,-10> translate <1.2,0.9,0>}
     }  
#end
//
#local letter_dimensions[0] = 2.62; // Width 
#local letter_dimensions[1] = 4.35; // Height
#local letter_dimensions[2] = 4.35; // Superscript height
#local letter_dimensions[3] = 2.5;  // Drop below line
//
#end
//*************************************************************************************************
// Maths line, surface and volume integral signs (all sizes)
//*************************************************************************************************
#macro CL_rlp_linesurfacevolume_integral(z1,z2,d_rad,offs,cham,isize,itype,oint,letter_dimensions)
//
// isize: 1-4 for any of the integral types.
// itype: 1 line, 2 surface, 3 volume
// oint:  0 for closed, 1 for not closed. Ignored for volume which is never closed.
// 
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//
// Set up local_oint, which will be used for line integrals only  
//   
#if(itype < 2)
  #local local_oint = oint;
#else
  #local local_oint = 1;
#end
//  
#switch(isize)
  #case(1)
    #local my_translate = 1.0;
    union{
//      cylinder{<-0.002, -0.4   ,0> <-0.002 , 2.2  ,0> 0.009 pigment{Red}}
//      cylinder{< 1.91+(itype-1)*my_translate , -0.4   ,0> < 1.91+(itype-1)*my_translate  , 2.2  ,0> 0.009 pigment{Red}}
//      cylinder{< 0.000,-0.402  ,0> < 1.91+(itype-1)*my_translate  ,-0.402,0> 0.009 pigment{Red}}
//      cylinder{< 0.000, 2.202  ,0> < 1.91+(itype-1)*my_translate  , 2.202,0> 0.009 pigment{Red}}
      #local icount = 0;
      #while(icount < itype)
        object{CL_rlp_Integral(z1,z2,d_rad,offs,cham,local_oint,letter_dimensions)
               translate <my_translate*icount,0,0>  }
        #local icount = icount + 1;
      #end
      #if(itype = 2 & oint = 0)                 
        #local box_dimensions = array[5]{1.8,0.8,0.1,0.4,0.4};
        object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
               translate <0.5,0.5,0>}
      #end
         }  
//
    #local letter_dimensions[0] = 1.91+(itype-1)*my_translate; // Width 
    #local letter_dimensions[1] = 2.20; // Height
    #local letter_dimensions[2] = 2.20; // Superscript height
    #local letter_dimensions[3] = 0.40; // Drop below line  
  #break
//
  #case(2)
    #local my_translate = 1.1;
    union{
//      cylinder{<-0.002, -1.05  ,0> <-0.002, 3.05 ,0> 0.009 pigment{Red}}
//      cylinder{< 2.17+(itype-1)*my_translate , -1.05  ,0> < 2.17+(itype-1)*my_translate , 3.05 ,0> 0.009 pigment{Red}}
//      cylinder{< 0.000,-1.102  ,0> < 2.17+(itype-1)*my_translate  ,-1.102,0> 0.009 pigment{Red}}
//      cylinder{< 0.000, 2.902  ,0> < 2.17+(itype-1)*my_translate  , 2.902,0> 0.009 pigment{Red}}
      #local icount = 0;
      #while(icount < itype)
        object{CL_rlp_bigIntegral(z1,z2,d_rad,offs,cham,local_oint,letter_dimensions)
               translate <my_translate*icount,0,0> }
        #local icount = icount + 1;
      #end
      #if(itype = 2 & oint = 0)                 
        #local box_dimensions = array[5]{2.1,1,0.1,0.5,0.5};
        object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
             translate <0.55,0.4,0>}
      #end
         }  
//  
    #local letter_dimensions[0] = 2.17+(itype-1)*my_translate; // Width 
    #local letter_dimensions[1] = 2.9;  // Height
    #local letter_dimensions[2] = 2.9;  // Superscript height
    #local letter_dimensions[3] = 1.1;  // Drop below line  
//
  #break
//
  #case(3)
    #local my_translate = 1.1;
    union{
//      cylinder{<-0.002, -1.8    ,0> <-0.002, 3.6   ,0> 0.009 pigment{Red}}
//      cylinder{< 2.45+(itype-1)*my_translate , -1.8    ,0> < 2.45+(itype-1)*my_translate , 3.6   ,0> 0.009 pigment{Red}}
//      cylinder{< 0.000, -1.802  ,0> < 2.45+(itype-1)*my_translate  ,-1.802 ,0> 0.009 pigment{Red}}
//      cylinder{< 0.000,  3.652  ,0> < 2.45+(itype-1)*my_translate  , 3.652 ,0> 0.009 pigment{Red}} 
      #local icount = 0;
      #while(icount < itype)
        object{CL_rlp_BigIntegral(z1,z2,d_rad,offs,cham,local_oint,letter_dimensions)
               translate <my_translate*icount,0,0>} 
        #local icount = icount + 1;
      #end
      #if(itype = 2 & oint = 0)                 
        #local box_dimensions = array[5]{2.3,1.2,0.1,0.6,0.6};
        object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
               translate <0.6,0.3,0>} 
      #end
         }  
//  
    #local letter_dimensions[0] = 2.45+(itype-1)*my_translate; // Width 
    #local letter_dimensions[1] = 3.65;  // Height
    #local letter_dimensions[2] = 3.65;  // Superscript height
    #local letter_dimensions[3] = 1.6;  // Drop below line  
  #break
//   
  #case(4)
    #local my_translate = 1.2;
    union{
//      cylinder{<-0.002, -2.5    ,0> <-0.002, 4.3   ,0> 0.006 pigment{Red}}
//      cylinder{< 2.62+(itype-1)*my_translate , -2.5    ,0> < 2.62+(itype-1)*my_translate , 4.3   ,0> 0.006 pigment{Red}}
//      cylinder{< 0.000, -2.502  ,0> < 2.62+(itype-1)*my_translate  ,-2.502 ,0> 0.006 pigment{Red}}
//      cylinder{< 0.000,  4.352  ,0> < 2.62+(itype-1)*my_translate  , 4.352 ,0> 0.006 pigment{Red}}
      #local icount = 0;
      #while(icount < itype)
        object{CL_rlp_ReallyBigIntegral(z1,z2,d_rad,offs,cham,local_oint,letter_dimensions)
               translate <my_translate*icount,0,0>}
        #local icount = icount + 1;
      #end
      #if(itype = 2 & oint = 0)                 
        #local box_dimensions = array[5]{2.6,1.4,0.1,0.7,0.7};
        object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
               translate <0.5,0.2,0>} 
      #end
         } // End of union
//  
      #local letter_dimensions[0] = 2.62+(itype-1)*my_translate; // Width 
      #local letter_dimensions[1] = 4.35; // Height
      #local letter_dimensions[2] = 4.35; // Superscript height
      #local letter_dimensions[3] = 2.5;  // Drop below line
//
#end      
//
#end
//*************************************************************************************************
// Nabla
//*************************************************************************************************
#macro CL_rlp_nabla(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_Delta(z1,z2,d_rad,offs,cham,letter_dimensions) 
       rotate <0,0,180> translate <1.8,2.0,0>}
//
#end   
//*************************************************************************************************
// Curly d (partial)
//*************************************************************************************************
#macro CL_rlp_partial(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,0.000,0.500>,     //  0.5
 <0.000,0.800,0.300>,     //  0.3
 <0.500,1.200,0.300>,     //  0.3

 <1.140,1.200,0.300>,     //  0.3
 <1.330,0.950,0.000>,     //  0.0 
 <1.400,1.150,0.200>,     //  0.2
 
 <1.400,1.800,0.600>,     //  0.6
 <0.520,1.930,0.300>,     //  0.3
 <0.430,1.680,0.000>,     //  0.0

 <0.600,1.680,0.200>,     //  0.2
 <0.536,1.400,0.150>,     //  0.15
 <0.220,1.400,0.250>,     //  0.25

 <0.432,2.000,0.500>,     //  0.5
 <1.500,2.000,0.900>,     //  0.8
 <1.700,0.000,1.250>      //  1.3
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[4]{
 <0.000,0.100,0.600>,     // 
 <1.150,0.100,0.700>,
 <1.300,1.100,0.500>,     // 

 <0.400,1.100,0.500>      // 
}
// invoking the object macro
//union{
//  cylinder{<-0.004,  0   ,0> <-0.004,  2.0 ,0> 0.004 pigment{Red}}
//  cylinder{< 1.600,  0   ,0> < 1.6,  2.0 ,0> 0.004 pigment{Red}}
//  cylinder{< 0.000,-0.004,0> < 1.6  ,-0.004,0> 0.004 pigment{Red}}
//  cylinder{< 0.000, 2.004,0> < 1.6  , 2.004,0> 0.004 pigment{Red}}
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.0,.7,0>} 
//  box{<-0.100,-.7,-0.101> < 0.100,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <0.17,.7,0>} 
//  box{<-0.050,-.7,-0.101> < 0.050,.7,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-14.04> translate <1.405,.7,0>} 
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)}
//     }
//
#end   
//*************************************************************************************************
// Right arrow
//*************************************************************************************************
#macro CL_rlp_rightarrow(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,0.950,0.000>,     // 
 <0.000,1.050,0.000>,     // 
 <1.600,1.050,0.000>,     // 

 <1.210,1.320,0.000>,     // 
 <1.250,1.400,0.000>,     // 
 <2.000,1.050,0.000>,     // 

 <2.000,0.950,0.000>,     // 
 <1.250,0.600,0.000>,     
 <1.210,0.680,0.000>,

 <1.600,0.950,0.000>
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.002,  0   ,0> < 2.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.00  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.00  , 2.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.4,0> < 2.00  , 1.4,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end  
//*************************************************************************************************
// Right arrow
//*************************************************************************************************
#macro CL_rlp_elastic_rightarrow(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = bwidth; // Width 
#local letter_dimensions[1] = 0.4; // Height
#local letter_dimensions[2] = 0.4; // Superscript height
#local letter_dimensions[3] = 0.4; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000         ,-.050,0.000>,     // 
 <0.000         ,0.050,0.000>,     // 
 <bwidth - 0.400,0.050,0.000>,     // 

 <bwidth - 0.790,0.320,0.000>,     // 
 <bwidth - 0.750,0.400,0.000>,     // 
 <bwidth        ,0.050,0.000>,     // 

 <bwidth        ,-.050,0.000>,     // 
 <bwidth - 0.750,-.400,0.000>,     
 <bwidth - 0.790,-.320,0.000>,

 <bwidth - 0.400,-.050,0.000>
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.002,  0   ,0> < 2.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.00  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.00  , 2.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.4,0> < 2.00  , 1.4,0> 0.002 pigment{Red}}
  object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)}   
// 
#end  
//*************************************************************************************************
// Maps to
//*************************************************************************************************
#macro CL_rlp_mapsto(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[14]{
 <0.000,0.600,0.000>,     // 
 <0.000,1.400,0.000>,     //
 <0.100,1.400,0.000>,
 
 <0.100,1.050,0.000>, 
 <1.600,1.050,0.000>,     // 
 <1.210,1.320,0.000>,     // 

 <1.250,1.400,0.000>,     // 
 <2.000,1.050,0.000>,     // 
 <2.000,0.950,0.000>,     // 

 <1.250,0.600,0.000>,     
 <1.210,0.680,0.000>,
 <1.600,0.950,0.000>,

 <0.100,0.950,0.000>,
 <0.100,0.600,0.000>
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.002,  0   ,0> < 2.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.00  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.00  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
//
#end  
//*************************************************************************************************
// Implies
//*************************************************************************************************
#macro CL_rlp_implies(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.100,0.000>,     // 
 <0.000,1.200,0.000>,     // 
 <1.440,1.200,0.000>,     // 

 <1.205,1.310,0.000>,     // 
 <1.250,1.400,0.000>,     // 
 <2.000,1.050,0.000>,     // 

 <2.000,0.950,0.000>,     // 
 <1.250,0.600,0.000>,     
 <1.205,0.690,0.000>,

 <1.440,0.800,0.000>,
 <0.000,0.800,0.000>,
 <0.000,0.900,0.000>,
 
 <1.650,0.900,0.000>,
 <1.850,0.990,0.000>, 
 <1.850,1.010,0.000>,
 
 <1.650,1.100,0.000>
}
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.002,  0   ,0> < 2.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.00  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.00  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
//
#end  
//*************************************************************************************************
// Implies and is implied by
//*************************************************************************************************
#macro CL_rlp_implies_implied(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.050,0.000>,     //
 <0.750,1.400,0.000>,
 <0.795,1.310,0.000>,
 
 <0.560,1.200,0.000>, 
 <1.440,1.200,0.000>,     // 

 <1.205,1.310,0.000>,     // 
 <1.250,1.400,0.000>,     // 
 <2.000,1.050,0.000>,     // 

 <2.000,0.950,0.000>,     // 
 <1.250,0.600,0.000>,     
 <1.205,0.690,0.000>,

 <1.440,0.800,0.000>,
 <0.560,0.800,0.000>,
 <0.795,0.690,0.000>,
 
 <0.750,0.600,0.000>,
 <0.000,0.950,0.000>, 
} 
#local pts[1] =
array[8]{
 <1.650,1.100,0.000>,  
 <0.350,1.100,0.000>, 
 <0.150,1.010,0.000>,
                     
 <0.150,0.990,0.000>,                    
 <0.350,0.900,0.000>, 
 <1.650,0.900,0.000>,

 <1.850,0.990,0.000> 
 <1.850,1.010,0.000>,
} 
// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.002,  0   ,0> < 2.002,  2.0 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.00  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 2.00  , 2.002,0> 0.002 pigment{Red}}
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
//
#end  
//*************************************************************************************************
// Proportional (propto)
//*************************************************************************************************
#macro CL_rlp_propto(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.2; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.000,0.100,0.600>,     // 
 <0.000,1.300,0.650>,     // 
 <0.862,1.300,0.300>,     // 

 <1.110,0.870,0.000>,     // 
 <1.750,2.000,1.000>,     // 
 <2.200,1.050,0.000>,     //   
 
 <2.130,1.000,0.000>,     // 
 <1.750,1.500,0.500>,     
 <1.250,0.620,0.000>,

 <1.740,-.170,0.500>,  
 <2.120,0.450,0.000>,
 <2.200,0.400,0.000>,
 
 <1.780,-.400,0.700>, 
 <1.190,0.520,0.000>, 
 <0.950,0.100,0.400>
}
// container, 2nd subset: edge of hole
#local pts[1] =
array[5]{
 <1.050,0.767,0.000>,     // 
 <0.830,1.150,0.300>,
 <0.100,1.150,0.450>,     // 
                 
 <0.100,0.250,0.450>,     // Always zero
 <0.745,0.250,0.300>      // 
}

// invoking the object macro
//  cylinder{< 0.002,  0   ,0> < 0.002,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 2.202,  0   ,0> < 2.202,  1.4 ,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.2  ,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 1.402,0> < 2.2  , 1.402,0> 0.002 pigment{Red}}
//  box{<-0.125,-1,-0.101> < 0.125,1.5,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0,-30> translate <1.15,.7,0>} 
//  box{<-0.050,-1,-0.101> < 0.050,1,0.101> pigment{rgbt <1,0,0,0.8>} rotate <0,0, 30> translate <1.15,.7,0>} 
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)   
//
#end  
//*************************************************************************************************
// Plus
//*************************************************************************************************
#macro CL_rlp_plus(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4;  // Width 
#local letter_dimensions[1] = 1.65; // Height
#local letter_dimensions[2] = 1.4 ; // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,1.000,0.000>,  
 <0.650,1.000,0.000>,
 <0.650,1.650,0.000>,
 
 <0.750,1.650,0.000>,
 <0.750,1.000,0.000>,
 <1.400,1.000,0.000>,
 
 <1.400,0.900,0.000>,
 <0.750,0.900,0.000>,
 <0.750,0.250,0.000>,
 
 <0.650,0.250,0.000>,
 <0.650,0.900,0.000>,
 <0.000,0.900,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Plus/Minus
//*************************************************************************************************
#macro CL_rlp_plusminus(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.65; // Height
#local letter_dimensions[2] = 1.65; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.000,0.000>,  
 <0.650,1.000,0.000>,
 <0.650,1.650,0.000>,
 
 <0.750,1.650,0.000>,
 <0.750,1.000,0.000>,
 <1.400,1.000,0.000>,
 
 <1.400,0.900,0.000>,
 <0.750,0.900,0.000>,  
 <0.750,0.350,0.000>,
 
 <1.400,0.350,0.000>,
 <1.400,0.250,0.000>,
 <0.000,0.250,0.000>,
 
 <0.000,0.350,0.000>, 
 <0.650,0.350,0.000>,
 <0.650,0.900,0.000>,
 
 <0.000,0.900,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Minus
//*************************************************************************************************
#macro CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.03; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.980,0.000>,
 <1.400,0.980,0.000>,
 <1.400,0.820,0.000>,

 <0.000,0.820,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Minus/Plus
//*************************************************************************************************
#macro CL_rlp_minusplus(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.65; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <0.000,1.000,0.000>,  
 <0.650,1.000,0.000>,
 <0.650,1.550,0.000>,   
 
 <0.000,1.550,0.000>,
 <0.000,1.650,0.000>,
 <1.400,1.650,0.000>,
 
 <1.400,1.550,0.000>,
 <0.750,1.550,0.000>,
 <0.750,1.000,0.000>,

 <1.400,1.000,0.000>,
 <1.400,0.900,0.000>,
 <0.750,0.900,0.000>,

 <0.750,0.250,0.000>,
 <0.650,0.250,0.000>,
 <0.650,0.900,0.000>,

 <0.000,0.900,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// O Plus
//*************************************************************************************************
#macro CL_rlp_oplus(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 1.8; // Height
#local letter_dimensions[2] = 1.8; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[5];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.000,0.900>,  
 <0.000,1.800,0.900>,
 <1.800,1.800,0.900>,
 
 <1.800,0.000,0.900> 
}
// container, 2nd subset: bottom left
#local pts[1] =
array[4]{
 <0.100,0.100,0.800>,  
 <0.850,0.100,0.000>, 
 <0.850,0.850,0.000>,
 
 <0.100,0.850,0.000>
}
// container, 3rd subset: top left
#local pts[2] =
array[4]{
 <0.100,0.950,0.000>,
 <0.850,0.950,0.000>,
 <0.850,1.700,0.000>,
 
 <0.100,1.700,0.800>
}
// container, 4th subset: bottom right
#local pts[3] =
array[4]{
 <0.950,0.100,0.000>,
 <1.700,0.100,0.800>,
 <1.700,0.850,0.000>,
 <0.950,0.850,0.000>
}
// container, 4th subset: top right
#local pts[4] =
array[4]{
 <0.950,0.950,0.000>,
 <1.700,0.950,0.000>,
 <1.700,1.700,0.800>,

 <0.950,1.700,0.000>
}
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// O Times
//*************************************************************************************************
#macro CL_rlp_otimes(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 1.8; // Height
#local letter_dimensions[2] = 1.8; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[5];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,0.000,0.900>,  
 <0.000,1.800,0.900>,
 <1.800,1.800,0.900>,
 
 <1.800,0.000,0.900> 
}
// container, 2nd subset: bottom left
#local pts[1] =
array[4]{
 <0.100,0.100,0.800>,  
 <0.850,0.100,0.000>, 
 <0.850,0.850,0.000>,
 
 <0.100,0.850,0.000>
}
// container, 3rd subset: top left
#local pts[2] =
array[4]{
 <0.100,0.950,0.000>,
 <0.850,0.950,0.000>,
 <0.850,1.700,0.000>,
 
 <0.100,1.700,0.800>
}
// container, 4th subset: bottom right
#local pts[3] =
array[4]{
 <0.950,0.100,0.000>,
 <1.700,0.100,0.800>,
 <1.700,0.850,0.000>,
 <0.950,0.850,0.000>
}
// container, 4th subset: top right
#local pts[4] =
array[4]{
 <0.950,0.950,0.000>,
 <1.700,0.950,0.000>,
 <1.700,1.700,0.800>,

 <0.950,1.700,0.000>
}
// invoking the object macro
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
       translate <-0.9,-0.9,0> rotate <0,0,45> translate <0.9,0.9,0>}
//
#end
//*************************************************************************************************
// Elastic line (for fractions)
//*************************************************************************************************
#macro CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = bwidth; // Width 
#local letter_dimensions[1] = 0.08; // Height
#local letter_dimensions[2] = 0.08; // Superscript height
#local letter_dimensions[3] = 0.08; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000 ,0.080,0.000>,
 <bwidth,0.080,0.000>,
 <bwidth,-.080,0.000>,

 <0.000 ,-.080,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Elastic right harpoon
//*************************************************************************************************
#macro CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] =  bwidth; // Width 
#local letter_dimensions[1] =  0.35;   // Height
#local letter_dimensions[2] =  0.35;   // Superscript height
#local letter_dimensions[3] =  0.05;   // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =  array[7]{
 <0.000       ,-.050,0.000>,
 <0.000       ,0.050,0.000>,
 <bwidth-0.400,0.050,0.000>,
 
 <bwidth-0.790,0.270,0.000>,
 <bwidth-0.760,0.350,0.000>,
 <bwidth      ,0.050,0.000>, 
 
 <bwidth      ,-.050,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Elastic left harpoon
//*************************************************************************************************
#macro CL_rlp_elastic_left_harpoon(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)
//
object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)  
       rotate <0,0,180> translate <bwidth,0,0>}
//
#local letter_dimensions[0] =  bwidth; // Width 
#local letter_dimensions[1] =  0.05;   // Height
#local letter_dimensions[2] =  0.05;   // Superscript height
#local letter_dimensions[3] =  0.35;   // Drop below line
//
#end
//*************************************************************************************************
// Left right harpoons
//*************************************************************************************************
#macro CL_rlp_left_right_harpoons(z1,z2,d_rad,offs,cham,letter_dimensions)
//                                                      
#local bwidth = 3;
//
union{
object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)  
       translate <0,1.15,0>}
object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,bwidth,letter_dimensions)  
       rotate <0,0,180> translate <bwidth,0.85,0>}
     }
//
#local letter_dimensions[0] =  bwidth; // Width 
#local letter_dimensions[1] =  1.5;    // Height
#local letter_dimensions[2] =  1.5;    // Superscript height
#local letter_dimensions[3] =  0.0;    // Drop below line
//
#end

//*************************************************************************************************
// Dash
//*************************************************************************************************
#macro CL_rlp_dash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.0; // Width 
#local letter_dimensions[1] = 1.0; // Height
#local letter_dimensions[2] = 1.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000,1.100,0.000>,
 <1.000,1.100,0.000>,
 <1.000,0.800,0.000>,

 <0.000,0.800,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Times (multiply)
//*************************************************************************************************
#macro CL_rlp_times(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.5; // Height
#local letter_dimensions[2] = 1.5; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,1.000,0.000>,  
 <0.650,1.000,0.000>,
 <0.650,1.650,0.000>,
 
 <0.750,1.650,0.000>,
 <0.750,1.000,0.000>,
 <1.400,1.000,0.000>,
 
 <1.400,0.900,0.000>,
 <0.750,0.900,0.000>,
 <0.750,0.250,0.000>,
 
 <0.650,0.250,0.000>,
 <0.650,0.900,0.000>,
 <0.000,0.900,0.000>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) 
       translate <-0.7,-0.95,0> rotate <0,0,45> translate <0.7,0.95,0>}
//
#end 
//*************************************************************************************************
// Divide
//*************************************************************************************************
#macro CL_rlp_divide(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)} 
  #local lett_width_temp = letter_dimensions[0];
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <lett_width_temp/2-letter_dimensions[0]/2,1.2,0>}
  object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <lett_width_temp/2-letter_dimensions[0]/2,0.45,0>}
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.45; // Height
#local letter_dimensions[2] = 1.45; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end  
//*************************************************************************************************
// Slash
//*************************************************************************************************
#macro CL_rlp_slash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.000,0.000,0.000>, 
 <0.000,0.100,0.000>,
 <1.290,2.000,0.000>,
 
 <1.400,2.000,0.000>,
 <1.400,1.900,0.000>,
 <0.110,0.000,0.000>
        }
// invoking the object macro
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Backslash
//*************************************************************************************************
#macro CL_rlp_backslash(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{   
 <1.290,0.000,0.000>,
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,

 <0.110,2.000,0.000>,
 <1.400,0.100,0.000>,
 <1.400,0.000,0.000>, 
        }
// invoking the object macro
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Equals
//*************************************************************************************************
#macro CL_rlp_equals(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,0.2,0>}
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,-0.2,0>} 
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 1.23; // Height
  #local letter_dimensions[2] = 1.23; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end   
//*************************************************************************************************
// Not equals
//*************************************************************************************************
#macro CL_rlp_notequals(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.100,0.350,0.000>, 
 <0.100,0.450,0.000>,
 <1.200,1.550,0.000>,
 
 <1.300,1.550,0.000>,
 <1.300,1.450,0.000>,
 <0.200,0.350,0.000>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,0.2,0>}
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,-0.2,0>} 
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 1.23; // Height
  #local letter_dimensions[2] = 1.23; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end  
//*************************************************************************************************
// Equivalent
//*************************************************************************************************
#macro CL_rlp_equivalent(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,0.4,0>}
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)}
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,-0.4,0>} 
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 1.23; // Height
  #local letter_dimensions[2] = 1.23; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end 
//*************************************************************************************************
// Approx
//*************************************************************************************************
#macro CL_rlp_approx(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,0.4,0>}
  object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,-0.0,0>} 
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 1.35; // Height
  #local letter_dimensions[2] = 1.35; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end  
//*************************************************************************************************
// Altapprox
//*************************************************************************************************
#macro CL_rlp_altapprox(z1,z2,d_rad,offs,cham,letter_dimensions)
//
union{
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,0.0,0>}
  object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,-0.4,0>} 
  object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions) 
         translate <0,0.6,0>} 
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 1.6; // Height
  #local letter_dimensions[2] = 1.6; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//
#end  
//*************************************************************************************************
// For all
//*************************************************************************************************
#macro CL_rlp_forall(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.8; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.820,0.000,0.000>, 
 <0.000,1.900,0.000>,
 <0.000,2.000,0.000>,
 
 <0.100,2.000,0.000>,
 <0.520,1.025,0.000>,
 <1.280,1.025,0.000>,
 
 <1.700,2.000,0.000>,
 <1.800,2.000,0.000>,
 <1.800,1.900,0.000>,
 
 <0.980,0.000,0.000>
        }
#local pts[1] =
array[4]{
 <0.880,0.200,0.000>, 
 <0.920,0.200,0.000>,
 <1.225,0.900,0.000>,
 
 <0.575,0.900,0.000>
         }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// There exists
//*************************************************************************************************
#macro CL_rlp_thereexists(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.6; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[12]{
 <0.000,1.875,0.000>, 
 <0.000,2.000,0.000>,
 <1.600,2.000,0.000>,
 
 <1.600,0.000,0.000>,
 <0.000,0.000,0.000>,
 <0.000,0.125,0.000>,
 
 <1.475,0.125,0.000>,
 <1.475,0.900,0.000>,
 <0.000,0.900,0.000>,
 
 <0.000,1.025,0.000>,
 <1.475,1.025,0.000>,
 <1.475,1.875,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Less than
//*************************************************************************************************
#macro CL_rlp_lessthan(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.3; // Height
#local letter_dimensions[2] = 1.3; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line

//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[9]{
 <0.000,0.800,0.000>, 
 <0.000,0.900,0.000>,
 <1.300,1.300,0.000>,
 
 <1.400,1.300,0.000>,
 <1.400,1.200,0.000>,
 <0.300,0.850,0.000>,
 
 <1.400,0.500,0.000>,
 <1.400,0.400,0.000>,
 <1.300,0.400,0.000>
        }
// invoking the object macro
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Less than or equal
//*************************************************************************************************
#macro CL_rlp_lessthanorequal(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 1.3; // Height
#local letter_dimensions[2] = 1.3; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[9]{
 <0.000,0.800,0.000>, 
 <0.000,0.900,0.000>,
 <1.300,1.300,0.000>,
 
 <1.400,1.300,0.000>,
 <1.400,1.200,0.000>,
 <0.300,0.850,0.000>,
 
 <1.400,0.500,0.000>,
 <1.400,0.400,0.000>,
 <1.300,0.400,0.000>
        }
#local pts[1] =
array[6]{
 <0.000,0.500,0.000>, 
 <0.000,0.600,0.000>,
 <0.100,0.600,0.000>,
 
 <1.400,0.200,0.000>,
 <1.400,0.100,0.000>,
 <1.300,0.100,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
//
#end
//*************************************************************************************************
// Greater Than
//*************************************************************************************************
#macro CL_rlp_greaterthan(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_lessthan(z1,z2,d_rad,offs,cham,letter_dimensions)
       translate <0,-0.85,0> rotate <0,0,180> translate <1.4,0.85,0>}
//
#end 
//*************************************************************************************************
// Greater Than or Equal
//*************************************************************************************************
#macro CL_rlp_greaterthanorequal(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.100,0.100,0.000>,
 <0.000,0.100,0.000>,
 <0.000,0.200,0.000>,

 <1.300,0.600,0.000>,
 <1.400,0.600,0.000>,
 <1.400,0.500,0.000>
        }
// invoking the object macro
union{
  object{CL_rlp_lessthan(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0,-0.85,0> rotate <0,0,180> translate <1.4,0.85,0>} 
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
     }
//
#end 
//*************************************************************************************************
// Infinity
//*************************************************************************************************
#macro CL_rlp_infinity(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//
#local pts = array[3];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <-1.400,-0.700,0.700>,
 <-1.400, 0.700,0.700>,
 <-0.300, 0.700,0.400>,

 < 0.060, 0.150,0.000>,
 < 0.300, 0.700,0.400>,
 < 1.400, 0.700,0.700>,

 < 1.400,-0.700,0.700>,
 < 0.300,-0.700,0.400>,
 <-0.030,-0.200,0.000>,
 
 <-0.300,-0.700,0.400> 
        }
// container, 2nd subset: left hole
#local pts[1] =
array[5]{
 <-1.300,-0.600,0.600>,
 <-0.400,-0.600,0.300>, 
 <-0.100,-0.100,0.000>,
 
 <-0.500, 0.500,0.200>,
 <-1.300, 0.600,0.600>
        }
// container, 3rd subset: left hole
#local pts[2] =
array[5]{
 < 1.300,-0.600,0.600>,
 < 1.300, 0.600,0.600>
 < 0.400, 0.600,0.300>, 
 < 0.130, 0.050,0.000>,
 
 < 0.500,-0.500,0.200>,
        }
// invoking the object macro
object{rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham) translate <1.4,0.9,0>}
//
#local letter_dimensions[0] = 2.8; // Width 
#local letter_dimensions[1] = 1.6; // Height
#local letter_dimensions[2] = 1.6; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end 
//*************************************************************************************************
// Decimal point
//*************************************************************************************************
#macro CL_rlp_point(z1,z2,d_rad,offs,cham,letter_dimensions)
//
object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)
       translate <0.1,0.825,0>}
#local letter_dimensions[0] = 0.45; // Width 
#local letter_dimensions[1] = 1.1; // Height
#local letter_dimensions[2] = 1.1; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#end
//*************************************************************************************************
// Space
//*************************************************************************************************
#macro CL_rlp_space(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#local letter_dimensions[0] = 0.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
box{<0,0,0> <0,0,0>}
//
#end  
//*************************************************************************************************
// Big space
//*************************************************************************************************
#macro CL_rlp_bigspace(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#local letter_dimensions[0] = 1.0; // Width 
#local letter_dimensions[1] = 1.4; // Height
#local letter_dimensions[2] = 1.4; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
box{<0,0,0> <0,0,0>}
//
#end  
//*************************************************************************************************
// Negative space
//*************************************************************************************************
#macro CL_rlp_negspace(negamount,z1,z2,d_rad,offs,cham,letter_dimensions)
//
#local letter_dimensions[0] = -negamount; // Width 
#local letter_dimensions[1] =  2.0; // Height
#local letter_dimensions[2] =  2.0; // Superscript height
#local letter_dimensions[3] =  0.0; // Drop below line
//
box{<0,0,0> <0,0,0>}
//
#end 
//*************************************************************************************************
// CURRENCY SYMBOLS *******************************************************************************
//*************************************************************************************************
// Pound
//*************************************************************************************************
#macro CL_rlp_pound(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[19]{
 <1.400,0.540,0.000>,      // Top tail
 <1.200,-.200,0.480>,
 <0.460,0.270,0.000>,      // Lower nick

 <0.300,0.000,0.100>,      // Left loop base  
 <0.000,0.000,0.200>,
 <0.000,0.600,0.350>,      // left loop top   
 
 <0.315,0.520,0.000>,      // Upper nick
 <0.330,0.600,0.400>,
 <0.200,1.400,0.100>, 
 
 <0.250,2.000,0.750>,     // Top loop left
 <1.350,2.000,0.500>,     // Top loop right
 <1.350,1.400,0.200>, 
 
 <1.000,1.400,0.200>, 
 <1.100,1.900,0.200>,
 <0.550,1.900,0.300>, 
 
 <0.600,0.600,0.500>,
 <0.550,0.450,0.000>,    // Right nick
 <1.200,0.200,0.400>,
 
 <1.300,0.550,0.000>    // Bottom tail
        }
#local pts[1] =
array[3]{
 <0.270,0.350,0.000>,      
 <0.030,0.420,0.250>,
 <0.150,-.020,0.200>,      
         }
// Currency bars
#local pts1 = array[2];
#local pts1[0] =
array[4]{
 <0.050,1.080,0.000>,
 <0.800,1.080,0.000>,
 <0.800,0.980,0.000>,

 <0.050,0.980,0.000>
        }
#local pts1[1] =
array[4]{
 <0.050,0.880,0.000>,
 <0.800,0.880,0.000>,
 <0.800,0.780,0.000>,

 <0.050,0.780,0.000>
        }
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.000,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.400, 2.002,0> 0.002 pigment{Red}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end 
//*************************************************************************************************
// Euro
//*************************************************************************************************
#macro CL_rlp_euro(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <0.560,0.000,0.400>,      //  
 <0.160,0.500,0.400>,
 <0.160,1.500,0.400>,
 
 <0.560,2.000,0.400>,
 <1.100,2.000,0.400>,      // 
 <1.400,1.865,0.000>,      //   

 <1.400,1.450,0.000>,
 <1.300,1.450,0.000>,      //   
 <1.300,1.900,0.400>,      // 

 <0.510,1.900,0.400>,
 <0.510,0.100,0.400>, 
 <1.120,0.100,0.300>,     

 <1.310,0.440,0.000>,     // 
 <1.400,0.400,0.000>, 
 <1.175,0.000,0.400>
        }
// Currency bars
#local pts1 = array[2];
#local pts1[0] =
array[4]{
 <0.040,1.080,0.000>,
 <1.240,1.080,0.000>, 
 <1.200,0.980,0.000>,

 <0.000,0.980,0.000>
        }
#local pts1[1] =
array[4]{
 <0.040,0.880,0.000>,
 <1.160,0.880,0.000>,
 <1.120,0.780,0.000>,

 <0.000,0.780,0.000>
        }
// invoking the object macro
union{
//  cylinder{<-0.002,  0   ,0> <-0.002, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 1.402,  0   ,0> < 1.402, 2.000,0> 0.002 pigment{Red}}
//  cylinder{< 0.000,-0.002,0> < 2.000,-0.002,0> 0.002 pigment{Red}}
//  cylinder{< 0.000, 2.002,0> < 1.400, 2.002,0> 0.002 pigment{Red}}
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
#end 
//*************************************************************************************************
// US Dollar
//*************************************************************************************************
#macro CL_rlp_dollar(z1,z2,d_rad,offs,cham,letter_dimensions)
//
// this pointset will contain two subsets eventually
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.550,0.000,0.000>,
 <0.550,2.000,0.000>,
 <0.650,2.000,0.000>,

 <0.650,0.000,0.000>
        }
#local pts[1] =
array[4]{
 <0.750,0.000,0.000>,
 <0.750,2.000,0.000>,
 <0.850,2.000,0.000>,

 <0.850,0.000,0.000>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts,z1,z2,ld_rad,l_offs,cham)
  object{CL_rlp_s(z1,z2,d_rad,offs,cham,letter_dimensions)
         translate <0.2,0.3,0>}
  #local letter_dimensions[0] = 1.4; // Width 
  #local letter_dimensions[1] = 2.0; // Height
  #local letter_dimensions[2] = 2.0; // Superscript height
  #local letter_dimensions[3] = 0.0; // Drop below line
     }
//     
#end 
//*************************************************************************************************
// Japanese Yen
//*************************************************************************************************
#macro CL_rlp_yen(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4; // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 2.0; // Superscript height
#local letter_dimensions[3] = 0.0; // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[21]{
 <0.425,0.000,0.000>,
 <0.425,0.100,0.000>,
 <0.575,0.100,0.100>,

 <0.575,0.800,0.000>,
 <0.130,1.900,0.100>,
 <0.000,1.900,0.000>,
 
 <0.000,2.000,0.000>,
 <0.550,2.000,0.000>,
 <0.550,1.900,0.000>,
 
 <0.400,1.900,0.100>,
 <0.700,1.150,0.000>,
 <1.000,1.900,0.100>,
 
 <0.850,1.900,0.000>,
 <0.850,2.000,0.000>,
 <1.400,2.000,0.000>,
 
 <1.400,1.900,0.000>,
 <1.270,1.900,0.100>,
 <0.825,0.800,0.000>, 
 
 <0.825,0.100,0.100>,
 <0.975,0.100,0.000>,
 <0.975,0.000,0.000> 
        }
#local pts1 = array[2];
#local pts1[0] =
array[4]{
 <0.100,1.080,0.000>,
 <1.300,1.080,0.000>,
 <1.300,0.980,0.000>,

 <0.100,0.980,0.000>
        }
#local pts1[1] =
array[4]{
 <0.100,0.880,0.000>,
 <1.300,0.880,0.000>,
 <1.300,0.780,0.000>,

 <0.100,0.780,0.000>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
  rlp_rounded_lprism(pts1,z1,z2,ld_rad,l_offs,cham)
     }
//
#end          
//*************************************************************************************************
// Accent object
//*************************************************************************************************
#macro CL_rlp_accent_part(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local y_height = 0.8; 
#local out_rad  = 0.1;
//
#local letter_dimensions[0] = 0.2;  // Width 
#local letter_dimensions[1] = y_height; // Height
#local letter_dimensions[2] = y_height; // Superscript height
#local letter_dimensions[3] = 0.0;      // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <-.050,0.000   ,0.000  >,
 <-.100,y_height,out_rad>,
 <0.100,y_height,out_rad>,

 <0.050,0.000   ,0.000  >
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Cedilla
//*************************************************************************************************
#macro CL_rlp_cedilla(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local y_height = 0.8; 
#local out_rad  = 0.1;
//
#local letter_dimensions[0] = 0.2;  // Width 
#local letter_dimensions[1] = y_height; // Height
#local letter_dimensions[2] = y_height; // Superscript height
#local letter_dimensions[3] = 0.0;      // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[9]{
 <-.050,0.080,0.000>,
 <0.050,0.080,0.000>,
 <0.010,-.200,0.000>,

 <0.300,-.200,0.200>,
 <0.300,-.600,0.200>,
 <-.200,-.800,0.000>,
 
 <0.150,-.500,0.100>,
 <0.150,-.300,0.150>,
 <-.100,-.300,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Corner
//*************************************************************************************************
#macro CL_rlp_corner(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 1.4;  // Width 
#local letter_dimensions[1] = 2.0; // Height
#local letter_dimensions[2] = 0.9; // Superscript height
#local letter_dimensions[3] = 0.0;      // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[6]{
 <0.000,0.950,0.000>,
 <1.400,0.950,0.000>,
 <1.400,0.650,0.000>,

 <1.300,0.650,0.000>,
 <1.300,0.850,0.000>,
 <0.000,0.850,0.000>
        }
// invoking the object macro
rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
//
#end 
//*************************************************************************************************
// Hollow rounded box
//*************************************************************************************************
#macro CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local x_width  = box_dimensions[0];
#local y_height = box_dimensions[1];
#local b_thick  = box_dimensions[2];
#local out_rad  = box_dimensions[3];
#local inn_rad  = box_dimensions[4];
//
#local letter_dimensions[0] = x_width;  // Width 
#local letter_dimensions[1] = y_height; // Height
#local letter_dimensions[2] = y_height; // Superscript height
#local letter_dimensions[3] = 0.0;      // Drop below line
//
#local pts = array[2];
// container, 1st subset: outer edge
#local pts[0] =
array[4]{
 <0.000  ,0.000   ,out_rad>,
 <0.000  ,y_height,out_rad>,
 <x_width,y_height,out_rad>,

 <x_width,0.000   ,out_rad>
        }
//
// container, 2nd subset: inner edge
#local pts[1] =
array[4]{
 <b_thick        ,b_thick         ,inn_rad>,
 <x_width-b_thick,b_thick         ,inn_rad>,
 <x_width-b_thick,y_height-b_thick,inn_rad>,

 <b_thick        ,y_height-b_thick,inn_rad>
        }
// invoking the object macro
union{
  rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
     }
#end         
//*************************************************************************************************
// CARD SUIT SYMBOLS ******************************************************************************
//*************************************************************************************************
// Spade suit
//*************************************************************************************************
#macro CL_rlp_Spadesuit(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0;  // Width 
#local letter_dimensions[1] = 2.0;  // Height
#local letter_dimensions[2] = 2.0;  // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[15]{
 <-.500,0.000,0.000>,
 <-.500,0.100,0.000>,
 <-.050,0.100,0.400>,

 <-.050,0.500,0.000>,
 <-.900,0.000,0.800>,
 <-.900,1.100,0.300>,
 
 <-.200,1.700,0.200>,
 <0.000,2.000,0.000>,
 <0.200,1.700,0.200>,
 
 <0.900,1.100,0.300>,
 <0.900,0.000,0.800>,
 <0.050,0.500,0.000>,
 
 <0.050,0.100,0.400>,
 <0.500,0.100,0.000>,
 <0.500,0.000,0.000>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
       translate <0.9,0.0,0.0>}
//
#end        
//*************************************************************************************************
// Heart suit
//*************************************************************************************************
#macro CL_rlp_Heartsuit(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0;  // Width 
#local letter_dimensions[1] = 2.0;  // Height
#local letter_dimensions[2] = 2.0;  // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[10]{
 <0.000,0.000,0.000>,
 <-.200,0.300,0.200>,
 <-.900,1.000,0.500>,

 <-.900,2.000,0.500>,
 <-.200,2.000,0.300>,
 <0.000,1.700,0.000>,
 
 <0.200,2.000,0.300>,
 <0.900,2.000,0.500>,
 <0.900,1.000,0.500>,
 
 <0.200,0.300,0.200>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
       translate <0.9,0.0,0.0>}
//
#end 
//*************************************************************************************************
// Diamond suit
//*************************************************************************************************
#macro CL_rlp_Diamondsuit(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0;  // Width 
#local letter_dimensions[1] = 2.0;  // Height
#local letter_dimensions[2] = 2.0;  // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[8]{
 <0.000,0.000,0.000>,
 <-.400,0.550,0.500>,
 <-.900,1.000,0.000>,

 <-.400,1.450,0.500>,
 <0.000,2.000,0.000>, 
 <0.400,1.450,0.500>,
 
 <0.900,1.000,0.000>,
 <0.400,0.550,0.500>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)  
       translate <0.9,0.0,0.0>}
//
#end 
//*************************************************************************************************
// Club suit
//*************************************************************************************************
#macro CL_rlp_Clubsuit(z1,z2,d_rad,offs,cham,letter_dimensions)
//
#if(d_rad>0.05)
  #local ld_rad = 0.05; 
#else
  #local ld_rad = d_rad;
#end
#if(offs>0.04)
  #local l_offs = 0.04;
#else
  #local l_offs = offs;
#end
//  
#local letter_dimensions[0] = 2.0;  // Width 
#local letter_dimensions[1] = 2.0;  // Height
#local letter_dimensions[2] = 2.0;  // Superscript height
#local letter_dimensions[3] = 0.0;  // Drop below line
//
#local pts = array[1];
// container, 1st subset: outer edge
#local pts[0] =
array[16]{
 <-.500,0.000,0.000>,
 <-.500,0.100,0.000>,
 <-.050,0.100,0.400>,

 <-.050,0.500,0.000>,
 <-.900,0.000,0.800>,
 <-.900,1.300,0.500>,
                    
 <-.300,1.200,0.000>,                   
 <-.800,2.000,0.800>,
 <0.800,2.000,0.800>,
 
 <0.300,1.200,0.000>,
 <0.900,1.300,0.500>,
 <0.900,0.000,0.800>,

 <0.050,0.500,0.000>,
 <0.050,0.100,0.400>,
 <0.500,0.100,0.000>,

 <0.500,0.000,0.000>
        }
// invoking the object macro
object{rlp_rounded_lprism(pts ,z1,z2,ld_rad,l_offs,cham)
       translate <0.9,0.0,0.0> }
//
#end 
//*************************************************************************************************
//*************************************************************************************************
// TYPESETTING MACROS******************************************************************************
//*************************************************************************************************
//*************************************************************************************************
// CL_rlp_make_text_string
//*************************************************************************************************
#macro CL_rlp_make_text_string(set_string,default_space,letter_adjust,z1,z2,d_rad,offs,cham,
                               font_type,string_dimensions)
//
// This function sets a string of characters in the xy plane facing the negative z direction.
// The string starts at <0,0,0> at the bottom left of the first character and moves to the +ve x 
// direction.
// 
// This function uses the kludge that a zero size box won't throw an error or a warning.
//
// Capital characters are 2 units tall with Q descending 0.5 units below the line.
// Spacing is proportional, though all numerals and currency signs are the same width.
// An A is 1.8 wide. An M is 2.0 wide. An I is 0.75 wide.
//
// Many small letters are 1.4 high. Thes, and plus and minus are given a superscript height of 1.4.
//
// set_string:        the string to be set as 3D rounded/chamfered characters. Any length.
// default_space:     the default space left between two characters
// letter_adjust:     array[5][?] giving any adjustment for the characters. kern (sideways)
//                                                                          height
//                                                                          shear
//                                                                          scale
//                                                                          rotate
//                    Kerning usually will have negative entries to close things up, or zero entries. 
//                    Height adjustment is +ve for up.
//                    Shear moves to right is positive. 0.2-0.4.
//                    Scale is the actual factor. 1.0 for leave alone. Capital letters are based on 2.0 height. 
//                    Rotate. Don't unless you really want to. You will need other adjustment as well.                  
//                    The nth entry in the array is the adjustment of the nth letter.
// 
// z1:                back z coordinate
// z2:                front z coordinate
// d_rad:             default corner radius. If d_rad is zero, those corners not specified as rounded 
//                    will be sharp. d_rad i slimited to 0.05 for this font.
// offs:              the round radius/chamfer offset. offs is limited to 0.04 for this font
// cham:              =0 for rounded, = 1 for chamfered.
// font_type:         =0 for normal, = 1 for a sheared italic, = 2 for a stretched bold, 
//                    = 3 for a bold italic. The bold and italic are a bit of a simple kludge,
//                    and bold won't work with any super- and sub-script characters.
//
// string_dimensions: has to be set on entry and will return as an array with the 
//                    width (length), height above the zero line, unused, drop below the zero line. 
//                    An idea to declare a named object as the string you want. Then string_width will 
//                    be correctly defined and used to position the string. As below.
//
// Example:
/*                           
CL_rlp_make(text_string_set(1) // Always make this call.
#declare mystring = object{CL_rlp_make_text_string("#x^2",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,
                                                   CL_offs,CL_cham,CL_font_type,CL_string_dimensions)}
object{mystring translate <-CL_string_dimensions[0]/2,0,0>} // Centres the object on <0,y,0>. The line y=0
                                                            // will be letter bottoms.
*/
//   
#local num_chars = strlen(set_string);
union{ 
  #local letter_dimensions      = array[4]{0,0,0,0};
  #local lett_shift             = 0;    // Overall shift of the current letter
  #local letter_width           = 0; 
  #local letter_height          = 0; 
  #local old_letter_height      = 0;
  #local max_height             = 0;
  #local max_drop               = 0; 
  #local lett_maths             = 0; 
  #local lett_width_temp        = 1;
  #if(font_type <2)
    #local lett_scale_base      = <1,1,1>; 
    #local lett_width_fact_base = 1;
  #end
// Set stuff for a scaled 'bold' font. Super- or sub-scripts won't work well with the pseudo-bold font.
  #if(font_type >= 2 )
    #local lett_scale_base      = <1.3,1,1>;  
    #local lett_width_fact_base = 1.3;
  #end
// Set stuff for a sheared 'italic' font. Super-scripts will need to be hand-reverse-kerned with the italic font.
  #if(font_type = 1 | font_type = 3)
    #local lett_shear_base = 0.3; 
  #else
    #local lett_shear_base = 0.0; 
  #end
//
// Start of the while loop along the character string
//
  #local icount = 0;
  #while(icount<num_chars)  
// Pick up a character
    #local this_char = substr(set_string,icount+1,1); 
// Reset the indicators
    #local lett_found           =  0; 
    #local lett_instr           =  0;
    #local lett_super           =  0;
    #local lett_subsc           =  0;
    #local lett_raise           =  0;   
    #local lett_vector          =  0;
    #local lett_width_fact      =  lett_width_fact_base;
// Math toggle
    #if(this_char = "#")  
      #local lett_maths         = -(lett_maths - 1);  // Toggle lett_maths between 0 and 1.
      #local icount             =  icount + 1;  
      #local this_char          =  substr(set_string,icount+1,1); 
    #end                        
// Pick up the user letter adjustments for this value of icount
    #local lett_shift           =  lett_shift + letter_adjust[0][icount];
    #local lett_drop            =  letter_adjust[1][icount]; 
    #local lett_shear           =  lett_shear_base + letter_adjust[2][icount];
    #local lett_scale_user      =  letter_adjust[3][icount]; 
    #local lett_scale           =  <lett_scale_base.x*lett_scale_user,lett_scale_base.y*lett_scale_user,1>;
    #local lett_rotate          =  letter_adjust[4][icount]; 
// Instruction characters   
    #if(this_char = "|")  
      #local lett_shift         =  lett_shift - letter_adjust[0][icount];
      #local lett_instr         =  1;
      #local icount             =  icount + 1;
      #local this_char          =  substr(set_string,icount+1,1);
// Move on the the next user letter adjustments 
      #local lett_shift         =  lett_shift + letter_adjust[0][icount];
      #local lett_drop          =  letter_adjust[1][icount]; 
      #local lett_shear         =  lett_shear_base + letter_adjust[2][icount];
      #local lett_scale_user    =  letter_adjust[3][icount]; 
      #local lett_scale         =  <lett_scale_base.x*lett_scale_user,lett_scale_base.y*lett_scale_user,1>;
      #local lett_rotate        =  letter_adjust[4][icount]; 
    #else
// Superscript
      #if(this_char = "^")     
        #local lett_shift       =  lett_shift - letter_adjust[0][icount];
        #local lett_super       =  1;
        #local lett_raise       =  1;
        #local icount           =  icount + 1;
        #local this_char        =  substr(set_string,icount+1,1);
// Move on the the next user letter adjustments 
        #local lett_width_fact  =  lett_width_fact_base*0.6*letter_adjust[3][icount];  
        #local lett_shift       =  lett_shift + letter_adjust[0][icount];
        #local lett_kern        =  letter_adjust[0][icount];
        #local lett_drop        =  letter_adjust[1][icount];   
        #local lett_shear       =  lett_shear_base + letter_adjust[2][icount];
        #local lett_scale_user  =  letter_adjust[3][icount]; 
        #local lett_scale       =  <lett_scale_base.x*lett_scale_user*0.6,lett_scale_base.y*lett_scale_user*0.6,1>;
        #local lett_rotate      =  letter_adjust[4][icount]; 
      #end    
// Subscript      
      #if(this_char = "_")     
        #local lett_shift       =  lett_shift - letter_adjust[0][icount];
        #local lett_subsc       =  1;         
        #local lett_width_fact  =  lett_width_fact_base*0.6;  
        #local icount           =  icount + 1;
        #local this_char        =  substr(set_string,icount+1,1);
// Move on the the next user letter adjustments 
        #local lett_shift       =  lett_shift + letter_adjust[0][icount];
        #local lett_kern        =  letter_adjust[0][icount];
        #local lett_drop        =  letter_adjust[1][icount] - 0.6; 
        #local lett_shear       =  lett_shear_base + letter_adjust[2][icount];
        #local lett_scale_user  =  letter_adjust[3][icount]; 
        #local lett_scale       =  <lett_scale_base.x*lett_scale_user*0.6,lett_scale_base.y*lett_scale_user*0.6,1>;
        #local lett_rotate      =  letter_adjust[4][icount]; 
      #end 
// Set as vector      
      #if(this_char = "")     
        #local lett_shift       =  lett_shift - letter_adjust[0][icount];
        #local lett_vector      =  1; 
        #if(lett_maths = 0)        
          #local lett_width_temp=  lett_width_fact_base*1.3; 
        #else
          #local lett_width_temp=  lett_width_fact_base;
        #end 
        #local icount           =  icount + 1;
        #local this_char        =  substr(set_string,icount+1,1);
// Move on the the next user letter adjustments 
        #local lett_shift       =  lett_shift + letter_adjust[0][icount];
        #local lett_kern        =  letter_adjust[0][icount];
        #local lett_drop        =  letter_adjust[1][icount]; 
        #local lett_shear       =  lett_shear_base + letter_adjust[2][icount];
        #local lett_scale_user  =  letter_adjust[3][icount]; 
        #local lett_scale       =  <lett_scale_base.x*lett_scale_user*lett_width_temp,lett_scale_base.y*lett_scale_user,1>;
        #local lett_rotate      =  letter_adjust[4][icount]; 
      #end 
    #end
// Menagerie of characters
//***********************************************************************************************
// CAPITAL LETTERS
//***********************************************************************************************
    #if(this_char="A") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_A(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Greek Alpha
        #else
          #local this_letter = object{CL_rlp_mathA(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_A(z1,z2,d_rad,offs,cham,letter_dimensions)} // Blackboard A
        #else    
          #local this_letter = object{CL_rlp_A(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end  
//
    #if(this_char="B") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_B(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathB(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_B(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_B(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end  
//
    #if(this_char="C") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_X(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Greek Chi
        #else
          #local this_letter = object{CL_rlp_mathC(z1,z2,d_rad,offs,cham,letter_dimensions)} // Maths C
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_C(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Blackboard C
        #else    
          #local this_letter = object{CL_rlp_C(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Roman C
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="D") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Delta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathD(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_D(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_D(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end  
//
    #if(this_char="E") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_E(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathE(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_E(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_E(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end  
//
    #if(this_char="F") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Phi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathF(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_F(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_F(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end  
//
    #if(this_char="G") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Gamma(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathG(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_G(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_G(z1,z2,d_rad,offs,cham,letter_dimensions)} 
        #end
      #end      
      #local lett_found = 1;  
    #end  
//
    #if(this_char="H") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_H(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathH(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_H(z1,z2,d_rad,offs,cham,letter_dimensions)}  
        #else
          #local this_letter = object{CL_rlp_H(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end  
//
    #if(this_char="I") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_I(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathI(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_I(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_I(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end  
//
    #if(this_char="J") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Aleph(z1,z2,d_rad,offs,cham,letter_dimensions)}
         #else
          #local this_letter = object{CL_rlp_mathJ(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_J(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_J(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="K") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_K(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathK(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_K(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_K(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="L") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Lambda(z1,z2,d_rad,offs,cham,letter_dimensions)} // Greek Lambda
        #else
          #local this_letter = object{CL_rlp_mathL(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Math L
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_scr_L(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Script L for Laplace Transforms
        #else    
          #local this_letter = object{CL_rlp_L(z1,z2,d_rad,offs,cham,letter_dimensions)}      // Roman L
       #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="M") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_M(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathM(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_M(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_M(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="N") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_N(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Greek Nu
        #else
          #local this_letter = object{CL_rlp_mathN(z1,z2,d_rad,offs,cham,letter_dimensions)} // Math N
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_N(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Blackboard Bold N (Naturals)
        #else    
          #local this_letter = object{CL_rlp_N(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Roman N
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="O") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_O(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathO(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local box_dimensions = array[5]{2,2,0.1,1,1};
          #local this_letter    = object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_O(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="P") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Pi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathP(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_P(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_P(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="Q") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Theta(z1,z2,d_rad,offs,cham,letter_dimensions)} // Greek Theta
        #else
          #local this_letter = object{CL_rlp_mathQ(z1,z2,d_rad,offs,cham,letter_dimensions)} // Math Q
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_Q(z1,z2,d_rad,offs,cham,letter_dimensions)}   // Blackboard bold Q (Rationals)
        #else    
          #local this_letter = object{CL_rlp_Q(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Roman Q
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="R") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_P(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Greek Rho
        #else
          #local this_letter = object{CL_rlp_mathR(z1,z2,d_rad,offs,cham,letter_dimensions)} // Math R
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_R(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Blacboard bold R (Reals)
        #else    
          #local this_letter = object{CL_rlp_R(z1,z2,d_rad,offs,cham,letter_dimensions)}     // Roman R
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="S") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Sigma(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #else
          #local this_letter = object{CL_rlp_mathS(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Spadesuit(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_S(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="T") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_T(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathT(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Heartsuit(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_T(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="U") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_Upsilon(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathU(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Diamondsuit(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else  
          #local this_letter = object{CL_rlp_U(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="V") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_forall(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathV(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Clubsuit(z1,z2,d_rad,offs,cham,letter_dimensions)}  
        #else  
          #local this_letter = object{CL_rlp_V(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="W") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Omega(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathW(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_W(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_W(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="X") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Xi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathX(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_X(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_X(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="Y") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Psi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_mathY(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Y(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_Y(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char="Z") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Z(z1,z2,d_rad,offs,cham,letter_dimensions)}      // Greek Zeta
        #else
          #local this_letter = object{CL_rlp_mathZ(z1,z2,d_rad,offs,cham,letter_dimensions)}  // Math Z
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bb_Z(z1,z2,d_rad,offs,cham,letter_dimensions)}   // Blackboard bold Z (Integers)
        #else    
          #local this_letter = object{CL_rlp_Z(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #end                                                                                   // Roman Z
      #end      
      #local lett_found = 1;  
    #end
//
    #if(this_char=" ") 
      #if(lett_instr = 1)   
        #local this_letter = object{CL_rlp_bigspace(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else
        #local this_letter = object{CL_rlp_space(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//*************************************************************************************************
// SMALL LETTERS    
//*************************************************************************************************
    #if(this_char="a")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_alpha(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_matha(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_a(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="b")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_beta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathb(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_b(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="c")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_chi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathc(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_c(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="d")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_delta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathd(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_mathd(z1,z2,d_rad,offs,cham,letter_dimensions) matrix <1,0,0,-0.2,1,0,0,0,1,0.1,0,0>}    
        #else
          #local this_letter = object{CL_rlp_d(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="e")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_epsilon(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathe(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_e(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="f")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_phi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathf(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_f(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="g")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_gamma(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathg(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_g(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="h")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_eta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathh(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_left_right_harpoons(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_h(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="i")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_iota(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_i(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="j")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_partial(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathj(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_j(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="k")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_kappa(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathk(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_k(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="l")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_lambda(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathl(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_l(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="m")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_mu(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #else 
          #local this_letter = object{CL_rlp_mathm(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_m(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="n")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_nu(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathn(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_nuvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_n(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="o")
      #if(lett_maths = 1) 
        #local this_letter = object{CL_rlp_matho(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #if(lett_instr = 1)
          #local box_dimensions = array[5]{1.4,1.4,0.1,0.7,0.7};
          #local this_letter    = object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)
                                         translate <0,0.3,0>}
        #else
          #local this_letter = object{CL_rlp_o(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="p")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_pi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathp(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_phiuvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_p(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
   #end   
//
    #if(this_char="q")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_theta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathq(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_q(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="r")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_rho(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathr(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_ruvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_r(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="s")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_sigma(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_maths(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_s(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="t")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_tau(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_matht(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_thetauvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_t(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="u")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_mathv(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathu(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
       #local this_letter = object{CL_rlp_u(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end   
//
    #if(this_char="v")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_thereexists(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathv(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_v(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
   #end   
//
   #if(this_char="w")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_omega(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathw(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_w(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
   #end   
//
    #if(this_char="x")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_xi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathx(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_x(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
   #if(this_char="y")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_psi(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathy(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_y(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
   #end   
//
   #if(this_char="z")
      #if(lett_maths = 1) 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_zeta(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathz(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #local this_letter = object{CL_rlp_z(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
   #end   
//**************************************************************************************************
// NUMERALS
//**************************************************************************************************
    #if(this_char="0")  
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_mathzeroslash(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math0(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_zeroslash(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_0(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end 
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="1") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_iuvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math1(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_1(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_1(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="2") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_juvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math2(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_2(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_2(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="3") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_kuvec(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math3(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_3(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_3(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="4") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_rightarrow(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math4(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_4(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_4(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="5") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_mapsto(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math5(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_5(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_5(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="6") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_implies(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math6(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_6(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_6(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end      #local lett_found = 1;  
    #end
//
    #if(this_char="7") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_notequals(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math7(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end       
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_7(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_7(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="8") 
      #if(lett_maths = 1)   
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_infinity(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math8(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_infinity(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_8(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="9") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_nabla(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_math9(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else   
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_nabla(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_9(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//*******************************************************************************************************
// Currency
//*******************************************************************************************************
    #if(this_char="$") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_otimes(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_half(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #end
     #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_yen(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_dollar(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
     #end
     #local lett_found = 1;  
    #end
//
    #if(this_char="") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_oplus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_quarter(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #end
     #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_euro(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_pound(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #end
     #end
     #local lett_found = 1;  
    #end
//*******************************************************************************************************
// BRACKETS
//*******************************************************************************************************
    #if(this_char="(") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_cup(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_round_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char=")") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_cap(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_round_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_round_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_round_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="[") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_Integral(z1,z2,d_rad,offs,cham,1,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_square_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="]") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_bigIntegral(z1,z2,d_rad,offs,cham,1,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_square_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_square_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_square_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="}") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_rangle(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_curly_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_curly_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_curly_right_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="{") 
      #if(lett_maths = 1)
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_langle(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else
          #local this_letter = object{CL_rlp_math_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1)
          #local this_letter = object{CL_rlp_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else    
          #local this_letter = object{CL_rlp_curly_left_bracket(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end  
      #local lett_found = 1;  
    #end
//*******************************************************************************************************
// PUNCTUATION
//*******************************************************************************************************
  #if(this_char="~") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_implies_implied(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_tilde(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_tilde(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end 
      #local lett_found = 1;  
    #end
//    
  #if(this_char=".") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_bullet(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_point(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end      
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_point(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end 
      #local lett_found = 1;  
    #end
//
    #if(this_char=",") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_negspace(0.5,z1,z2,d_rad,offs,cham,letter_dimensions)}
//  Since negative space is treated just like another letter, default space will be added which, 
//  if default_space is set quite large, can negate the effect of negative space.
        #local lett_shift = lett_shift - default_space;        
      #else 
        #local this_letter = object{CL_rlp_comma(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char=";") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_approx(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_semi_colon(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char=":") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_altapprox(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_colon(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="!") 
//      #warning "Exclamation mark\n"
      #if(lett_instr = 1) 
//        #warning "Negspace 0.2\n"
        #local this_letter = object{CL_rlp_negspace(0.2,z1,z2,d_rad,offs,cham,letter_dimensions)} 
//  Since negative space is treated just like another letter, default space will be added which, 
//  if default_space is set quite large, can negate the effect of negative space.
        #local lett_shift = lett_shift - default_space;        
      #else 
//        #warning "Exclamation mark\n"
        #local this_letter = object{CL_rlp_exclamation_mark(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="?") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_elastic_left_harpoon(z1,z2,d_rad,offs,cham,2.0,letter_dimensions)
                                      translate <0,0.9,0>}
        #else 
          #local this_letter = object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,2.0,letter_dimensions)
                                      translate <0,0.9,0>}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_upside_down_question_mark(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_question_mark(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="'") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_dagger(z1,z2,d_rad,offs,cham,letter_dimensions)}
       #else 
          #local this_letter = object{CL_rlp_prime(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else   
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_prime(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_right_inverted_comma(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end  
      #local lett_found = 1;  
    #end
//
    #if(this_char="`") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_nullsubscript(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_degrees(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else   
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_degrees(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_left_inverted_comma(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="%") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_backslash(z1,z2,d_rad,offs,cham,letter_dimensions)}
     #else 
        #local this_letter = object{CL_rlp_percent(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="*") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_times(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_asterisk(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="^") 
      #if(lett_maths = 1) 
        #local this_letter = object{CL_rlp_Integral(z1,z2,d_rad,offs,cham,0,letter_dimensions)}
      #else
        #local this_letter = object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="_") 
      #if(lett_maths = 1) 
        #local this_letter = object{CL_rlp_bigIntegral(z1,z2,d_rad,offs,cham,0,letter_dimensions)}
      #else
        #local this_letter = object{CL_rlp_underscore(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="#")  
      #if(lett_maths = 1)       
        #local this_letter = object{CL_rlp_linesurfacevolume_integral(z1,z2,d_rad,offs,cham,1,2,0,letter_dimensions)}
      #else  
        #local this_letter = object{CL_rlp_hash(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="")
      #if(lett_maths = 1)       
        #local this_letter = object{CL_rlp_linesurfacevolume_integral(z1,z2,d_rad,offs,cham,2,2,0,letter_dimensions)}
      #else  
        #local this_letter = object{CL_rlp_corner(z1,z2,d_rad,offs,cham,letter_dimensions)} 
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="&") 
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_surd(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_threequarters(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_ampersand(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_ampersand(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end  
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="@")
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_propto(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_general_fraction(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_at(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_at(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end 
      #local lett_found = 1;  
    #end
//
//***********************************************************************************************************
// MATHEMATICAL SYMBOLS
//***********************************************************************************************************
    #if(this_char="+") 
      #if(lett_maths = 1)
       #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_plusminus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_plus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_plus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_plus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="-")
      #if(lett_maths = 1)
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_minusplus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #else 
        #if(lett_instr = 1) 
          #local this_letter = object{CL_rlp_minus(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #else 
          #local this_letter = object{CL_rlp_dash(z1,z2,d_rad,offs,cham,letter_dimensions)}
        #end
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="/") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_divide(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_slash(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="=") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_equivalent(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_equals(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="<") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_lessthanorequal(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_lessthan(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char=">") 
      #if(lett_instr = 1) 
        #local this_letter = object{CL_rlp_greaterthanorequal(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #else 
        #local this_letter = object{CL_rlp_greaterthan(z1,z2,d_rad,offs,cham,letter_dimensions)}
      #end
      #local lett_found = 1;  
    #end
//
    #if(this_char="|") 
     #local this_letter = object{CL_rlp_vertical(z1,z2,d_rad,offs,cham,letter_dimensions) }
     #local lett_found = 1;  
    #end
//*****************************************************************************************************
// No letter found - insert an asterisk 
//***************************************************************************************************** 
    #if(lett_found = 0)
      #local this_letter = object{CL_rlp_asterisk(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #end 
//*****************************************************************************************************
// Transform the object according to the super/sub-script requirements and the letter_adjust and vector 
// kludges
//*****************************************************************************************************
    #local lett_y_raise = (old_letter_height-0.4)*lett_raise+lett_drop;
    object{this_letter scale lett_scale 
                       matrix <1,0,0,lett_shear,1,0,0,0,1,0,0,0> 
                       rotate <0,0,lett_rotate> 
                       translate <lett_shift,lett_y_raise,0>} 
    #local lett_under_drop = 0; 
    #if(lett_vector = 1)
      #if(lett_maths = 1) 
        #local temp_dimensions = array[4]{0,0,0,0}; 
        #local bwidth = letter_dimensions[0]*0.9; 
        #local lett_under_drop = default_space + 0.16;
        object{CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,bwidth,temp_dimensions) 
                       scale lett_scale 
                       matrix <1,0,0,lett_shear,1,0,0,0,1,0,0,0> 
                       rotate <0,0,lett_rotate> 
                       translate <lett_shift,(old_letter_height-0.4)*lett_raise+lett_drop-0.28*(lett_scale.y),0>}  
      #end
    #end
///****************************************************************************************************
//  Tidy up and add to the shift
//*****************************************************************************************************
    #local this_height             =  (old_letter_height-0.4)*lett_raise + lett_drop + letter_dimensions[1]*lett_scale.y; 
    #local this_drop_before_ytrans =  max(letter_dimensions[3]*lett_scale.y,lett_under_drop);
    #local this_drop               =  max(0,this_drop_before_ytrans-lett_y_raise); 
    #local max_height              =  max(max_height,this_height);
    #local max_drop                =  max(max_drop,this_drop);
    #local old_letter_height       =  letter_dimensions[2];      // The superscript height
//    #local letter_width            =  letter_dimensions[0]*lett_width_fact*lett_width_temp;
    #local letter_width            =  letter_dimensions[0]*lett_scale.x;
    #local lett_shift              =  lett_shift + letter_width + default_space; // + letter_adjust[0][icount];  
    #local lett_width_fact         =  lett_width_fact_base;
    #local icount                  =  icount + 1;
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_text_string this_char is:",this_char,"\n")  
      #warning concat("CL_rlp_make_text_string lett_drop is:",str(lett_drop ,8,3),"\n")  
    #end
  #end  
// End of #while loop. Pass back the text box size. 
  #local string_dimensions[0] =  lett_shift - default_space;  // Width. Take off the last letter separation.
  #local string_dimensions[1] =  max_height;  // Height
  #local string_dimensions[2] =  max_height;  // Height for super-script
  #local string_dimensions[3] =  max_drop;    // Drop
// Debug boundary lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002               ,-string_dimensions[3],0> < 0.002               , string_dimensions[1],0> 0.02 pigment{Red}}
    cylinder{< string_dimensions[0],-string_dimensions[3],0> < string_dimensions[0], string_dimensions[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000               ,-string_dimensions[3],0> < string_dimensions[0],-string_dimensions[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000               , string_dimensions[1],0> < string_dimensions[0], string_dimensions[1],0> 0.02 pigment{Red}}
  #end
       } 
//
#end  
//*************************************************************************************************
// End of the main typesetting routine Search for DDDD Met Bat
//*************************************************************************************************
//***************************************************************************************************  
// CL_rlp_make_array
//*************************************************************************************************
#macro CL_rlp_make_array(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                         inner_parts,col_align,space_around,horiz_space,vert_space,
                         inner_dimensions,dimensions_out) 
//
// 
// Determine the array dimensions
//
#local nrows                     = dimension_size(inner_parts,1);   
#local ncols                     = dimension_size(inner_parts,2);
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_array nrows is:",str(nrows ,8,3),"\n")
  #warning concat("CL_rlp_make_array ncols is:",str(ncols,8,3),"\n")
#end  
//
// Determine the column widths
//
#local col_widths                = array[ncols];
#local sum_col_widths            = 0;
#local icol                      = 0;
#while(icol < ncols)
  #local this_col_width          = 0;
  #local irow                    = 0;    
  #while(irow < nrows) 
    #local this_obj_dims         = inner_dimensions[irow][icol]
//
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_array this_obj_dims[0] is:",str(this_obj_dims[0] ,8,3),"\n")
      #warning concat("CL_rlp_make_array this_obj_dims[1] is:",str(this_obj_dims[1] ,8,3),"\n")
      #warning concat("CL_rlp_make_array this_obj_dims[2] is:",str(this_obj_dims[2] ,8,3),"\n")
      #warning concat("CL_rlp_make_array this_obj_dims[3] is:",str(this_obj_dims[3] ,8,3),"\n")
    #end
//      
    #if(this_obj_dims[0] > this_col_width) 
      #if(CL_debug_lines = 1)
        #warning concat("CL_rlp_make_array this_col_width is:",str(this_col_width ,8,3),"\n")
      #end    
      #local this_col_width      = this_obj_dims[0];
    #end 
    #local irow                  = irow + 1;
  #end
  #local col_widths[icol]        = this_col_width;
  #local sum_col_widths          = sum_col_widths + this_col_width;
  #local icol                    = icol + 1;
#end 
//
// Determine the row heights. Tricky, since we want to align all the entries y-co-ordinate zeros
// so we need to take the maxima of both heights and drops.
//
#local row_heights               = array[nrows]
#local row_drops                 = array[nrows];
#local this_row_height           = 0; 
#local max_object_height         = 0;
#local max_object_drop           = 0;
#local irow = 0;
#while(irow < nrows)
  #local icol                    = 0;    
  #while(icol < ncols)  
    #local this_obj_dims         = inner_dimensions[irow][icol]
    #local this_object_height    = this_obj_dims[1]; 
    #local this_object_drop      = this_obj_dims[3];
    #if(this_object_height > max_object_height)
      #local max_object_height   = this_object_height;
    #end 
    #if(this_object_drop > max_object_drop)
      #local max_object_drop     = this_object_drop;
    #end  
    #local this_row_height       = max_object_height + max_object_drop;
    #local icol                  = icol + 1;
  #end
  #local row_heights[irow]       = this_row_height;  
  #local row_drops[irow]         = max_object_drop;
  #local irow                    = irow + 1;
#end 
//
#local irow                      = 0; 
#local sum_row_heights           = 0;
#while(irow < nrows)
  #local sum_row_heights         = sum_row_heights + row_heights[irow];
  #local irow                    = irow + 1;
#end 
#local icol                      = 0; 
#local sum_col_widths            = 0;   
#while(icol < ncols)  
  #local sum_col_widths          = sum_col_widths  + col_widths[icol];   
  #local icol                    = icol + 1;
#end
//
// We can work out the overall dimensions at this point
//
#local dimensions_out[0]         = sum_col_widths  + (ncols - 1)*horiz_space;
#local dimensions_out[1]         = sum_row_heights + (nrows - 1)*vert_space;
#local dimensions_out[1]         = dimensions_out[1]/2 + 0.9;
#local dimensions_out[2]         = dimensions_out[1];
#local dimensions_out[3]         = dimensions_out[1] - 1.8;
//
// Start placing the objects. Top left to bottom right. Top left corner of top left object starts off at 
// or close to (dimensions_out[1],0) 
//
union{
  #local irow = 0;  
  #local row_low_y_co            = dimensions_out[1]; 
  #while(irow < nrows) 
    #local row_low_y_co          = row_low_y_co - row_heights[irow];
    #local icol = 0;    
    #local col_left_x_co         = 0;
    #while(icol < ncols) 
// Horizontal shift    
       #local col_adjust_space   = 0;
       #local this_space         = col_widths[icol] - inner_dimensions[irow][icol][0]; 
       #local col_align_char     = substr(col_align,icol+1,1); 
       #if(col_align_char = "c")
         #local col_adjust_space = this_space/2; 
       #end
       #if(col_align_char = "r")
         #local col_adjust_space = this_space; 
       #end  
       #local x_tran             = col_left_x_co + col_adjust_space; 
// Vertical shift. 
       #local y_tran             = row_low_y_co  + row_drops[irow];
// Place the object 
       object{inner_parts[irow][icol] translate <x_tran,y_tran,0>}
//
       #local col_left_x_co      = col_left_x_co + col_widths[icol] + horiz_space;  
       #local icol               = icol + 1;
    #end
    #local row_low_y_co          = row_low_y_co - vert_space;
    #local irow                  = irow + 1;
  #end 
// Debug lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     } 
//                                
#end
//*****************************************************************************************************************************
// CL_rlp_make_bracketed_text_array
//*************************************************************************************************
#macro CL_rlp_make_bracketed_text_array(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                        array_nrows,array_ncols,text_array_elements,array_alignment,
                                        left_bracket_type,right_bracket_type,space_around,horiz_space,vert_space,
                                        dimensions_out)  
//                                                                                                                        
// Generate the objects to put in the objects array 
//
#local inner_parts                          = array[array_nrows][array_ncols] 
#local element_dimensions_out               = array[4] 
#local inner_dimensions                     = array[array_nrows][array_ncols] 
#local temp_dimensions                      = array[4]
//
#local icount = 0;
#while(icount < array_nrows)
  #local jcount = 0;
  #while(jcount < array_ncols) 
    #if(CL_debug_lines = 1)
      #warning concat("CL_make_bracketed_text_array icount:",str(icount,8,3)," jcount:",str(jcount,8,3),"\n") 
    #end
    #local element_text_string              = text_array_elements[icount][jcount];  
    #if(CL_debug_lines = 1)
      #warning concat("CL_make_bracketed_text_array text:",element_text_string,"\n") 
    #end
    #local inner_parts[icount][jcount]      = object{CL_rlp_make_text_string(element_text_string,default_space,letter_adjust,z1,z2,
                                                                             d_rad,offs,cham,font_type,dimensions_out)} 
    #local inner_dimensions[icount][jcount] = dimensions_out;
    #local jcount                           = jcount + 1;
  #end
  #local icount                             = icount +1;
#end
//
// Put the elements into the array object
//
#local array_obj                            = object{CL_rlp_make_array(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                                                       inner_parts,array_alignment,space_around,horiz_space,vert_space,
                                                                       inner_dimensions,dimensions_out) }
#local temp_dimensions                      = dimensions_out;
// 
// Put the brackets around the array object
//
#local delimited_object                     = object{CL_rlp_make_elastic_bracket_pair(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                                                                      array_obj,default_space,left_bracket_type,right_bracket_type, 
                                                                                      temp_dimensions,dimensions_out)}
object{delimited_object}
//
#end             
//*************************************************************************************************
// CL_rlp_make_fraction
//*************************************************************************************************
#macro CL_rlp_make_fraction(z1,z2,d_rad,offs,cham,numerator,denominator,space_size,fraction_dimensions,dimensions_out) 
//
// z1, z2, d_rad, offs, cham as normal out of CL_rlp_make_text_string_set(set_type)
// numerator, denominator a pair of OBJECTS representing the top and bottom of the fraction. These will not
//                        normally be objects that would be constructed by CL_rlp_make_text_string, since
//                        you could use CL_rlp_make_text_fraction for that situation. They would tend to 
//                        be composite objects, including fractions, integrals, sums etc..
// space_size             A separation space between the horizontal line and the components.
// fraction_dimensions    Array of arrays of the dimensions of the numerator and denominator.
// dimensions_out         Array of the output dimensions of the whole object.
//
// The fraction line is at y = 0.9.
//
// Example Call: See CL_rlp_template_test.pov
//
#local num_width = fraction_dimensions[0][0];
#local den_width = fraction_dimensions[1][0];  
#local max_width = max(num_width,den_width);
//
union{ 
  CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,max_width,dimensions_out)
  #local dimensions_out[0] = max_width;
  #local dimensions_out[1] = 0.05+space_size+fraction_dimensions[0][1]+fraction_dimensions[0][3]+0.9;  
  #local dimensions_out[2] = dimensions_out[1];
  #local dimensions_out[3] = 0.05+space_size+fraction_dimensions[1][1]+fraction_dimensions[1][3]-0.9; 
  object{numerator   translate <(max_width-num_width)/2, 0.05+space_size+fraction_dimensions[0][3],0>   }
  object{denominator translate <(max_width-den_width)/2,-0.05-space_size-fraction_dimensions[1][1],0>   }
// Debug boundary lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3]-0.9,0> < 0.002            , dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3]-0.9,0> < dimensions_out[0], dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3]-0.9,0> < dimensions_out[0],-dimensions_out[3]-0.9,0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1]-0.9,0> < dimensions_out[0], dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
  #end
  translate <0,0.9,0.0> // Have the dividing line centred on y = 0.9, to line up with a standard equals sign
     }  
//                                
#end                               
//*************************************************************************************************
// CL_rlp_make_text_fraction
//*************************************************************************************************
#macro CL_rlp_make_text_fraction(default_space,letter_adjust_numer,letter_adjust_denom,z1,z2,d_rad,offs,cham,font_type,
                                 numer_string,denom_string,space_size,dimensions_out) 
//
// z1, z2, d_rad, offs, cham as normal out of CL_rlp_make_text_string_set(set_type)
// numer_string, denom_string A pair of STRINGS representing the top and bottom of the fraction. 
// space_size                 A separation space between the horizontal line and the components.
// fraction_dimensions        Array of arrays of the dimensions of the numerator and denominator.
// dimensions_out             Array of the output dimensions of the whole object.
//
// The fraction line is at y = 0.9
//
// Example Call: See CL_rlp_template_test
// 
#local fraction_dimensions    = array[2];
#local numerator              = object{CL_rlp_make_text_string(numer_string,default_space,letter_adjust_numer,
                                                  z1,z2,d_rad,offs,cham,font_type,dimensions_out)}
#local fraction_dimensions[0] = dimensions_out;
#local denominator            = object{CL_rlp_make_text_string(denom_string,default_space,letter_adjust_denom,
                                                  z1,z2,d_rad,offs,cham,font_type,dimensions_out)}
#local fraction_dimensions[1] = dimensions_out;
//
#local num_width = fraction_dimensions[0][0];
#local den_width = fraction_dimensions[1][0];  
#local max_width = max(num_width,den_width);
// 
#declare den_height = fraction_dimensions[1][1];
#warning concat("CL_rlp_make_text_fraction den_height     is:",str(den_height   ,8,3),"\n")
//
union{ 
  CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,max_width,dimensions_out)
  #local dimensions_out[0] = max_width;
  #local dimensions_out[1] = 0.05+space_size+fraction_dimensions[0][1]+fraction_dimensions[0][3]+0.9;  
  #local dimensions_out[2] = dimensions_out[1];
  #local dimensions_out[3] = 0.05+space_size+fraction_dimensions[1][1]+fraction_dimensions[1][3]-0.9; 
  object{numerator   translate <(max_width-num_width)/2, 0.05+space_size+fraction_dimensions[0][3],0>   }
  object{denominator translate <(max_width-den_width)/2,-0.05-space_size-fraction_dimensions[1][1],0>   }
// Debug boundary lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3]-0.9,0> < 0.002            , dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3]-0.9,0> < dimensions_out[0], dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3]-0.9,0> < dimensions_out[0],-dimensions_out[3]-0.9,0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1]-0.9,0> < dimensions_out[0], dimensions_out[1]-0.9,0> 0.02 pigment{Red}}
  #end
  translate <0,0.9,0.0> // Have the dividing line centred on y = 0.9, to line up with a standard equals sign
     }  
//                                
#end     
                                                                         
//*****************************************************************************************************************************
// CL_rlp_make_text_function_fraction
//*************************************************************************************************
#macro CL_rlp_make_text_function_fraction(default_space,letter_adjust_1,letter_adjust_2,letter_adjust_3,letter_adjust_4,
                                          z1,z2,d_rad,offs,cham,font_type,
                                          text_function_elements,left_bracket_type,right_bracket_type,
                                          space_around,horiz_space,back_adjust,dimensions_out)  
// 
// default_space          Inter-letter space for the typeset strings
// letter_adjust_1        Any letter adjustment for the initial 'function' string                                                                                                                       
// letter_adjust_2        Any letter adjustment for the numerator of the fraction string                                                                                                                       
// letter_adjust_3        Any letter adjustment for the denominator of the fraction string                                                                                                                       
// letter_adjust_4        Any letter adjustment for the trailing/superscript string 
// z1,z2,d_rad,offs,cham,font_type Usual stuff for the letter producing macros
// text_function_elements array[4] containing the front function, numerator, denominator and trailing/superscript strings
// left_bracket_type      left bracket type. 0 for none, 1 round, 2 square, 3 curly, 4 vertical
// right_bracket_type     right bracket type
// space_aroud            space between the fraction and the brackets
// horiz_space            space between the front/trailing strings and the bracketed fraction
// back_adjust            Start off at zero. Vertical adjustment for the trailing/superscript string, not a non-superscript
// dimensions_out         The usual. array[4]{width,height,super_height,drop_below}; 
//                                                                                                                      
// Generate the objects to put in the fraction. We assume there will always be a fraction object. Why use this routine if not? 
//
#local top_fraction_part      = text_function_elements[1]; 
#local bot_fraction_part      = text_function_elements[2]; 
#local temp_dimensions        = array[4]
//
#local fraction_object        =  object{CL_rlp_make_text_fraction(default_space,letter_adjust_2,letter_adjust_3,z1,z2,d_rad,offs,cham,font_type,
                                                               top_fraction_part,bot_fraction_part,space_around,temp_dimensions)}
#local fraction_dimensions    =  temp_dimensions; 
// 
// Put the brackets around the fraction object
//
#local delimited_object       = object{CL_rlp_make_elastic_bracket_pair(default_space,letter_adjust_1,z1,z2,d_rad,offs,cham,font_type,
                                                                     fraction_object,default_space,left_bracket_type,right_bracket_type, 
                                                                     fraction_dimensions,temp_dimensions)}
#local delimited_dimensions   = temp_dimensions;
//
//  Generate the front/function name part. We assume there will always be a front/function object. Why use this routine if not? 
//
#local function_part          = text_function_elements[0]; 
//
#local function_object        = object{CL_rlp_make_text_string(function_part,default_space,letter_adjust_1,
                                                             z1,z2,d_rad,offs,cham,font_type,temp_dimensions)} 
#local function_dimensions    = temp_dimensions;
//
// Concatenate the function object and the argument
//  
#local part_dimensions        = array[2]{function_dimensions,delimited_dimensions};
#local front_arg_obj          = object{CL_rlp_make_concatenate(function_object,delimited_object,horiz_space,part_dimensions,dimensions_out)}
//  
// Look at the back string. Check that there is one first. Note dimensions_out has been set above
//
#local back_string            = text_function_elements[3]
#local back_length            = strlen(back_string);
#if(back_length = 0)
  object{front_arg_obj}
#else
// Look to see if the first character is a # to decide if we are in Roman or maths.
// Then look for a ^, in which case, the whole of the back string forms a superscript.
  #local char_num             = 1;
  #local maths_mode           = 0;
  #local sup_script           = 0;
  #local this_char            = substr(back_string,1,1);
//
  #if(this_char = "#")
    #local maths_mode         = 1;
    #local char_num           = 2;
  #end
  #if(this_char = "^")
    #local sup_script         = 1;
  #end
  #if(char_num = 2 & back_length > 1)
    #local this_char          = substr(back_string,2,1);
    #if(this_char = "^")
      #local sup_script       = 1;
    #end
  #end
//
// maths_mode is 0 or 1, sup_script is 0 or 1. Construct a new_back_string that strips out any ^ character
//
  #if(sup_script = 1) 
    #if(maths_mode = 0)
      #local new_back_string  = substr(back_string,2,back_length-1);
    #else 
      #local new_back_string  = concat("#",substr(back_string,3,back_length-2));
    #end
  #else
     #local new_back_string   = back_string;  
  #end
//
// Make an object from the new back string.
//  
  #local back_object          = object{CL_rlp_make_text_string(new_back_string,default_space,letter_adjust_4,
                                                             z1,z2,d_rad,offs,cham,font_type,temp_dimensions)} 
  #local back_dimensions      = temp_dimensions;
//
  #if(sup_script = 1)
//
// Tinse up the back object as a superscript, and union it with the front and middle objects
// 
    #local back_width         = back_dimensions[0]*0.6;
    #local back_height        = back_dimensions[1]*0.6;
    #local back_super         = back_dimensions[2]*0.6;
    #local back_drop          = back_dimensions[3]*0.6;  
    #local lett_width_shift   = dimensions_out[0] + default_space; 
    #local lett_upper_shift   = dimensions_out[1] - 0.4 + back_adjust;
//
    #local dimensions_out[0]  = lett_width_shift + back_width;
    #local dimensions_out[1]  = lett_upper_shift + back_height;
    #local dimensions_out[2]  = lett_upper_shift + back_height;
    #local dimensions_out[3]  = max(back_drop - lett_upper_shift,dimensions_out[3]);
//
    #local super_object       = object{back_object scale <0.6,0.6,1> translate <lett_width_shift,lett_upper_shift,0>}
    union{object{front_arg_obj}
          object{super_object}
          #if(CL_debug_lines = 1)
            cylinder{<       0         ,-dimensions_out[3],0> <dimensions_out[0],-dimensions_out[3],0> 0.04 pigment{Red}}
            cylinder{<       0         , dimensions_out[2],0> <dimensions_out[0], dimensions_out[2],0> 0.04 pigment{Red}}
            cylinder{<       0         ,-dimensions_out[3],0> <       0         , dimensions_out[2],0> 0.04 pigment{Red}}
            cylinder{<dimensions_out[0],-dimensions_out[3],0> <dimensions_out[0], dimensions_out[2],0> 0.04 pigment{Red}}
          #end
         }   
//
  #else
//
// Just concatenate the back object with the front and middle objects
// 
    #local temp_dimensions    = dimensions_out; 
    #local part_dimensions    = array[2]{temp_dimensions,back_dimensions};
    object{CL_rlp_make_concatenate(front_arg_obj,back_object,horiz_space,part_dimensions,dimensions_out)}
//
  #end
//
// Now is the end of the back_string #if structure.     
#end 
//
#end  
//***************************************************************************************************  
// CL_rlp_make_stack
//*************************************************************************************************
#macro CL_rlp_make_stack(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                         middle_string,lower_string,upper_string,
                         space_below,space_above,dimensions_out) 
//
// ASSUMES the middle string will yield an object centred on y = 0.9, like the equals sign. 
// You can fiddle with space_below and space_above.  
//
// default_space       inter-letter space, usually CL_tine_space
// z1, z2, d_rad, offs, cham as normal out of CL_rlp_make_text_string_set(set_type)
//
// middle_string       a STRING for the middle part. 
// lower_string        a string for the lower part of the stack
// upper_string        a string for the upper part of the stack    
// space_below         We try to leave a sensible space below, so this might start off = 0, but +ve number
//                     drops the lower part further
// space above         See space_below. A positive number raises the upper part further
// dimensions_out      Array of the output dimensions of the whole object.
//
// Example Call: See CL_rlp_template_test
// 
#local middle_part       = object{CL_rlp_make_text_string(middle_string,default_space,letter_adjust,z1,
                                                            z2,d_rad,offs,cham,font_type,dimensions_out)}
#local middle_width      = dimensions_out[0];                                
#local middle_height     = dimensions_out[1];
#local middle_drop       = dimensions_out[3];
//
// Deal with the lower string
//  
#local lower_len         = strlen(lower_string);
#if(lower_len > 0)
  #local lower_part       = object{CL_rlp_make_text_string(lower_string,default_space,letter_adjust,z1,
                                                            z2,d_rad,offs,cham,font_type,dimensions_out) scale <0.6,0.6,1>}
  #local lower_width      = dimensions_out[0]*0.6;                                
  #local lower_height     = dimensions_out[1]*0.6;
  #local lower_drop       = dimensions_out[3]*0.6;
//
  #local mid_drop         = middle_height - 0.9; 
//
  #local middle_part      = union{object{middle_part} 
                                  object{lower_part 
                                         translate <middle_width/2-lower_width/2,0.9-mid_drop-default_space-space_below-lower_height,0>}
                                 }
  #local middle_width = max(middle_width,lower_width);
  #local middle_drop  = max(0,mid_drop+default_space+space_below+lower_height+lower_drop);                                                                    
#end
//
// Deal with the upper string
//  
#local upper_len           = strlen(upper_string);
#if(upper_len > 0)
  #local upper_part        = object{CL_rlp_make_text_string(upper_string,default_space,letter_adjust,z1,
                                                            z2,d_rad,offs,cham,font_type,dimensions_out) scale <0.6,0.6,1>}
  #local upper_width       = dimensions_out[0]*0.6;                                
  #local upper_height      = dimensions_out[1]*0.6;
  #local upper_drop        = dimensions_out[3]*0.6;
//
  #local mid_raise         = middle_height - 0.9; 
//
  #local middle_part       = union{object{middle_part} 
                                  object{upper_part 
                                         translate <middle_width/2-upper_width/2,0.9+mid_raise+default_space+space_above+upper_drop,0>}
                                 }
  #local middle_width      = max(middle_width,upper_width);
  #local middle_height     = middle_height+mid_raise+default_space+space_above+upper_drop+upper_height;                                                                    
#end
//
#if(CL_debug_lines = 1)
  union{
#end
  object{middle_part}
// 
  #local dimensions_out[0] = middle_width;
  #local dimensions_out[1] = middle_height;  
  #local dimensions_out[2] = middle_width/2; // Allows positioning on the centre of the middle part/symbol.
  #local dimensions_out[3] = middle_drop; 
// Debug boundary lines
#if(CL_debug_lines = 1)
  cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
  cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
  cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
   }
#end
//                                
#end    
//***************************************************************************************************  
// CL_rlp_make_equation
//*************************************************************************************************
#macro CL_rlp_make_equation(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                            left_part,right_part,middle_part,middle_string,
                            space_size,part_dimensions,dimensions_out) 
//
// z1, z2, d_rad, offs, cham as normal out of CL_rlp_make_text_string_set(set_type)
// left_part, right_part A pair of OBJECTS representing the LHS and RHS of the equation. 
// middle_part                Can be an OBJECT for the middle part
// middle_string              Can be a STRING for the middle part. If of zero length (""), use the middle_part object.
// space_size                 A separation space between the horizontal line and the components.
// part_dimensions            Array of arrays of the dimensions of the LHS and RHS.
// dimensions_out             Array of the output dimensions of the whole object.
//
//
// Example Call: See CL_rlp_template_test
// 
// Pull out the dimensions of the left and right parts.
#local left_width          = part_dimensions[0][0];
#local right_width         = part_dimensions[1][0];  
#local left_height         = part_dimensions[0][1];
#local right_height        = part_dimensions[1][1];
#local left_drop           = part_dimensions[0][3];
#local right_drop          = part_dimensions[1][3];
#local max_height          = max(left_height,right_height);
#local max_drop            = max(left_drop,right_drop);
//
#local rel_str_len         = strlen(middle_string);
#if(rel_str_len > 0)
// Generate the middle part from the middle_string
  #local middle_dims       = array[4]{0,0,0,0};
  #local middle_part       = object{CL_rlp_make_text_string(middle_string,default_space,letter_adjust,z1,
                                                            z2,d_rad,offs,cham,font_type,middle_dims)}
  #local middle_width      = middle_dims[0];                                
#else
// Use the dimensions of the middle part.
  #local middle_width      = part_dimensions[2][0];
  #local middle_height     = part_dimensions[2][1];
  #local middle_drop       = part_dimensions[2][3];
  #local max_height        = max(max_height,middle_height);
  #local max_drop          = max(max_drop,middle_drop);
#end
//  
#local total_width         = left_width+2*space_size+middle_width+right_width;
union{
  object{left_part}
  object{middle_part translate <left_width+space_size,0,0>} 
  object{right_part  translate <left_width+2*space_size+middle_width,0,0>   }
// 
  #local dimensions_out[0] = total_width;
  #local dimensions_out[1] = max_height;  
  #local dimensions_out[2] = left_width+space_size+middle_width/2; // Allows positioning on the centre of the middle part/symbol.
  #local dimensions_out[3] = max_drop; 
// Debug boundary lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }
//                                
#end    
//***************************************************************************************************  
// CL_rlp_make_elastic_surd
//*************************************************************************************************
#macro CL_rlp_make_elastic_surd(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                inner_part,space_around,surd_super,inner_dimensions,dimensions_out) 
//
//
// z1, z2, d_rad, offs, cham as normal out of CL_rlp_make_text_string_set(set_type)
// inner_part        An OBJECT representing the internals of the surd. 
// space_around      A separation space between the horizontal line and the components.
// surd_super        A number. Only 3 or 4 appears as the pre-superscript   
// inner_dimensions  Array of the dimensions of the inner part.
// dimensions_out    Array of the output dimensions of the whole object.
//
// Example Call: See CL_rlp_template_test
// 
#local surd_part  = object{CL_rlp_elastic_surd(z1,z2,d_rad,offs,cham,inner_dimensions,space_around,surd_super,dimensions_out)}
union{ 
  object{surd_part}
  object{inner_part translate <dimensions_out[2],0,0>} 
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }  
//                                
#end    
//***************************************************************************************************  
// CL_rlp_make_elastic_bracket_pair
//*************************************************************************************************
#macro CL_rlp_make_elastic_bracket_pair(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                        inner_part,space_around,left_type,right_type,inner_dimensions,dimensions_out) 
// 
#local inner_width  = inner_dimensions[0];
#local height_above = inner_dimensions[1];
#local inner_drop   = inner_dimensions[3];
//
#local bheight      = height_above+inner_drop+0.4; 
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local left_delimiter  = object{CL_rlp_elastic_math_round_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
//
#if(left_type = 2)  
  #local left_delimiter  = object{CL_rlp_elastic_math_square_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(left_type = 3)  
  #local left_delimiter  = object{CL_rlp_elastic_math_curly_left_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(left_type = 4)  
  #local left_delimiter  = object{CL_rlp_elastic_langle(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(left_type = 5)  
  #local left_delimiter  = object{CL_rlp_elastic_vertical(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end 
//
#local left_delimiter_width = letter_dimensions[0];
#local letter_dimensions = array[4]{0,0,0,0};
//
#local right_delimiter  = object{CL_rlp_elastic_math_round_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
//
#if(right_type = 2)  
  #local right_delimiter  = object{CL_rlp_elastic_math_square_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(right_type = 3)  
  #local right_delimiter  = object{CL_rlp_elastic_math_curly_right_bracket(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(right_type = 4)  
  #local right_delimiter  = object{CL_rlp_elastic_rangle(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
#if(right_type = 5)  
  #local right_delimiter  = object{CL_rlp_elastic_vertical(z1,z2,d_rad,offs,cham,bheight,letter_dimensions)}
#end
//
#local right_delimiter_width = letter_dimensions[0];
//
#local dimensions_out[0] = left_delimiter_width+2*space_around+inner_width+right_delimiter_width;
#local dimensions_out[1] = height_above+0.2;
#local dimensions_out[2] = height_above+0.2;
#local dimensions_out[3] = inner_drop+0.2;
//
union{
  #if(left_type > 0)
    object{left_delimiter translate <0,bheight/2-1-inner_drop-0.2,0>}
  #end
  object{inner_part translate <left_delimiter_width+space_around,0,0>} 
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
  #if(right_type > 0)
    object{right_delimiter translate <left_delimiter_width+2*space_around+inner_width,bheight/2-1-inner_drop-0.2,0>}
  #end
     } 
//                                
#end 
//***************************************************************************************************  
// CL_rlp_make_sumprod
//*************************************************************************************************
#macro CL_rlp_make_sumprod(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,right_part,right_string,
                           sub_string,super_string,space_around,display_type,sumprod_type,
                           right_dimensions,dimensions_out) 
// 
#local right_num = strlen(right_string);
#if(right_num > 0)
#local right_obj    = object{CL_rlp_make_text_string(right_string,default_space,letter_adjust,
                                                     z1,z2,d_rad,offs,cham,font_type,right_dimensions)}
#else
  #local right_obj  = right_part;
#end
//
#local right_width  = right_dimensions[0];
#local right_height = right_dimensions[1];
#local right_drop   = right_dimensions[3];
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#if(display_type = 0)   // Not display
  #if(sumprod_type = 0) // Sum 
    #local sumprod_obj  = object{CL_rlp_bigSigma(z1,z2,d_rad,offs,cham,letter_dimensions)}
  #else
    #local sumprod_obj  = object{CL_rlp_bigPi(z1,z2,d_rad,offs,cham,letter_dimensions)}
  #end
#else
  #if(sumprod_type = 0) // Sum 
    #local sumprod_obj  = object{CL_rlp_BigSigma(z1,z2,d_rad,offs,cham,letter_dimensions)}
  #else
    #local sumprod_obj  = object{CL_rlp_BigPi(z1,z2,d_rad,offs,cham,letter_dimensions)}
  #end
#end
//
#local spo_width  = letter_dimensions[0];
#local spo_height = letter_dimensions[1];  
#local spo_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_sumprod spo_width     is:",str(spo_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod spo_height    is:",str(spo_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod spo_drop      is:",str(spo_drop     ,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod default_space is:",str(default_space,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local super_obj  = object{CL_rlp_make_text_string(super_string,default_space,letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local sup_width  = 0.6*letter_dimensions[0];
#local sup_height = 0.6*letter_dimensions[1];  
#local sup_drop   = 0.6*letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_sumprod sup_width  is:",str(sup_width ,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod sup_height is:",str(sup_height,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod sup_drop   is:",str(sup_drop  ,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local sub_obj    = object{CL_rlp_make_text_string(sub_string,default_space,letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local sub_width  = 0.6*letter_dimensions[0];
#local sub_height = 0.6*letter_dimensions[1];  
#local sub_drop   = 0.6*letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_sumprod sub_width  is:",str(sub_width ,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod sub_height is:",str(sub_height,8,3),"\n")
  #warning concat("CL_rlp_make_sumprod sub_drop   is:",str(sub_drop  ,8,3),"\n")
#end
//
#if(display_type = 0)    // Inline
  #local spo_tran_x = 0;   
  #local sup_tran_x = spo_width+default_space;
  #local sub_tran_x = sup_tran_x;
  #local rpt_tran_x = sup_tran_x+max(sup_width,sub_width)+space_around;
//
  #local supersub_adj = 0;
  #if(sup_height+sup_drop+sub_height+sub_drop+default_space > spo_height+spo_drop)
    #local supersub_adj = (sup_height+sup_drop+sub_height+sub_drop+default_space - spo_height-spo_drop)/2;
  #end
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_sumprod supersub_adj is:",str(supersub_adj,8,3),"\n")
  #end
//
  #local sup_tran_y = spo_height-sup_height+supersub_adj;
  #local sub_tran_y = spo_drop-sub_drop+supersub_adj;  
//
  #local total_height_above = max(spo_height+supersub_adj,right_height);
  #local total_drop_below   = max(spo_drop  +supersub_adj,right_drop  );
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_sumprod total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_sumprod total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#else
  #local max_width  = max(spo_width,sup_width);
  #local max_width  = max(max_width,sub_width);
  #local spo_tran_x = (max_width-spo_width)/2;   
  #local sup_tran_x = (max_width-sup_width)/2;
  #local sub_tran_x = (max_width-sub_width)/2;
  #local rpt_tran_x = max_width+space_around;
//
  #local sup_tran_y = spo_height+default_space+sup_drop;
  #local sub_tran_y = spo_drop+default_space+sub_height+sub_drop;  
//
  #local total_height_above = max(spo_height+default_space+sup_height+sup_drop,right_height);
  #local total_drop_below   = max(spo_drop  +default_space+sub_height+sub_drop,right_drop  );
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_sumprod total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_sumprod total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#end
//
#local dimensions_out[0] = rpt_tran_x+right_width;
#local dimensions_out[1] = total_height_above;
#local dimensions_out[2] = total_height_above;
#local dimensions_out[3] = total_drop_below;
//
union{ 
  object{sumprod_obj           translate <spo_tran_x,    0     ,0>}
  object{super_obj   scale 0.6 translate <sup_tran_x, sup_tran_y,0>}
  object{sub_obj     scale 0.6 translate <sub_tran_x,-sub_tran_y,0>}
  object{right_obj             translate <rpt_tran_x ,    0     ,0>} 
// Debug outline cylinders.
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }  
//                                
#end       
//***************************************************************************************************  
// CL_rlp_make_integral
//*************************************************************************************************
#macro CL_rlp_make_integral(default_space,int_letter_adjust,default_letter_adjust,
                            z1,z2,d_rad,offs,cham,font_type,right_part,right_string,
                            int_varb_string,sub_string,super_string,front_space,back_space,display_type,
                            right_dimensions,dimensions_out) 
// 
// Produce an object, given either an object or a string for the integrand. Decides using the length of the passed string
//
// default_space         Default interletter space. Maybe CL_tiny_space or CL_small_space.
// int_letter_adjust     Letter adjustment for the integrand. 
// default_letter_adjust Letter adjustment for ALL of int_varb_string, sub_string, super_string. This should probably be the default - i.e. no adjustment.
//
// z1, z2, d_rad, offs, cham, font_type Values out of CL_rlp_make_text_string_set
//
// right_part            An object for the integrand, or set to 0.
// right_string          A string for the integrand or set to "", the zero length string. 
//                       If right_string has length zero, use the right_part object.
// int_varb_string       A string representing the integration variable, e.g."#x"
// sub_string            A string representing the lower integration limit, e.g "#0"
// super_string          A string representing the upper integration limit, e.g. "#|8" for infinity.
// space_around          A bit of space between the integral sign and the right expression. Could be 
//                       CL_medium_space, defined in CL_rlp_make_text_string_set
// display_type          0 for inline, 1 for displayed 
// right_dimensions      Dimensions of the right_part if you pass an object, or define as 
//                       #declare right_dimensions = array[4]{0,0,0,0};
//                       before the call if you pass a string.
// dimensions_out        Exits as the overall dimensions of the integral object. Define as 
//                       #declare dimensions_out = array[4]{0,0,0,0}; before the call.
//
// Example call: See CL_rlp_template_test
// 
#local right_num    = strlen(right_string);
#local int_varb_num = strlen(int_varb_string);
//
#if(right_num > 0)
#local right_obj    = object{CL_rlp_make_text_string(right_string,default_space,int_letter_adjust,
                                                     z1,z2,d_rad,offs,cham,font_type,right_dimensions)}
#else
  #local right_obj  = right_part;
#end
//
#local right_width  = right_dimensions[0];
#local right_height = right_dimensions[1];
#local right_drop   = right_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral right_width     is:",str(right_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_integral right_height    is:",str(right_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_integral right_drop      is:",str(right_drop     ,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#if(display_type = 0)   // Inline
  #local int_obj  = object{CL_rlp_Integral(z1,z2,d_rad,offs,cham,1,letter_dimensions)}
#else   // Display 
//  #warning concat("CL_rlp_make_integral display","\n")
  #if(right_height > 0 & right_drop > 1.5)
    #if(right_height > 3.41 | right_drop > 2.31)
          #local int_obj  = object{CL_rlp_ReallyBigIntegral(z1,z2,d_rad,offs,cham,1,letter_dimensions)} 
//    #warning concat("CL_rlp_make_integral Really BIG","\n")  
    #else  
      #local int_obj  = object{CL_rlp_BigIntegral(z1,z2,d_rad,offs,cham,1,letter_dimensions)} 
//    #warning concat("CL_rlp_make_integral BIG","\n")
    #end
  #else
    #local int_obj  = object{CL_rlp_bigIntegral(z1,z2,d_rad,offs,cham,1,letter_dimensions)}
//    #warning concat("CL_rlp_make_integral big","\n")
  #end 
#end
//
#local ino_width  = letter_dimensions[0];
#local ino_height = letter_dimensions[1];  
#local ino_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral ino_width     is:",str(ino_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_integral ino_height    is:",str(ino_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_integral ino_drop      is:",str(ino_drop     ,8,3),"\n")
  #warning concat("CL_rlp_make_integral default_space is:",str(default_space,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local super_obj  = object{CL_rlp_make_text_string(super_string,default_space,default_letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local sup_width  = 0.6*letter_dimensions[0];
#local sup_height = 0.6*letter_dimensions[1];  
#local sup_drop   = 0.6*letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral sup_width  is:",str(sup_width ,8,3),"\n")
  #warning concat("CL_rlp_make_integral sup_height is:",str(sup_height,8,3),"\n")
  #warning concat("CL_rlp_make_integral sup_drop   is:",str(sup_drop  ,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local sub_obj    = object{CL_rlp_make_text_string(sub_string,default_space,default_letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local sub_width  = 0.6*letter_dimensions[0];
#local sub_height = 0.6*letter_dimensions[1];  
#local sub_drop   = 0.6*letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral sub_width  is:",str(sub_width ,8,3),"\n")
  #warning concat("CL_rlp_make_integral sub_height is:",str(sub_height,8,3),"\n")
  #warning concat("CL_rlp_make_integral sub_drop   is:",str(sub_drop  ,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local ope_obj    = object{CL_rlp_mathd(z1,z2,d_rad,offs,cham,letter_dimensions) matrix <1,0,0,-0.20,1,0,0,0,1,0.1,0,0>}
//
#local ope_width  = letter_dimensions[0];
#local ope_height = letter_dimensions[1];  
#local ope_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral ope_width  is:",str(ope_width ,8,3),"\n")
  #warning concat("CL_rlp_make_integral ope_height is:",str(ope_height,8,3),"\n")
  #warning concat("CL_rlp_make_integral ope_drop   is:",str(ope_drop  ,8,3),"\n")
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local var_obj    = object{CL_rlp_make_text_string(int_varb_string,default_space,default_letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local var_width  = letter_dimensions[0];
#local var_height = letter_dimensions[1];  
#local var_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral var_width  is:",str(var_width ,8,3),"\n")
  #warning concat("CL_rlp_make_integral var_height is:",str(var_height,8,3),"\n")
  #warning concat("CL_rlp_make_integral var_drop   is:",str(var_drop  ,8,3),"\n")
#end
//
#local supersub_adj = 0; 
//
#if(sup_height+sup_drop+sub_height+sub_drop+default_space > ino_height+ino_drop)
  #local supersub_adj = (sup_height+sup_drop+sub_height+sub_drop+default_space - ino_height-ino_drop)/2;
#end
//
#if(display_type = 0)    // Inline
  #local ino_tran_x         = 0;   
  #local sup_tran_x         = ino_width+default_space;
  #local sub_tran_x         = sup_tran_x-ino_width*0.4;
  #local rpt_tran_x         = sup_tran_x+max(sup_width,sub_width-ino_width*0.4)+front_space;
  #local ope_tran_x         = rpt_tran_x+right_width+back_space;
  #local var_tran_x         = ope_tran_x+ope_width+default_space;
//
  #local sup_tran_y         = ino_height-sup_height+supersub_adj;
  #local sub_tran_y         = ino_drop+supersub_adj;  
//
  #local total_height_above = max(ino_height+supersub_adj,right_height);
  #local total_drop_below   = max(ino_drop+sub_drop+supersub_adj,right_drop  );
//
  #if(CL_debug_lines = 0)
    #warning concat("CL_rlp_make_integral supersub_adj is:",str(supersub_adj,8,3),"\n")
    #warning concat("CL_rlp_make_integral total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_integral total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#else 
  #local ino_tran_x         = 0;
  #local sup_tran_x         = ino_width+default_space;
  #local sub_tran_x         = sup_tran_x-ino_width*0.4;
  #local rpt_tran_x         = sup_tran_x+sub_width+front_space;
  #local ope_tran_x         = rpt_tran_x+right_width+back_space;
  #local var_tran_x         = ope_tran_x+ope_width+default_space;
//
  #local sup_tran_y         = ino_height-sup_height+supersub_adj;
  #local sub_tran_y         = ino_drop+supersub_adj;  
//
  #local total_height_above = max(ino_height,right_height);
  #local total_drop_below   = max(ino_drop+sub_drop,right_drop  );
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_integral total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_integral total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#end
//
#local dimensions_out[0] = rpt_tran_x+right_width+default_space+ope_width+back_space+var_width;
#local dimensions_out[1] = total_height_above;
#local dimensions_out[2] = total_height_above;
#local dimensions_out[3] = total_drop_below;
//
union{ 
  object{int_obj                       translate <ino_tran_x,    0      , 0>}
  object{super_obj   scale <0.6,0.6,1> translate <sup_tran_x, sup_tran_y, 0>}
  object{sub_obj     scale <0.6,0.6,1> translate <sub_tran_x,-sub_tran_y, 0>}
  object{right_obj                     translate <rpt_tran_x,    0      , 0>}
  object{ope_obj                       translate <ope_tran_x,    0      , 0>} 
  object{var_obj                       translate <var_tran_x,    0      , 0>} 
//
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }  
//                                
#end 
//***************************************************************************************************  
// CL_rlp_make_multiple_integrals
//*************************************************************************************************
#macro CL_rlp_make_multiple_integrals(default_space,int_letter_adjust,default_letter_adjust,
                                      z1,z2,d_rad,offs,cham,font_type,
                                      integrand_part,integrand_string,int_varb_array,
                                      sub_super_array,space_around_array,oper_space,display_type,mult_int_level,
                                      integrand_dimensions,dimensions_out) 
// 
// Produce an object representing a multiple integral, given either an object or a string for the integrand 
// arrays of strings for the integration variables and arrays of strings for the upper and lower limits.
//
// default_space         Default interletter space. Maybe CL_tiny_space or CL_small_space.
// int_letter_adjust     Letter adjustment for the integrand. 
// default_letter_adjust Letter adjustment for ALL of the int_varb_strings, sub_strings, super_strings. 
//                       This should probably be the default - i.e. no adjustment.
//
// z1, z2, d_rad, offs, cham, font_type Values out of CL_rlp_make_text_string_set
//
// integrand_part        An object for the integrand, or set to 0.
// integrand_string      A string for the integrand or set to "", the zero length string. 
//                       If integrand_string has length zero, use the integrand_part object.
// int_varb_array        An array of strings representing the integration variables, 
//                       Start inner and work your way out.
// sub_super_array       An array of strings representing the lower and upper integration limits.
//                       lower, upper, starting inner and working your way out.
// space_around_array    An array of spaces, starting with the space between the inner integral sign 
//                       and the integrand object, which may be non-zero. Could be CL_medium_space, 
//                       defined in CL_rlp_make_text_string_set. 
//                       Follows up with spaces between the multiple integral signs. We try to guess 
//                       a good spacing, but you may disagree. +ve opens up, -ve closes down                       
// display_type          0 for inline, 1 for displayed. Displayed could be one of three levels 
// mult_int_level        2, 3 or upwards.
// integrand_dimensions  Dimensions of the integrand_part if you pass an object, or define as 
//                       #declare integrand_dimensions = array[4]{0,0,0,0};
//                       before the call if you pass an integrand_string.
// dimensions_out        Exits as the overall dimensions of the integral object. Define as 
//                       #declare dimensions_out = array[4]{0,0,0,0}; before the call.
//
// Example call: See CL_rlp_template_test
// 
// Get the integrand objectmade
// 
//
#local integrand_dimensions = array[4]{0,0,0,0};
#local integrand_num        = strlen(integrand_string);
//
#if(integrand_num > 0)
#local int_obj              = object{CL_rlp_make_text_string(integrand_string,default_space,int_letter_adjust,
                                                             z1,z2,d_rad,offs,cham,font_type,integrand_dimensions)}
#else
  #local int_obj            = integrand_part;
#end
//
#local int_width            = integrand_dimensions[0];
#local int_height           = integrand_dimensions[1];
#local int_drop             = integrand_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_integral int_width     is:",str(int_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_integral int_height    is:",str(int_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_integral int_drop      is:",str(int_drop     ,8,3),"\n")
#end 
//
// Start the while loop for the multiple integrals 
//  
#local dimensions_out         = array[4]{0,0,0,0};
#local icount                 = 0;
#while(icount < mult_int_level)
//
  #local int_varb_string      = int_varb_array[icount];
  #local sub_string           = sub_super_array[2*icount];
  #local super_string         = sub_super_array[2*icount+1];
  #local space_around         = space_around_array[icount];
//
  #local int_obj              = CL_rlp_make_integral(default_space,default_letter_adjust,default_letter_adjust,
                                                     z1,z2,d_rad,offs,cham,font_type,int_obj,"",
                                                     int_varb_string,sub_string,super_string,space_around,oper_space,
                                                     display_type,integrand_dimensions,dimensions_out) 
  #local integrand_dimensions = dimensions_out; 
  #local icount               = icount + 1;
//
#end
// 
object{int_obj}
//
#end
//*************************************************************************************************  
// CL_rlp_make_linesurfacevolume_integral
//*************************************************************************************************
#macro CL_rlp_make_linesurfacevolume_integral(default_space,int_letter_adjust,default_letter_adjust,
                                              z1,z2,d_rad,offs,cham,font_type,
                                              integrand_part,integrand_string,int_varb_string,sub_string,
                                              front_space,back_space,display_type,integral_type,vector_type,oint,
                                              integrand_dimensions,dimensions_out) 
// 
// Produce an object, given either an object or a string for the integrand. Decides using the length of the passed string
//
// default_space         Default interletter space. Maybe CL_tiny_space or CL_small_space.
// int_letter_adjust     Letter adjustment for the integrand. 
// default_letter_adjust Letter adjustment for ALL of int_varb_string, sub_string, super_string. 
//                       This should probably be the default - i.e. no adjustment, since it is the same .
//
// z1, z2, d_rad, offs, cham, font_type Values out of CL_rlp_make_text_string_set
//
// integrand_part        An object for the integrand, or set to 0.
// integrand_string      A string for the integrand or set to "", the zero length string. 
//                       If right_string has length zero, use the right_part object.
// int_varb_string       A string for the integration variable. If you want a vectorised greek letter, use e.g. "#|G".
//                       It will be underlined or emboldened according to vector_type. If "", i.e.empty, ell will be used for line, 
//                       S for surface and V for volume.  
// sub_string            A string representing the region of integration.
// front_space           A bit of space between the integral sign and the integrand expression. Could be 
//                       CL_medium_space, defined in CL_rlp_make_text_string_set
// back_space            A bit of space between the integrand and the integration operator.
// display_type          0 for inline, 1 for displayed/elastic
// integral_type         1 for line, 2 for surface, 3 for volume.
// vector_type           For line integrals: 1 for underlined, 2 for emboldened.
//                       For surface integrals: 1 for underlined, 2 for emboldened, 3 for using n underlined, 4 for using n emboldened. 
//                       Not used for volume integrals. 
//                       Note that the user takes care of the vectorisation in the integrand. If emboldened vectorisation is to be used, 
//                       the user takes care of that in the int_varb_string. If underlining is to be used, both the d and the 
//                       int_varb_string will be underlined, so this is taken care of in this routine. 
// oint                  0 for a closed curve/surface, 1 otherwise.
// 
// integrand_dimensions  Dimensions of the integrand_part if you pass an object, or define as 
//                       #declare right_dimensions = array[4]{0,0,0,0};
//                       before the call if you pass a non-empty string integrand_string.
// dimensions_out        Exits as the overall dimensions of the integral object. Define as 
//                       #declare dimensions_out = array[4]{0,0,0,0}; before the call.
//
// Example call: See CL_rlp_template_test
//
// Create the integrand object.
// 
#local integrand_num   = strlen(integrand_string);
#if(integrand_num > 0)
#local integrand_obj   = object{CL_rlp_make_text_string(integrand_string,default_space,int_letter_adjust,
                                                        z1,z2,d_rad,offs,cham,font_type,integrand_dimensions)}
#else
  #local integrand_obj = integrand_part;
#end
//
#local integrand_width  = integrand_dimensions[0];
#local integrand_height = integrand_dimensions[1];
#local integrand_drop   = integrand_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_linesurfacevolume_integral integrand_width     is:",str(integrand_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral integrand_height    is:",str(integrand_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral integrand_drop      is:",str(integrand_drop     ,8,3),"\n")
#end
//
// Construct the integration sign(s)
// First, decide on the size of the integration signs.
//
#if(display_type = 0)   // Inline
  #local isize = 1;
#else   // Display 
  #if(integrand_height > 0 & integrand_drop > 1.5)
    #if(integrand_height > 3.41 | integrand_drop > 2.31)
          #local isize = 4; 
    #else  
      #local isize     = 3; 
    #end
  #else
    #local isize       = 2;
  #end 
#end
//   
#local letter_dimensions = array[4]{0,0,0,0};
#local ino_obj = object{CL_rlp_linesurfacevolume_integral(z1,z2,d_rad,offs,cham,isize,integral_type,oint,letter_dimensions)}
//
#local ino_width  = letter_dimensions[0];
#local ino_height = letter_dimensions[1];  
#local ino_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_linesurfacevolume_integral ino_width     is:",str(ino_width    ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral ino_height    is:",str(ino_height   ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral ino_drop      is:",str(ino_drop     ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral default_space is:",str(default_space,8,3),"\n")
#end
//
// Construct the subscript object, which characterises the integration region.
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local sub_obj    = object{CL_rlp_make_text_string(sub_string,default_space,default_letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
//
#local sub_width  = 0.6*letter_dimensions[0];
#local sub_height = 0.6*letter_dimensions[1];  
#local sub_drop   = 0.6*letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_linesurfacevolume_integral sub_width  is:",str(sub_width ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral sub_height is:",str(sub_height,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral sub_drop   is:",str(sub_drop  ,8,3),"\n")
#end
//
// Do we need a dot or a dot n hat or a dot emboldened n unioned with the integrand object?
//
#if(integral_type < 3) 
  #if(vector_type < 3) 
    #local dot_string    = "#."
  #elseif(vector_type = 4)
    #local dot_string    = "#. #n"
  #else  
    #local dot_string    = "#. #|n"
  #end
  #local dot_obj         = object{CL_rlp_make_text_string(dot_string,default_space,default_letter_adjust,
                                                          z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
  #local integrand_obj   = union{object{integrand_obj} object{dot_obj translate <integrand_width+back_space,0,0>}}
  #local integrand_width = integrand_width+back_space+letter_dimensions[0];
#end
//
// Construct the integration operation symbol
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local ope_obj    = object{CL_rlp_mathd(z1,z2,d_rad,offs,cham,letter_dimensions) matrix <1,0,0,-0.20,1,0,0,0,1,0.1,0,0>}
//
#local ope_width  = letter_dimensions[0];
#local ope_height = letter_dimensions[1];  
#local ope_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_linesurfacevolume_integral ope_width  is:",str(ope_width ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral ope_height is:",str(ope_height,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral ope_drop   is:",str(ope_drop  ,8,3),"\n")
#end
//
// Construct the integration variable symbol/string
//
#local ope_num   = strlen(int_varb_string); 
#if(ope_num = 0)
  #if(integral_type = 1)    
    #local ope_varb_string = "#l"
  #elseif(integral_type = 2)     
    #local ope_varb_string = "#S"
  #else
    #local ope_varb_string = "#V"
  #end
#else
  #local ope_varb_string   = int_varb_string;
#end
//
#local letter_dimensions = array[4]{0,0,0,0};
//
#local var_obj    = object{CL_rlp_make_text_string(ope_varb_string,default_space,default_letter_adjust,
                                                   z1,z2,d_rad,offs,cham,font_type,letter_dimensions)}
// 
#local var_width  = letter_dimensions[0];
#local var_height = letter_dimensions[1];  
#local var_drop   = letter_dimensions[3];
//
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_linesurfacevolume_integral var_width  is:",str(var_width ,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral var_height is:",str(var_height,8,3),"\n")
  #warning concat("CL_rlp_make_linesurfacevolume_integral var_drop   is:",str(var_drop  ,8,3),"\n")
#end
//
// Decide whether we are underlining the ope_obj/var_obj combination
// 
#if(vector_type = 1)
  #local underl_width = ope_width+default_space+var_width*0.9;  
  #local pts = array[1];
// container, 1st subset: outer edge
  #local pts[0] =
  array[4]{
   <0.000       ,-.200,0.000>,    
   <underl_width,-.200,0.000>,
   <underl_width,-.360,0.000>,
 
   <0.000       ,-.360,0.000>
  } 
//
  #local underl_obj   = rlp_rounded_lprism(pts,z1,z2,d_rad,offs,cham)
  #local ope_obj      = union{object{ope_obj} object{underl_obj}}
#end
//
#if(display_type = 0)    // Inline
  #local ino_tran_x         = 0;   
  #local sub_tran_x         = ino_width-0.6-isize*0.2+default_space;
  #local ing_tran_x         = sub_tran_x+sub_width+front_space;
  #local ope_tran_x         = ing_tran_x+integrand_width+back_space;
  #local var_tran_x         = ope_tran_x+ope_width+default_space;
//
  #local sub_tran_y         = ino_drop+0.4;  
//
  #local total_height_above = max(ino_height,integrand_height);
  #local total_drop_below   = max(ino_drop+sub_drop+0.4,integrand_drop  );
//
  #if(CL_debug_lines = 0)
    #warning concat("CL_rlp_make_linesurfacevolume_integral supersub_adj is:",str(supersub_adj,8,3),"\n")
    #warning concat("CL_rlp_make_linesurfacevolume_integral total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_linesurfacevolume_integral total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#else 
  #local ino_tran_x         = 0;
  #local sub_tran_x         = ino_width-0.3-isize*0.2;
  #local ing_tran_x         = sub_tran_x+sub_width+front_space;
  #local ope_tran_x         = ing_tran_x+integrand_width+back_space;
  #local var_tran_x         = ope_tran_x+ope_width+default_space;
//
  #local sub_tran_y         = ino_drop+0.4;  
//
  #local total_height_above = max(ino_height,integrand_height);
  #local total_drop_below   = max(ino_drop+sub_drop+0.4,integrand_drop  );
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_linesurfacevolume_integral total_height_above is:",str(total_height_above,8,3),"\n")
    #warning concat("CL_rlp_make_linesurfacevolume_integral total_drop_below   is:",str(total_drop_below  ,8,3),"\n")
  #end
//
#end
//
#local dimensions_out[0] = ing_tran_x+integrand_width+default_space+ope_width+back_space+var_width;
#local dimensions_out[1] = total_height_above;
#local dimensions_out[2] = total_height_above;
#local dimensions_out[3] = total_drop_below;
//
union{ 
  object{ino_obj                         translate <ino_tran_x,    0      , 0>}
  object{sub_obj       scale <0.6,0.6,1> translate <sub_tran_x,-sub_tran_y, 0>}
  object{integrand_obj                   translate <ing_tran_x,    0      , 0>}
  object{ope_obj                         translate <ope_tran_x,    0      , 0>} 
  object{var_obj                         translate <var_tran_x,    0      , 0>} 
//
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }  
//                                
#end 
//***************************************************************************************************  
// CL_rlp_make_supersubscript
//***************************************************************************************************
#macro CL_rlp_make_supersubscript(default_space,letter_adjust,z1,z2,d_rad,offs,cham,font_type,
                                  main_part,main_string,sub_string,super_string,script_space,
                                  sup_letter_adjust,sub_letter_adjust,sup_adjust,main_dimensions,dimensions_out) 
//
  
#local main_num = strlen(main_string);
#if(main_num > 0)
#local main_obj             = object{CL_rlp_make_text_string(main_string,default_space,letter_adjust,
                                                             z1,z2,d_rad,offs,cham,font_type,main_dimensions)}
#else
  #local main_obj           = main_part;
#end
//
#local main_width           = main_dimensions[0];
#local main_height          = main_dimensions[1];
#local main_drop            = main_dimensions[3];
//
#local main_depth           = main_height + main_drop;
//
#local object_dimensions    = array[4]{0,0,0,0};
//
#local super_num            = strlen(super_string);
#if(super_num > 0) 
  #local super_obj          = object{CL_rlp_make_text_string(super_string,default_space,sup_letter_adjust,
                                                             z1,z2,d_rad,offs,cham,font_type,object_dimensions)}
//
  #local sup_width          = 0.6*object_dimensions[0];
  #local sup_height         = 0.6*object_dimensions[1];  
  #local sup_drop           = 0.6*object_dimensions[3];
  #local sup_overall_height = sup_height + sup_drop;
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_supersubscript sup_width  is:",str(sup_width ,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sup_height is:",str(sup_height,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sup_drop   is:",str(sup_drop  ,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sup_overall_height is:",str(sup_overall_height  ,8,3),"\n")
  #end
//
#else 
  #local sup_height         = 0;
  #local sup_width          = 0;
  #local sup_drop           = 0;
#end
//
#local sup_midy             = (sup_height - sup_drop)/2; 
#local sup_depth            =  sup_height + sup_drop;
//
#local object_dimensions    = array[4]{0,0,0,0};
//
#local sub_num = strlen(sub_string);
#if(sub_num > 0)
  #local sub_obj            = object{CL_rlp_make_text_string(sub_string,default_space,sub_letter_adjust,
                                                             z1,z2,d_rad,offs,cham,font_type,object_dimensions)}
//
  #local sub_width          = 0.6*object_dimensions[0];
  #local sub_height         = 0.6*object_dimensions[1];  
  #local sub_drop           = 0.6*object_dimensions[3];
  #local sub_overall_height = sub_height + sub_drop;
//
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_supersubscript sub_width  is:",str(sub_width ,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sub_height is:",str(sub_height,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sub_drop   is:",str(sub_drop  ,8,3),"\n")
    #warning concat("CL_rlp_make_supersubscript sub_overall_height is:",str(sub_overall_height  ,8,3),"\n")
  #end
//
#else
  #local sub_width          = 0;
  #local sub_drop           = 0;
  #local sub_height         = 0;
#end  
//
#local sub_midy             = (sub_height - sub_drop)/2; 
#local sub_depth            =  sub_height + sub_drop;
//
#local supersub_adj         = (sup_depth  + sub_depth)/2 - sup_adjust - main_depth;
#if(supersub_adj > 0)
  #local supersub_adj       = supersub_adj/2;
#else
  #local supersub_adj       = 0;
#end
//
#local supersub_width       = max(sub_width,sup_width);
//
#local dimensions_out[0]    = main_width  + script_space + supersub_width;
#local dimensions_out[1]    = main_height + sup_depth/2  + sup_adjust + supersub_adj;
#local dimensions_out[2]    = dimensions_out[1];
#local dimensions_out[3]    = main_drop   + sub_depth/2  + supersub_adj;
//
union{ 
  object{main_obj} 
  #if(super_num > 0)
    #local sup_tran_x       = main_width  + script_space;
    #local sup_tran_y       = main_height + sup_adjust - sup_overall_height/2;    
    object{super_obj scale 0.6 translate <sup_tran_x, sup_tran_y, 0>}
  #end
  #if(sub_num > 0)
    #local sub_tran_x       = main_width  + script_space;
    #local sub_tran_y       = main_drop   + sub_overall_height/2;    
    object{sub_obj   scale 0.6 translate <sub_tran_x,-sub_tran_y, 0>}
  #end
//    
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
     }  
//                                
#end       
//***************************************************************************************************  
// CL_rlp_make_concatenate
//*************************************************************************************************
#macro CL_rlp_make_concatenate(left_part,right_part,space_size,part_dimensions,dimensions_out) 
//
// left_part       OBJECT to form the left part.
// right_part      OBJECT to form the right part.
// space_size      Space left between the parts.
// part_dimensions Dimensions of the parts. array[2][4]
// dimensions_out  Dimensions of the concatenated structure. array[4]
//
#local left_width   = part_dimensions[0][0];
#local right_width  = part_dimensions[1][0];  
#local total_width  = left_width+space_size+right_width;
#local left_height  = part_dimensions[0][1];
#local right_height = part_dimensions[1][1];
#local max_height   = max(left_height,right_height);
#local left_drop    = part_dimensions[0][3];
#local right_drop   = part_dimensions[1][3];                          
#local max_drop     = max(left_drop,right_drop);
//
union{
  object{left_part}
  object{right_part translate <left_width+space_size,0,0>}
//
#local dimensions_out[0] = total_width;
#local dimensions_out[1] = max_height;  
#local dimensions_out[2] = dimensions_out[1];
#local dimensions_out[3] = max_drop; 
// Debug boundary lines
  #if(CL_debug_lines = 1)
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
  #end
    }
//                                
#end                               
//***************************************************************************************************
// CL_rlp_make_embellish
//*************************************************************************************************
#macro CL_rlp_make_embellish(default_space,letter_adjust_main,letter_adjust_over,letter_adjust_under,
                             z1,z2,d_rad,offs,cham,font_type,
                             char_obj,char_string,over_embellish_type,under_embellish_type,
                             over_string,under_string,outer_box,embellish_adjust,dimensions_in,
                             dimensions_out) 
// 
// Usual arguments for CL_rlp_make_text_string:
//  default_space,kern_adjust,z1,z2,d_rad,offs,cham,font_type as usual
//
//  char_obj             the object to be embellished or ...  
//  char_string          the string to be embellished. If you are passing in an object this has to be ""
//  over_embellish_type  See below for the possibilities.   
//  under_embellish_type See below for the possibilities.
//  under_string         String to appear under the object. "" for no string.
//  over_string          String to appear over the object.  "" for no string.
//  outer_box            0 for no outer box, 1 for an outer box.
//  embellish_adjust     array[5][4] to control the placing of the embellishments and over-/under-text
//                                   and any outer box. Start off all zeros.
//  dimensions_in        array[4] Dimensions of the char_obj if passed in. 0 if a string passed in.
//  dimensions_out       Dimensions of the embellished object.
//
//*****Embellished Objects
//
// Objects can be over- and/or under-embellished in several ways, and text strings, 
// in super- or sub-script size can appear over and/or under the embellished object.
// 
// Over embellishment:
//  0) No over embellishment;
//  1) Over lined;
//  2) Over tilded;
//  3) Over vectored;
//  4) Over caretted; 
//  5) Over right harpooned
//  6) Over curly braced;
//  7) Over acute accent;
//  8) Over grave accent;
//  9) Over small circle;
// 10) Over single dot;
// 11) Over double dot;
// 12) Square/Rounded corner box around the object. Not sure why this is here.
//
// Under embellishment:
//  0) No under embellishment
//  1) Under lined              based on y = 0;
//  2) Under lined              based on the drop below of the object;
//  3) Under tilded             based on y = 0;
//  4) Under tilded             based on the drop below of the object;  
//  5) Under vectored           based on y = 0;
//  6) Under vectored           based on the drop below of the object;
//  7) Under left harpooned     based on y = 0;  
//  8) Under left harpooned     based on the drop below of the object;
//  9) Under curly braced       based on the drop below of the object; 
// 10) Under cedilla            based on y = 0;
// 11) Square/Rounded corner box around the object;
//
// Over embellishment is done before under embellishment.
//
// Since both over- and under-embellishment can be with a box and a final box can be added, strictly a 
// triple boxed object is available, but why would you want more than one box?
//
// You can also have centred under- and over- text strings that go under or over 
// the embellishment(s), if there is one.
//
// By default, many embellishments will be stretched horizontally to cover the whole width of the object
// and all embellishments will be placed in a (hopefully) sensible default position. You can use 
// #local embellish_adjust = array[5][4]{{add_scale_x, add_scale_y , shift_x, shift_y}, // Over  text
//                                       {add_dist_x , add_scale_y , shift_x, shift_y}, // Over  embellishment
//                                       {add_dist_x , add_scale_y , shift_x, shift_y}, // Under embellishment
//                                       {add_scale_x, add_scale_y , shift_x, shift_y}, // Under text
//                                       {add_to_gap , add_to-thick, out_rad, inn_rad}} // Outer box. 
//
// Start off with #local embellish_adjust = array[5][4]{{0,0,0,0},{0,0,0,0},{0,0,0,0},{0,0,0,0},{0,0,0,0}};
// and change the numbers if you don't like what you are getting.
//
// If you are using boxes as over and/or under embellishments, the meaining of embellish_adjust is as for the 
// outer box
//
// The contents of embellish_adjust can be initially left at all zeros. If adjustment is required, 
// they are used as follows:
//
// add_dist_x   add or subtract a distance to the x-width of the embellishment. This dictates a scale factor. 
// add_scale_x  add or subtract an amount to the scale factor in the x-direction. Used for the over and under text.
//              There is a default 0.6 scale factor for these so 0.4 returns to full size.
// add_scale_y  add or subtract an amount to the scale factor in the y-direction. Thus 1 doubles the size 
//              and -0.4 results in a 0.6 scale factor.
// shift_x      add or subtract a shift in the x direction. shift_x = add_dist_x/2 will keep a scaled 
//              embellishment centered over the object.
// shift_y      move the embellishment up or down.
//
// Over and under text are scaled by 0.6 then multiplied by (1 + add_scale_x) or (1 + add_scale_y), so add_scale_x = 0.67 restores them to full size.
//
// Over and under embellishments may be scaled across the whole width of the main object. This apparent width can be changed with add_dist_x.
// The default y scale for the embellishment is 1, which is added to by add_scale_y 
// Once the embellishment has been lengthened/shortened, it can be shifted. 
//
// When the embellishment is a box, the meanings are as for the outer box. Default gap is 0.3, Default thick is 0.3. These can't be reduced 
// below 0.1 however negative add_to_gap and add_to_thick are. 
//
// When an over or under embellishment is a box or for the outer box, if any, the meaning of the entries is as follows:  
//
// add_to_gap   add to the default gap (which is 0.3). -ve values reduce the gap which can't be reduced below 0.1.
// add_to_thick add to the default thickness (which is 0.3). -ve values reduce the thick which can't be reduced below 0.1.
// out_rad      radii are 0 by default. This adds to the outer radius.
// inn_rad      if out_rad > b_thick, inn_rad should be out_rad - b_thick to have the same centre
//
// Over embellishing an i or a j conventionally removes the dot. The unit vectors are available as #|1 and #|2, 
// in math mode but if you want other over-embellishments, the no-dot characters are available as CL_rlp_imath and 
// CL_rlp_jmath and you will have to pass them in as an object. 
//
// TEST CALLING SEQUENCE
/*
CL_rlp_make_text_string_set(1)  
#declare object_to_embellish = 
#declare object_dimensions   = CL_dimensions_out; 
#declare embellished_object  = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                 ,object_dimensions,CL_dimensions_out)} 
object{embellished_object translate <-CL_dimensions_out[0]/2,0,0> pigment{rgb 1} finish{ambient 0 specular 1}}      
*/  
// Decide whether we are using an object or a string
#if(strlen(char_string) = 0)
  #local main_obj  = char_obj;
  #local main_dims = dimensions_in; 
#else
  #local main_dims = array[4];
  #local main_obj  = object{CL_rlp_make_text_string(char_string,default_space,letter_adjust_main,
                                                     z1,z2,d_rad,offs,cham,font_type,main_dims)}  
  #declare global_obj = main_obj;
#end  
//
#local main_width  = main_dims[0];
#local main_height = main_dims[1];
#local main_supers = main_dims[2];
#local main_drop   = main_dims[3];   
//
// A box round the main object
#local dimensions_out = main_dims;
#if(CL_debug_lines = 1)
  #local main_obj    = union{
                         object{main_obj}                    
                         cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
                         cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                         cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
                         cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                            }     
#end
// Debugging output, if turned on.
#if(CL_debug_lines = 1)
  #warning concat("CL_rlp_make_embellish main_width    is:",str(main_width ,8,3),"\n")
  #warning concat("CL_rlp_make_embellish main_height   is:",str(main_height,8,3),"\n")
  #warning concat("CL_rlp_make_embellish main_supers   is:",str(main_supers,8,3),"\n")
  #warning concat("CL_rlp_make_embellish main_drop     is:",str(main_drop  ,8,3),"\n")
#end
//****************************************************************************************************************************     
// Over embellishment
//****************************************************************************************************************************
#local over_embellish_dims = main_dims;
#local letter_dimensions   = array[4];
#local over_add_dist_x     = embellish_adjust[1][0];
#local over_scale_y        = embellish_adjust[1][1];
#local over_shift_x        = embellish_adjust[1][2];
#local over_shift_y        = embellish_adjust[1][3];
//
//  0) No embellishment;
//  1) Over lined;
//  2) Over tilded;
//  3) Over vectored;
//  4) Over caretted; 
//  5) Over right harpooned
//  6) Over curly braced;
//  7) Over acute accent;
//  8) Over grave accent;
//  9) Over small circle;
// 10) Over single dot;
// 11) Over double dot;
// 12) Square/Rounded corner box around the object;
//
#switch(over_embellish_type)
  #case(0)  
// No embellishment 
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is void (0):",str(over_embellish_type,8,0),"\n")
    #end
// Do nothing. The embellished dimensions are the same as the main object dimensions.
    #local over_embellish_obj     = main_obj;  
  #break
  #case(1)
// Overlined based on the height of the object;     
    #warning concat("CL_rlp_make_embellish. Embellish type is overlined (1):",str(over_embellish_type,8,0),"\n")
    #local over_embellish_obj     = union{
                                      object{CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,main_width+over_add_dist_x,
                                                                 letter_dimensions)
                                                                 scale <1,1+over_scale_y,1>   // Standard character is +-0.08
                                                                 translate <over_shift_x,main_height+0.1+0.08*(1+over_scale_y)+over_shift_y,0>}
                                      object{main_obj}
                                         }
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+0.16*(1+over_scale_y)+over_shift_y);                               
  #break
  #case(2)
//  Over tilded based on the height of the object;   
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is over tilded (2):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)} // Object goes from 0.67 to 1.03
    #local over_embellish_obj     = union{
                                      object{embellishment 
                                             translate <0,-0.67,0> scale <(main_width+over_add_dist_x)/letter_dimensions[0],1+over_scale_y,1>
                                             translate <over_shift_x,main_height+0.1+over_shift_y,0>}
                                      object{main_obj}
                                         }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+0.36*(1+over_scale_y)+over_shift_y);  
  #break
  #case(3)
//  Over vectored based on the height of the object;    
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is vector (3):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_rightarrow(z1,z2,d_rad,offs,cham,main_width+over_add_dist_x,letter_dimensions)} // Object goes from 0.67 to 1.03
    #local over_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+over_scale_y,1>
                                             translate <over_shift_x,main_height+0.1+0.4*(1+over_scale_y)+over_shift_y,0>}
                                      object{main_obj}
                                         }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+0.8*(1+over_scale_y)+over_shift_y);  
  #break
  #case(4)
//  Over caretted based on the height of the object;  
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is caret (4):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_caret(z1,z2,d_rad,offs,cham,letter_dimensions) translate <0,0,0>} // Object is 1.4 to 2.0
    #local over_embellish_obj     = union{
                                      object{embellishment 
                                             translate <0,-1.4,0>
                                             scale <(main_width+over_add_dist_x)/letter_dimensions[0],1+over_scale_y,1>
                                             translate <over_shift_x,main_height+0.1+over_shift_y,0>}
                                      object{main_obj}
                                         }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+0.6*(1+over_scale_y)+over_shift_y);  
  #break
  #case(5)
//  Over right harpooned based on the height of the object;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is right harpoon (5):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,main_width+over_add_dist_x,letter_dimensions)} 
// Object goes from -0.05 to 0.35
    #local over_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+over_scale_y,1>
                                             translate <over_shift_x,main_height+0.1+0.05*(1+over_scale_y)+over_shift_y,0>}
                                      object{main_obj}
                                         }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+0.4*(1+over_scale_y)+over_shift_y);    
  #break
  #case(6)
//  Over curly braced based on the height of the object;
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is over curly brace (6):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_math_curly_left_bracket(z1,z2,d_rad,offs,cham,main_width+over_add_dist_x,letter_dimensions)} 
// Object has variable dimensions
    #local over_embellish_obj     = union{
                                      object{embellishment 
                                             translate <-letter_dimensions[0],letter_dimensions[3],0> 
                                             scale <0.5,1,1>
                                             rotate <0,0,-90>
                                             scale <1,1+over_scale_y,1>
                                             translate <over_shift_x,main_height+0.1+over_shift_y,0>}
                                      object{main_obj}
                                         }        
    #local over_embellish_dims[1] = max(main_height,main_height+0.1+(letter_dimensions[0]/2)*(1+over_scale_y)+over_shift_y);    
  #break
  #case(7)
//  Over acute accent based on the height of the object;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is acute accent (7):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_accent_part(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #local over_embellish_obj = union{
                                object{embellishment 
                                       rotate <0,0,-60>
                                       scale  <1,1+over_scale_y,1>
                                       translate <main_width/2+over_shift_x-0.1,main_height+0.1+over_shift_y,0>}
                                object{main_obj}
                                     }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.45*(1+over_scale_y)+0.1+over_shift_y);          
  #break
  #case(8)
//  Over grave accent based on the height of the object;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is grave accent (8):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_accent_part(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #local over_embellish_obj = union{
                                object{embellishment 
                                       rotate <0,0,60>
                                       scale  <1,1+over_scale_y,1>
                                       translate <main_width/2+over_shift_x+0.1,main_height+0.1+over_shift_y,0>}
                                object{main_obj}
                                     }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.45*(1+over_scale_y)+0.1+over_shift_y);       
  #break
  #case(9)
//  Over small circle based on the height of the object;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is over small circle (9):",str(over_embellish_type,8,0),"\n")
    #end 
    #local embellishment = object{CL_rlp_degrees(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #local over_embellish_obj = union{
                                object{embellishment 
                                       translate <-0.25,-1.5,0>
                                       scale     <1,1+over_scale_y,1>
                                       translate <main_width/2+over_shift_x,main_height+0.1+over_shift_y,0>}
                                object{main_obj}
                                     }    
    #local over_embellish_dims[1] = max(main_height,main_height+0.5*(1+over_scale_y)+0.1+over_shift_y);    
  #break
  #case(10)
//  Over single dot based on the height of the object;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is single dot (10):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #local over_embellish_obj = union{
                                object{embellishment 
                                       scale     <1,1+over_scale_y,1>
                                       translate <(main_width-letter_dimensions[0])/2+0.1+over_shift_x,main_height+0.1+over_shift_y,0>}
                                object{main_obj}
                                     }    
    #local over_embellish_dims[1] = max(main_height,main_height+letter_dimensions[1]*(1+over_scale_y)+0.1+over_shift_y);  
  #break
  #case(11)
// Over double dot based on the height of the object;
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Over embellish type is double dot (11):",str(over_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_full_stop(z1,z2,d_rad,offs,cham,letter_dimensions)}
    #local over_embellish_obj = union{
                                  object{embellishment translate <(main_width-letter_dimensions[0])/2-0.25+over_shift_x,main_height+0.1+over_shift_y,0>}
                                  object{embellishment translate <(main_width-letter_dimensions[0])/2+0.45+over_shift_x,main_height+0.1+over_shift_y,0>}
                                  object{main_obj}
                                }    
    #local over_embellish_dims[1] = max(main_height,main_height+letter_dimensions[1]*(1+over_scale_y)+0.1+over_shift_y);   
  #break
  #case(12)
// Rounded corner box around the object.
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Embellish type is rounded corner box (12):",str(over_embellish_type,8,0),"\n")
    #end  
//
    #local add_to_gap         = embellish_adjust[1][0];
    #local add_to_thick       = embellish_adjust[1][1];
    #local out_rad            = max(0,embellish_adjust[1][2]);
    #local inn_rad            = max(0,embellish_adjust[1][3]);
    #local b_gap              = 0.3 + max(-0.2,add_to_gap);
    #local b_thick            = 0.3 + max(-0.2,add_to_thick);
    #local x_width            = main_width+2*(b_gap+b_thick);
    #local y_height           = (main_height+main_drop)+2*(b_gap+b_thick);
    #local box_dimensions     = array[5]{x_width,y_height,b_thick,out_rad,inn_rad};  
//    
    #local embellishment      = object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)}
    #local over_embellish_obj = union{
                                  object{embellishment translate <0,-(main_drop+b_gap+b_thick),0>}
                                  object{main_obj translate <b_thick+b_gap,0,0>}
                                     }
    #local over_embellish_dims[0] = main_width  + 2*(b_gap + b_thick);    
    #local over_embellish_dims[1] = main_height + b_gap + b_thick;  
    #local over_embellish_dims[2] = main_height + b_gap + b_thick;  
    #local over_embellish_dims[3] = main_drop   + b_gap + b_thick;      
  #break
// add any higher case numbers here, as they are programmed
  #else
// Over-embellish type not recognised  
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Embellish type with this number is not dealt with:",str(over_embellish_type,8,0),"\n")
    #end
// Do nothing. The embellished dimensions are the same as the main object dimensions.
    #local over_embellish_obj  = main_obj;  
    #local over_embellish_dims = main_dims;
#end 
//
#local over_width  = over_embellish_dims[0];
#local over_height = over_embellish_dims[1];
#local over_super  = over_embellish_dims[2];
#local over_drop   = over_embellish_dims[3];   
// A box round the over embellished object
#local dimensions_out = over_embellish_dims;
#if(CL_debug_lines = 1)
  #local over_embellish_obj = union{
                                object{over_embellish_obj}                    
                                cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
                                cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
                                cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                   }
#end
//***************************************************************************************************************************************
// Under embellishment   
//***************************************************************************************************************************************
// 
//  1) Under lined              based on y = 0;
//  2) Under lined              based on the drop below of the object;
//  3) Under tilded             based on y = 0;
//  4) Under tilded             based on the drop below of the object;  
//  5) Under vectored           based on y = 0;
//  6) Under vectored           based on the drop below of the object;
//  7) Under left harpooned     based on y = 0;  
//  8) Under left harpooned     based on the drop below of the object;
//  9) Under curly braced       based on the drop below of the object; 
// 10) Under cedilla            based on y = 0;
// 11) Square/Rounded corner box around the object;
//
#local under_embellish_dims = over_embellish_dims;
#local under_add_dist_x     = embellish_adjust[2][0];
#local under_scale_y        = embellish_adjust[2][1];
#local under_shift_x        = embellish_adjust[2][2];
#local under_shift_y        = embellish_adjust[2][3];
#switch(under_embellish_type)
  #case(0)  
// No embellishment
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is none (0):",str(under_embellish_type,8,0),"\n")
    #end
// Do nothing. The embellished dimensions are the same as the main object dimensions.
    #local under_embellish_obj     = over_embellish_obj;  
  #break
  #case(1)
// Underlined based on y = 0;
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is underlined based on y = 0 (1):",str(under_embellish_type,8,0),"\n") 
    #end
    #local under_embellish_obj = union{
                             object{CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,over_width+under_add_dist_x,letter_dimensions)
                                    scale <1,1+under_scale_y,1> translate <under_shift_x,-0.15-0.08*(1+under_scale_y)+under_shift_y,0>}
                             object{over_embellish_obj}
                                }
    #local under_embellish_dims[3] = max(over_drop,0.15+0.08*(1+under_scale_y)-under_shift_y);
  #break  
  #case(2)
// Underlined based on the drop below of the object; 
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is undelined based on drop below (2):",str(under_embellish_type,8,0),"\n")
    #end
    #local under_embellish_obj = union{
                                   object{CL_rlp_elastic_line(z1,z2,d_rad,offs,cham,over_width+under_add_dist_x,letter_dimensions)
                                          translate <under_shift_x,-over_drop-0.15,0>}
                                   object{over_embellish_obj}
                                      }
    #local under_embellish_dims[3] = over_drop+0.23;                               
  #break
  #case(3)
//  Under tilded based on y = 0;   
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is tilde based on y = 0 (3):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)} 
    #local under_embellish_obj = union{
                             object{embellishment scale <(over_width+under_add_dist_x)/letter_dimensions[0],1,1>
                                                  translate <under_shift_x,-letter_dimensions[1]-0.07,0>}
                             object{over_embellish_obj}
                                }    
    #local under_embellish_dims[3] = max(over_drop,0.4);                               
  #break
  #case(4)
//  Under tilded based on the drop below of the object;   
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is tilde based on drop below (4):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment = object{CL_rlp_mathtilde(z1,z2,d_rad,offs,cham,letter_dimensions)} 
    #local under_embellish_obj = union{
                             object{embellishment scale <(over_width+under_add_dist_x)/letter_dimensions[0],1,1>
                                                  translate <under_shift_x,-over_drop-letter_dimensions[1]-0.07,0>}
                             object{over_embellish_obj}
                                }    
    #local under_embellish_dims[3] = over_drop+0.4;                               
  #break
  #case(5)
//  Under vectored based on y = 0;    
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is vector based on y = 0 (5):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_rightarrow(z1,z2,d_rad,offs,cham,main_width+under_add_dist_x,letter_dimensions)} // Object goes from 0.67 to 1.03
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+under_scale_y,1>
                                             translate <under_shift_x,-0.1-0.4*(1+under_scale_y)+under_shift_y,0>}
                                      object{over_embellish_obj}
                                         }    
    #local under_embellish_dims[3] = max(main_drop,0.1+0.8*(1+under_scale_y)-under_shift_y);  
  #break 
  #case(6)
//  Under vectored based on the drop below;    
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is vector based on drop below (6):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_rightarrow(z1,z2,d_rad,offs,cham,main_width+under_add_dist_x,letter_dimensions)} // Object goes from 0.67 to 1.03
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+under_scale_y,1>
                                             translate <under_shift_x,-main_drop-0.1-0.4*(1+under_scale_y)+under_shift_y,0>}
                                      object{over_embellish_obj}
                                         }    
    #local under_embellish_dims[3] = max(main_drop,main_drop+0.1+0.8*(1+under_scale_y)-under_shift_y);  
  #break
  #case(7)
//  Under right harpoon based on y = 0;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is right harpoon based on y = 0 (7):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,main_width+under_add_dist_x,letter_dimensions)
                                           scale <1,-1,1>} 
// Object goes from -0.05 to 0.35
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+over_scale_y,1>
                                             translate <under_shift_x,-0.1-0.05*(1+over_scale_y)+over_shift_y,0>}
                                      object{over_embellish_obj}
                                         }    
    #local under_embellish_dims[3] = max(main_drop,+0.1+0.4*(1+over_scale_y)-over_shift_y);    
  #break
  #case(8)
//  Under right harpoon based on y = 0;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is right harpoon based on drop below (7):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_elastic_right_harpoon(z1,z2,d_rad,offs,cham,main_width+under_add_dist_x,letter_dimensions)
                                           scale <1,-1,1>} 
// Object goes from -0.05 to 0.35
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+over_scale_y,1>
                                             translate <under_shift_x,-main_drop-0.1-0.05*(1+over_scale_y)+over_shift_y,0>}
                                      object{over_embellish_obj}
                                         }    
    #local under_embellish_dims[3] = max(main_drop,main_drop+0.1+0.4*(1+over_scale_y)-over_shift_y);    
  #break
  #case(9)
// Under curly braced based on the drop below of the object;  
  #if(CL_debug_lines = 1)
    #warning concat("CL_rlp_make_embellish. Under embellish type is under curly brace (8):",str(under_embellish_type,8,0),"\n")
  #end
    #local embellishment           = object{CL_rlp_elastic_math_curly_left_bracket(z1,z2,d_rad,offs,cham,main_width+under_add_dist_x,letter_dimensions)} 
// Object has variable dimensions
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             translate <-letter_dimensions[0],letter_dimensions[3],0> 
                                             scale <0.5,-1,1>
                                             rotate <0,0,90>
                                             scale <1,1+under_scale_y,1>
                                             translate <under_shift_x,-main_drop-0.1+under_shift_y,0>}
                                      object{over_embellish_obj}
                                         }        
    #local under_embellish_dims[3] = max(main_drop,main_drop+0.1+(letter_dimensions[0]/2)*(1+under_scale_y)-under_shift_y);    
  #break
  #case(10)
//  Under cedilla based on y = 0;
    #if(CL_debug_lines =1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is cedilla based on y = 0 (7):",str(under_embellish_type,8,0),"\n")
    #end
    #local embellishment          = object{CL_rlp_cedilla(z1,z2,d_rad,offs,cham,letter_dimensions)} 
// Object goes from 0.0 to -0.5
    #local under_embellish_obj     = union{
                                      object{embellishment 
                                             scale <1,1+under_scale_y,1>
                                             translate <main_width/2,under_shift_y,0>}
                                      object{over_embellish_obj}
                                         }    
    #local under_embellish_dims[3] = max(main_drop,+0.8*(1+over_scale_y)-under_shift_y);    
  #break
  #case(11)
// Rounded corner box around the object.
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type is rounded corner box (11):",str(over_embellish_type,8,0),"\n")
    #end  
//
    #local add_to_gap          = embellish_adjust[2][0];
    #local add_to_thick        = embellish_adjust[2][1];
    #local out_rad             = max(0,embellish_adjust[2][2]);
    #local inn_rad             = max(0,embellish_adjust[2][3]);
    #local b_gap               = 0.3 + max(-0.2,add_to_gap);
    #local b_thick             = 0.3 + max(-0.2,add_to_thick);
    #local x_width             = over_width+2*(b_gap+b_thick);
    #local y_height            = (over_height+over_drop)+2*(b_gap+b_thick);
    #local box_dimensions      = array[5]{x_width,y_height,b_thick,out_rad,inn_rad};  
//    
    #local embellishment       = object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)}
    #local under_embellish_obj = union{
                                  object{embellishment translate <0,-(over_drop+b_gap+b_thick),0>}
                                  object{over_embellish_obj translate <b_thick+b_gap,0,0>}
                                     }
    #local under_embellish_dims[0] = over_width  + 2*(b_gap + b_thick);    
    #local under_embellish_dims[1] = over_height + b_gap + b_thick;  
    #local under_embellish_dims[2] = over_height + b_gap + b_thick;  
    #local under_embellish_dims[3] = over_drop   + b_gap + b_thick;      
  #break
// add any higher case numbers here, as they are programmed
  #else
// Over-embellish type not recognised  
    #if(CL_debug_lines = 1)
      #warning concat("CL_rlp_make_embellish. Under embellish type with this number is not dealt with:",str(over_embellish_type,8,0),"\n")
    #end
// Do nothing. The under embellished object and dimensions are the same as the over embellished object and dimensions.
    #local under_embellish_obj  = over_embellish_obj;  
    #local under_embellish_dims = over_embellish_dims;
#end 
// A box round the under embellished object
#local under_width           = under_embellish_dims[0];
#local under_height          = under_embellish_dims[1];
#local under_super           = under_embellish_dims[2];
#local under_drop            = under_embellish_dims[3];
#if(CL_debug_lines = 1)
  #local dimensions_out      = under_embellish_dims;
  #local under_embellish_obj = union{
                                 object{under_embellish_obj}                    
                                 cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
                                 cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                 cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
                                 cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                    }
#end
//****************************************************************************************************************************
// Over and under text
//****************************************************************************************************************************
// Construct the over text object, if any.
#local over_text_num               = strlen(over_string);  
#local over_text_dims              = array[4];
#if(over_text_num > 0) 
  #local over_text_add_to_scale_x  = embellish_adjust[0][0];
  #local over_text_add_to_scale_y  = embellish_adjust[0][1];
  #local over_text_shift_x         = embellish_adjust[0][2];
  #local over_text_shift_y         = embellish_adjust[0][3];
  #local embellishment             = object{CL_rlp_make_text_string(over_string,default_space,letter_adjust_over,
                                                                   z1,z2,d_rad,offs,cham,font_type,over_text_dims)}           
  #local embellishment_width       = over_text_dims[0]*0.6*(1+over_text_add_to_scale_x);
  #local embellishment_height      = over_text_dims[1]*0.6*(1+over_text_add_to_scale_y);
  #local embellishment_drop        = over_text_dims[3]*0.6*(1+over_text_add_to_scale_y);  
  #if(embellishment_width < under_width)
    #local emb_x_shift             = (under_width-embellishment_width)/2;
    #local obj_x_shift             = 0;
  #else                             
    #local emb_x_shift             = 0;
    #local obj_x_shift             = (embellishment_width-under_width)/2;
  #end
  #local over_text_width           = max(embellishment_width,under_width);   
  #local over_text_height          = under_height+0.3+embellishment_drop+embellishment_height+over_text_shift_y;
  #local over_text_super           = under_height+0.3+embellishment_drop+embellishment_height+over_text_shift_y; 
  #local over_text_drop            = under_drop;
  #local over_text_embellish_obj   = union{
                                       object{embellishment scale     <0.6*(1+over_text_add_to_scale_x),0.6*(1+over_text_add_to_scale_y),1> 
                                                            translate <emb_x_shift+over_text_shift_x,under_height+0.3+embellishment_drop+over_text_shift_y,0>}
                                       object{under_embellish_obj translate <obj_x_shift,0,0> }
                                          }
// A debugging box round the under embellished object
  #local dimensions_out = array[4]{over_text_width,over_text_height,over_text_super,over_text_drop};
  #if(CL_debug_lines = 1)
    #local over_text_embellish_obj = union{
                                       object{over_text_embellish_obj}                    
                                       cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
                                       cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                       cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
                                       cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                          }
  #end
  #local over_text_embellish_dims  = dimensions_out;
#else
  #local over_text_embellish_obj   = under_embellish_obj;
  #local over_text_embellish_dims  = under_embellish_dims; 
#end

// Construct the under text object, if any.
#local under_text_num              = strlen(under_string);  
#local under_text_dims             = array[4];
#if(over_text_num > 0) 
  #local under_text_add_to_scale_x = embellish_adjust[3][0];
  #local under_text_add_to_scale_y = embellish_adjust[3][1];
  #local under_text_shift_x        = embellish_adjust[3][2];
  #local under_text_shift_y        = embellish_adjust[3][3];
  #local embellishment             = object{CL_rlp_make_text_string(under_string,default_space,letter_adjust_over,
                                                                   z1,z2,d_rad,offs,cham,font_type,under_text_dims)}           
  #local embellishment_width       = under_text_dims[0]*0.6*(1+under_text_add_to_scale_x);
  #local embellishment_height      = under_text_dims[1]*0.6*(1+under_text_add_to_scale_y);
  #local embellishment_drop        = under_text_dims[3]*0.6*(1+under_text_add_to_scale_y);  
  #if(embellishment_width < under_width)
    #local emb_x_shift             = (over_text_width-embellishment_width)/2;
    #local obj_x_shift             = 0;
  #else                             
    #local emb_x_shift             = 0;
    #local obj_x_shift             = (embellishment_width-over_text_width)/2;
  #end
  #local under_text_width          = max(embellishment_width,over_text_width);   
  #local under_text_height         = over_text_height;
  #local under_text_super          = over_text_height; 
  #local under_text_drop           = over_text_drop+0.3+embellishment_height+embellishment_drop-under_text_shift_y;
  #local under_text_embellish_obj  = union{
                                       object{embellishment scale     <0.6*(1+under_text_add_to_scale_x),0.6*(1+under_text_add_to_scale_y),1> 
                                                            translate <emb_x_shift+under_text_shift_x,-(over_text_drop+0.3+embellishment_height)+under_text_shift_y,0>}
                                       object{over_text_embellish_obj translate <obj_x_shift,0,0> }
                                          }
// A debugging box round the under embellished object
  #local dimensions_out = array[4]{under_text_width,under_text_height,under_text_super,under_text_drop};
  #if(CL_debug_lines = 1)
    #local under_text_embellish_obj = union{
                                        object{under_text_embellish_obj}                    
                                        cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
                                        cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                        cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
                                        cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
                                           }
  #end
  #local under_text_embellish_dims  = dimensions_out;
#else
  #local under_text_embellish_obj   = over_text_embellish_obj;
  #local under_text_embellish_dims  = over_text_embellish_dims; 
#end


#local text_embellish_dims = under_text_embellish_dims; 
// 
#local text_width          = text_embellish_dims[0];
#local text_height         = text_embellish_dims[1];
#local text_super          = text_embellish_dims[2];
#local text_drop           = text_embellish_dims[3];   
//
#local text_embellish_obj  = under_text_embellish_obj;
//****************************************************************************************************************************
// Final outer box, if any
//****************************************************************************************************************************
#if(CL_debug_lines = 1)
 #warning concat("CL_rlp_make_embellish. Outer rounded corner box type is:",str(outer_box,8,0),"\n")
#end  
//
#if(outer_box = 1)
  #local add_to_gap        = embellish_adjust[4][0];
  #local add_to_thick      = embellish_adjust[4][1];
  #local out_rad           = max(0,embellish_adjust[4][2]);
  #local inn_rad           = max(0,embellish_adjust[4][3]);
  #local b_gap             = 0.3 + max(-0.2,add_to_gap);
  #local b_thick           = 0.3 + max(-0.2,add_to_thick);
  #local x_width           = text_width+2*(b_gap+b_thick);
  #local y_height          = (text_height+text_drop)+2*(b_gap+b_thick);
  #local box_dimensions    = array[5]{x_width,y_height,b_thick,out_rad,inn_rad};  
//    
  #local embellishment     = object{CL_rlp_hollow_rounded_box(z1,z2,d_rad,offs,cham,box_dimensions,letter_dimensions)}
  #local embellish_obj     = union{
                                 object{embellishment translate <0,-(text_drop+b_gap+b_thick),0>}
                                 object{text_embellish_obj translate <b_thick+b_gap,0,0>}
                                    }
  #local embellish_dims    = array[4];
  #local embellish_dims[0] = text_width  + 2*(b_gap + b_thick);    
  #local embellish_dims[1] = text_height + b_gap + b_thick;  
  #local embellish_dims[2] = text_height + b_gap + b_thick;  
  #local embellish_dims[3] = text_drop   + b_gap + b_thick;      
#else
  #local embellish_dims    = text_embellish_dims;   
  #local embellish_obj     = text_embellish_obj;    
#end
//****************************************************************************************************************************
// Create the final object
//****************************************************************************************************************************
#if(CL_debug_lines = 1)
  union{
    object{embellish_obj} 
// Debug boundary lines 
// Line for y = 0
    cylinder{<0.002,0,0> <embellish_dims[0],0,0> 0.02 pigment{Green}}
// A box round the final embellished object
    #local dimensions_out = embellish_dims;
    cylinder{< 0.002            ,-dimensions_out[3],0> < 0.002            , dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< dimensions_out[0],-dimensions_out[3],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
    cylinder{< 0.000            ,-dimensions_out[3],0> < dimensions_out[0],-dimensions_out[3],0> 0.02 pigment{Red}}
    cylinder{< 0.000            , dimensions_out[1],0> < dimensions_out[0], dimensions_out[1],0> 0.02 pigment{Red}}
       }
#else
  #local dimensions_out = embellish_dims;
  object{embellish_obj} 
#end    
//                      
#end       
//******************************************************************************************************************************************************************
